@@ -47,6 +47,18 @@ abstract class EntityBase implements EntityInterface {
    */
   protected $typedData;
 
+  /**
+   * The original unchanged entity.
+   *
+   * This property will be set and used during the saving process.
+   *
+   * This is named originalEntity to not clash with the deprecated magic
+   * property "original".
+   *
+   * @var static|null
+   */
+  protected ?EntityInterface $originalEntity = NULL;
+
   /**
    * Constructs an Entity object.
    *
@@ -68,6 +80,7 @@ abstract class EntityBase implements EntityInterface {
    * Gets the entity type manager.
    *
    * @return \Drupal\Core\Entity\EntityTypeManagerInterface
+   *   The entity type manager.
    */
   protected function entityTypeManager() {
     return \Drupal::entityTypeManager();
@@ -77,6 +90,7 @@ abstract class EntityBase implements EntityInterface {
    * Gets the entity type bundle info service.
    *
    * @return \Drupal\Core\Entity\EntityTypeBundleInfoInterface
+   *   The entity type bundle info service.
    */
   protected function entityTypeBundleInfo() {
     return \Drupal::service('entity_type.bundle.info');
@@ -86,6 +100,7 @@ abstract class EntityBase implements EntityInterface {
    * Gets the language manager.
    *
    * @return \Drupal\Core\Language\LanguageManagerInterface
+   *   The language manager service.
    */
   protected function languageManager() {
     return \Drupal::languageManager();
@@ -95,6 +110,7 @@ abstract class EntityBase implements EntityInterface {
    * Gets the UUID generator.
    *
    * @return \Drupal\Component\Uuid\UuidInterface
+   *   The UUID service.
    */
   protected function uuidGenerator() {
     return \Drupal::service('uuid');
@@ -104,14 +120,14 @@ abstract class EntityBase implements EntityInterface {
    * {@inheritdoc}
    */
   public function id() {
-    return isset($this->id) ? $this->id : NULL;
+    return $this->id ?? NULL;
   }
 
   /**
    * {@inheritdoc}
    */
   public function uuid() {
-    return isset($this->uuid) ? $this->uuid : NULL;
+    return $this->uuid ?? NULL;
   }
 
   /**
@@ -156,7 +172,7 @@ abstract class EntityBase implements EntityInterface {
   /**
    * {@inheritdoc}
    */
-  public function toUrl($rel = 'canonical', array $options = []) {
+  public function toUrl($rel = NULL, array $options = []) {
     if ($this->id() === NULL) {
       throw new EntityMalformedException(sprintf('The "%s" entity cannot have a URI as it does not have an ID', $this->getEntityTypeId()));
     }
@@ -170,6 +186,21 @@ abstract class EntityBase implements EntityInterface {
       $rel = 'canonical';
     }
 
+    $exception_message = "No link template '$rel' found for the '{$this->getEntityTypeId()}' entity type";
+    // Use the canonical link template by default, or edit-form if there is not
+    // a canonical one.
+    if ($rel === NULL) {
+      if (isset($link_templates['canonical'])) {
+        $rel = 'canonical';
+      }
+      elseif (isset($link_templates['edit-form'])) {
+        $rel = 'edit-form';
+      }
+      else {
+        $exception_message = "Cannot generate default URL because no link template 'canonical' or 'edit-form' was found for the '{$this->getEntityTypeId()}' entity type";
+      }
+    }
+
     if (isset($link_templates[$rel])) {
       $route_parameters = $this->urlRouteParameters($rel);
       $route_name = "entity.{$this->entityTypeId}." . str_replace(['-', 'drupal:'], ['_', ''], $rel);
@@ -193,7 +224,7 @@ abstract class EntityBase implements EntityInterface {
         $uri = call_user_func($uri_callback, $this);
       }
       else {
-        throw new UndefinedLinkTemplateException("No link template '$rel' found for the '{$this->getEntityTypeId()}' entity type");
+        throw new UndefinedLinkTemplateException($exception_message);
       }
     }
 
@@ -271,7 +302,7 @@ abstract class EntityBase implements EntityInterface {
       $parameter_name = $this->getEntityType()->getBundleEntityType() ?: $this->getEntityType()->getKey('bundle');
       $uri_route_parameters[$parameter_name] = $this->bundle();
     }
-    if ($this instanceof RevisionableInterface && strpos($rel, 'revision') === 0) {
+    if ($this instanceof RevisionableInterface && str_starts_with($rel, 'revision')) {
       $uri_route_parameters[$this->getEntityTypeId() . '_revision'] = $this->getRevisionId();
     }
 
@@ -290,10 +321,10 @@ abstract class EntityBase implements EntityInterface {
       try {
         $this->toUrl($link_relation_type)->toString(TRUE)->getGeneratedUrl();
       }
-      catch (RouteNotFoundException $e) {
+      catch (RouteNotFoundException) {
         return FALSE;
       }
-      catch (MissingMandatoryParametersException $e) {
+      catch (MissingMandatoryParametersException) {
         return FALSE;
       }
       return TRUE;
@@ -303,7 +334,7 @@ abstract class EntityBase implements EntityInterface {
   /**
    * {@inheritdoc}
    */
-  public function access($operation, AccountInterface $account = NULL, $return_as_object = FALSE) {
+  public function access($operation, ?AccountInterface $account = NULL, $return_as_object = FALSE) {
     if ($operation == 'create') {
       return $this->entityTypeManager()
         ->getAccessControlHandler($this->entityTypeId)
@@ -362,6 +393,12 @@ abstract class EntityBase implements EntityInterface {
     if ($entity_type->hasKey('uuid')) {
       $duplicate->{$entity_type->getKey('uuid')} = $this->uuidGenerator()->generate();
     }
+
+    // Modules might need to add or change the data initially held by the new
+    // entity object, for instance to fill-in default values.
+    \Drupal::moduleHandler()->invokeAll($this->getEntityTypeId() . '_duplicate', [$duplicate, $this]);
+    \Drupal::moduleHandler()->invokeAll('entity_duplicate', [$duplicate, $this]);
+
     return $duplicate;
   }
 
@@ -380,7 +417,7 @@ abstract class EntityBase implements EntityInterface {
     if ($this->getEntityType()->getBundleOf()) {
       // Throw an exception if the bundle ID is longer than 32 characters.
       if (mb_strlen($this->id()) > EntityTypeInterface::BUNDLE_MAX_LENGTH) {
-        throw new ConfigEntityIdLengthException("Attempt to create a bundle with an ID longer than " . EntityTypeInterface::BUNDLE_MAX_LENGTH . " characters: $this->id().");
+        throw new ConfigEntityIdLengthException("Attempt to create a bundle with an ID longer than " . EntityTypeInterface::BUNDLE_MAX_LENGTH . " characters: " . $this->id() . ".");
       }
     }
   }
@@ -446,7 +483,10 @@ abstract class EntityBase implements EntityInterface {
   protected function getListCacheTagsToInvalidate() {
     $tags = $this->getEntityType()->getListCacheTags();
     if ($this->getEntityType()->hasKey('bundle')) {
-      $tags[] = $this->getEntityTypeId() . '_list:' . $this->bundle();
+      $tags = Cache::mergeTags(
+        $tags,
+        $this->getEntityType()->getBundleListCacheTags($this->bundle())
+      );
     }
     return $tags;
   }
@@ -491,7 +531,7 @@ abstract class EntityBase implements EntityInterface {
   /**
    * {@inheritdoc}
    */
-  public static function loadMultiple(array $ids = NULL) {
+  public static function loadMultiple(?array $ids = NULL) {
     $entity_type_repository = \Drupal::service('entity_type.repository');
     $entity_type_manager = \Drupal::entityTypeManager();
     $storage = $entity_type_manager->getStorage($entity_type_repository->getEntityTypeFromClass(static::class));
@@ -587,16 +627,42 @@ abstract class EntityBase implements EntityInterface {
    */
   public function getTypedData() {
     if (!isset($this->typedData)) {
-      $class = \Drupal::typedDataManager()->getDefinition('entity')['class'];
+      $class = $this->getTypedDataClass();
       $this->typedData = $class::createFromEntity($this);
     }
     return $this->typedData;
   }
 
+  /**
+   * Returns the typed data class name for this entity.
+   *
+   * @return string
+   *   The string representing the typed data class name.
+   *
+   * @see \Drupal\Core\Entity\Plugin\DataType\EntityAdapter
+   */
+  private function getTypedDataClass(): string {
+    $typed_data_manager = \Drupal::typedDataManager();
+
+    // Check more specific data types that could apply to this entity.
+    $candidate_data_types = [
+      "entity:{$this->getEntityTypeId()}:{$this->bundle()}",
+      "entity:{$this->getEntityTypeId()}",
+    ];
+    foreach ($candidate_data_types as $candidate_data_type) {
+      if ($typed_data_manager->hasDefinition($candidate_data_type)) {
+        return $typed_data_manager->getDefinition($candidate_data_type)['class'];
+      }
+    }
+
+    // Fall back to the generic entity definition.
+    return $typed_data_manager->getDefinition('entity')['class'];
+  }
+
   /**
    * {@inheritdoc}
    */
-  public function __sleep() {
+  public function __sleep(): array {
     $this->typedData = NULL;
     return $this->traitSleep();
   }
@@ -624,4 +690,65 @@ abstract class EntityBase implements EntityInterface {
     return $this->uuid();
   }
 
+  /**
+   * {@inheritdoc}
+   */
+  public function getOriginal(): ?static {
+    return $this->originalEntity;
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  public function setOriginal(?EntityInterface $original): static {
+    $this->originalEntity = $original;
+    return $this;
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  public function __get($name) {
+    if ($name == 'original') {
+      @trigger_error("Getting the original property is deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Use \Drupal\Core\Entity\EntityInterface::getOriginal() instead. See https://www.drupal.org/node/3295826", E_USER_DEPRECATED);
+      return $this->getOriginal();
+    }
+    return $this->$name ?? NULL;
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  public function __set($name, $value) {
+    if ($name == 'original') {
+      @trigger_error("Setting the original property is deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Use \Drupal\Core\Entity\EntityInterface::setOriginal() instead. See https://www.drupal.org/node/3295826", E_USER_DEPRECATED);
+      $this->setOriginal($value);
+      return;
+    }
+    $this->$name = $value;
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  public function __isset($name) {
+    if ($name == 'original') {
+      @trigger_error("Checking for the original property is deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Use \Drupal\Core\Entity\EntityInterface::getOriginal() instead. See https://www.drupal.org/node/3295826", E_USER_DEPRECATED);
+      return $this->getOriginal();
+    }
+    return isset($this->$name);
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  public function __unset($name) {
+    if ($name == 'original') {
+      @trigger_error("Unsetting the original property is deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Use \Drupal\Core\Entity\EntityInterface::setOriginal() instead. See https://www.drupal.org/node/3295826", E_USER_DEPRECATED);
+      $this->setOriginal(NULL);
+      return;
+    }
+    unset($this->$name);
+  }
+
 }
