@@ -2,21 +2,31 @@
 
 namespace Drupal\Core\File\MimeType;
 
+use Drupal\Core\DependencyInjection\DeprecatedServicePropertyTrait;
 use Drupal\Core\Extension\ModuleHandlerInterface;
+use Drupal\Core\File\Event\MimeTypeMapLoadedEvent;
+use Drupal\Core\File\FileSystemInterface;
 use Symfony\Component\Mime\MimeTypeGuesserInterface;
 
 /**
  * Makes possible to guess the MIME type of a file using its extension.
  */
 class ExtensionMimeTypeGuesser implements MimeTypeGuesserInterface {
+  use DeprecatedServicePropertyTrait;
 
   /**
    * Default MIME extension mapping.
    *
    * @var array
    *   Array of mimetypes correlated to the extensions that relate to them.
+   *
+   * @deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Pass a
+   *   MimeTypeMapInterface $map to the constructor instead.
+   *
+   * @see https://www.drupal.org/node/3494040
    */
   protected $defaultMapping = [
+    // cspell:disable
     'mimetypes' => [
       0 => 'application/andrew-inset',
       1 => 'application/atom',
@@ -152,6 +162,8 @@ class ExtensionMimeTypeGuesser implements MimeTypeGuesserInterface {
       129 => 'application/x-iphone',
       130 => 'application/x-iso9660-image',
       131 => 'application/x-java-jnlp-file',
+      // Per RFC 9239, text/javascript is preferred over application/javascript.
+      // @see https://www.rfc-editor.org/rfc/rfc9239
       132 => 'text/javascript',
       133 => 'application/x-jmol',
       134 => 'application/x-kchart',
@@ -867,62 +879,93 @@ class ExtensionMimeTypeGuesser implements MimeTypeGuesserInterface {
       'json' => 361,
       'avif' => 362,
     ],
+    // cspell:enable
   ];
 
   /**
    * The MIME types mapping array after going through the module handler.
    *
    * @var array
+   *
+   * @deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Pass a
+   *   MimeTypeMapInterface $map to the constructor instead.
+   *
+   * @see https://www.drupal.org/node/3494040
    */
   protected $mapping;
 
   /**
-   * The module handler.
+   * Deprecated service properties.
    *
-   * @var \Drupal\Core\Extension\ModuleHandlerInterface
+   * @var string[]
+   *
+   * @see https://www.drupal.org/node/3494040
    */
-  protected $moduleHandler;
+  protected $deprecatedProperties = [
+    'moduleHandler' => 'module_handler',
+  ];
+
+  /**
+   * The MIME type map.
+   */
+  protected MimeTypeMapInterface $map;
+
+  /**
+   * The file system.
+   */
+  protected FileSystemInterface $fileSystem;
 
   /**
    * Constructs a new ExtensionMimeTypeGuesser.
    *
-   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
-   *   The module handler.
+   * @param \Drupal\Core\Extension\ModuleHandlerInterface|\Drupal\Core\File\MimeType\MimeTypeMapInterface $map
+   *   The MIME type map.
+   * @param \Drupal\Core\File\FileSystemInterface|null $fileSystem
+   *   The file system.
    */
-  public function __construct(ModuleHandlerInterface $module_handler) {
-    $this->moduleHandler = $module_handler;
+  public function __construct(
+    MimeTypeMapInterface|ModuleHandlerInterface $map,
+    ?FileSystemInterface $fileSystem = NULL,
+  ) {
+    if ($map instanceof ModuleHandlerInterface) {
+      @trigger_error(
+        'Calling ' . __METHOD__ . '() with the $map argument as an instance of \Drupal\Core\Extension\ModuleHandlerInterface is deprecated in drupal:11.2.0 and an instance of \Drupal\Core\File\MimeType\MimeTypeMapInterface is required in drupal:12.0.0. See https://www.drupal.org/node/3494040',
+        E_USER_DEPRECATED
+      );
+      $map = \Drupal::service(MimeTypeMapInterface::class);
+    }
+    $this->map = $map;
+    if (!$fileSystem) {
+      @trigger_error(
+        'Calling ' . __METHOD__ . '() without the $fileSystem argument is deprecated in drupal:11.2.0 and is required in drupal:12.0.0. See https://www.drupal.org/node/3494040',
+        E_USER_DEPRECATED
+      );
+      $fileSystem = \Drupal::service(FileSystemInterface::class);
+    }
+    $this->fileSystem = $fileSystem;
   }
 
   /**
    * {@inheritdoc}
    */
   public function guessMimeType($path): ?string {
-    if ($this->mapping === NULL) {
-      $mapping = $this->defaultMapping;
-      // Allow modules to alter the default mapping.
-      $this->moduleHandler->alter('file_mimetype_mapping', $mapping);
-      $this->mapping = $mapping;
-    }
-
     $extension = '';
-    $file_parts = explode('.', \Drupal::service('file_system')->basename($path));
+    $file_parts = explode('.', $this->fileSystem->basename($path));
 
-    // Remove the first part: a full filename should not match an extension.
-    array_shift($file_parts);
-
-    // Iterate over the file parts, trying to find a match.
-    // For my.awesome.image.jpeg, we try:
-    // - jpeg
-    // - image.jpeg, and
-    // - awesome.image.jpeg
-    while ($additional_part = array_pop($file_parts)) {
-      $extension = strtolower($additional_part . ($extension ? '.' . $extension : ''));
-      if (isset($this->mapping['extensions'][$extension])) {
-        return $this->mapping['mimetypes'][$this->mapping['extensions'][$extension]];
+    // Remove the first part: a full filename should not match an extension,
+    // then iterate over the file parts, trying to find a match.
+    // For 'my.awesome.image.jpeg', we try: 'awesome.image.jpeg', then
+    // 'image.jpeg', then 'jpeg'.
+    // We explicitly check for NULL because that indicates that the array is
+    // empty.
+    while (array_shift($file_parts) !== NULL) {
+      $extension = strtolower(implode('.', $file_parts));
+      if ($mimeType = $this->map->getMimeTypeForExtension($extension)) {
+        return $mimeType;
       }
     }
 
-    return 'application/octet-stream';
+    return NULL;
   }
 
   /**
@@ -930,9 +973,32 @@ class ExtensionMimeTypeGuesser implements MimeTypeGuesserInterface {
    *
    * @param array|null $mapping
    *   Passing a NULL mapping will cause guess() to use self::$defaultMapping.
+   *
+   * @deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Use
+   *   \Drupal\Core\File\MimeType\MimeTypeMapInterface::addMapping() instead.
+   *
+   * @see https://www.drupal.org/node/3494040
    */
-  public function setMapping(array $mapping = NULL) {
-    $this->mapping = $mapping;
+  public function setMapping(?array $mapping = NULL): void {
+    @trigger_error(
+      __METHOD__ . '() is deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Use \Drupal\Core\File\MimeType\MimeTypeMapInterface::addMapping() instead or define your own MimeTypeMapInterface implementation. See https://www.drupal.org/node/3494040',
+      E_USER_DEPRECATED
+    );
+    // Convert the mapping to be keyed by type.
+    $typeMapping = [];
+    foreach ($mapping['mimetypes'] as $index => $mimetype) {
+      $typeMapping[$mimetype] = array_keys($mapping['extensions'], $index);
+    }
+
+    $this->map = new MimeTypeMap();
+    foreach ($typeMapping as $type => $extensions) {
+      foreach ($extensions as $extension) {
+        $this->map->addMapping($type, $extension);
+      }
+    }
+    \Drupal::service('event_dispatcher')->dispatch(
+      new MimeTypeMapLoadedEvent($this->map)
+    );
   }
 
   /**
