@@ -16,7 +16,7 @@ class CacheableConflictHttpException extends ConflictHttpException implements Ca
   /**
    * {@inheritdoc}
    */
-  public function __construct(CacheableDependencyInterface $cacheability, $message = '', ?\Exception $previous = NULL, $code = 0) {
+  public function __construct(CacheableDependencyInterface $cacheability, $message = '', ?\Throwable $previous = NULL, $code = 0) {
     $this->setCacheability($cacheability);
     parent::__construct($message, $previous, $code);
   }
