@@ -23,6 +23,7 @@ use Twig\Node\Expression\ConstantExpression;
 use Twig\Node\Node;
 use Twig\TwigFilter;
 use Twig\TwigFunction;
+use Twig\Runtime\EscaperRuntime;
 
 /**
  * A class providing Drupal Twig extensions.
@@ -127,7 +128,14 @@ class TwigExtension extends AbstractExtension {
       new TwigFilter('placeholder', [$this, 'escapePlaceholder'], ['is_safe' => ['html'], 'needs_environment' => TRUE]),
 
       // Replace twig's escape filter with our own.
-      new TwigFilter('drupal_escape', [$this, 'escapeFilter'], ['needs_environment' => TRUE, 'is_safe_callback' => 'twig_escape_filter_is_safe']),
+      new TwigFilter(
+        'drupal_escape',
+        [$this, 'escapeFilter'],
+        [
+          'needs_environment' => TRUE,
+          'is_safe_callback' => 'twig_escape_filter_is_safe',
+        ]
+      ),
 
       // Implements safe joining.
       // @todo Make that the default for |join? Upstream issue:
@@ -157,10 +165,18 @@ class TwigExtension extends AbstractExtension {
   public function getNodeVisitors() {
     // The node visitor is needed to wrap all variables with
     // render_var -> TwigExtension->renderVar() function.
-    return [
+    $visitors = [
       new TwigNodeVisitor(),
       new TwigNodeVisitorCheckDeprecations(),
     ];
+    if (\in_array('__toString', TwigSandboxPolicy::getMethodsAllowedOnAllObjects(), TRUE)) {
+      // When __toString is an allowed method, there is no point in running
+      // \Twig\Extension\SandboxExtension::ensureToStringAllowed, so we add a
+      // node visitor to remove any CheckToStringNode nodes added by the
+      // sandbox extension.
+      $visitors[] = new RemoveCheckToStringNodeVisitor();
+    }
+    return $visitors;
   }
 
   /**
@@ -182,7 +198,7 @@ class TwigExtension extends AbstractExtension {
   /**
    * Generates a URL path given a route name and parameters.
    *
-   * @param $name
+   * @param string $name
    *   The name of the route.
    * @param array $parameters
    *   (optional) An associative array of route parameters names and values.
@@ -205,7 +221,7 @@ class TwigExtension extends AbstractExtension {
   /**
    * Generates an absolute URL given a route name and parameters.
    *
-   * @param $name
+   * @param string $name
    *   The name of the route.
    * @param array $parameters
    *   An associative array of route parameter names and values.
@@ -461,7 +477,7 @@ class TwigExtension extends AbstractExtension {
       if ($strategy == 'html') {
         return Html::escape($return);
       }
-      return twig_escape_filter($env, $return, $strategy, $charset, $autoescape);
+      return $env->getRuntime(EscaperRuntime::class)->escape($arg, $strategy, $charset, $autoescape);
     }
 
     // This is a normal render array, which is safe by definition, with
@@ -481,12 +497,11 @@ class TwigExtension extends AbstractExtension {
    * For example: a generated link or generated URL object is passed as a Twig
    * template argument, and its bubbleable metadata must be bubbled.
    *
-   * @see \Drupal\Core\GeneratedLink
-   * @see \Drupal\Core\GeneratedUrl
-   *
    * @param mixed $arg
    *   A Twig template argument that is about to be printed.
    *
+   * @see \Drupal\Core\GeneratedLink
+   * @see \Drupal\Core\GeneratedUrl
    * @see \Drupal\Core\Theme\ThemeManager::render()
    * @see \Drupal\Core\Render\RendererInterface::render()
    */
@@ -554,6 +569,9 @@ class TwigExtension extends AbstractExtension {
       if ($arg instanceof RenderableInterface) {
         $arg = $arg->toRenderable();
       }
+      elseif ($arg instanceof MarkupInterface) {
+        return $arg;
+      }
       elseif (method_exists($arg, '__toString')) {
         return (string) $arg;
       }
@@ -630,22 +648,20 @@ class TwigExtension extends AbstractExtension {
    *
    * @param array|object $element
    *   The parent renderable array to exclude the child items.
-   * @param string[]|string ...
+   * @param string[]|string ...$args
    *   The string keys of $element to prevent printing. Arguments can include
    *   string keys directly, or arrays of string keys to hide.
    *
    * @return array
    *   The filtered renderable array.
    */
-  public function withoutFilter($element) {
+  public function withoutFilter($element, ...$args) {
     if ($element instanceof \ArrayAccess) {
       $filtered_element = clone $element;
     }
     else {
       $filtered_element = $element;
     }
-    $args = func_get_args();
-    unset($args[0]);
     // Since the remaining arguments can be a mix of arrays and strings, we use
     // some native PHP iterator classes to allow us to recursively iterate over
     // everything in a single pass.
