@@ -3,7 +3,6 @@
 namespace Drupal\Core\Test\StackMiddleware;
 
 use Drupal\Core\Lock\LockBackendInterface;
-use Drupal\Core\State\StateInterface;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\HttpKernel\HttpKernelInterface;
@@ -18,15 +17,15 @@ class TestWaitTerminateMiddleware implements HttpKernelInterface {
    *
    * @param \Symfony\Component\HttpKernel\HttpKernelInterface $httpKernel
    *   The decorated kernel.
-   * @param \Drupal\Core\State\StateInterface $state
-   *   The state server.
    * @param \Drupal\Core\Lock\LockBackendInterface $lock
    *   The lock backend.
+   * @param bool $waitForTerminate
+   *   Container parameter to toggle this behavior.
    */
   public function __construct(
     protected HttpKernelInterface $httpKernel,
-    protected StateInterface $state,
     protected LockBackendInterface $lock,
+    protected bool $waitForTerminate = FALSE,
   ) {
   }
 
@@ -36,14 +35,16 @@ class TestWaitTerminateMiddleware implements HttpKernelInterface {
   public function handle(Request $request, $type = self::MAIN_REQUEST, $catch = TRUE): Response {
     $result = $this->httpKernel->handle($request, $type, $catch);
 
-    if ($this->state->get('drupal.test_wait_terminate')) {
-      // Set a header on the response to instruct the test runner that it must
-      // await the lock. Note that the lock acquired here is automatically
-      // released from within a shutdown function.
-      $this->lock->acquire('test_wait_terminate');
-      $result->headers->set('X-Drupal-Wait-Terminate', '1');
+    if (!$this->waitForTerminate) {
+      return $result;
     }
 
+    // Set a header on the response to instruct the test runner that it must
+    // await the lock. Note that the lock acquired here is automatically
+    // released from within a shutdown function.
+    $this->lock->acquire('test_wait_terminate');
+    $result->headers->set('X-Drupal-Wait-Terminate', '1');
+
     return $result;
   }
 
