@@ -2,6 +2,7 @@
 
 namespace Drupal\Core\TypedData\Plugin\DataType;
 
+use Drupal\Core\Serialization\Attribute\JsonSchema;
 use Drupal\Core\StringTranslation\TranslatableMarkup;
 use Drupal\Core\TypedData\Attribute\DataType;
 use Drupal\Core\TypedData\Type\StringInterface;
@@ -18,4 +19,12 @@ use Drupal\Core\TypedData\Type\StringInterface;
 )]
 class Email extends StringData implements StringInterface {
 
+  /**
+   * {@inheritdoc}
+   */
+  #[JsonSchema(['type' => 'string', 'format' => 'email'])]
+  public function getCastedValue() {
+    return parent::getCastedValue();
+  }
+
 }
