@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\block_test\Plugin\Block;
 
 use Drupal\Core\Block\Attribute\Block;
@@ -19,7 +21,7 @@ class TestCacheBlock extends BlockBase {
    * {@inheritdoc}
    */
   public function build() {
-    $content = \Drupal::state()->get('block_test.content');
+    $content = \Drupal::keyValue('block_test')->get('content');
 
     $build = [];
     if (!empty($content)) {
