@@ -47,6 +47,17 @@ class BlockAddTest extends WebDriverTestBase {
     $assert_session->assertWaitOnAjaxRequest();
     $assert_session->pageTextNotContains('The submitted value Pre-content in the Region element is not allowed.');
     $assert_session->optionExists('Region', '- Select -');
+    // Check that the summary line is not present in the title.
+    $summary_text = $this->getSession()->getPage()->find('css', 'li.vertical-tabs__menu-item:nth-child(1) > a:nth-child(1) > span:nth-child(2)')->getText();
+    $assert_session->elementTextContains('css', '.vertical-tabs__menu-item-title', 'Response status');
+    $assert_session->elementTextNotContains('css', '.vertical-tabs__menu-item-title', $summary_text);
+
+    // Search for the "Pages" tab link and click it
+    $this->getSession()->getPage()->find('css', 'a[href="#edit-visibility-request-path"]')->click();
+    // Check that the corresponding form section is open and visible.
+    $form_section = $this->getSession()->getPage()->find('css', '#edit-visibility-request-path');
+    $this->assertNotEmpty($form_section, 'The "Pages" form section exists.');
+    $this->assertTrue($form_section->isVisible(), 'The "Pages" form section is visible after clicking the tab.');
   }
 
 }
