@@ -46,7 +46,7 @@ class BlockRebuildTest extends KernelTestBase {
   }
 
   /**
-   * @covers ::block_rebuild
+   * @covers \Drupal\block\Hook\BlockHooks::rebuild
    */
   public function testRebuildNoBlocks(): void {
     $blockRebuild = new BlockHooks();
@@ -57,7 +57,7 @@ class BlockRebuildTest extends KernelTestBase {
   }
 
   /**
-   * @covers ::block_rebuild
+   * @covers \Drupal\block\Hook\BlockHooks::rebuild
    */
   public function testRebuildNoInvalidBlocks(): void {
     $this->placeBlock('system_powered_by_block', ['region' => 'content']);
@@ -70,7 +70,7 @@ class BlockRebuildTest extends KernelTestBase {
   }
 
   /**
-   * @covers ::block_rebuild
+   * @covers \Drupal\block\Hook\BlockHooks::rebuild
    */
   public function testRebuildInvalidBlocks(): void {
     $this->placeBlock('system_powered_by_block', ['region' => 'content']);
@@ -103,7 +103,14 @@ class BlockRebuildTest extends KernelTestBase {
 
     $messages = \Drupal::messenger()->all();
     \Drupal::messenger()->deleteAll();
-    $expected = ['warning' => [new TranslatableMarkup('The block %info was assigned to the invalid region %region and has been disabled.', ['%info' => $block1->id(), '%region' => 'INVALID'])]];
+    $expected = [
+      'warning' => [
+        new TranslatableMarkup('The block %info was assigned to the invalid region %region and has been disabled.', [
+          '%info' => $block1->id(),
+          '%region' => 'INVALID',
+        ]),
+      ],
+    ];
     $this->assertEquals($expected, $messages);
 
     $default_region = system_default_region('stark');
