@@ -4,7 +4,7 @@ namespace Drupal\block_content\Plugin\migrate\source\d7;
 
 use Drupal\migrate\Row;
 use Drupal\migrate_drupal\Plugin\migrate\source\DrupalSqlBase;
-use Drupal\content_translation\Plugin\migrate\source\I18nQueryTrait;
+use Drupal\migrate_drupal\Plugin\migrate\source\I18nQueryTrait;
 
 /**
  * Drupal 7 i18n content block translations source from database.
