@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\block_content\Functional\Views;
 
 /**
@@ -17,9 +19,7 @@ class BlockContentRedirectTest extends BlockContentTestBase {
   public static $testViews = ['test_block_content_redirect_destination'];
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['block', 'block_content', 'views'];
 
@@ -31,25 +31,25 @@ class BlockContentRedirectTest extends BlockContentTestBase {
   /**
    * Tests the redirect destination when editing block content.
    */
-  public function testRedirectDestination() {
-    $this->drupalLogin($this->drupalCreateUser(['administer blocks']));
-    $this->drupalGet('admin/structure/block/block-content');
+  public function testRedirectDestination(): void {
+    $this->drupalLogin($this->drupalCreateUser(['access block library', 'administer block content']));
+    $this->drupalGet('admin/content/block');
 
-    // Create a custom block.
-    $this->clickLink('custom block');
+    // Create a content block.
+    $this->clickLink('content block');
     $edit = [];
     $edit['info[0][value]'] = 'Test redirect destination';
     $edit['body[0][value]'] = $this->randomMachineName(16);
-    $this->drupalPostForm(NULL, $edit, 'Save');
+    $this->submitForm($edit, 'Save');
 
     // Check the block content is present in the view redirect destination.
     $this->drupalGet('admin/content/redirect_destination');
-    $this->assertText('Test redirect destination');
+    $this->assertSession()->pageTextContains('Test redirect destination');
 
     // Edit the created block and save.
     $this->clickLink('Edit');
-    $this->drupalPostForm(NULL, [], 'Save');
-    $this->assertUrl('admin/content/redirect_destination');
+    $this->submitForm([], 'Save');
+    $this->assertSession()->addressEquals('admin/content/redirect_destination');
   }
 
 }
