@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\block_content\Kernel;
 
 use Drupal\block_content\Entity\BlockContentType;
@@ -9,6 +11,7 @@ use Drupal\KernelTests\Core\Config\ConfigEntityValidationTestBase;
  * Tests validation of block_content_type entities.
  *
  * @group block_content
+ * @group #slow
  */
 class BlockContentTypeValidationTest extends ConfigEntityValidationTestBase {
 
@@ -17,6 +20,11 @@ class BlockContentTypeValidationTest extends ConfigEntityValidationTestBase {
    */
   protected static $modules = ['block_content'];
 
+  /**
+   * {@inheritdoc}
+   */
+  protected static array $propertiesWithOptionalValues = ['description'];
+
   /**
    * {@inheritdoc}
    */
