@@ -4,19 +4,20 @@ declare(strict_types = 1);
 
 namespace Drupal\ckeditor5\Plugin\Validation\Constraint;
 
-use Symfony\Component\Validator\Constraint;
+use Drupal\Core\StringTranslation\TranslatableMarkup;
+use Drupal\Core\Validation\Attribute\Constraint;
+use Symfony\Component\Validator\Constraint as SymfonyConstraint;
 
 /**
  * A CKEditor 5 toolbar item.
  *
- * @Constraint(
- *   id = "CKEditor5ToolbarItemDependencyConstraint",
- *   label = @Translation("CKEditor 5 toolbar item dependency", context = "Validation"),
- * )
- *
  * @internal
  */
-class ToolbarItemDependencyConstraint extends Constraint {
+#[Constraint(
+  id: 'CKEditor5ToolbarItemDependencyConstraint',
+  label: new TranslatableMarkup('CKEditor 5 toolbar item dependency', [], ['context' => 'Validation'])
+)]
+class ToolbarItemDependencyConstraint extends SymfonyConstraint {
 
   /**
    * The default violation message.
@@ -35,7 +36,7 @@ class ToolbarItemDependencyConstraint extends Constraint {
   /**
    * {@inheritdoc}
    */
-  public function getRequiredOptions() {
+  public function getRequiredOptions(): array {
     return ['toolbarItem'];
   }
 
