@@ -2,24 +2,24 @@
 
 namespace Drupal\comment\Plugin\views\field;
 
+use Drupal\views\Attribute\ViewsField;
 use Drupal\views\Plugin\views\field\Date;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
 use Drupal\views\ResultRow;
 use Drupal\views\ViewExecutable;
 
 /**
- * Field handler to display the timestamp of a comment with the count of comments.
+ * Displays the timestamp of a comment with the count of comments.
  *
  * @ingroup views_field_handlers
- *
- * @ViewsField("comment_last_timestamp")
  */
+#[ViewsField("comment_last_timestamp")]
 class LastTimestamp extends Date {
 
   /**
    * {@inheritdoc}
    */
-  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
+  public function init(ViewExecutable $view, DisplayPluginBase $display, ?array &$options = NULL) {
     parent::init($view, $display, $options);
 
     $this->additional_fields['comment_count'] = 'comment_count';
