@@ -3,6 +3,7 @@
 namespace Drupal\comment\Plugin\views\field;
 
 use Drupal\Core\Url;
+use Drupal\views\Attribute\ViewsField;
 use Drupal\views\Plugin\views\field\LinkBase;
 use Drupal\views\ResultRow;
 
@@ -10,9 +11,8 @@ use Drupal\views\ResultRow;
  * Field handler to present a link to reply to a comment.
  *
  * @ingroup views_field_handlers
- *
- * @ViewsField("comment_link_reply")
  */
+#[ViewsField("comment_link_reply")]
 class LinkReply extends LinkBase {
 
   /**
