@@ -75,14 +75,16 @@ class CommentPreviewTest extends CommentTestBase {
     $this->assertSession()->pageTextContains($edit['subject[0][value]']);
     $this->assertSession()->pageTextContains($edit['comment_body[0][value]']);
 
-    // Check that the title and body fields are displayed with the correct values.
+    // Check that the title and body fields are displayed with the correct
+    // values.
     $this->assertSession()->fieldValueEquals('subject[0][value]', $edit['subject[0][value]']);
     $this->assertSession()->fieldValueEquals('comment_body[0][value]', $edit['comment_body[0][value]']);
 
     // Check that the user picture is displayed.
     $this->assertSession()->elementExists('xpath', "//article[contains(@class, 'preview')]//div[contains(@class, 'user-picture')]//img");
 
-    // Ensure that preview node is displayed after the submit buttons of the form.
+    // Ensure that preview node is displayed after the submit buttons of the
+    // form.
     $xpath = $this->assertSession()->buildXPathQuery('//div[@id=:id]/following-sibling::article', [':id' => 'edit-actions']);
     $this->assertSession()->elementExists('xpath', $xpath);
   }
@@ -111,7 +113,8 @@ class CommentPreviewTest extends CommentTestBase {
     $this->assertSession()->pageTextContains($edit['subject[0][value]']);
     $this->assertSession()->pageTextContains($edit['comment_body[0][value]']);
 
-    // Check that the title and body fields are displayed with the correct values.
+    // Check that the title and body fields are displayed with the correct
+    // values.
     $this->assertSession()->fieldValueEquals('subject[0][value]', $edit['subject[0][value]']);
     $this->assertSession()->fieldValueEquals('comment_body[0][value]', $edit['comment_body[0][value]']);
 
@@ -159,14 +162,16 @@ class CommentPreviewTest extends CommentTestBase {
     $this->drupalGet('comment/' . $comment->id() . '/edit');
     $this->submitForm($edit, 'Preview');
 
-    // Check that the preview is displaying the subject, comment, author and date correctly.
+    // Check that the preview is displaying the subject, comment, author and
+    // date correctly.
     $this->assertSession()->titleEquals('Preview comment | Drupal');
     $this->assertSession()->pageTextContains($edit['subject[0][value]']);
     $this->assertSession()->pageTextContains($edit['comment_body[0][value]']);
     $this->assertSession()->pageTextContains($web_user->getAccountName());
     $this->assertSession()->pageTextContains($expected_text_date);
 
-    // Check that the subject, comment, author and date fields are displayed with the correct values.
+    // Check that the subject, comment, author and date fields are displayed
+    // with the correct values.
     $this->assertSession()->fieldValueEquals('subject[0][value]', $edit['subject[0][value]']);
     $this->assertSession()->fieldValueEquals('comment_body[0][value]', $edit['comment_body[0][value]']);
     $this->assertSession()->fieldValueEquals('uid', $edit['uid']);
@@ -178,7 +183,8 @@ class CommentPreviewTest extends CommentTestBase {
     $this->submitForm($edit, 'Save');
     $this->assertSession()->pageTextContains('Your comment has been updated.');
 
-    // Check that the comment fields are correct after loading the saved comment.
+    // Check that the comment fields are correct after loading the saved
+    // comment.
     $this->drupalGet('comment/' . $comment->id() . '/edit');
     $this->assertSession()->fieldValueEquals('subject[0][value]', $edit['subject[0][value]']);
     $this->assertSession()->fieldValueEquals('comment_body[0][value]', $edit['comment_body[0][value]']);
@@ -197,8 +203,6 @@ class CommentPreviewTest extends CommentTestBase {
     $this->submitForm($displayed, 'Save');
 
     // Check that the saved comment is still correct.
-    $comment_storage = \Drupal::entityTypeManager()->getStorage('comment');
-    $comment_storage->resetCache([$comment->id()]);
     /** @var \Drupal\comment\CommentInterface $comment_loaded */
     $comment_loaded = Comment::load($comment->id());
     $this->assertEquals($edit['subject[0][value]'], $comment_loaded->getSubject(), 'Subject loaded.');
@@ -216,7 +220,6 @@ class CommentPreviewTest extends CommentTestBase {
     unset($edit['uid']);
     $this->drupalGet('comment/' . $comment->id() . '/edit');
     $this->submitForm($user_edit, 'Save');
-    $comment_storage->resetCache([$comment->id()]);
     $comment_loaded = Comment::load($comment->id());
     $this->assertEquals($expected_created_time, $comment_loaded->getCreatedTime(), 'Expected date and time for comment edited.');
     $this->drupalLogout();
