@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\content_moderation\Functional;
 
 use Drupal\Core\Entity\Entity\EntityFormDisplay;
@@ -10,16 +12,13 @@ use Drupal\Tests\content_translation\Traits\ContentTranslationTestTrait;
  * Tests the moderation form, specifically on nodes.
  *
  * @group content_moderation
- * @group #slow
  */
 class ModerationFormTest extends ModerationStateTestBase {
 
   use ContentTranslationTestTrait;
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = [
     'node',
@@ -33,6 +32,18 @@ class ModerationFormTest extends ModerationStateTestBase {
    */
   protected $defaultTheme = 'stark';
 
+  /**
+   * {@inheritdoc}
+   */
+  protected function getAdministratorPermissions(): array {
+    return array_merge($this->permissions, [
+      'administer entity_test content',
+      'view test entity',
+      'translate any entity',
+      'bypass node access',
+    ]);
+  }
+
   /**
    * {@inheritdoc}
    */
@@ -51,7 +62,7 @@ class ModerationFormTest extends ModerationStateTestBase {
    * @see \Drupal\content_moderation\EntityOperations
    * @see \Drupal\Tests\content_moderation\Functional\ModerationStateBlockTest::testCustomBlockModeration
    */
-  public function testModerationForm() {
+  public function testModerationForm(): void {
     // Test the states that appear by default when creating a new item of
     // content.
     $this->drupalGet('node/add/moderated_content');
@@ -188,8 +199,9 @@ class ModerationFormTest extends ModerationStateTestBase {
   /**
    * Tests moderation non-bundle entity type.
    */
-  public function testNonBundleModerationForm() {
-    $this->drupalLogin($this->rootUser);
+  public function testNonBundleModerationForm(): void {
+    $this->adminUser = $this->drupalCreateUser($this->getAdministratorPermissions());
+    $this->drupalLogin($this->adminUser);
     $this->workflow->getTypePlugin()->addEntityTypeAndBundle('entity_test_mulrevpub', 'entity_test_mulrevpub');
     $this->workflow->save();
 
@@ -256,7 +268,7 @@ class ModerationFormTest extends ModerationStateTestBase {
   /**
    * Tests the revision author is updated when the moderation form is used.
    */
-  public function testModerationFormSetsRevisionAuthor() {
+  public function testModerationFormSetsRevisionAuthor(): void {
     // Create new moderated content in published.
     $node = $this->createNode(['type' => 'moderated_content', 'moderation_state' => 'published']);
     // Make a pending revision.
@@ -282,8 +294,9 @@ class ModerationFormTest extends ModerationStateTestBase {
   /**
    * Tests translated and moderated nodes.
    */
-  public function testContentTranslationNodeForm() {
-    $this->drupalLogin($this->rootUser);
+  public function testContentTranslationNodeForm(): void {
+    $this->adminUser = $this->drupalCreateUser($this->getAdministratorPermissions());
+    $this->drupalLogin($this->adminUser);
 
     // Add French language.
     static::createLanguageFromLangcode('fr');
@@ -483,7 +496,7 @@ class ModerationFormTest extends ModerationStateTestBase {
   /**
    * Tests the moderation_state field when an alternative widget is set.
    */
-  public function testAlternativeModerationStateWidget() {
+  public function testAlternativeModerationStateWidget(): void {
     $entity_form_display = EntityFormDisplay::load('node.moderated_content.default');
     $entity_form_display->setComponent('moderation_state', [
       'type' => 'string_textfield',
@@ -504,7 +517,7 @@ class ModerationFormTest extends ModerationStateTestBase {
    * @covers \Drupal\content_moderation\Plugin\WorkflowType\ContentModeration::workflowHasData
    * @covers \Drupal\content_moderation\Plugin\WorkflowType\ContentModeration::workflowStateHasData
    */
-  public function testWorkflowInUse() {
+  public function testWorkflowInUse(): void {
     $user = $this->createUser([
       'administer workflows',
       'create moderated_content content',
