@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\content_moderation\Functional;
 
 use Drupal\node\NodeInterface;
@@ -16,9 +18,7 @@ class ModerationLocaleTest extends ModerationStateTestBase {
   use ContentTranslationTestTrait;
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = [
     'node',
@@ -32,14 +32,25 @@ class ModerationLocaleTest extends ModerationStateTestBase {
    */
   protected $defaultTheme = 'stark';
 
+  /**
+   * {@inheritdoc}
+   */
+  protected function getAdministratorPermissions(): array {
+    return array_merge($this->permissions, [
+      'create content translations',
+      'bypass node access',
+      'translate any entity',
+    ]);
+  }
+
   /**
    * {@inheritdoc}
    */
   protected function setUp(): void {
     parent::setUp();
 
-    $this->drupalLogin($this->rootUser);
-
+    $this->adminUser = $this->drupalCreateUser($this->getAdministratorPermissions());
+    $this->drupalLogin($this->adminUser);
     // Enable moderation on Article node type.
     $this->createContentTypeFromUi('Article', 'article', TRUE);
 
@@ -58,7 +69,7 @@ class ModerationLocaleTest extends ModerationStateTestBase {
   /**
    * Tests article translations can be moderated separately.
    */
-  public function testTranslateModeratedContent() {
+  public function testTranslateModeratedContent(): void {
     // Create a published article in English.
     $edit = [
       'title[0][value]' => 'Published English node',
@@ -208,7 +219,7 @@ class ModerationLocaleTest extends ModerationStateTestBase {
   /**
    * Tests that individual translations can be moderated independently.
    */
-  public function testLanguageIndependentContentModeration() {
+  public function testLanguageIndependentContentModeration(): void {
     // Create a published article in English (revision 1).
     $this->drupalGet('node/add/article');
     $node = $this->submitNodeForm('Test 1.1 EN', 'published');
@@ -340,11 +351,11 @@ class ModerationLocaleTest extends ModerationStateTestBase {
     foreach (range(11, 16) as $revision_id) {
       /** @var \Drupal\node\NodeInterface $revision */
       $revision = $storage->loadRevision($revision_id);
-      foreach ($revision->getTranslationLanguages() as $langcode => $language) {
+      foreach (array_keys($revision->getTranslationLanguages()) as $langcode) {
         if ($revision->isRevisionTranslationAffected()) {
-          $this->drupalGet($revision->toUrl('revision'));
+          $translation = $revision->getTranslation($langcode);
+          $this->drupalGet($translation->toUrl('revision'));
           $this->assertFalse($this->hasModerationForm(), 'Moderation form is not displayed correctly for revision ' . $revision_id);
-          break;
         }
       }
     }
@@ -405,7 +416,7 @@ class ModerationLocaleTest extends ModerationStateTestBase {
   /**
    * Checks that new translation values are populated properly.
    */
-  public function testNewTranslationSourceValues() {
+  public function testNewTranslationSourceValues(): void {
     // Create a published article in Italian (revision 1).
     $this->drupalGet('node/add/article');
     $node = $this->submitNodeForm('Test 1.1 IT', 'published', TRUE, 'it');
@@ -442,7 +453,7 @@ class ModerationLocaleTest extends ModerationStateTestBase {
   /**
    * Tests article revision history shows revisions for the correct translation.
    */
-  public function testTranslationRevisionsHistory() {
+  public function testTranslationRevisionsHistory(): void {
     // Create a published article in English.
     $edit = [
       'title[0][value]' => 'English node',
