@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\content_moderation\Kernel;
 
 use Drupal\content_moderation\Entity\ContentModerationState;
@@ -9,6 +11,7 @@ use Drupal\Core\Entity\EntityPublishedInterface;
 use Drupal\Core\Entity\EntityStorageException;
 use Drupal\Core\Language\LanguageInterface;
 use Drupal\Core\State\StateInterface;
+use Drupal\entity_test\EntityTestHelper;
 use Drupal\KernelTests\KernelTestBase;
 use Drupal\language\Entity\ConfigurableLanguage;
 use Drupal\node\Entity\Node;
@@ -94,6 +97,7 @@ class ContentModerationStateTest extends KernelTestBase {
     $this->installEntitySchema('block_content');
     $this->installEntitySchema('media');
     $this->installEntitySchema('file');
+    $this->installEntitySchema('taxonomy_term');
     $this->installEntitySchema('content_moderation_state');
     $this->installConfig('content_moderation');
     $this->installSchema('file', 'file_usage');
@@ -107,10 +111,18 @@ class ContentModerationStateTest extends KernelTestBase {
 
   /**
    * Tests basic monolingual content moderation through the API.
-   *
-   * @dataProvider basicModerationTestCases
    */
-  public function testBasicModeration($entity_type_id) {
+  public function testBasicModeration(): void {
+    foreach (static::basicModerationTestCases() as $case) {
+      [$entity_type_id] = $case;
+      $this->doTestBasicModeration($entity_type_id);
+    }
+  }
+
+  /**
+   * Tests basic monolingual content moderation through the API.
+   */
+  protected function doTestBasicModeration($entity_type_id): void {
     $entity = $this->createEntity($entity_type_id, 'draft');
     $entity = $this->reloadEntity($entity);
     $this->assertEquals('draft', $entity->moderation_state->value);
@@ -169,11 +181,14 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Test cases for basic moderation test.
    */
-  public function basicModerationTestCases() {
+  public static function basicModerationTestCases() {
     return [
       'Nodes' => [
         'node',
       ],
+      'Taxonomy term' => [
+        'taxonomy_term',
+      ],
       'Block content' => [
         'block_content',
       ],
@@ -194,10 +209,18 @@ class ContentModerationStateTest extends KernelTestBase {
 
   /**
    * Tests removal of content moderation state entity.
-   *
-   * @dataProvider basicModerationTestCases
    */
-  public function testContentModerationStateDataRemoval($entity_type_id) {
+  public function testContentModerationStateDataRemoval(): void {
+    foreach (static::basicModerationTestCases() as $case) {
+      [$entity_type_id] = $case;
+      $this->doTestContentModerationStateDataRemoval($entity_type_id);
+    }
+  }
+
+  /**
+   * Tests removal of content moderation state entity.
+   */
+  public function doTestContentModerationStateDataRemoval($entity_type_id): void {
     /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
     $entity = $this->createEntity($entity_type_id);
     $entity = $this->reloadEntity($entity);
@@ -208,10 +231,18 @@ class ContentModerationStateTest extends KernelTestBase {
 
   /**
    * Tests removal of content moderation state entity revisions.
-   *
-   * @dataProvider basicModerationTestCases
    */
-  public function testContentModerationStateRevisionDataRemoval($entity_type_id) {
+  public function testContentModerationStateRevisionDataRemoval(): void {
+    foreach (static::basicModerationTestCases() as $case) {
+      [$entity_type_id] = $case;
+      $this->doTestContentModerationStateRevisionDataRemoval($entity_type_id);
+    }
+  }
+
+  /**
+   * Tests removal of content moderation state entity revisions.
+   */
+  public function doTestContentModerationStateRevisionDataRemoval($entity_type_id): void {
     /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
     $entity = $this->createEntity($entity_type_id);
     $revision_1 = clone $entity;
@@ -243,10 +274,18 @@ class ContentModerationStateTest extends KernelTestBase {
 
   /**
    * Tests removal of content moderation state pending entity revisions.
-   *
-   * @dataProvider basicModerationTestCases
    */
-  public function testContentModerationStatePendingRevisionDataRemoval($entity_type_id) {
+  public function testContentModerationStatePendingRevisionDataRemoval(): void {
+    foreach (static::basicModerationTestCases() as $case) {
+      [$entity_type_id] = $case;
+      $this->doTestContentModerationStatePendingRevisionDataRemoval($entity_type_id);
+    }
+  }
+
+  /**
+   * Tests removal of content moderation state pending entity revisions.
+   */
+  public function doTestContentModerationStatePendingRevisionDataRemoval($entity_type_id): void {
     $entity = $this->createEntity($entity_type_id, 'published');
     $entity->setNewRevision(TRUE);
     $entity->moderation_state = 'draft';
@@ -266,7 +305,7 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Tests removal of content moderation state entities for preexisting content.
    */
-  public function testExistingContentModerationStateDataRemoval() {
+  public function testExistingContentModerationStateDataRemoval(): void {
     /** @var \Drupal\Core\Entity\RevisionableStorageInterface $storage */
     $storage = $this->entityTypeManager->getStorage('entity_test_mulrevpub');
 
@@ -289,16 +328,24 @@ class ContentModerationStateTest extends KernelTestBase {
 
   /**
    * Tests removal of content moderation state translations.
-   *
-   * @dataProvider basicModerationTestCases
    */
-  public function testContentModerationStateTranslationDataRemoval($entity_type_id) {
+  public function testContentModerationStateTranslationDataRemoval(): void {
+    foreach (static::basicModerationTestCases() as $case) {
+      [$entity_type_id] = $case;
+      $this->doTestContentModerationStateTranslationDataRemoval($entity_type_id);
+    }
+  }
+
+  /**
+   * Tests removal of content moderation state translations.
+   */
+  public function doTestContentModerationStateTranslationDataRemoval($entity_type_id): void {
     // Test content moderation state translation deletion.
     if ($this->entityTypeManager->getDefinition($entity_type_id)->isTranslatable()) {
       /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
       $entity = $this->createEntity($entity_type_id, 'published');
       $langcode = 'fr';
-      $translation = $entity->addTranslation($langcode, ['title' => 'French title test']);
+      $translation = $entity->addTranslation($langcode, [$entity->getEntityType()->getKey('label') => 'French title test']);
       // Make sure we add values for all of the required fields.
       if ($entity_type_id == 'block_content') {
         $translation->info = $this->randomString();
@@ -316,7 +363,7 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Tests basic multilingual content moderation through the API.
    */
-  public function testMultilingualModeration() {
+  public function testMultilingualModeration(): void {
     $this->createContentType([
       'type' => 'example',
     ]);
@@ -426,7 +473,7 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Tests moderation when the moderation_state field has a config override.
    */
-  public function testModerationWithFieldConfigOverride() {
+  public function testModerationWithFieldConfigOverride(): void {
     $this->createContentType([
       'type' => 'test_type',
     ]);
@@ -458,7 +505,7 @@ class ContentModerationStateTest extends KernelTestBase {
    *
    * @dataProvider moderationWithSpecialLanguagesTestCases
    */
-  public function testModerationWithSpecialLanguages($original_language, $updated_language) {
+  public function testModerationWithSpecialLanguages($original_language, $updated_language): void {
     $workflow = $this->createEditorialWorkflow();
     $this->addEntityTypeAndBundleToWorkflow($workflow, $this->revEntityTypeId, $this->revEntityTypeId);
 
@@ -480,7 +527,7 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Test cases for ::testModerationWithSpecialLanguages().
    */
-  public function moderationWithSpecialLanguagesTestCases() {
+  public static function moderationWithSpecialLanguagesTestCases() {
     return [
       'Not specified to not specified' => [
         LanguageInterface::LANGCODE_NOT_SPECIFIED,
@@ -500,7 +547,7 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Tests changing the language of content without adding a translation.
    */
-  public function testChangingContentLangcode() {
+  public function testChangingContentLangcode(): void {
     $this->createContentType([
       'type' => 'test_type',
     ]);
@@ -533,7 +580,7 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Tests that a non-translatable entity type with a langcode can be moderated.
    */
-  public function testNonTranslatableEntityTypeModeration() {
+  public function testNonTranslatableEntityTypeModeration(): void {
     $workflow = $this->createEditorialWorkflow();
     $this->addEntityTypeAndBundleToWorkflow($workflow, $this->revEntityTypeId, $this->revEntityTypeId);
 
@@ -556,7 +603,7 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Tests moderation of a non-translatable entity type with no langcode.
    */
-  public function testNonLangcodeEntityTypeModeration() {
+  public function testNonLangcodeEntityTypeModeration(): void {
     // Unset the langcode entity key for 'entity_test_rev'.
     $entity_type = clone $this->entityTypeManager->getDefinition($this->revEntityTypeId);
     $keys = $entity_type->getKeys();
@@ -591,7 +638,7 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Tests the dependencies of the workflow when using content moderation.
    */
-  public function testWorkflowDependencies() {
+  public function testWorkflowDependencies(): void {
     $node_type = $this->createContentType([
       'type' => 'example',
     ]);
@@ -634,9 +681,9 @@ class ContentModerationStateTest extends KernelTestBase {
   /**
    * Tests the content moderation workflow dependencies for non-config bundles.
    */
-  public function testWorkflowNonConfigBundleDependencies() {
+  public function testWorkflowNonConfigBundleDependencies(): void {
     // Create a bundle not based on any particular configuration.
-    entity_test_create_bundle('test_bundle');
+    EntityTestHelper::createBundle('test_bundle');
 
     $workflow = $this->createEditorialWorkflow();
     $workflow->getTypePlugin()->addEntityTypeAndBundle('entity_test', 'test_bundle');
@@ -655,7 +702,7 @@ class ContentModerationStateTest extends KernelTestBase {
 
     // Delete the test bundle to ensure the workflow entity responds
     // appropriately.
-    entity_test_delete_bundle('test_bundle');
+    EntityTestHelper::deleteBundle('test_bundle');
 
     $workflow = Workflow::load('editorial');
     $this->assertEquals([], $workflow->getTypePlugin()->getBundlesForEntityType('entity_test'));
@@ -666,15 +713,23 @@ class ContentModerationStateTest extends KernelTestBase {
     ], $workflow->getDependencies());
   }
 
+  /**
+   * Tests the revision default state of the moderation state entity revisions.
+   */
+  public function testRevisionDefaultState(): void {
+    foreach (static::basicModerationTestCases() as $case) {
+      [$entity_type_id] = $case;
+      $this->doTestRevisionDefaultState($entity_type_id);
+    }
+  }
+
   /**
    * Tests the revision default state of the moderation state entity revisions.
    *
    * @param string $entity_type_id
    *   The ID of entity type to be tested.
-   *
-   * @dataProvider basicModerationTestCases
    */
-  public function testRevisionDefaultState($entity_type_id) {
+  public function doTestRevisionDefaultState($entity_type_id): void {
     // Check that the revision default state of the moderated entity and the
     // content moderation state entity always match.
     $entity = $this->createEntity($entity_type_id, 'published');
@@ -780,7 +835,7 @@ class ContentModerationStateTest extends KernelTestBase {
    * @return \Drupal\Core\Entity\EntityInterface
    *   The reloaded entity.
    */
-  protected function reloadEntity(EntityInterface $entity, $revision_id = FALSE) {
+  protected function reloadEntity(EntityInterface $entity, $revision_id = FALSE): EntityInterface {
     /** @var \Drupal\Core\Entity\RevisionableStorageInterface $storage */
     $storage = \Drupal::entityTypeManager()->getStorage($entity->getEntityTypeId());
     $storage->resetCache([$entity->id()]);
@@ -813,14 +868,4 @@ class ContentModerationStateTest extends KernelTestBase {
     }
   }
 
-  /**
-   * Tests that the 'taxonomy_term' entity type cannot be moderated.
-   */
-  public function testTaxonomyTermEntityTypeModeration() {
-    /** @var \Drupal\content_moderation\ModerationInformationInterface $moderation_info */
-    $moderation_info = \Drupal::service('content_moderation.moderation_information');
-    $entity_type = \Drupal::entityTypeManager()->getDefinition('taxonomy_term');
-    $this->assertFalse($moderation_info->canModerateEntitiesOfEntityType($entity_type));
-  }
-
 }
