@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace Drupal\Tests\content_translation\Functional;
 
+use Drupal\Core\Language\LanguageInterface;
 use Drupal\Tests\content_translation\Traits\ContentTranslationTestTrait;
 use Drupal\Tests\image\Kernel\ImageFieldCreationTrait;
 use Drupal\Tests\node\Functional\NodeTestBase;
@@ -50,20 +51,6 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
       static::createLanguageFromLangcode($langcode);
     }
     $this->drupalPlaceBlock('local_tasks_block');
-    $user = $this->drupalCreateUser([
-      'administer site configuration',
-      'administer nodes',
-      'create article content',
-      'edit any article content',
-      'delete any article content',
-      'administer content translation',
-      'translate any entity',
-      'create content translations',
-      'administer languages',
-      'administer content types',
-      'administer node fields',
-    ]);
-    $this->drupalLogin($user);
 
     // Enable translations for article.
     $this->enableContentTranslation('node', 'article');
@@ -71,6 +58,21 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
     $this->rebuildContainer();
 
     $this->createImageField('field_image_field', 'node', 'article');
+
+    $user = $this->drupalCreateUser([
+      'administer site configuration',
+      'administer nodes',
+      'create article content',
+      'edit any article content',
+      'delete any article content',
+      'administer content translation',
+      'translate article node',
+      'create content translations',
+      'administer languages',
+      'administer content types',
+      'administer node fields',
+    ]);
+    $this->drupalLogin($user);
   }
 
   /**
@@ -155,4 +157,27 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
     $this->assertArrayNotHasKey('de', $translation_languages);
   }
 
+  /**
+   * Tests language switch links while translating content.
+   */
+  public function testLanguageSwitchLinks(): void {
+    $this->drupalPlaceBlock('language_block:' . LanguageInterface::TYPE_INTERFACE, [
+      'id' => 'test_language_block',
+    ]);
+
+    $this->drupalGet('node/add/article');
+    $edit = [
+      'title[0][value]' => 'english_title',
+    ];
+    $this->submitForm($edit, 'Save');
+
+    // Create a translation in French.
+    $this->clickLink('Translate');
+    $language_switch_links = $this->xpath('//div[@id=:id]/ul/li', [':id' => 'block-test-language-block']);
+    $this->assertCount(3, $language_switch_links);
+    $this->clickLink('Add');
+    $language_switch_links = $this->xpath('//div[@id=:id]/ul/li', [':id' => 'block-test-language-block']);
+    $this->assertCount(3, $language_switch_links);
+  }
+
 }
