@@ -3,15 +3,14 @@
 namespace Drupal\contextual\Hook;
 
 use Drupal\Core\Hook\Attribute\Hook;
+use Drupal\Core\StringTranslation\StringTranslationTrait;
 
 /**
  * Hook implementations for contextual.
  */
 class ContextualViewsHooks {
-  /**
-   * @file
-   * Provide views data for contextual.module.
-   */
+
+  use StringTranslationTrait;
 
   /**
    * Implements hook_views_data_alter().
@@ -19,8 +18,8 @@ class ContextualViewsHooks {
   #[Hook('views_data_alter')]
   public function viewsDataAlter(&$data): void {
     $data['views']['contextual_links'] = [
-      'title' => t('Contextual Links'),
-      'help' => t('Display fields in a contextual links menu.'),
+      'title' => $this->t('Contextual Links'),
+      'help' => $this->t('Display fields in a contextual links menu.'),
       'field' => [
         'id' => 'contextual_links',
       ],
