@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace Drupal\Tests\datetime\Functional;
 
-use Drupal\Component\Render\FormattableMarkup;
 use Drupal\Core\Datetime\DrupalDateTime;
 use Drupal\Core\Datetime\Entity\DateFormat;
 use Drupal\datetime\Plugin\Field\FieldType\DateTimeItemInterface;
@@ -169,11 +168,11 @@ class DateTimeFieldTest extends DateTestBase {
       $output = $this->renderTestEntity($id);
       $this->assertStringContainsString($expected, $output, "Formatted date field using daterange_custom format displayed as $expected in $timezone.");
 
-      // Verify that the 'datetime_time_ago' formatter works for intervals in the
-      // past.  First update the test entity so that the date difference always
-      // has the same interval.  Since the database always stores UTC, and the
-      // interval will use this, force the test date to use UTC and not the local
-      // or user timezone.
+      // Verify that the 'datetime_time_ago' formatter works for intervals in
+      // the past.  First update the test entity so that the date difference
+      // always has the same interval.  Since the database always stores UTC,
+      // and the interval will use this, force the test date to use UTC and not
+      // the local or user timezone.
       $timestamp = \Drupal::time()->getRequestTime() - 87654321;
       $entity = EntityTest::load($id);
       $field_name = $this->fieldStorage->getName();
@@ -190,17 +189,21 @@ class DateTimeFieldTest extends DateTestBase {
       $display_repository->getViewDisplay($this->field->getTargetEntityTypeId(), $this->field->getTargetBundle(), 'full')
         ->setComponent($field_name, $this->displayOptions)
         ->save();
-      $expected = new FormattableMarkup($this->displayOptions['settings']['past_format'], [
-        '@interval' => $this->dateFormatter->formatTimeDiffSince($timestamp, ['granularity' => $this->displayOptions['settings']['granularity']]),
-      ]);
+      $expected = str_replace(
+        '@interval',
+        $this->dateFormatter->formatTimeDiffSince(
+          $timestamp,
+          ['granularity' => $this->displayOptions['settings']['granularity']]),
+        $this->displayOptions['settings']['past_format']
+      );
       $output = $this->renderTestEntity($id);
-      $this->assertStringContainsString((string) $expected, $output, "Formatted date field using datetime_time_ago format displayed as $expected in $timezone.");
+      $this->assertStringContainsString($expected, $output, "Formatted date field using datetime_time_ago format displayed as $expected in $timezone.");
 
-      // Verify that the 'datetime_time_ago' formatter works for intervals in the
-      // future.  First update the test entity so that the date difference always
-      // has the same interval.  Since the database always stores UTC, and the
-      // interval will use this, force the test date to use UTC and not the local
-      // or user timezone.
+      // Verify that the 'datetime_time_ago' formatter works for intervals in
+      // the future.  First update the test entity so that the date difference
+      // always has the same interval.  Since the database always stores UTC,
+      // and the interval will use this, force the test date to use UTC and not
+      // the local or user timezone.
       $timestamp = \Drupal::time()->getRequestTime() + 87654321;
       $entity = EntityTest::load($id);
       $field_name = $this->fieldStorage->getName();
@@ -211,11 +214,15 @@ class DateTimeFieldTest extends DateTestBase {
       $display_repository->getViewDisplay($this->field->getTargetEntityTypeId(), $this->field->getTargetBundle(), 'full')
         ->setComponent($field_name, $this->displayOptions)
         ->save();
-      $expected = new FormattableMarkup($this->displayOptions['settings']['future_format'], [
-        '@interval' => $this->dateFormatter->formatTimeDiffUntil($timestamp, ['granularity' => $this->displayOptions['settings']['granularity']]),
-      ]);
+      $expected = str_replace(
+        '@interval',
+        $this->dateFormatter->formatTimeDiffUntil(
+          $timestamp,
+          ['granularity' => $this->displayOptions['settings']['granularity']]),
+        $this->displayOptions['settings']['future_format']
+      );
       $output = $this->renderTestEntity($id);
-      $this->assertStringContainsString((string) $expected, $output, "Formatted date field using datetime_time_ago format displayed as $expected in $timezone.");
+      $this->assertStringContainsString($expected, $output, "Formatted date field using datetime_time_ago format displayed as $expected in $timezone.");
     }
   }
 
@@ -341,11 +348,15 @@ class DateTimeFieldTest extends DateTestBase {
     $display_repository->getViewDisplay($this->field->getTargetEntityTypeId(), $this->field->getTargetBundle(), 'full')
       ->setComponent($field_name, $this->displayOptions)
       ->save();
-    $expected = new FormattableMarkup($this->displayOptions['settings']['past_format'], [
-      '@interval' => $this->dateFormatter->formatTimeDiffSince($timestamp, ['granularity' => $this->displayOptions['settings']['granularity']]),
-    ]);
+    $expected = str_replace(
+      '@interval',
+      $this->dateFormatter->formatTimeDiffSince(
+        $timestamp,
+        ['granularity' => $this->displayOptions['settings']['granularity']]),
+      $this->displayOptions['settings']['past_format']
+    );
     $output = $this->renderTestEntity($id);
-    $this->assertStringContainsString((string) $expected, $output, "Formatted date field using datetime_time_ago format displayed as $expected.");
+    $this->assertStringContainsString($expected, $output, "Formatted date field using datetime_time_ago format displayed as $expected.");
 
     // Verify that the 'datetime_time_ago' formatter works for intervals in the
     // future.  First update the test entity so that the date difference always
@@ -363,11 +374,15 @@ class DateTimeFieldTest extends DateTestBase {
       ->getViewDisplay($this->field->getTargetEntityTypeId(), $this->field->getTargetBundle(), 'full')
       ->setComponent($field_name, $this->displayOptions)
       ->save();
-    $expected = new FormattableMarkup($this->displayOptions['settings']['future_format'], [
-      '@interval' => $this->dateFormatter->formatTimeDiffUntil($timestamp, ['granularity' => $this->displayOptions['settings']['granularity']]),
-    ]);
+    $expected = str_replace(
+      '@interval',
+      $this->dateFormatter->formatTimeDiffUntil(
+        $timestamp,
+        ['granularity' => $this->displayOptions['settings']['granularity']]),
+      $this->displayOptions['settings']['future_format']
+    );
     $output = $this->renderTestEntity($id);
-    $this->assertStringContainsString((string) $expected, $output, "Formatted date field using datetime_time_ago format displayed as $expected.");
+    $this->assertStringContainsString($expected, $output, "Formatted date field using datetime_time_ago format displayed as $expected.");
 
     // Test the required field validation error message.
     $entity = EntityTest::create(['name' => 'test datetime required message']);
@@ -375,9 +390,9 @@ class DateTimeFieldTest extends DateTestBase {
     $form_state = new FormState();
     \Drupal::formBuilder()->submitForm($form, $form_state);
     $errors = $form_state->getErrors();
-    $expected_error_message = new FormattableMarkup('The %field date is required.', ['%field' => $field_label]);
+    $expected_error_message = "The <em class=\"placeholder\">$field_label</em> date is required.";
     $actual_error_message = $errors["{$field_name}][0][value"]->__toString();
-    $this->assertEquals($expected_error_message->__toString(), $actual_error_message);
+    $this->assertEquals($expected_error_message, $actual_error_message);
   }
 
   /**
@@ -415,7 +430,8 @@ class DateTimeFieldTest extends DateTestBase {
     $this->assertSession()->elementNotExists('xpath', "//*[@id=\"edit-$field_name-0-value-hour\"]");
     $this->assertSession()->elementNotExists('xpath', "//*[@id=\"edit-$field_name-0-value-minute\"]");
 
-    // Go to the form display page to assert that increment option does not appear on Date Only
+    // Go to the form display page to assert that increment option does not
+    // appear on Date Only.
     $fieldEditUrl = 'entity_test/structure/entity_test/form-display';
     $this->drupalGet($fieldEditUrl);
 
@@ -441,7 +457,8 @@ class DateTimeFieldTest extends DateTestBase {
       ->save();
     \Drupal::service('entity_field.manager')->clearCachedFieldDefinitions();
 
-    // Go to the form display page to assert that increment option does appear on Date Time
+    // Go to the form display page to assert that increment option does appear
+    // on Date Time.
     $fieldEditUrl = 'entity_test/structure/entity_test/form-display';
     $this->drupalGet($fieldEditUrl);
 
