@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\field\Functional;
 
 use Drupal\Component\Utility\Html;
@@ -8,6 +10,7 @@ use Drupal\Core\Field\FieldStorageDefinitionInterface;
 use Drupal\Core\Form\FormState;
 use Drupal\entity_test\Entity\EntityTest;
 use Drupal\entity_test\Entity\EntityTestBaseFieldDisplay;
+use Drupal\entity_test\EntityTestHelper;
 use Drupal\field\Entity\FieldConfig;
 use Drupal\field\Entity\FieldStorageConfig;
 
@@ -15,19 +18,17 @@ use Drupal\field\Entity\FieldStorageConfig;
  * Tests field form handling.
  *
  * @group field
- * @group #slow
  */
 class FormTest extends FieldTestBase {
 
   /**
-   * Modules to enable.
+   * Modules to install.
    *
    * Locale is installed so that TranslatableMarkup actually does something.
    *
    * @var array
    */
   protected static $modules = [
-    'node',
     'field_test',
     'options',
     'entity_test',
@@ -47,13 +48,6 @@ class FormTest extends FieldTestBase {
    */
   protected $fieldStorageSingle;
 
-  /**
-   * An array of values defining a field multiple.
-   *
-   * @var array
-   */
-  protected $fieldStorageMultiple;
-
   /**
    * An array of values defining a field with unlimited cardinality.
    *
@@ -86,12 +80,6 @@ class FormTest extends FieldTestBase {
       'entity_type' => 'entity_test',
       'type' => 'test_field',
     ];
-    $this->fieldStorageMultiple = [
-      'field_name' => 'field_multiple',
-      'entity_type' => 'entity_test',
-      'type' => 'test_field',
-      'cardinality' => 4,
-    ];
     $this->fieldStorageUnlimited = [
       'field_name' => 'field_unlimited',
       'entity_type' => 'entity_test',
@@ -111,7 +99,10 @@ class FormTest extends FieldTestBase {
     ];
   }
 
-  public function testFieldFormSingle() {
+  /**
+   * Tests the single-value field form functionality.
+   */
+  public function testFieldFormSingle(): void {
     $field_storage = $this->fieldStorageSingle;
     $field_name = $field_storage['field_name'];
     $this->field['field_name'] = $field_name;
@@ -145,7 +136,7 @@ class FormTest extends FieldTestBase {
     ];
     $this->submitForm($edit, 'Save');
     $this->assertSession()->pageTextContains("{$this->field['label']} does not accept the value -1.");
-    // TODO : check that the correct field is flagged for error.
+    // @todo check that the correct field is flagged for error.
 
     // Create an entity
     $value = mt_rand(1, 127);
@@ -173,7 +164,6 @@ class FormTest extends FieldTestBase {
     ];
     $this->submitForm($edit, 'Save');
     $this->assertSession()->pageTextContains('entity_test ' . $id . ' has been updated.');
-    $this->container->get('entity_type.manager')->getStorage('entity_test')->resetCache([$id]);
     $entity = EntityTest::load($id);
     $this->assertEquals($value, $entity->{$field_name}->value, 'Field value was updated');
 
@@ -185,7 +175,6 @@ class FormTest extends FieldTestBase {
     $this->drupalGet('entity_test/manage/' . $id . '/edit');
     $this->submitForm($edit, 'Save');
     $this->assertSession()->pageTextContains('entity_test ' . $id . ' has been updated.');
-    $this->container->get('entity_type.manager')->getStorage('entity_test')->resetCache([$id]);
     $entity = EntityTest::load($id);
     $this->assertTrue($entity->{$field_name}->isEmpty(), 'Field was emptied');
   }
@@ -193,7 +182,7 @@ class FormTest extends FieldTestBase {
   /**
    * Tests field widget default values on entity forms.
    */
-  public function testFieldFormDefaultValue() {
+  public function testFieldFormDefaultValue(): void {
     $field_storage = $this->fieldStorageSingle;
     $field_name = $field_storage['field_name'];
     $this->field['field_name'] = $field_name;
@@ -223,7 +212,10 @@ class FormTest extends FieldTestBase {
     $this->assertTrue($entity->{$field_name}->isEmpty(), 'Field is now empty.');
   }
 
-  public function testFieldFormSingleRequired() {
+  /**
+   * Tests the required single-value field form.
+   */
+  public function testFieldFormSingleRequired(): void {
     $field_storage = $this->fieldStorageSingle;
     $field_name = $field_storage['field_name'];
     $this->field['field_name'] = $field_name;
@@ -263,7 +255,10 @@ class FormTest extends FieldTestBase {
     $this->assertSession()->pageTextContains("{$this->field['label']} field is required.");
   }
 
-  public function testFieldFormUnlimited() {
+  /**
+   * Tests the unlimited-value field form.
+   */
+  public function testFieldFormUnlimited(): void {
     $field_storage = $this->fieldStorageUnlimited;
     $field_name = $field_storage['field_name'];
     $this->field['field_name'] = $field_name;
@@ -294,7 +289,7 @@ class FormTest extends FieldTestBase {
     $this->assertSession()->fieldValueEquals("{$field_name}[1][value]", '');
     // Verify that no extraneous widget is displayed.
     $this->assertSession()->fieldNotExists("{$field_name}[2][value]");
-    // TODO : check that non-field inputs are preserved ('title'), etc.
+    // @todo check that non-field inputs are preserved ('title'), etc.
 
     // Yet another time so that we can play with more values -> 3 widgets.
     $this->submitForm([], 'Add another item');
@@ -358,7 +353,7 @@ class FormTest extends FieldTestBase {
   /**
    * Tests the position of the required label.
    */
-  public function testFieldFormUnlimitedRequired() {
+  public function testFieldFormUnlimitedRequired(): void {
     $field_name = $this->fieldStorageUnlimited['field_name'];
     $this->field['field_name'] = $field_name;
     $this->field['required'] = TRUE;
@@ -371,7 +366,8 @@ class FormTest extends FieldTestBase {
 
     // Display creation form -> 1 widget.
     $this->drupalGet('entity_test/add');
-    // Check that the Required symbol is present for the multifield label.
+    // Check that the Required symbol is present for the label of the field
+    // with unlimited cardinality.
     $this->assertSession()->elementAttributeContains('xpath', "//h4[contains(@class, 'label') and contains(text(), '{$this->field['label']}')]", 'class', 'js-form-required');
     // Check that the label of the field input is visually hidden and contains
     // the field title and an indication of the delta for a11y.
@@ -381,7 +377,7 @@ class FormTest extends FieldTestBase {
   /**
    * Tests widget handling of multiple required radios.
    */
-  public function testFieldFormMultivalueWithRequiredRadio() {
+  public function testFieldFormMultivalueWithRequiredRadio(): void {
     /** @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface $display_repository */
     $display_repository = \Drupal::service('entity_display.repository');
 
@@ -433,66 +429,10 @@ class FormTest extends FieldTestBase {
     $this->assertSession()->fieldNotExists("{$field_name}[2][value]");
   }
 
-  /**
-   * Tests widgets handling multiple values.
-   */
-  public function testFieldFormMultipleWidget() {
-    // Create a field with fixed cardinality, configure the form to use a
-    // "multiple" widget.
-    $field_storage = $this->fieldStorageMultiple;
-    $field_name = $field_storage['field_name'];
-    $this->field['field_name'] = $field_name;
-    FieldStorageConfig::create($field_storage)->save();
-    FieldConfig::create($this->field)->save();
-    $form = \Drupal::service('entity_display.repository')->getFormDisplay($this->field['entity_type'], $this->field['bundle'], 'default')
-      ->setComponent($field_name, [
-        'type' => 'test_field_widget_multiple',
-      ]);
-    $form->save();
-    $session = $this->assertSession();
-
-    // Display creation form.
-    $this->drupalGet('entity_test/add');
-    $this->assertSession()->fieldValueEquals($field_name, '');
-
-    // Create entity with three values.
-    $edit = [
-      $field_name => '1, 2, 3',
-    ];
-    $this->submitForm($edit, 'Save');
-    preg_match('|entity_test/manage/(\d+)|', $this->getUrl(), $match);
-    $id = $match[1];
-
-    // Check that the values were saved.
-    $entity_init = EntityTest::load($id);
-    $this->assertFieldValues($entity_init, $field_name, [1, 2, 3]);
-
-    // Display the form, check that the values are correctly filled in.
-    $this->drupalGet('entity_test/manage/' . $id . '/edit');
-    $this->assertSession()->fieldValueEquals($field_name, '1, 2, 3');
-
-    // Submit the form with more values than the field accepts.
-    $edit = [$field_name => '1, 2, 3, 4, 5'];
-    $this->submitForm($edit, 'Save');
-    $this->assertSession()->pageTextContains('this field cannot hold more than 4 values');
-    // Check that the field values were not submitted.
-    $this->assertFieldValues($entity_init, $field_name, [1, 2, 3]);
-
-    // Check that Attributes are rendered on the multivalue container if it is
-    // a multiple widget form.
-    $form->setComponent($field_name, [
-      'type' => 'entity_reference_autocomplete',
-    ])
-      ->save();
-    $this->drupalGet('entity_test/manage/' . $id . '/edit');
-    $name = str_replace('_', '-', $field_name);
-    $session->responseContains('data-drupal-selector="edit-' . $name . '"');
-  }
-
   /**
    * Tests fields with no 'edit' access.
    */
-  public function testFieldFormAccess() {
+  public function testFieldFormAccess(): void {
     /** @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface $display_repository */
     $display_repository = \Drupal::service('entity_display.repository');
 
@@ -573,7 +513,6 @@ class FormTest extends FieldTestBase {
     $this->submitForm($edit, 'Save');
 
     // Check that the new revision has the expected values.
-    $storage->resetCache([$id]);
     $entity = $storage->load($id);
     $this->assertEquals(99, $entity->{$field_name_no_access}->value, 'New revision has the expected value for the field with no edit access.');
     $this->assertEquals(2, $entity->{$field_name}->value, 'New revision has the expected value for the field with edit access.');
@@ -590,7 +529,7 @@ class FormTest extends FieldTestBase {
   /**
    * Tests hiding a field in a form.
    */
-  public function testHiddenField() {
+  public function testHiddenField(): void {
     $entity_type = 'entity_test_rev';
     $field_storage = $this->fieldStorageSingle;
     $field_storage['entity_type'] = $entity_type;
@@ -641,7 +580,6 @@ class FormTest extends FieldTestBase {
     $edit = ["{$field_name}[0][value]" => $value];
     $this->submitForm($edit, 'Save');
     $this->assertSession()->pageTextContains('entity_test_rev ' . $id . ' has been updated.');
-    $storage->resetCache([$id]);
     $entity = $storage->load($id);
     $this->assertEquals($value, $entity->{$field_name}->value, 'Field value was updated');
 
@@ -665,10 +603,13 @@ class FormTest extends FieldTestBase {
   /**
    * Tests the form display of the label for multi-value fields.
    */
-  public function testLabelOnMultiValueFields() {
+  public function testLabelOnMultiValueFields(): void {
     $user = $this->drupalCreateUser(['administer entity_test content']);
     $this->drupalLogin($user);
 
+    // Ensure that the 'bar' bundle exists, to avoid config validation errors.
+    EntityTestHelper::createBundle('bar', entity_type: 'entity_test_base_field_display');
+
     FieldStorageConfig::create([
       'entity_type' => 'entity_test_base_field_display',
       'field_name' => 'foo',
@@ -698,68 +639,4 @@ class FormTest extends FieldTestBase {
     $this->assertSession()->assertEscaped("<script>alert('a configurable field');</script>");
   }
 
-  /**
-   * Tests hook_field_widget_complete_form_alter().
-   */
-  public function testFieldFormMultipleWidgetAlter() {
-    $this->widgetAlterTest('hook_field_widget_complete_form_alter', 'test_field_widget_multiple');
-  }
-
-  /**
-   * Tests hook_field_widget_complete_form_alter() with single value elements.
-   */
-  public function testFieldFormMultipleWidgetAlterSingleValues() {
-    $this->widgetAlterTest('hook_field_widget_complete_form_alter', 'test_field_widget_multiple_single_value');
-  }
-
-  /**
-   * Tests hook_field_widget_complete_WIDGET_TYPE_form_alter().
-   */
-  public function testFieldFormMultipleWidgetTypeAlter() {
-    $this->widgetAlterTest('hook_field_widget_complete_WIDGET_TYPE_form_alter', 'test_field_widget_multiple');
-  }
-
-  /**
-   * Tests hook_field_widget_complete_WIDGET_TYPE_form_alter() with single value elements.
-   */
-  public function testFieldFormMultipleWidgetTypeAlterSingleValues() {
-    $this->widgetAlterTest('hook_field_widget_complete_WIDGET_TYPE_form_alter', 'test_field_widget_multiple_single_value');
-  }
-
-  /**
-   * Tests widget alter hooks for a given hook name.
-   */
-  protected function widgetAlterTest($hook, $widget) {
-    // Create a field with fixed cardinality, configure the form to use a
-    // "multiple" widget.
-    $field_storage = $this->fieldStorageMultiple;
-    $field_name = $field_storage['field_name'];
-    $this->field['field_name'] = $field_name;
-    FieldStorageConfig::create($field_storage)->save();
-    FieldConfig::create($this->field)->save();
-
-    // Set a flag in state so that the hook implementations will run.
-    \Drupal::state()->set("field_test.widget_alter_test", [
-      'hook' => $hook,
-      'field_name' => $field_name,
-      'widget' => $widget,
-    ]);
-    \Drupal::service('entity_display.repository')->getFormDisplay($this->field['entity_type'], $this->field['bundle'], 'default')
-      ->setComponent($field_name, [
-        'type' => $widget,
-      ])
-      ->save();
-
-    // We need to rebuild hook information after setting the component through
-    // the API.
-    $this->rebuildAll();
-
-    $this->drupalGet('entity_test/add');
-    $this->assertSession()->pageTextMatchesCount(1, '/From ' . $hook . '.* prefix on ' . $field_name . ' parent element\./');
-    if ($widget === 'test_field_widget_multiple_single_value') {
-      $suffix_text = "From $hook(): suffix on $field_name child element.";
-      $this->assertEquals($field_storage['cardinality'], substr_count($this->getTextContent(), $suffix_text), "'$suffix_text' was found {$field_storage['cardinality']} times  using widget $widget");
-    }
-  }
-
 }
