@@ -1,7 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\field\Kernel;
 
+use Drupal\entity_test\EntityTestHelper;
 use Drupal\field\Entity\FieldConfig;
 
 /**
@@ -12,7 +15,7 @@ use Drupal\field\Entity\FieldConfig;
 class FieldImportChangeTest extends FieldKernelTestBase {
 
   /**
-   * Modules to enable.
+   * Modules to install.
    *
    * The default configuration provided by field_test_config is imported by
    * \Drupal\Tests\field\Kernel\FieldKernelTestBase::setUp() when it installs
@@ -25,7 +28,9 @@ class FieldImportChangeTest extends FieldKernelTestBase {
   /**
    * Tests importing an updated field.
    */
-  public function testImportChange() {
+  public function testImportChange(): void {
+    EntityTestHelper::createBundle('test_bundle');
+
     $this->installConfig(['field_test_config']);
     $field_storage_id = 'field_test_import';
     $field_id = "entity_test.entity_test.$field_storage_id";
