@@ -1,17 +1,18 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\file\Functional;
 
 /**
  * Tests file formatter access.
+ *
  * @group file
  */
 class FileFieldFormatterAccessTest extends FileFieldTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['node', 'file', 'field_ui', 'file_test'];
 
@@ -23,7 +24,7 @@ class FileFieldFormatterAccessTest extends FileFieldTestBase {
   /**
    * Tests the custom access handler is invoked.
    */
-  public function testFileAccessHandler() {
+  public function testFileAccessHandler(): void {
     $type_name = 'article';
     $field_name = $this->randomMachineName();
     $this->createFileField($field_name, 'node', $type_name);
