@@ -1,11 +1,17 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\file\Functional\Rest;
 
 use Drupal\file\Entity\File;
 use Drupal\Tests\rest\Functional\EntityResource\EntityResourceTestBase;
 use Drupal\user\Entity\User;
+use PHPUnit\Framework\Attributes\Before;
 
+/**
+ * Resource test base for file entity.
+ */
 abstract class FileResourceTestBase extends EntityResourceTestBase {
 
   /**
@@ -39,6 +45,22 @@ abstract class FileResourceTestBase extends EntityResourceTestBase {
    */
   protected $author;
 
+  /**
+   * Marks some tests as skipped because XML cannot be deserialized.
+   */
+  #[Before]
+  public function fileResourceTestBaseSkipTests(): void {
+    if ($this->name() === 'testPost') {
+      // Drupal does not allow creating file entities independently. It allows
+      // you to create file entities that are referenced from another entity
+      // (e.g. an image for a node's image field).
+      // For that purpose, there is the "file_upload" REST resource plugin.
+      // @see \Drupal\file\FileAccessControlHandler::checkCreateAccess()
+      // @see \Drupal\file\Plugin\rest\resource\FileUploadResource
+      $this->markTestSkipped('Drupal does not allow creating file entities independently.');
+    }
+  }
+
   /**
    * {@inheritdoc}
    */
@@ -195,19 +217,6 @@ abstract class FileResourceTestBase extends EntityResourceTestBase {
     ];
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function testPost() {
-    // Drupal does not allow creating file entities independently. It allows you
-    // to create file entities that are referenced from another entity (e.g. an
-    // image for a node's image field).
-    // For that purpose, there is the "file_upload" REST resource plugin.
-    // @see \Drupal\file\FileAccessControlHandler::checkCreateAccess()
-    // @see \Drupal\file\Plugin\rest\resource\FileUploadResource
-    $this->markTestSkipped();
-  }
-
   /**
    * {@inheritdoc}
    */
