@@ -11,13 +11,6 @@ use Drupal\Core\Form\FormStateInterface;
  */
 class FilterFormatAddForm extends FilterFormatFormBase {
 
-  /**
-   * {@inheritdoc}
-   */
-  public function form(array $form, FormStateInterface $form_state) {
-    return parent::form($form, $form_state);
-  }
-
   /**
    * {@inheritdoc}
    */
