@@ -327,16 +327,16 @@ class ImageItem extends FileItem {
   public function preSave() {
     parent::preSave();
 
-    $width = $this->width;
-    $height = $this->height;
+    $width = $this->get('width')->getValue();
+    $height = $this->get('height')->getValue();
 
     // Determine the dimensions if necessary.
     if ($this->entity && $this->entity instanceof EntityInterface) {
-      if (empty($width) || empty($height)) {
+      if ($width === NULL || $height === NULL) {
         $image = \Drupal::service('image.factory')->get($this->entity->getFileUri());
         if ($image->isValid()) {
-          $this->width = $image->getWidth();
-          $this->height = $image->getHeight();
+          $this->set('width', $image->getWidth());
+          $this->set('height', $image->getHeight());
         }
       }
     }
@@ -389,7 +389,9 @@ class ImageItem extends FileItem {
         $image->setFileName($file_system->basename($path));
         $destination_dir = static::doGetUploadLocation($settings);
         $file_system->prepareDirectory($destination_dir, FileSystemInterface::CREATE_DIRECTORY);
-        $destination = $destination_dir . '/' . basename($path);
+        // Ensure directory ends with a slash.
+        $destination_dir .= str_ends_with($destination_dir, '/') ? '' : '/';
+        $destination = $destination_dir . basename($path);
         $file = \Drupal::service('file.repository')->move($image, $destination);
         $images[$extension][$min_resolution][$max_resolution][$file->id()] = $file;
       }
@@ -421,8 +423,9 @@ class ImageItem extends FileItem {
     if (!empty($element['x']['#value']) || !empty($element['y']['#value'])) {
       foreach (['x', 'y'] as $dimension) {
         if (!$element[$dimension]['#value']) {
-          // We expect the field name placeholder value to be wrapped in $this->t()
-          // here, so it won't be escaped again as it's already marked safe.
+          // We expect the field name placeholder value to be wrapped in
+          // $this->t() here, so it won't be escaped again as it's already
+          // marked safe.
           $form_state->setError($element[$dimension], new TranslatableMarkup('Both a height and width value must be specified in the @name field.', ['@name' => $element['#title']]));
           return;
         }
