@@ -1,14 +1,19 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\locale\Functional;
 
 use Drupal\Core\Site\Settings;
+use Drupal\Core\StringTranslation\StringTranslationTrait;
 use Drupal\Core\Url;
 use Drupal\Core\Database\Database;
 use Drupal\language\Entity\ConfigurableLanguage;
 use Drupal\Tests\BrowserTestBase;
 use Drupal\Core\Language\LanguageInterface;
 
+// phpcs:disable Drupal.Semantics.FunctionT.NotLiteralString
+
 /**
  * Tests the validation of translation strings and search results.
  *
@@ -16,10 +21,10 @@ use Drupal\Core\Language\LanguageInterface;
  */
 class LocaleTranslationUiTest extends BrowserTestBase {
 
+  use StringTranslationTrait;
+
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['locale'];
 
@@ -28,10 +33,15 @@ class LocaleTranslationUiTest extends BrowserTestBase {
    */
   protected $defaultTheme = 'stark';
 
+  /**
+   * {@inheritdoc}
+   */
+  protected bool $useOneTimeLoginLinks = FALSE;
+
   /**
    * Enable interface translation to English.
    */
-  public function testEnglishTranslation() {
+  public function testEnglishTranslation(): void {
     $admin_user = $this->drupalCreateUser([
       'administer languages',
       'access administration pages',
@@ -46,7 +56,7 @@ class LocaleTranslationUiTest extends BrowserTestBase {
   /**
    * Adds a language and tests string translation by users with the appropriate permissions.
    */
-  public function testStringTranslation() {
+  public function testStringTranslation(): void {
     // User to add and remove language.
     $admin_user = $this->drupalCreateUser([
       'administer languages',
@@ -76,7 +86,7 @@ class LocaleTranslationUiTest extends BrowserTestBase {
     $this->drupalGet('admin/config/regional/language/add');
     $this->submitForm($edit, 'Add custom language');
     // Add string.
-    t($name, [], ['langcode' => $langcode])->render();
+    $this->t($name, [], ['langcode' => $langcode])->render();
     // Reset locale cache.
     $this->container->get('string_translation')->reset();
     $this->assertSession()->responseContains('"edit-languages-' . $langcode . '-weight"');
@@ -158,15 +168,15 @@ class LocaleTranslationUiTest extends BrowserTestBase {
     $this->assertSession()->pageTextContains($translation_to_en);
 
     $this->assertNotEquals($translation, $name);
-    $this->assertEquals($translation, t($name, [], ['langcode' => $langcode]), 't() works for non-English.');
+    $this->assertEquals($translation, $this->t($name, [], ['langcode' => $langcode]), 't() works for non-English.');
     // Refresh the locale() cache to get fresh data from t() below. We are in
     // the same HTTP request and therefore t() is not refreshed by saving the
     // translation above.
     $this->container->get('string_translation')->reset();
     // Now we should get the proper fresh translation from t().
     $this->assertNotEquals($translation_to_en, $name);
-    $this->assertEquals($translation_to_en, t($name, [], ['langcode' => 'en']), 't() works for English.');
-    $this->assertTrue(t($name, [], ['langcode' => LanguageInterface::LANGCODE_SYSTEM]) == $name, 't() works for LanguageInterface::LANGCODE_SYSTEM.');
+    $this->assertEquals($translation_to_en, $this->t($name, [], ['langcode' => 'en']), 't() works for English.');
+    $this->assertTrue($this->t($name, [], ['langcode' => LanguageInterface::LANGCODE_SYSTEM]) == $name, 't() works for LanguageInterface::LANGCODE_SYSTEM.');
 
     $search = [
       'string' => $name,
@@ -247,7 +257,7 @@ class LocaleTranslationUiTest extends BrowserTestBase {
   /**
    * Tests the rebuilding of JavaScript translation files on deletion.
    */
-  public function testJavaScriptTranslation() {
+  public function testJavaScriptTranslation(): void {
     $user = $this->drupalCreateUser([
       'translate interface',
       'administer languages',
@@ -328,7 +338,7 @@ class LocaleTranslationUiTest extends BrowserTestBase {
   /**
    * Tests the validation of the translation input.
    */
-  public function testStringValidation() {
+  public function testStringValidation(): void {
     // User to add language and strings.
     $admin_user = $this->drupalCreateUser([
       'administer languages',
@@ -360,7 +370,7 @@ class LocaleTranslationUiTest extends BrowserTestBase {
     $this->drupalGet('admin/config/regional/language/add');
     $this->submitForm($edit, 'Add custom language');
     // Add string.
-    t($name, [], ['langcode' => $langcode])->render();
+    $this->t($name, [], ['langcode' => $langcode])->render();
     // Reset locale cache.
     $search = [
       'string' => $name,
@@ -389,7 +399,7 @@ class LocaleTranslationUiTest extends BrowserTestBase {
   /**
    * Tests translation search form.
    */
-  public function testStringSearch() {
+  public function testStringSearch(): void {
     // User to add and remove language.
     $admin_user = $this->drupalCreateUser([
       'administer languages',
@@ -429,7 +439,7 @@ class LocaleTranslationUiTest extends BrowserTestBase {
     $this->submitForm($edit, 'Add custom language');
 
     // Add string.
-    t($name, [], ['langcode' => $langcode])->render();
+    $this->t($name, [], ['langcode' => $langcode])->render();
     // Reset locale cache.
     $this->container->get('string_translation')->reset();
     $this->drupalLogout();
@@ -549,7 +559,7 @@ class LocaleTranslationUiTest extends BrowserTestBase {
   /**
    * Tests that only changed strings are saved customized when edited.
    */
-  public function testUICustomizedStrings() {
+  public function testUICustomizedStrings(): void {
     $user = $this->drupalCreateUser([
       'translate interface',
       'administer languages',
