@@ -1,12 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\locale\Kernel;
 
+use Drupal\KernelTests\KernelTestBase;
 use Drupal\language\Entity\ConfigurableLanguage;
-use Drupal\locale\Locale;
 use Drupal\locale\StringInterface;
 use Drupal\locale\TranslationString;
-use Drupal\KernelTests\KernelTestBase;
 
 /**
  * Tests that shipped configuration translations are updated correctly.
@@ -67,8 +68,9 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
     // @see locale_system_update()
     locale_system_set_config_langcodes();
     $langcodes = array_keys(\Drupal::languageManager()->getLanguages());
-    $names = Locale::config()->getComponentNames();
-    Locale::config()->updateConfigTranslations($names, $langcodes);
+    $locale_config_manager = \Drupal::service('locale.config_manager');
+    $names = $locale_config_manager->getComponentNames();
+    $locale_config_manager->updateConfigTranslations($names, $langcodes);
 
     $this->configFactory = $this->container->get('config.factory');
     $this->stringStorage = $this->container->get('locale.storage');
@@ -81,21 +83,21 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * Sets up default language for this test.
    */
-  protected function setUpDefaultLanguage() {
+  protected function setUpDefaultLanguage(): void {
     // Keep the default English.
   }
 
   /**
    * Sets up languages needed for this test.
    */
-  protected function setUpLanguages() {
+  protected function setUpLanguages(): void {
     ConfigurableLanguage::createFromLangcode('de')->save();
   }
 
   /**
    * Sets up the locale storage strings to be in line with configuration.
    */
-  protected function setUpLocale() {
+  protected function setUpLocale(): void {
     // Set up the locale database the same way we have in the config samples.
     $this->setUpNoTranslation('locale_test.no_translation', 'test', 'Test', 'de');
     $this->setUpTranslation('locale_test.translation', 'test', 'English test', 'German test', 'de');
@@ -105,7 +107,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * Tests creating translations of shipped configuration.
    */
-  public function testCreateTranslation() {
+  public function testCreateTranslation(): void {
     $config_name = 'locale_test.no_translation';
 
     $this->saveLanguageOverride($config_name, 'test', 'Test (German)', 'de');
@@ -115,11 +117,25 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * Tests creating translations configuration with multi value settings.
    */
-  public function testCreateTranslationMultiValue() {
+  public function testCreateTranslationMultiValue(): void {
     $config_name = 'locale_test.translation_multiple';
 
-    $this->saveLanguageOverride($config_name, 'test_multiple', ['string' => 'String (German)', 'another_string' => 'Another string (German)'], 'de');
-    $this->saveLanguageOverride($config_name, 'test_after_multiple', ['string' => 'After string (German)', 'another_string' => 'After another string (German)'], 'de');
+    $this->saveLanguageOverride(
+      $config_name,
+      'test_multiple',
+      [
+        'string' => 'String (German)',
+        'another_string' => 'Another string (German)',
+      ],
+      'de');
+    $this->saveLanguageOverride(
+      $config_name,
+      'test_after_multiple',
+      [
+        'string' => 'After string (German)',
+        'another_string' => 'After another string (German)',
+      ],
+      'de');
     $strings = $this->stringStorage->getTranslations([
       'type' => 'configuration',
       'name' => $config_name,
@@ -132,7 +148,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * Tests importing community translations of shipped configuration.
    */
-  public function testLocaleCreateTranslation() {
+  public function testLocaleCreateTranslation(): void {
     $config_name = 'locale_test.no_translation';
 
     $this->saveLocaleTranslationData($config_name, 'test', 'Test', 'Test (German)', 'de');
@@ -142,7 +158,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * Tests updating translations of shipped configuration.
    */
-  public function testUpdateTranslation() {
+  public function testUpdateTranslation(): void {
     $config_name = 'locale_test.translation';
 
     $this->saveLanguageOverride($config_name, 'test', 'Updated German test', 'de');
@@ -152,7 +168,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * Tests updating community translations of shipped configuration.
    */
-  public function testLocaleUpdateTranslation() {
+  public function testLocaleUpdateTranslation(): void {
     $config_name = 'locale_test.translation';
 
     $this->saveLocaleTranslationData($config_name, 'test', 'English test', 'Updated German test', 'de');
@@ -162,7 +178,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * Tests deleting translations of shipped configuration.
    */
-  public function testDeleteTranslation() {
+  public function testDeleteTranslation(): void {
     $config_name = 'locale_test.translation';
 
     $this->deleteLanguageOverride($config_name, 'test', 'English test', 'de');
@@ -175,7 +191,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * Tests deleting community translations of shipped configuration.
    */
-  public function testLocaleDeleteTranslation() {
+  public function testLocaleDeleteTranslation(): void {
     $config_name = 'locale_test.translation';
 
     $this->deleteLocaleTranslationData($config_name, 'test', 'English test', 'de');
@@ -199,7 +215,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    * @param string $langcode
    *   The language code.
    */
-  protected function setUpNoTranslation($config_name, $key, $source, $langcode) {
+  protected function setUpNoTranslation($config_name, $key, $source, $langcode): void {
     $this->localeConfigManager->updateConfigTranslations([$config_name], [$langcode]);
     $this->assertNoConfigOverride($config_name, $key);
     $this->assertNoTranslation($config_name, $langcode);
@@ -226,7 +242,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    * @param bool $is_active
    *   Whether the update will affect the active configuration.
    */
-  protected function setUpTranslation($config_name, $key, $source, $translation, $langcode, $is_active = FALSE) {
+  protected function setUpTranslation($config_name, $key, $source, $translation, $langcode, $is_active = FALSE): void {
     // Create source and translation strings for the configuration value and add
     // the configuration name as a location. This would be performed by
     // locale_translate_batch_import() invoking
@@ -268,7 +284,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    * @param string $langcode
    *   The language code.
    */
-  protected function saveLanguageOverride($config_name, $key, $value, $langcode) {
+  protected function saveLanguageOverride($config_name, $key, $value, $langcode): void {
     $translation_override = $this->languageManager
       ->getLanguageConfigOverride($langcode, $config_name);
     $translation_override
@@ -301,7 +317,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    * @param bool $is_active
    *   Whether the update will affect the active configuration.
    */
-  protected function saveLocaleTranslationData($config_name, $key, $source, $translation, $langcode, $is_active = FALSE) {
+  protected function saveLocaleTranslationData($config_name, $key, $source, $translation, $langcode, $is_active = FALSE): void {
     $this->localeConfigManager->reset();
     $this->localeConfigManager
       ->getStringTranslation($config_name, $langcode, $source, '')
@@ -338,7 +354,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    * @param string $langcode
    *   The language code.
    */
-  protected function deleteLanguageOverride($config_name, $key, $source_value, $langcode) {
+  protected function deleteLanguageOverride($config_name, $key, $source_value, $langcode): void {
     $translation_override = $this->languageManager
       ->getLanguageConfigOverride($langcode, $config_name);
     $translation_override
@@ -368,7 +384,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    * @param string $langcode
    *   The language code.
    */
-  protected function deleteLocaleTranslationData($config_name, $key, $source_value, $langcode) {
+  protected function deleteLocaleTranslationData($config_name, $key, $source_value, $langcode): void {
     $this->localeConfigManager
       ->getStringTranslation($config_name, $langcode, $source_value, '')
       ->delete();
