@@ -16,10 +16,10 @@ class AuditException extends \RuntimeException {
    *   The migration that caused the exception.
    * @param string $message
    *   The reason the audit failed.
-   * @param \Exception $previous
+   * @param \Throwable $previous
    *   (optional) The previous exception.
    */
-  public function __construct(MigrationInterface $migration, $message, \Exception $previous = NULL) {
+  public function __construct(MigrationInterface $migration, $message, ?\Throwable $previous = NULL) {
     $message = sprintf('Cannot audit migration %s: %s', $migration->id(), $message);
     parent::__construct($message, 0, $previous);
   }
