@@ -5,6 +5,7 @@ namespace Drupal\migrate\Plugin\migrate\source;
 use Drupal\Core\Database\ConnectionNotDefinedException;
 use Drupal\Core\Database\Database;
 use Drupal\Core\Database\DatabaseException;
+use Drupal\Core\Database\Statement\FetchAs;
 use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
 use Drupal\Core\State\StateInterface;
 use Drupal\migrate\Exception\RequirementsException;
@@ -133,7 +134,7 @@ abstract class SqlBase extends SourcePluginBase implements ContainerFactoryPlugi
    *   The query string.
    */
   public function __toString() {
-    return (string) $this->query();
+    return (string) $this->prepareQuery();
   }
 
   /**
@@ -224,7 +225,7 @@ abstract class SqlBase extends SourcePluginBase implements ContainerFactoryPlugi
    * Wrapper for database select.
    */
   protected function select($table, $alias = NULL, array $options = []) {
-    $options['fetch'] = \PDO::FETCH_ASSOC;
+    $options['fetch'] = FetchAs::Associative;
     return $this->getDatabase()->select($table, $alias, $options);
   }
 
@@ -265,13 +266,13 @@ abstract class SqlBase extends SourcePluginBase implements ContainerFactoryPlugi
       // The rules for determining what conditions to add to the query are as
       // follows (applying first applicable rule):
       // 1. If the map is joinable, join it. We will want to accept all rows
-      //    which are either not in the map, or marked in the map as NEEDS_UPDATE.
-      //    Note that if high water fields are in play, we want to accept all rows
-      //    above the high water mark in addition to those selected by the map
-      //    conditions, so we need to OR them together (but AND with any existing
-      //    conditions in the query). So, ultimately the SQL condition will look
-      //    like (original conditions) AND (map IS NULL OR map needs update
-      //    OR above high water).
+      //    which are either not in the map, or marked in the map as
+      //    NEEDS_UPDATE. Note that if high water fields are in play, we want to
+      //    accept all rows above the high water mark in addition to those
+      //    selected by the map conditions, so we need to OR them together (but
+      //    AND with any existing conditions in the query). So, ultimately the
+      //    SQL condition will look like (original conditions) AND (map IS NULL
+      //    OR map needs update OR above high water).
       $conditions = $this->query->orConditionGroup();
       $condition_added = FALSE;
       $added_fields = [];
@@ -347,7 +348,7 @@ abstract class SqlBase extends SourcePluginBase implements ContainerFactoryPlugi
       $this->query->range($this->batch * $this->batchSize, $this->batchSize);
     }
     $statement = $this->query->execute();
-    $statement->setFetchMode(\PDO::FETCH_ASSOC);
+    $statement->setFetchMode(FetchAs::Associative);
     return new \IteratorIterator($statement);
   }
 
@@ -383,7 +384,13 @@ abstract class SqlBase extends SourcePluginBase implements ContainerFactoryPlugi
   }
 
   /**
+   * Prepares query object to retrieve data from the source database.
+   *
+   * This method should not be called directly. It is called automatically from
+   * SqlBase::prepareQuery().
+   *
    * @return \Drupal\Core\Database\Query\SelectInterface
+   *   A Select query object with the source data.
    */
   abstract public function query();
 
@@ -391,7 +398,7 @@ abstract class SqlBase extends SourcePluginBase implements ContainerFactoryPlugi
    * Gets the source count using countQuery().
    */
   protected function doCount() {
-    return (int) $this->query()->countQuery()->execute()->fetchField();
+    return (int) $this->prepareQuery()->countQuery()->execute()->fetchField();
   }
 
   /**
