@@ -4,9 +4,7 @@ declare(strict_types=1);
 
 namespace Drupal\Tests\migrate\Unit;
 
-use Drupal\Core\DependencyInjection\ContainerBuilder;
 use Drupal\sqlite\Driver\Database\sqlite\Connection;
-use Drupal\migrate\Plugin\MigrationPluginManager;
 use Drupal\migrate\Plugin\MigrationInterface;
 use Drupal\migrate\MigrateException;
 use Drupal\migrate\Plugin\MigrateIdMapInterface;
@@ -72,7 +70,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * @param array $map
    *   The row to save.
    */
-  protected function saveMap(array $map) {
+  protected function saveMap(array $map): void {
     $table = 'migrate_map_sql_idmap_test';
 
     $schema = $this->database->schema();
@@ -136,7 +134,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    *   - rollback_action
    *   - hash
    */
-  protected function idMapDefaults() {
+  protected function idMapDefaults(): array {
     $defaults = [
       'source_row_status' => MigrateIdMapInterface::STATUS_IMPORTED,
       'rollback_action' => MigrateIdMapInterface::ROLLBACK_DELETE,
@@ -163,7 +161,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * - saving new to nonempty tables work.
    * - updating work.
    */
-  public function testSaveIdMapping() {
+  public function testSaveIdMapping(): void {
     $source = [
       'source_id_property' => 'source_value',
     ];
@@ -197,7 +195,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests the SQL ID map set message method.
    */
-  public function testSetMessage() {
+  public function testSetMessage(): void {
     $message = $this->createMock('Drupal\migrate\MigrateMessageInterface');
     $id_map = $this->getIdMap();
     $id_map->setMessage($message);
@@ -207,7 +205,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests the clear messages method.
    */
-  public function testClearMessages() {
+  public function testClearMessages(): void {
     $message = 'Hello world.';
     $expected_results = [0, 1, 2, 3];
     $id_map = $this->getIdMap();
@@ -227,7 +225,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests the getRowsNeedingUpdate method for rows that need an update.
    */
-  public function testGetRowsNeedingUpdate() {
+  public function testGetRowsNeedingUpdate(): void {
     $id_map = $this->getIdMap();
     $row_statuses = [
       MigrateIdMapInterface::STATUS_IMPORTED,
@@ -283,7 +281,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests the SQL ID map message count method by counting and saving messages.
    */
-  public function testMessageCount() {
+  public function testMessageCount(): void {
     $message = 'Hello world.';
     $expected_results = [0, 1, 2, 3];
     $id_map = $this->getIdMap();
@@ -299,7 +297,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests the SQL ID map save message method.
    */
-  public function testMessageSave() {
+  public function testMessageSave(): void {
     $message = 'Hello world.';
     $original_values = [
       1 => ['message' => $message, 'level' => MigrationInterface::MESSAGE_ERROR],
@@ -308,10 +306,22 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
       4 => ['message' => $message, 'level' => MigrationInterface::MESSAGE_INFORMATIONAL],
     ];
     $expected_results = [
-      '7ad742edb7e866caa78ced1e4455d2e9cbd8adb2074e7c323d21b4e67732e755' => ['message' => $message, 'level' => MigrationInterface::MESSAGE_ERROR],
-      '2d3ec2b0c547e819346e6ae03f881fd9f5c978ff3cbe29dfb807d40735e53703' => ['message' => $message, 'level' => MigrationInterface::MESSAGE_WARNING],
-      '12a042f72cad9a2a8c7715df0c7695d762975f0687d87f5d480725dae1432a6f' => ['message' => $message, 'level' => MigrationInterface::MESSAGE_NOTICE],
-      'd9d1fd27a2447ace48f47a2e9ff649673f67b446d9381a7963c949fc083f8791' => ['message' => $message, 'level' => MigrationInterface::MESSAGE_INFORMATIONAL],
+      '7ad742edb7e866caa78ced1e4455d2e9cbd8adb2074e7c323d21b4e67732e755' => [
+        'message' => $message,
+        'level' => MigrationInterface::MESSAGE_ERROR,
+      ],
+      '2d3ec2b0c547e819346e6ae03f881fd9f5c978ff3cbe29dfb807d40735e53703' => [
+        'message' => $message,
+        'level' => MigrationInterface::MESSAGE_WARNING,
+      ],
+      '12a042f72cad9a2a8c7715df0c7695d762975f0687d87f5d480725dae1432a6f' => [
+        'message' => $message,
+        'level' => MigrationInterface::MESSAGE_NOTICE,
+      ],
+      'd9d1fd27a2447ace48f47a2e9ff649673f67b446d9381a7963c949fc083f8791' => [
+        'message' => $message,
+        'level' => MigrationInterface::MESSAGE_INFORMATIONAL,
+      ],
     ];
     $id_map = $this->getIdMap();
 
@@ -350,7 +360,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests the getRowBySource method.
    */
-  public function testGetRowBySource() {
+  public function testGetRowBySource(): void {
     $this->getDatabase([]);
     $row = [
       'sourceid1' => 'source_id_value_1',
@@ -362,7 +372,8 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
     $row = [
       'sourceid1' => 'source_id_value_3',
       'sourceid2' => 'source_id_value_4',
-      'source_ids_hash' => $this->getIdMap()->getSourceIdsHash(['source_id_property' => 'source_id_value_3', 'sourceid2' => 'source_id_value_4']),
+      'source_ids_hash' => $this->getIdMap()
+        ->getSourceIdsHash(['source_id_property' => 'source_id_value_3', 'sourceid2' => 'source_id_value_4']),
       'destid1' => 'destination_id_value_2',
     ] + $this->idMapDefaults();
     $this->saveMap($row);
@@ -387,7 +398,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * @return array
    *   An array of data values.
    */
-  public function lookupDestinationIdMappingDataProvider() {
+  public static function lookupDestinationIdMappingDataProvider() {
     return [
       [1, 1],
       [2, 2],
@@ -406,7 +417,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    *
    * @dataProvider lookupDestinationIdMappingDataProvider
    */
-  public function testLookupDestinationIdMapping($num_source_fields, $num_destination_fields) {
+  public function testLookupDestinationIdMapping($num_source_fields, $num_destination_fields): void {
     // Adjust the migration configuration according to the number of source and
     // destination fields.
     $this->sourceIds = [];
@@ -475,7 +486,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests lookupDestinationIds().
    */
-  public function testLookupDestinationIds() {
+  public function testLookupDestinationIds(): void {
     // Simple map with one source and one destination ID.
     $id_map = $this->setupRows(['nid'], ['nid'], [
       [1, 101],
@@ -523,9 +534,11 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
     // Lookup by partial associative list.
     $this->assertEquals([[101, 'en'], [101, 'fr'], [101, 'de']], $id_map->lookupDestinationIds(['nid' => 1]));
     $this->assertEquals([[102, 'en']], $id_map->lookupDestinationIds(['nid' => 2]));
-    $this->assertEquals([], $id_map->lookupDestinationIds(['nid' => 99]));
-    $this->assertEquals([[101, 'en'], [101, 'fr'], [101, 'de']], $id_map->lookupDestinationIds(['nid' => 1, 'language' => NULL]));
     $this->assertEquals([[102, 'en']], $id_map->lookupDestinationIds(['nid' => 2, 'language' => NULL]));
+    $this->assertEquals([], $id_map->lookupDestinationIds(['nid' => 99]));
+    $this->assertEquals(
+      [[101, 'en'], [101, 'fr'], [101, 'de']],
+      $id_map->lookupDestinationIds(['nid' => 1, 'language' => NULL]));
     // Out-of-order partial associative list.
     $this->assertEquals([[101, 'en'], [102, 'en']], $id_map->lookupDestinationIds(['language' => 'en']));
     $this->assertEquals([[101, 'fr']], $id_map->lookupDestinationIds(['language' => 'fr']));
@@ -559,7 +572,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests the getRowByDestination method.
    */
-  public function testGetRowByDestination() {
+  public function testGetRowByDestination(): void {
     $row = [
       'sourceid1' => 'source_id_value_1',
       'sourceid2' => 'source_id_value_2',
@@ -605,7 +618,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * @return array
    *   An array of data values.
    */
-  public function lookupSourceIdMappingDataProvider() {
+  public static function lookupSourceIdMappingDataProvider() {
     return [
       [1, 1],
       [2, 2],
@@ -624,7 +637,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    *
    * @dataProvider lookupSourceIdMappingDataProvider
    */
-  public function testLookupSourceIdMapping($num_source_fields, $num_destination_fields) {
+  public function testLookupSourceIdMapping($num_source_fields, $num_destination_fields): void {
     $source_id_property_prefix = 'source_id_property_';
     $this->doTestLookupSourceIdMapping($num_source_fields, $num_destination_fields, $source_id_property_prefix);
   }
@@ -643,7 +656,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    *
    * @dataProvider lookupSourceIdMappingDataProvider
    */
-  public function testLookupSourceIdMappingNonSqlCharacters($num_source_fields, $num_destination_fields) {
+  public function testLookupSourceIdMappingNonSqlCharacters($num_source_fields, $num_destination_fields): void {
     $source_id_property_prefix = '$ource id property * ';
     $this->doTestLookupSourceIdMapping($num_source_fields, $num_destination_fields, $source_id_property_prefix);
   }
@@ -696,7 +709,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests currentDestination() and currentSource().
    */
-  public function testCurrentDestinationAndSource() {
+  public function testCurrentDestinationAndSource(): void {
     // Simple map with one source and one destination ID.
     $id_map = $this->setupRows(['nid'], ['nid'], [
       [1, 101],
@@ -730,7 +743,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * - One import.
    * - Multiple imports.
    */
-  public function testImportedCount() {
+  public function testImportedCount(): void {
     $id_map = $this->getIdMap();
     // Add a single failed row and assert zero imported rows.
     $source = ['source_id_property' => 'source_value_failed'];
@@ -762,7 +775,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * - One processed row.
    * - Multiple processed rows.
    */
-  public function testProcessedCount() {
+  public function testProcessedCount(): void {
     $id_map = $this->getIdMap();
     // Assert zero rows have been processed before adding rows.
     $this->assertSame(0, $id_map->processedCount());
@@ -798,7 +811,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * @return array
    *   An array of data values.
    */
-  public function updateCountDataProvider() {
+  public static function updateCountDataProvider() {
     return [
       [0],
       [1],
@@ -814,7 +827,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    *
    * @dataProvider updateCountDataProvider
    */
-  public function testUpdateCount($num_update_rows) {
+  public function testUpdateCount($num_update_rows): void {
     for ($i = 0; $i < 5; $i++) {
       $row = $this->idMapDefaults();
       $row['sourceid1'] = "source_id_value_$i";
@@ -846,7 +859,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * @return array
    *   An array of data values.
    */
-  public function errorCountDataProvider() {
+  public static function errorCountDataProvider() {
     return [
       [0],
       [1],
@@ -862,7 +875,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    *
    * @dataProvider errorCountDataProvider
    */
-  public function testErrorCount($num_error_rows) {
+  public function testErrorCount($num_error_rows): void {
     for ($i = 0; $i < 5; $i++) {
       $row = $this->idMapDefaults();
       $row['sourceid1'] = "source_id_value_$i";
@@ -886,7 +899,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests setting a row source_row_status to STATUS_NEEDS_UPDATE.
    */
-  public function testSetUpdate() {
+  public function testSetUpdate(): void {
     $id_map = $this->getIdMap();
     $row_statuses = [
       MigrateIdMapInterface::STATUS_IMPORTED,
@@ -926,7 +939,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
       $id_map->setUpdate([]);
       $this->assertFalse(FALSE, 'MigrateException not thrown, when source identifiers were provided to update.');
     }
-    catch (MigrateException $e) {
+    catch (MigrateException) {
       $this->assertTrue(TRUE, "MigrateException thrown, when source identifiers were not provided to update.");
     }
   }
@@ -934,7 +947,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests prepareUpdate().
    */
-  public function testPrepareUpdate() {
+  public function testPrepareUpdate(): void {
     $id_map = $this->getIdMap();
     $row_statuses = [
       MigrateIdMapInterface::STATUS_IMPORTED,
@@ -980,7 +993,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * - One error.
    * - Multiple errors.
    */
-  public function testDestroy() {
+  public function testDestroy(): void {
     $id_map = $this->getIdMap();
     // Initialize the ID map.
     $id_map->getDatabase();
@@ -1003,7 +1016,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests the getQualifiedMapTable method with a prefixed database.
    */
-  public function testGetQualifiedMapTablePrefix() {
+  public function testGetQualifiedMapTablePrefix(): void {
     $connection_options = [
       'database' => ':memory:',
       'prefix' => 'prefix',
@@ -1027,7 +1040,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * - Sql::key()
    * - Sql::current()
    */
-  public function testIterators() {
+  public function testIterators(): void {
     for ($i = 0; $i < 3; $i++) {
       $row = $this->idMapDefaults();
       $row['sourceid1'] = "source_id_value_$i";
@@ -1047,7 +1060,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * @return array
    *   The contents of an ID map.
    */
-  private function getIdMapContents() {
+  private function getIdMapContents(): array {
     $result = $this->database
       ->select('migrate_map_sql_idmap_test', 't')
       ->fields('t')
@@ -1066,7 +1079,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
   /**
    * Tests the delayed creation of the "map" and "message" migrate tables.
    */
-  public function testMapTableCreation() {
+  public function testMapTableCreation(): void {
     $id_map = $this->getIdMap();
     $map_table_name = $id_map->mapTableName();
     $message_table_name = $id_map->messageTableName();
@@ -1098,7 +1111,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    *
    * @dataProvider getHighestIdDataProvider
    */
-  public function testGetHighestId(array $destination_ids, array $rows, $expected) {
+  public function testGetHighestId(array $destination_ids, array $rows, $expected): void {
     $this->database = $this->getDatabase([]);
     $this->sourceIds = $destination_ids;
     $this->destinationIds = $destination_ids;
@@ -1132,10 +1145,10 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * @return array
    *   An array of data values.
    */
-  public function getHighestIdDataProvider() {
+  public static function getHighestIdDataProvider() {
     return [
       'Destination ID type integer' => [
-        'dest_ids' => [
+        'destination_ids' => [
           'nid' => [
             'type' => 'integer',
           ],
@@ -1149,7 +1162,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
         'expected' => 5,
       ],
       'Destination ID types integer and string' => [
-        'dest_ids' => [
+        'destination_ids' => [
           'nid' => [
             'type' => 'integer',
           ],
@@ -1179,7 +1192,7 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    *
    * @dataProvider getHighestIdInvalidDataProvider
    */
-  public function testGetHighestIdInvalid(array $destination_ids) {
+  public function testGetHighestIdInvalid(array $destination_ids): void {
     $this->expectException(\LogicException::class);
     $this->expectExceptionMessage('To determine the highest migrated ID the first ID must be an integer');
     $this->destinationIds = $destination_ids;
@@ -1197,17 +1210,17 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
    * @return array
    *   An array of data values.
    */
-  public function getHighestIdInvalidDataProvider() {
+  public static function getHighestIdInvalidDataProvider() {
     return [
       'Destination ID type string' => [
-        'ids' => [
+        'destination_ids' => [
           'language' => [
             'type' => 'string',
           ],
         ],
       ],
       'Destination ID types int (not integer) and string' => [
-        'ids' => [
+        'destination_ids' => [
           'nid' => [
             'type' => 'int',
           ],
@@ -1219,20 +1232,4 @@ class MigrateSqlIdMapTest extends MigrateTestCase {
     ];
   }
 
-  /**
-   * Tests deprecation message from Sql::getMigrationPluginManager().
-   *
-   * @group legacy
-   */
-  public function testGetMigrationPluginManagerDeprecation() {
-    $container = new ContainerBuilder();
-    $migration_plugin_manager = $this->createMock(MigrationPluginManager::class);
-    $container->set('plugin.manager.migration', $migration_plugin_manager);
-    \Drupal::setContainer($container);
-
-    $this->expectDeprecation('Drupal\migrate\Plugin\migrate\id_map\Sql::getMigrationPluginManager() is deprecated in drupal:9.5.0 and is removed from drupal:11.0.0. Use $this->migrationPluginManager instead. See https://www.drupal.org/node/3277306');
-    $id_map = $this->getIdMap();
-    $id_map->getMigrationPluginManager();
-  }
-
 }
