@@ -1,7 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\node\Kernel\Migrate\d6;
 
+use Drupal\Core\Database\Statement\FetchAs;
 use Drupal\node\NodeInterface;
 use Drupal\Tests\file\Kernel\Migrate\d6\FileMigrationTestTrait;
 use Drupal\Tests\migrate_drupal\Traits\CreateTestContentEntitiesTrait;
@@ -56,21 +59,21 @@ class MigrateNodeCompleteTest extends MigrateNodeTestBase {
   /**
    * Tests the complete node migration.
    */
-  public function testNodeCompleteMigration() {
+  public function testNodeCompleteMigration(): void {
     $db = \Drupal::database();
     $this->assertEquals($this->expectedNodeFieldRevisionTable(), $db->select('node_field_revision', 'nr')
       ->fields('nr')
       ->orderBy('vid')
       ->orderBy('langcode')
       ->execute()
-      ->fetchAll(\PDO::FETCH_ASSOC));
+      ->fetchAll(FetchAs::Associative));
     $this->assertEquals($this->expectedNodeFieldDataTable(), $db->select('node_field_data', 'nr')
       ->fields('nr')
       ->orderBy('nid')
       ->orderBy('vid')
       ->orderBy('langcode')
       ->execute()
-      ->fetchAll(\PDO::FETCH_ASSOC));
+      ->fetchAll(FetchAs::Associative));
 
     // Now load and test each revision, including the field 'field_text_plain'
     // which has text reflecting the revision.
@@ -116,7 +119,7 @@ class MigrateNodeCompleteTest extends MigrateNodeTestBase {
    * @return array
    *   The expected table rows.
    */
-  protected function expectedNodeFieldDataTable() {
+  protected function expectedNodeFieldDataTable(): array {
     return [
       0 =>
         [
@@ -523,7 +526,7 @@ class MigrateNodeCompleteTest extends MigrateNodeTestBase {
    * @return array
    *   The table.
    */
-  protected function expectedNodeFieldRevisionTable() {
+  protected function expectedNodeFieldRevisionTable(): array {
     return [
       0 =>
         [
@@ -1044,9 +1047,9 @@ class MigrateNodeCompleteTest extends MigrateNodeTestBase {
    * @return array
    *   Selected properties and fields on the revision.
    */
-  protected function expectedRevisionEntityData() {
+  protected function expectedRevisionEntityData(): array {
     return [
-      $revision_data = [
+      [
         // Node 1, revision 1, und.
         0 =>
           [
