@@ -7,5 +7,5 @@ namespace Drupal\package_manager\Event;
 /**
  * Event fired after staged changes are synced to the active directory.
  */
-final class PostApplyEvent extends StageEvent {
+final class PostApplyEvent extends SandboxEvent {
 }
