@@ -7,8 +7,8 @@ namespace Drupal\package_manager\Event;
 /**
  * Event fired after packages are updated to the stage directory.
  */
-final class PostRequireEvent extends StageEvent {
+final class PostRequireEvent extends SandboxEvent {
 
-  use RequireEventTrait;
+  use EventWithPackageListTrait;
 
 }
