@@ -347,7 +347,7 @@ END;
     $this->assertDirectoryIsWritable($log);
     $log .= '/' . str_replace('\\', '_', static::class) . '-' . $this->name();
     if ($this->usesDataProvider()) {
-      $log .= '-' . preg_replace('/[^a-z0-9]+/i', '_', $this->dataName());
+      $log .= '-' . preg_replace('/[^a-z0-9]+/i', '_', (string) $this->dataName());
     }
     $code .= <<<END
 \$config['package_manager.settings']['log'] = '$log-package_manager.log';
@@ -441,16 +441,18 @@ END;
         $requirements['symfony/polyfill-php81'],
         $requirements['symfony/polyfill-php82'],
         $requirements['symfony/polyfill-php83'],
+        // Needed for PHP 8.4 features while PHP 8.3 is the minimum.
+        $requirements['symfony/polyfill-php84'],
       );
       // If this package requires any Drupal core packages, ensure it allows
       // any version.
       self::unboundCoreConstraints($requirements);
-      // In certain situations, like Drupal CI, auto_updates might be
-      // required into the code base by Composer. This may cause it to be added to
-      // the drupal/core-recommended metapackage, which can prevent the test site
-      // from being built correctly, among other deleterious effects. To prevent
-      // such shenanigans, always remove drupal/auto_updates from
-      // drupal/core-recommended.
+      // In certain situations, like specific CI environments, auto_updates
+      // might be required into the code base by Composer. This may cause it to
+      // be added to the drupal/core-recommended metapackage, which can prevent
+      // the test site from being built correctly, among other deleterious
+      // effects. To prevent such shenanigans, always remove drupal/auto_updates
+      // from drupal/core-recommended.
       if ($name === 'drupal/core-recommended') {
         unset($requirements['drupal/auto_updates']);
       }
@@ -719,6 +721,9 @@ END;
       $this->serverErrorLog,
     );
     $this->assertSame(200, $session->getStatusCode(), $message);
+    // Sometimes we get a 200 response after a PHP timeout or OOM error, so we
+    // also check the page content to ensure it's what we expect.
+    $this->assertSame('Finished', $session->getPage()->getText());
   }
 
   /**
