@@ -23,9 +23,7 @@ class ResponsiveImageFieldUiTest extends WebDriverTestBase {
   protected $defaultTheme = 'stark';
 
   /**
-   * Modules to install.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = [
     'node',
@@ -49,6 +47,7 @@ class ResponsiveImageFieldUiTest extends WebDriverTestBase {
   protected function setUp(): void {
     parent::setUp();
     $this->drupalPlaceBlock('system_breadcrumb_block');
+    $this->drupalPlaceBlock('local_actions_block');
     // Create a test user.
     $admin_user = $this->drupalCreateUser([
       'access content',
@@ -72,7 +71,7 @@ class ResponsiveImageFieldUiTest extends WebDriverTestBase {
   /**
    * Tests formatter settings.
    */
-  public function testResponsiveImageFormatterUi() {
+  public function testResponsiveImageFormatterUi(): void {
     $manage = 'admin/structure/types/manage/' . $this->type;
     $manage_display = $manage . '/display';
     /** @var \Drupal\FunctionalJavascriptTests\JSWebAssert $assert_session */
@@ -143,8 +142,8 @@ class ResponsiveImageFieldUiTest extends WebDriverTestBase {
     // Save the form to save the settings.
     $page->pressButton('Save');
 
-    $assert_session->responseContains('Responsive image style: Style One');
-    $assert_session->responseContains('Linked to content');
+    $this->assertTrue($assert_session->waitForText('Responsive image style: Style One'));
+    $this->assertTrue($assert_session->waitForText('Linked to content'));
 
     $page->find('css', '#edit-fields-field-image-settings-edit')->click();
     $assert_session->waitForField('fields[field_image][settings_edit_form][settings][responsive_image_style]');
@@ -153,8 +152,8 @@ class ResponsiveImageFieldUiTest extends WebDriverTestBase {
     // Save the form to save the settings.
     $page->pressButton('Save');
 
-    $assert_session->responseContains('Responsive image style: Style One');
-    $assert_session->responseContains('Linked to file');
+    $this->assertTrue($assert_session->waitForText('Responsive image style: Style One'));
+    $this->assertTrue($assert_session->waitForText('Linked to file'));
   }
 
 }
