@@ -19,6 +19,9 @@ use Symfony\Component\Validator\Constraint as SymfonyConstraint;
 )]
 class RestTestConstraint extends SymfonyConstraint {
 
-  public $message = 'REST test validation failed';
+  /**
+   * The default violation message.
+   */
+  public string $message = 'REST test validation failed';
 
 }
