@@ -1,9 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\shortcut\Functional;
 
 use Drupal\block_content\Entity\BlockContentType;
-use Drupal\Component\Render\FormattableMarkup;
 use Drupal\Core\Url;
 use Drupal\shortcut\Entity\Shortcut;
 use Drupal\shortcut\Entity\ShortcutSet;
@@ -15,7 +16,6 @@ use Drupal\views\Entity\View;
  * Create, view, edit, delete, and change shortcut links.
  *
  * @group shortcut
- * @group #slow
  */
 class ShortcutLinksTest extends ShortcutTestBase {
 
@@ -23,12 +23,15 @@ class ShortcutLinksTest extends ShortcutTestBase {
   use PathAliasTestTrait;
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['router_test', 'views', 'block'];
 
+  /**
+   * {@inheritdoc}
+   */
+  protected $adminUser;
+
   /**
    * {@inheritdoc}
    */
@@ -40,13 +43,29 @@ class ShortcutLinksTest extends ShortcutTestBase {
   protected function setUp(): void {
     parent::setUp();
 
+    $this->adminUser = $this->drupalCreateUser([
+      'access toolbar',
+      'administer shortcuts',
+      'view the administration theme',
+      'access content overview',
+      'administer users',
+      'administer site configuration',
+      'administer content types',
+      'create article content',
+      'create page content',
+      'edit any article content',
+      'edit any page content',
+      'administer blocks',
+      'access shortcuts',
+    ]);
+
     $this->drupalPlaceBlock('page_title_block');
   }
 
   /**
    * Tests that creating a shortcut works properly.
    */
-  public function testShortcutLinkAdd() {
+  public function testShortcutLinkAdd(): void {
     $set = $this->set;
 
     // Create an alias for the node so we can test aliases.
@@ -89,10 +108,10 @@ class ShortcutLinksTest extends ShortcutTestBase {
       $this->assertContains('internal:' . $test_path, $paths, 'Shortcut created: ' . $test_path);
 
       if (in_array($test_path, $test_cases_non_access)) {
-        $this->assertSession()->linkNotExists($title, new FormattableMarkup('Shortcut link %url not accessible on the page.', ['%url' => $test_path]));
+        $this->assertSession()->linkNotExists($title, "Shortcut link $test_path not accessible on the page.");
       }
       else {
-        $this->assertSession()->linkExists($title, 0, new FormattableMarkup('Shortcut link %url found on the page.', ['%url' => $test_path]));
+        $this->assertSession()->linkExists($title, 0, "Shortcut link $test_path found on the page.");
       }
     }
     $saved_set = ShortcutSet::load($set->id());
@@ -148,13 +167,11 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * Tests that the "add to shortcut" and "remove from shortcut" links work.
    */
-  public function testShortcutQuickLink() {
+  public function testShortcutQuickLink(): void {
     \Drupal::service('theme_installer')->install(['claro']);
     $this->config('system.theme')->set('admin', 'claro')->save();
-    $this->config('node.settings')->set('use_admin_theme', '1')->save();
-    $this->container->get('router.builder')->rebuild();
 
-    $this->drupalLogin($this->rootUser);
+    $this->drupalLogin($this->adminUser);
     $this->drupalGet('admin/config/system/cron');
 
     // Test the "Add to shortcuts" link.
@@ -211,8 +228,10 @@ class ShortcutLinksTest extends ShortcutTestBase {
     $this->clickLink('Remove from Default shortcuts');
     $this->assertSession()->pageTextContains("The shortcut $title has been deleted.");
     $this->assertShortcutQuickLink('Add to Default shortcuts');
-
     \Drupal::service('module_installer')->install(['block_content']);
+    $this->adminUser
+      ->addRole($this->drupalCreateRole(['administer block types']))
+      ->save();
     BlockContentType::create([
       'id' => 'basic',
       'label' => 'Basic block',
@@ -230,7 +249,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * Tests that shortcut links can be renamed.
    */
-  public function testShortcutLinkRename() {
+  public function testShortcutLinkRename(): void {
     $set = $this->set;
 
     // Attempt to rename shortcut link.
@@ -250,7 +269,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * Tests that changing the path of a shortcut link works.
    */
-  public function testShortcutLinkChangePath() {
+  public function testShortcutLinkChangePath(): void {
     $set = $this->set;
 
     // Tests changing a shortcut path.
@@ -273,8 +292,8 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * Tests that changing the route of a shortcut link works.
    */
-  public function testShortcutLinkChangeRoute() {
-    $this->drupalLogin($this->rootUser);
+  public function testShortcutLinkChangeRoute(): void {
+    $this->drupalLogin($this->adminUser);
     $this->drupalGet('admin/content');
     $this->assertSession()->statusCodeEquals(200);
     // Disable the view.
@@ -289,7 +308,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * Tests deleting a shortcut link.
    */
-  public function testShortcutLinkDelete() {
+  public function testShortcutLinkDelete(): void {
     $set = $this->set;
 
     $shortcuts = $set->getShortcuts();
@@ -314,7 +333,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
    * Tests that the "Add to shortcuts" link is not displayed on a page not
    * found or a page the user does not have access to.
    */
-  public function testNoShortcutLink() {
+  public function testNoShortcutLink(): void {
     // Change to a theme that displays shortcuts.
     \Drupal::service('theme_installer')->install(['claro']);
     $this->config('system.theme')
@@ -342,7 +361,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * Tests that the 'access shortcuts' permissions works properly.
    */
-  public function testAccessShortcutsPermission() {
+  public function testAccessShortcutsPermission(): void {
     // Change to a theme that displays shortcuts.
     \Drupal::service('theme_installer')->install(['claro']);
     $this->config('system.theme')
@@ -350,7 +369,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
       ->save();
 
     // Add cron to the default shortcut set.
-    $this->drupalLogin($this->rootUser);
+    $this->drupalLogin($this->adminUser);
     $this->drupalGet('admin/config/system/cron');
     $this->clickLink('Add to Default shortcuts');
 
@@ -382,7 +401,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * Tests the shortcuts are correctly ordered by weight in the toolbar.
    */
-  public function testShortcutLinkOrder() {
+  public function testShortcutLinkOrder(): void {
     // Ensure to give permissions to access the shortcuts.
     $this->drupalLogin($this->drupalCreateUser([
       'access toolbar',
@@ -406,7 +425,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * Tests the 'access shortcuts' permission for shortcut set administration.
    */
-  private function verifyAccessShortcutsPermissionForEditPages() {
+  private function verifyAccessShortcutsPermissionForEditPages(): void {
     // Create a user with customize links and switch sets permissions  but
     // without the 'access shortcuts' permission.
     $test_permissions = [
@@ -429,7 +448,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * Tests the 'access shortcuts' permission with the shortcut block.
    */
-  public function testShortcutBlockAccess() {
+  public function testShortcutBlockAccess(): void {
     // Creates a block instance and place in a region through api.
     $block = $this->drupalPlaceBlock('shortcuts');
 
@@ -459,14 +478,14 @@ class ShortcutLinksTest extends ShortcutTestBase {
    *   Link position counting from zero.
    * @param string $message
    *   (optional) A message to display with the assertion. Do not translate
-   *   messages: use new FormattableMarkup() to embed variables in the message text, not
-   *   t(). If left blank, a default message will be displayed.
+   *   messages: use new FormattableMarkup() to embed variables in the message
+   *   text, not t(). If left blank, a default message will be displayed.
    *
    * @internal
    */
   protected function assertShortcutQuickLink(string $label, int $index = 0, string $message = ''): void {
     $links = $this->xpath('//a[normalize-space()=:label]', [':label' => $label]);
-    $message = ($message ? $message : (string) new FormattableMarkup('Shortcut quick link with label %label found.', ['%label' => $label]));
+    $message = ($message ?: "Shortcut quick link with label $label found.");
     $this->assertArrayHasKey($index, $links, $message);
   }
 
