@@ -7,6 +7,7 @@ namespace Drupal\Tests\sqlite\Unit;
 use Drupal\sqlite\Driver\Database\sqlite\Connection;
 use Drupal\Tests\Core\Database\Stub\StubPDO;
 use Drupal\Tests\UnitTestCase;
+use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 
 /**
  * @coversDefaultClass \Drupal\sqlite\Driver\Database\sqlite\Connection
@@ -24,9 +25,8 @@ class ConnectionTest extends UnitTestCase {
    *   Expected connection option.
    */
   public function testCreateConnectionOptionsFromUrl(string $url, string $expected): void {
-    $root = dirname(__DIR__, 8);
     $sqlite_connection = new Connection($this->createMock(StubPDO::class), []);
-    $database = $sqlite_connection->createConnectionOptionsFromUrl($url, $root);
+    $database = $sqlite_connection->createConnectionOptionsFromUrl($url, NULL);
     $this->assertEquals('sqlite', $database['driver']);
     $this->assertEquals($expected, $database['database']);
   }
@@ -47,4 +47,17 @@ class ConnectionTest extends UnitTestCase {
     ];
   }
 
+  /**
+   * Confirms deprecation of the $root argument.
+   */
+  #[IgnoreDeprecations]
+  public function testDeprecationOfRootInConnectionOptionsFromUrl(): void {
+    $this->expectDeprecation('Passing the $root value to Drupal\sqlite\Driver\Database\sqlite\Connection::createConnectionOptionsFromUrl() is deprecated in drupal:11.2.0 and will be removed in drupal:12.0.0. There is no replacement. See https://www.drupal.org/node/3511287');
+    $root = dirname(__DIR__, 8);
+    $sqlite_connection = new Connection($this->createMock(StubPDO::class), []);
+    $database = $sqlite_connection->createConnectionOptionsFromUrl('sqlite://localhost/tmp/test', $root);
+    $this->assertEquals('sqlite', $database['driver']);
+    $this->assertEquals('tmp/test', $database['database']);
+  }
+
 }
