@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\cache_test\Controller;
 
 use Drupal\Core\Url;
@@ -32,7 +34,7 @@ class CacheTestController {
    */
   public function bundleTags($entity_type_id, $bundle) {
     $storage = \Drupal::entityTypeManager()->getStorage($entity_type_id);
-    $entity_ids = $storage->getQuery()->condition('type', $bundle)->execute();
+    $entity_ids = $storage->getQuery()->accessCheck(TRUE)->condition('type', $bundle)->execute();
     $page = [];
 
     $entities = $storage->loadMultiple($entity_ids);
