@@ -25,16 +25,17 @@ class FormTestFormStateValuesCleanAdvancedForm extends FormBase {
    * {@inheritdoc}
    */
   public function buildForm(array $form, FormStateInterface $form_state) {
-    // Build an example form containing a managed file and a submit form element.
+    // Build an example form containing a managed file and a submit form
+    // element.
     $form['image'] = [
       '#type' => 'managed_file',
-      '#title' => t('Image'),
+      '#title' => $this->t('Image'),
       '#upload_location' => 'public://',
       '#default_value' => 0,
     ];
     $form['submit'] = [
       '#type' => 'submit',
-      '#value' => t('Submit'),
+      '#value' => $this->t('Submit'),
     ];
     return $form;
   }
@@ -44,7 +45,7 @@ class FormTestFormStateValuesCleanAdvancedForm extends FormBase {
    */
   public function submitForm(array &$form, FormStateInterface $form_state) {
     $form_state->cleanValues();
-    print t('You WIN!');
+    print $this->t('You WIN!');
     exit;
   }
 
