@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\form_test\Form;
 
 use Drupal\Core\Form\FormStateInterface;
+use Drupal\form_test\Callbacks;
 
 /**
  * Builds a form to test table selects with different column spans.
@@ -22,7 +25,7 @@ class FormTestTableSelectColspanForm extends FormTestTableSelectFormBase {
    * {@inheritdoc}
    */
   public function buildForm(array $form, FormStateInterface $form_state) {
-    list($header, $options) = _form_test_tableselect_get_data();
+    [$header, $options] = Callbacks::tableselectGetData();
 
     // Change the data so that the third column has colspan=2.
     $header['three'] = ['data' => 'Three', 'colspan' => 2];
