@@ -1,10 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\service_provider_test;
 
 use Drupal\file\FileInterface;
 use Drupal\file\FileUsage\FileUsageBase;
 
+/**
+ * Test class of database file usage backend implementation.
+ */
 class TestFileUsage extends FileUsageBase {
 
   /**
