@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\system\Functional\Form;
 
 use Drupal\Tests\BrowserTestBase;
@@ -8,14 +10,11 @@ use Drupal\Tests\BrowserTestBase;
  * Tests building and processing of core form elements.
  *
  * @group Form
- * @group #slow
  */
 class ElementTest extends BrowserTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['form_test'];
 
@@ -24,10 +23,27 @@ class ElementTest extends BrowserTestBase {
    */
   protected $defaultTheme = 'starterkit_theme';
 
+  /**
+   * Test form elements.
+   */
+  public function testFormElements(): void {
+    $this->testPlaceHolderText();
+    $this->testOptions();
+    $this->testRadiosChecked();
+    $this->testWrapperIds();
+    $this->testButtonClasses();
+    $this->testSubmitButtonAttribute();
+    $this->testGroupElements();
+    $this->testRequiredFieldsetsAndDetails();
+    $this->testFormAutocomplete();
+    $this->testFormElementErrors();
+    $this->testDetailsSummaryAttributes();
+  }
+
   /**
    * Tests placeholder text for elements that support placeholders.
    */
-  public function testPlaceHolderText() {
+  protected function testPlaceHolderText(): void {
     $this->drupalGet('form-test/placeholder-text');
     foreach (['textfield', 'tel', 'url', 'password', 'email', 'number', 'textarea'] as $type) {
       $field = $this->assertSession()->fieldExists("edit-$type");
@@ -38,7 +54,7 @@ class ElementTest extends BrowserTestBase {
   /**
    * Tests expansion of #options for #type checkboxes and radios.
    */
-  public function testOptions() {
+  protected function testOptions(): void {
     $this->drupalGet('form-test/checkboxes-radios');
 
     // Verify that all options appear in their defined order.
@@ -79,7 +95,7 @@ class ElementTest extends BrowserTestBase {
   /**
    * Tests correct checked attribute for radios element.
    */
-  public function testRadiosChecked() {
+  protected function testRadiosChecked(): void {
     // Verify that there is only one radio option checked.
     $this->drupalGet('form-test/radios-checked');
     $this->assertSession()->elementsCount('xpath', '//input[@name="radios" and @checked]', 1);
@@ -108,7 +124,7 @@ class ElementTest extends BrowserTestBase {
   /**
    * Tests wrapper ids for checkboxes and radios.
    */
-  public function testWrapperIds() {
+  protected function testWrapperIds(): void {
     $this->drupalGet('form-test/checkboxes-radios');
 
     // Verify that wrapper id is different from element id.
@@ -122,7 +138,7 @@ class ElementTest extends BrowserTestBase {
   /**
    * Tests button classes.
    */
-  public function testButtonClasses() {
+  protected function testButtonClasses(): void {
     $this->drupalGet('form-test/button-class');
     // Just contains(@class, "button") won't do because then
     // "button--foo" would contain "button". Instead, check
@@ -133,10 +149,22 @@ class ElementTest extends BrowserTestBase {
     $this->assertSession()->elementsCount('xpath', '//*[contains(concat(" ", @class, " "), " button--danger ")]', 1);
   }
 
+  /**
+   * Tests the submit_button attribute.
+   */
+  protected function testSubmitButtonAttribute(): void {
+    // Set the submit_button attribute to true
+    $this->drupalGet('form-test/submit-button-attribute');
+    $this->assertSession()->elementsCount('xpath', '//input[@type="submit"]', 1);
+    // Set the submit_button attribute to false
+    $this->drupalGet('form-test/submit-button-attribute/1');
+    $this->assertSession()->elementsCount('xpath', '//input[@type="button"]', 1);
+  }
+
   /**
    * Tests the #group property.
    */
-  public function testGroupElements() {
+  protected function testGroupElements(): void {
     $this->drupalGet('form-test/group-details');
     $this->assertSession()->elementsCount('xpath', '//div[@class="details-wrapper"]//div[@class="details-wrapper"]//label', 1);
     $this->drupalGet('form-test/group-container');
@@ -152,7 +180,7 @@ class ElementTest extends BrowserTestBase {
   /**
    * Tests the #required property on details and fieldset elements.
    */
-  public function testRequiredFieldsetsAndDetails() {
+  protected function testRequiredFieldsetsAndDetails(): void {
     $this->drupalGet('form-test/group-details');
     $this->assertEmpty($this->cssSelect('summary.form-required'));
     $this->drupalGet('form-test/group-details/1');
@@ -166,7 +194,7 @@ class ElementTest extends BrowserTestBase {
   /**
    * Tests a form with an autocomplete setting..
    */
-  public function testFormAutocomplete() {
+  protected function testFormAutocomplete(): void {
     $this->drupalGet('form-test/autocomplete');
 
     // Ensure that the user does not have access to the autocompletion.
@@ -188,7 +216,7 @@ class ElementTest extends BrowserTestBase {
   /**
    * Tests form element error messages.
    */
-  public function testFormElementErrors() {
+  protected function testFormElementErrors(): void {
     $this->drupalGet('form_test/details-form');
     $this->submitForm([], 'Submit');
     $this->assertSession()->pageTextContains('I am an error on the details element.');
@@ -197,7 +225,7 @@ class ElementTest extends BrowserTestBase {
   /**
    * Tests summary attributes of details.
    */
-  public function testDetailsSummaryAttributes() {
+  protected function testDetailsSummaryAttributes(): void {
     $this->drupalGet('form-test/group-details');
     $this->assertSession()->elementExists('css', 'summary[data-summary-attribute="test"]');
   }
