@@ -27,13 +27,6 @@ class UrlBubbleableMetadataBubblingTest extends BrowserTestBase {
    */
   protected $defaultTheme = 'stark';
 
-  /**
-   * {@inheritdoc}
-   */
-  protected function setUp(): void {
-    parent::setUp();
-  }
-
   /**
    * Tests that URL bubbleable metadata is correctly bubbled.
    */
