@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\system\Functional\Routing;
 
 use Drupal\Tests\BrowserTestBase;
@@ -12,9 +14,7 @@ use Drupal\Tests\BrowserTestBase;
 class RouterPermissionTest extends BrowserTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['router_test'];
 
@@ -26,7 +26,7 @@ class RouterPermissionTest extends BrowserTestBase {
   /**
    * Tests permission requirements on routes.
    */
-  public function testPermissionAccess() {
+  public function testPermissionAccess(): void {
     // Ensure 403 Access Denied for a route without permission.
     $this->drupalGet('router_test/test7');
     $this->assertSession()->statusCodeEquals(403);
@@ -39,8 +39,8 @@ class RouterPermissionTest extends BrowserTestBase {
     $this->drupalLogin($user);
     $this->drupalGet('router_test/test7');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertNoRaw('Access denied');
-    $this->assertRaw('test7text', 'The correct string was returned because the route was successful.');
+    $this->assertSession()->responseNotContains('Access denied');
+    $this->assertSession()->pageTextContains('test7text');
   }
 
 }
