@@ -1,7 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\system\Functional\Session;
 
+use Drupal\Component\Utility\Crypt;
 use Drupal\Core\Database\Database;
 use Drupal\Tests\BrowserTestBase;
 
@@ -9,14 +12,11 @@ use Drupal\Tests\BrowserTestBase;
  * Drupal session handling tests.
  *
  * @group Session
- * @group #slow
  */
 class SessionTest extends BrowserTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['session_test'];
 
@@ -32,7 +32,7 @@ class SessionTest extends BrowserTestBase {
    * @covers \Drupal\Core\Session\WriteSafeSessionHandler::isSessionWritable
    * @covers \Drupal\Core\Session\SessionManager::regenerate
    */
-  public function testSessionSaveRegenerate() {
+  public function testSessionSaveRegenerate(): void {
     $session_handler = $this->container->get('session_handler.write_safe');
     $this->assertTrue($session_handler->isSessionWritable(), 'session_handler->isSessionWritable() initially returns TRUE.');
     $session_handler->setSessionWritable(FALSE);
@@ -86,7 +86,7 @@ class SessionTest extends BrowserTestBase {
   /**
    * Tests data persistence via the session_test module callbacks.
    */
-  public function testDataPersistence() {
+  public function testDataPersistence(): void {
     $user = $this->drupalCreateUser([]);
     // Enable sessions.
     $this->sessionReset();
@@ -170,7 +170,7 @@ class SessionTest extends BrowserTestBase {
   /**
    * Tests storing data in Session() object.
    */
-  public function testSessionPersistenceOnLogin() {
+  public function testSessionPersistenceOnLogin(): void {
     // Store information via hook_user_login().
     $user = $this->drupalCreateUser();
     $this->drupalLogin($user);
@@ -179,10 +179,79 @@ class SessionTest extends BrowserTestBase {
     $this->assertSession()->pageTextContains('foobar');
   }
 
+  /**
+   * Tests that an invalid session ID in the cookie is rejected.
+   *
+   * @covers \Drupal\Core\Session\SessionManager::start
+   */
+  public function testAnonymousSessionFixation(): void {
+
+    $mink = $this->getSession();
+    $connection = Database::getConnection();
+
+    // Initialize a session for anonymous user.
+    $this->drupalGet('session-test/set/foo');
+
+    // Switch browser cookie to arbitrary session_id.
+    $session_cookie_name = $this->getSessionName();
+    $initial_session_cookie_value = $mink->getCookie($session_cookie_name);
+
+    $mink->restart();
+    $this->initFrontPage();
+    // Session restart always resets all the cookies by design, so we
+    // set an arbitrary session_id in the cookie for the next request.
+    $invalid_session_cookie_value = bin2hex($this->randomMachineName(13));
+    $mink->setCookie($session_cookie_name, $invalid_session_cookie_value);
+
+    // Make another request.
+    sleep(1);
+    $this->drupalGet('session-test/set/bar');
+
+    // Check returned cookie value.
+    $returned_session_cookie_value = $mink->getCookie($session_cookie_name);
+
+    // The backend should reject $invalid_session_cookie_value and return a
+    // new session_id that's different from both the first and the invalid
+    // SIDs.
+    $this->assertNotEquals(
+      $initial_session_cookie_value,
+      $returned_session_cookie_value,
+      'Returned session ID is not equal to initial session ID'
+    );
+
+    $this->assertNotEquals(
+      $invalid_session_cookie_value,
+      $returned_session_cookie_value,
+      'Returned session ID is not equal to invalid session ID'
+    );
+
+    // Check that invalid SID does not exist in database.
+    $this->assertEmpty(
+      $connection
+        ->select('sessions', 's')
+        ->fields('s', ['timestamp'])
+        ->condition('sid', Crypt::hashBase64($invalid_session_cookie_value))
+        ->execute()
+        ->fetchField(),
+        'Invalid session ID is not in database'
+    );
+
+    // Check that returned SID does exist in database.
+    $this->assertNotEmpty(
+      $connection
+        ->select('sessions', 's')
+        ->fields('s', ['timestamp'])
+        ->condition('sid', Crypt::hashBase64($returned_session_cookie_value))
+        ->execute()
+        ->fetchField(),
+        'Returned session ID is in database'
+    );
+  }
+
   /**
    * Tests that empty anonymous sessions are destroyed.
    */
-  public function testEmptyAnonymousSession() {
+  public function testEmptyAnonymousSession(): void {
     // Disable the dynamic_page_cache module; it'd cause session_test's debug
     // output (that is added in
     // SessionTestSubscriber::onKernelResponseSessionTest()) to not be added.
@@ -217,7 +286,7 @@ class SessionTest extends BrowserTestBase {
     $this->assertSessionCookie(FALSE);
     $this->assertSessionEmpty(FALSE);
     // Verify that caching was bypassed.
-    $this->assertSession()->responseHeaderDoesNotExist('X-Drupal-Cache');
+    $this->assertSession()->responseHeaderEquals('X-Drupal-Cache', 'UNCACHEABLE (request policy)');
     $this->assertSession()->pageTextContains('This is a dummy message.');
     // Verify that session cookie was deleted.
     $this->assertSession()->responseHeaderMatches('Set-Cookie', '/SESS\w+=deleted/');
@@ -231,7 +300,8 @@ class SessionTest extends BrowserTestBase {
     $this->assertSession()->responseHeaderEquals('X-Drupal-Cache', 'HIT');
     $this->assertSession()->responseHeaderDoesNotExist('Set-Cookie');
 
-    // Verify that no session is created if drupal_save_session(FALSE) is called.
+    // Verify that no session is created if drupal_save_session(FALSE) is
+    // called.
     $this->drupalGet('session-test/set-message-but-do-not-save');
     $this->assertSessionCookie(FALSE);
     $this->assertSessionEmpty(TRUE);
@@ -247,7 +317,7 @@ class SessionTest extends BrowserTestBase {
   /**
    * Tests that sessions are only saved when necessary.
    */
-  public function testSessionWrite() {
+  public function testSessionWrite(): void {
     $user = $this->drupalCreateUser([]);
     $this->drupalLogin($user);
     $connection = Database::getConnection();
@@ -298,7 +368,7 @@ class SessionTest extends BrowserTestBase {
   /**
    * Tests that empty session IDs are not allowed.
    */
-  public function testEmptySessionID() {
+  public function testEmptySessionID(): void {
     $user = $this->drupalCreateUser([]);
     $this->drupalLogin($user);
     $this->drupalGet('session-test/is-logged-in');
@@ -327,7 +397,7 @@ class SessionTest extends BrowserTestBase {
   /**
    * Tests session bag.
    */
-  public function testSessionBag() {
+  public function testSessionBag(): void {
     // Ensure the flag is absent to start with.
     $this->drupalGet('/session-test/has-bag-flag');
     $this->assertSessionCookie(FALSE);
@@ -362,7 +432,7 @@ class SessionTest extends BrowserTestBase {
   /**
    * Test exception thrown during session write close.
    */
-  public function testSessionWriteError() {
+  public function testSessionWriteError(): void {
     // Login to ensure a session exists.
     $user = $this->drupalCreateUser([]);
     $this->drupalLogin($user);
@@ -376,7 +446,7 @@ class SessionTest extends BrowserTestBase {
   /**
    * Reset the cookie file so that it refers to the specified user.
    */
-  public function sessionReset() {
+  public function sessionReset(): void {
     // Close the internal browser.
     $this->mink->resetSessions();
     $this->loggedInUser = FALSE;
@@ -401,7 +471,7 @@ class SessionTest extends BrowserTestBase {
   }
 
   /**
-   * Assert whether $_SESSION is empty at the beginning of the request.
+   * Assert whether the session is empty at the beginning of the request.
    *
    * @internal
    */
