@@ -1,12 +1,16 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\system\Functional\UpdateSystem;
 
 use Drupal\Component\Serialization\Yaml;
+use Drupal\Core\Extension\Requirement\RequirementSeverity;
 use Drupal\Core\Url;
 use Drupal\language\Entity\ConfigurableLanguage;
 use Drupal\Tests\BrowserTestBase;
 use Drupal\Tests\RequirementsPageTrait;
+use Drupal\TestTools\Extension\InfoWriterTrait;
 
 /**
  * Tests the update script access and functionality.
@@ -15,15 +19,13 @@ use Drupal\Tests\RequirementsPageTrait;
  * @group #slow
  */
 class UpdateScriptTest extends BrowserTestBase {
-
+  use InfoWriterTrait;
   use RequirementsPageTrait;
 
   protected const HANDBOOK_MESSAGE = 'Review the suggestions for resolving this incompatibility to repair your installation, and then re-run update.php.';
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = [
     'update_script_test',
@@ -63,6 +65,9 @@ class UpdateScriptTest extends BrowserTestBase {
    * {@inheritdoc}
    */
   protected function setUp(): void {
+    if ($this->name() === 'testMissingExtension') {
+      $this->markTestSkipped('Skipped due to major version-specific logic. See https://www.drupal.org/project/drupal/issues/3359322');
+    }
     parent::setUp();
     $this->updateUrl = Url::fromRoute('system.db_update');
     $this->statusReportUrl = Url::fromRoute('system.status');
@@ -76,7 +81,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Tests access to the update script.
    */
-  public function testUpdateAccess() {
+  public function testUpdateAccess(): void {
     // Try accessing update.php without the proper permission.
     $regular_user = $this->drupalCreateUser();
     $this->drupalLogin($regular_user);
@@ -107,12 +112,17 @@ class UpdateScriptTest extends BrowserTestBase {
     $this->drupalGet('/update-script-test/database-updates-menu-item');
     $this->assertSession()->linkExists('Run database updates');
 
-    // Access the update page as user 1.
-    $this->drupalLogin($this->rootUser);
+    // Access the update page as administrator.
+    $this->drupalLogin($this->createUser([
+      'administer software updates',
+      'access site in maintenance mode',
+      'administer themes',
+    ]));
     $this->drupalGet($this->updateUrl, ['external' => TRUE]);
     $this->assertSession()->statusCodeEquals(200);
 
-    // Check that a link to the update page is accessible to user 1.
+    // Check that a link to the update page is accessible to users with proper
+    // permissions.
     $this->drupalGet('/update-script-test/database-updates-menu-item');
     $this->assertSession()->linkExists('Run database updates');
   }
@@ -120,7 +130,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Tests that requirements warnings and errors are correctly displayed.
    */
-  public function testRequirements() {
+  public function testRequirements(): void {
     $update_script_test_config = $this->config('update_script_test.settings');
     $this->drupalLogin($this->updateUser);
 
@@ -140,7 +150,7 @@ class UpdateScriptTest extends BrowserTestBase {
     // First, run this test with pending updates to make sure they can be run
     // successfully.
     $this->drupalLogin($this->updateUser);
-    $update_script_test_config->set('requirement_type', REQUIREMENT_WARNING)->save();
+    $update_script_test_config->set('requirement_type', RequirementSeverity::Warning->value)->save();
     /** @var \Drupal\Core\Update\UpdateHookRegistry $update_registry */
     $update_registry = \Drupal::service('update.update_hook_registry');
     $update_registry->setInstalledVersion('update_script_test', $update_registry->getInstalledVersion('update_script_test') - 1);
@@ -168,7 +178,7 @@ class UpdateScriptTest extends BrowserTestBase {
     // If there is a requirements error, it should be displayed even after
     // clicking the link to proceed (since the problem that triggered the error
     // has not been fixed).
-    $update_script_test_config->set('requirement_type', REQUIREMENT_ERROR)->save();
+    $update_script_test_config->set('requirement_type', RequirementSeverity::Error->value)->save();
     $this->drupalGet($this->updateUrl, ['external' => TRUE]);
     $this->assertSession()->pageTextContains('This is a requirements error provided by the update_script_test module.');
     $this->clickLink('try again');
@@ -176,7 +186,7 @@ class UpdateScriptTest extends BrowserTestBase {
 
     // Ensure that changes to a module's requirements that would cause errors
     // are displayed correctly.
-    $update_script_test_config->set('requirement_type', REQUIREMENT_OK)->save();
+    $update_script_test_config->set('requirement_type', RequirementSeverity::OK->value)->save();
     \Drupal::state()->set('update_script_test.system_info_alter', ['dependencies' => ['a_module_that_does_not_exist']]);
     $this->drupalGet($this->updateUrl, ['external' => TRUE]);
     $this->assertSession()->responseContains('a_module_that_does_not_exist (Missing)');
@@ -252,7 +262,7 @@ class UpdateScriptTest extends BrowserTestBase {
     $folder_path = \Drupal::getContainer()->getParameter('site.path') . "/{$extension_type}s/$extension_machine_names[0]";
     $file_path = "$folder_path/$extension_machine_names[0].info.yml";
     mkdir($folder_path, 0777, TRUE);
-    file_put_contents($file_path, Yaml::encode($base_info + $correct_info));
+    $this->writeInfoFile($file_path, $base_info + $correct_info);
     $this->enableExtensions($extension_type, $extension_machine_names, [$extension_name]);
     $this->assertInstalledExtensionsConfig($extension_type, $extension_machine_names);
 
@@ -262,13 +272,13 @@ class UpdateScriptTest extends BrowserTestBase {
     $this->assertUpdateWithNoErrors([$test_error_text], $extension_type, $extension_machine_names);
 
     // Change the values in the info.yml and confirm updating is not possible.
-    file_put_contents($file_path, Yaml::encode($base_info + $breaking_info));
+    $this->writeInfoFile($file_path, $base_info + $breaking_info);
     $this->drupalGet($this->statusReportUrl);
     $this->assertErrorOnUpdates([$test_error_text], $extension_type, $extension_machine_names, $test_error_urls);
 
     // Fix the values in the info.yml file and confirm updating is possible
     // again.
-    file_put_contents($file_path, Yaml::encode($base_info + $correct_info));
+    $this->writeInfoFile($file_path, $base_info + $correct_info);
     $this->drupalGet($this->statusReportUrl);
     $this->assertUpdateWithNoErrors([$test_error_text], $extension_type, $extension_machine_names);
   }
@@ -276,7 +286,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Date provider for testExtensionCompatibilityChange().
    */
-  public function providerExtensionCompatibilityChange() {
+  public static function providerExtensionCompatibilityChange() {
     $incompatible_module_message = "The following module is installed, but it is incompatible with Drupal " . \Drupal::VERSION . ":";
     $incompatible_theme_message = "The following theme is installed, but it is incompatible with Drupal " . \Drupal::VERSION . ":";
     return [
@@ -344,7 +354,6 @@ class UpdateScriptTest extends BrowserTestBase {
    * @dataProvider providerMissingExtension
    */
   public function testMissingExtension(array $core, array $contrib): void {
-    $this->markTestSkipped('Skipped due to major version-specific logic. See https://www.drupal.org/project/drupal/issues/3359322');
     $this->drupalLogin(
       $this->drupalCreateUser(
         [
@@ -499,7 +508,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Tests that orphan schemas are handled properly.
    */
-  public function testOrphanedSchemaEntries() {
+  public function testOrphanedSchemaEntries(): void {
     $this->drupalLogin($this->updateUser);
 
     // Insert a bogus value into the system.schema key/value storage for a
@@ -530,7 +539,8 @@ class UpdateScriptTest extends BrowserTestBase {
     // But verify that we warn the admin about this situation.
     $this->assertSession()->elementTextEquals('xpath', '//div[@aria-label="Warning message"]', 'Warning message Module update_test_0 has an entry in the system.schema key/value storage, but is not installed. More information about this error.');
 
-    // Finally, try with both kinds of orphans and make sure we get both warnings.
+    // Finally, try with both kinds of orphans and make sure we get both
+    // warnings.
     \Drupal::service('update.update_hook_registry')->setInstalledVersion('my_already_removed_module', 8000);
     $this->drupalGet($this->updateUrl, ['external' => TRUE]);
     $this->updateRequirementsProblem();
@@ -550,7 +560,7 @@ class UpdateScriptTest extends BrowserTestBase {
    * @return array[]
    *   Set of test cases to pass to the test method.
    */
-  public function providerMissingExtension(): array {
+  public static function providerMissingExtension(): array {
     return [
       'core only' => [
         'core' => [
@@ -646,7 +656,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Tests the effect of using the update script on the theme system.
    */
-  public function testThemeSystem() {
+  public function testThemeSystem(): void {
     // Since visiting update.php triggers a rebuild of the theme system from an
     // unusual maintenance mode environment, we check that this rebuild did not
     // put any incorrect information about the themes into the database.
@@ -660,7 +670,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Tests update.php when there are no updates to apply.
    */
-  public function testNoUpdateFunctionality() {
+  public function testNoUpdateFunctionality(): void {
     // Click through update.php with 'administer software updates' permission.
     $this->drupalLogin($this->updateUser);
     $this->drupalGet($this->updateUrl, ['external' => TRUE]);
@@ -691,7 +701,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Tests update.php after performing a successful update.
    */
-  public function testSuccessfulUpdateFunctionality() {
+  public function testSuccessfulUpdateFunctionality(): void {
     $initial_maintenance_mode = $this->container->get('state')->get('system.maintenance_mode');
     $this->assertNull($initial_maintenance_mode, 'Site is not in maintenance mode.');
     $this->runUpdates($initial_maintenance_mode);
@@ -735,7 +745,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Tests update.php while in maintenance mode.
    */
-  public function testMaintenanceModeUpdateFunctionality() {
+  public function testMaintenanceModeUpdateFunctionality(): void {
     $this->container->get('state')
       ->set('system.maintenance_mode', TRUE);
     $initial_maintenance_mode = $this->container->get('state')
@@ -750,7 +760,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Tests performing updates with update.php in a multilingual environment.
    */
-  public function testSuccessfulMultilingualUpdateFunctionality() {
+  public function testSuccessfulMultilingualUpdateFunctionality(): void {
     // Add some custom languages.
     foreach (['aa', 'bb'] as $language_code) {
       ConfigurableLanguage::create([
@@ -787,7 +797,8 @@ class UpdateScriptTest extends BrowserTestBase {
     ]);
     $this->drupalLogin($admin_user);
 
-    // Visit status report page and ensure, that link to update.php has no path prefix set.
+    // Visit status report page and ensure, that link to update.php has no path
+    // prefix set.
     $this->drupalGet('en/admin/reports/status', ['external' => TRUE]);
     $this->assertSession()->statusCodeEquals(200);
     $this->assertSession()->linkByHrefExists('/update.php');
@@ -803,15 +814,16 @@ class UpdateScriptTest extends BrowserTestBase {
     $this->assertSession()->pageTextContains('Updates were attempted.');
     $this->assertSession()->linkExists('logged');
     $this->assertSession()->linkExists('Administration pages');
+    $this->assertSession()->linkExists('Status report');
     $this->assertSession()->elementNotExists('xpath', '//main//a[contains(@href, "update.php")]');
-    $this->clickLink('Administration pages');
+    $this->clickLink('Status report');
     $this->assertSession()->statusCodeEquals(200);
   }
 
   /**
    * Tests maintenance mode link on update.php.
    */
-  public function testMaintenanceModeLink() {
+  public function testMaintenanceModeLink(): void {
     $full_admin_user = $this->drupalCreateUser([
       'administer software updates',
       'access administration pages',
@@ -839,7 +851,7 @@ class UpdateScriptTest extends BrowserTestBase {
   /**
    * Helper function to run updates via the browser.
    */
-  protected function runUpdates($maintenance_mode) {
+  protected function runUpdates($maintenance_mode): void {
     /** @var \Drupal\Core\Update\UpdateHookRegistry $update_registry */
     $update_registry = \Drupal::service('update.update_hook_registry');
     $schema_version = $update_registry->getInstalledVersion('update_script_test');
