@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\system\Kernel\Mail;
 
 use Drupal\Component\Utility\Random;
@@ -13,6 +15,8 @@ use Drupal\file\Entity\File;
 use Drupal\KernelTests\KernelTestBase;
 use Drupal\system_mail_failure_test\Plugin\Mail\TestPhpMailFailure;
 
+// cspell:ignore drépal
+
 /**
  * Performs tests on the pluggable mailing framework.
  *
@@ -40,6 +44,7 @@ class MailTest extends KernelTestBase {
     parent::setUp();
     $this->installEntitySchema('user');
     $this->installEntitySchema('file');
+    $this->installConfig(['system']);
 
     // Set required site configuration.
     $this->config('system.site')
@@ -51,7 +56,7 @@ class MailTest extends KernelTestBase {
   /**
    * Assert that the pluggable mail system is functional.
    */
-  public function testPluggableFramework() {
+  public function testPluggableFramework(): void {
     // Switch mail backends.
     $this->configureDefaultMailInterface('test_php_mail_failure');
 
@@ -64,10 +69,10 @@ class MailTest extends KernelTestBase {
     $this->assertInstanceOf(TestPhpMailFailure::class, $mail_backend);
 
     // Add a module-specific mail backend.
-    $this->config('system.mail')->set('interface.mymodule_testkey', 'test_mail_collector')->save();
+    $this->config('system.mail')->set('interface.my_module_test_key', 'test_mail_collector')->save();
 
     // Get the added MailInterface class instance.
-    $mail_backend = \Drupal::service('plugin.manager.mail')->getInstance(['module' => 'mymodule', 'key' => 'testkey']);
+    $mail_backend = \Drupal::service('plugin.manager.mail')->getInstance(['module' => 'my_module', 'key' => 'test_key']);
 
     // Assert whether the added mail backend is an instance of the expected
     // class.
@@ -78,7 +83,7 @@ class MailTest extends KernelTestBase {
   /**
    * Assert that the pluggable mail system is functional.
    */
-  public function testErrorMessageDisplay() {
+  public function testErrorMessageDisplay(): void {
     // Switch mail backends.
     $this->configureDefaultMailInterface('test_php_mail_failure');
 
@@ -98,7 +103,7 @@ class MailTest extends KernelTestBase {
    *
    * @see mail_cancel_test_mail_alter()
    */
-  public function testCancelMessage() {
+  public function testCancelMessage(): void {
     $language_interface = \Drupal::languageManager()->getCurrentLanguage();
 
     // Reset the state variable that holds sent messages.
@@ -118,7 +123,7 @@ class MailTest extends KernelTestBase {
   /**
    * Checks the From: and Reply-to: headers.
    */
-  public function testFromAndReplyToHeader() {
+  public function testFromAndReplyToHeader(): void {
     $language = \Drupal::languageManager()->getCurrentLanguage();
 
     // Reset the state variable that holds sent messages.
@@ -195,7 +200,7 @@ class MailTest extends KernelTestBase {
   /**
    * Checks that relative paths in mails are converted into absolute URLs.
    */
-  public function testConvertRelativeUrlsIntoAbsolute() {
+  public function testConvertRelativeUrlsIntoAbsolute(): void {
     $language_interface = \Drupal::languageManager()->getCurrentLanguage();
 
     $this->configureDefaultMailInterface('test_html_mail_collector');
@@ -282,7 +287,7 @@ class MailTest extends KernelTestBase {
    * By default Drupal uses relative paths for images and links. When sending
    * emails, absolute paths should be used instead.
    */
-  public function testRenderedElementsUseAbsolutePaths() {
+  public function testRenderedElementsUseAbsolutePaths(): void {
     $language_interface = \Drupal::languageManager()->getCurrentLanguage();
 
     $this->configureDefaultMailInterface('test_html_mail_collector');
@@ -382,7 +387,7 @@ class MailTest extends KernelTestBase {
    * @param string $mail_interface
    *   The mail interface to configure.
    */
-  protected function configureDefaultMailInterface($mail_interface) {
+  protected function configureDefaultMailInterface($mail_interface): void {
     $GLOBALS['config']['system.mail']['interface']['default'] = $mail_interface;
   }
 
