@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\system\Kernel\Migrate\d7;
 
 use Drupal\Tests\SchemaCheckTestTrait;
@@ -25,7 +27,7 @@ class MigrateActionConfigsTest extends MigrateDrupal7TestBase {
   /**
    * Tests migration of action variables to null.
    */
-  public function testActionSettings() {
+  public function testActionSettings(): void {
     $config = $this->config('action.settings');
     $this->assertTrue($config->isNew());
   }
