@@ -1,9 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\taxonomy\Functional;
 
 use Drupal\Component\Utility\Tags;
 use Drupal\Core\Field\FieldStorageDefinitionInterface;
+use Drupal\Core\Url;
 use Drupal\field\Entity\FieldConfig;
 use Drupal\taxonomy\Entity\Term;
 use Drupal\taxonomy\TermInterface;
@@ -13,7 +16,6 @@ use Drupal\Tests\system\Functional\Menu\AssertBreadcrumbTrait;
  * Tests load, save and delete for taxonomy terms.
  *
  * @group taxonomy
- * @group #slow
  */
 class TermTest extends TaxonomyTestBase {
 
@@ -34,11 +36,9 @@ class TermTest extends TaxonomyTestBase {
   protected $field;
 
   /**
-   * Modules to enable.
-   *
-   * @var string[]
+   * {@inheritdoc}
    */
-  protected static $modules = ['block'];
+  protected static $modules = ['block', 'taxonomy_test'];
 
   /**
    * {@inheritdoc}
@@ -70,7 +70,7 @@ class TermTest extends TaxonomyTestBase {
       ],
       'auto_create' => TRUE,
     ];
-    $this->createEntityReferenceField('node', 'article', $field_name, NULL, 'taxonomy_term', 'default', $handler_settings, FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED);
+    $this->createEntityReferenceField('node', 'article', $field_name, '', 'taxonomy_term', 'default', $handler_settings, FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED);
     $this->field = FieldConfig::loadByName('node', 'article', $field_name);
 
     /** @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface $display_repository */
@@ -87,19 +87,10 @@ class TermTest extends TaxonomyTestBase {
       ->save();
   }
 
-  /**
-   * The "parent" field must restrict references to the same vocabulary.
-   */
-  public function testParentHandlerSettings() {
-    $vocabulary_fields = \Drupal::service('entity_field.manager')->getFieldDefinitions('taxonomy_term', $this->vocabulary->id());
-    $parent_target_bundles = $vocabulary_fields['parent']->getSetting('handler_settings')['target_bundles'];
-    $this->assertSame([$this->vocabulary->id() => $this->vocabulary->id()], $parent_target_bundles);
-  }
-
   /**
    * Tests terms in a single and multiple hierarchy.
    */
-  public function testTaxonomyTermHierarchy() {
+  public function testTaxonomyTermHierarchy(): void {
     // Create two taxonomy terms.
     $term1 = $this->createTerm($this->vocabulary);
     $term2 = $this->createTerm($this->vocabulary);
@@ -141,14 +132,12 @@ class TermTest extends TaxonomyTestBase {
   /**
    * Tests that many terms with parents show on each page.
    */
-  public function testTaxonomyTermChildTerms() {
+  public function testTaxonomyTermChildTerms(): void {
     // Set limit to 10 terms per page. Set variable to 9 so 10 terms appear.
     $this->config('taxonomy.settings')->set('terms_per_page_admin', '9')->save();
     $term1 = $this->createTerm($this->vocabulary);
     $terms_array = [];
 
-    $taxonomy_storage = $this->container->get('entity_type.manager')->getStorage('taxonomy_term');
-
     // Create 40 terms. Terms 1-12 get parent of $term1. All others are
     // individual terms.
     for ($x = 1; $x <= 40; $x++) {
@@ -161,8 +150,6 @@ class TermTest extends TaxonomyTestBase {
         $edit['parent'] = $term1->id();
       }
       $term = $this->createTerm($this->vocabulary, $edit);
-      $children = $taxonomy_storage->loadChildren($term1->id());
-      $parents = $taxonomy_storage->loadParents($term->id());
       $terms_array[$x] = Term::load($term->id());
     }
 
@@ -195,7 +182,7 @@ class TermTest extends TaxonomyTestBase {
   /**
    * Tests term creation with a free-tagging vocabulary from the node form.
    */
-  public function testNodeTermCreationAndDeletion() {
+  public function testNodeTermCreationAndDeletion(): void {
     // Enable tags in the vocabulary.
     $field = $this->field;
     \Drupal::service('entity_display.repository')
@@ -290,7 +277,7 @@ class TermTest extends TaxonomyTestBase {
   /**
    * Save, edit and delete a term using the user interface.
    */
-  public function testTermInterface() {
+  public function testTermInterface(): void {
     \Drupal::service('module_installer')->install(['views']);
     $edit = [
       'name[0][value]' => $this->randomMachineName(12),
@@ -427,7 +414,7 @@ class TermTest extends TaxonomyTestBase {
   /**
    * Test UI with override_selector TRUE.
    */
-  public function testTermSaveOverrideSelector() {
+  public function testTermSaveOverrideSelector(): void {
     $this->config('taxonomy.settings')->set('override_selector', TRUE)->save();
 
     // Create a Term.
@@ -452,7 +439,7 @@ class TermTest extends TaxonomyTestBase {
   /**
    * Save, edit and delete a term using the user interface.
    */
-  public function testTermReorder() {
+  public function testTermReorder(): void {
     $assert = $this->assertSession();
     $this->createTerm($this->vocabulary);
     $this->createTerm($this->vocabulary);
@@ -520,7 +507,7 @@ class TermTest extends TaxonomyTestBase {
   /**
    * Tests saving a term with multiple parents through the UI.
    */
-  public function testTermMultipleParentsInterface() {
+  public function testTermMultipleParentsInterface(): void {
     // Add two new terms to the vocabulary so that we can have multiple parents.
     // These will be terms with tids of 1 and 2 respectively.
     $this->createTerm($this->vocabulary);
@@ -578,6 +565,43 @@ class TermTest extends TaxonomyTestBase {
     $this->assertEquals([1, 2], $this->getParentTids($term), 'Term parents (two real) were successfully saved.');
   }
 
+  /**
+   * Tests destination after saving terms.
+   */
+  public function testRedirects(): void {
+    // Save a new term.
+    $addUrl = Url::fromRoute('entity.taxonomy_term.add_form', ['taxonomy_vocabulary' => $this->vocabulary->id()]);
+    $this->drupalGet($addUrl);
+    $this->submitForm([
+      'name[0][value]' => $this->randomMachineName(),
+    ], 'Save');
+
+    // Adding a term reloads the form.
+    $this->assertSession()->addressEquals($addUrl->toString());
+    $this->assertSession()->pageTextContains('Created new term');
+
+    // Update a term.
+    $term = Term::create(['vid' => $this->vocabulary->id(), 'name' => $this->randomMachineName()]);
+    $term->save();
+    $this->drupalGet($term->toUrl('edit-form'));
+    $this->submitForm(edit: [], submit: 'Save');
+
+    // Updating a term sends user to view the term.
+    $this->assertSession()->addressEquals($term->toUrl()->setAbsolute());
+    $this->assertSession()->pageTextContains('Updated term');
+
+    // Unless the term is not accessible to the user.
+    // Label triggers forbidden in taxonomy_test_entity_access().
+    $term = Term::create(['vid' => $this->vocabulary->id(), 'name' => 'Inaccessible view']);
+    $term->save();
+    $this->drupalGet($term->toUrl('edit-form'));
+    $this->submitForm(edit: [], submit: 'Save');
+
+    // In which case, the edit form is reloaded.
+    $this->assertSession()->addressEquals($term->toUrl('edit-form')->setAbsolute());
+    $this->assertSession()->pageTextContains('Updated term');
+  }
+
   /**
    * Reloads a term by name.
    *
@@ -603,7 +627,7 @@ class TermTest extends TaxonomyTestBase {
    * @return array
    *   A sorted array of tids and 0 if the root is a parent.
    */
-  private function getParentTids($term) {
+  private function getParentTids($term): array {
     $parent_tids = [];
     foreach ($term->get('parent') as $item) {
       $parent_tids[] = (int) $item->target_id;
@@ -616,7 +640,7 @@ class TermTest extends TaxonomyTestBase {
   /**
    * Tests that editing and saving a node with no changes works correctly.
    */
-  public function testReSavingTags() {
+  public function testReSavingTags(): void {
     // Enable tags in the vocabulary.
     $field = $this->field;
     \Drupal::service('entity_display.repository')
@@ -646,7 +670,7 @@ class TermTest extends TaxonomyTestBase {
   /**
    * Check the breadcrumb on edit and delete a term page.
    */
-  public function testTermBreadcrumbs() {
+  public function testTermBreadcrumbs(): void {
     $edit = [
       'name[0][value]' => $this->randomMachineName(14),
       'description[0][value]' => $this->randomMachineName(100),
@@ -680,4 +704,24 @@ class TermTest extends TaxonomyTestBase {
     $this->assertSession()->assertEscaped($term->label());
   }
 
+  /**
+   * Tests the order of primary tabs on the term edit page.
+   */
+  public function testPrimaryTabsOrder(): void {
+    $term = $this->createTerm($this->vocabulary);
+    $this->drupalGet($term->toUrl('edit-form'));
+    $this->assertSession()->statusCodeEquals(200);
+
+    // Getting primary tab items.
+    $tab_links = $this->xpath('//h2[text()[contains(.,"Primary tabs")]]/following-sibling::ul[1]/li/a');
+    $labels = array_map(fn($link) => $link->getText(), $tab_links);
+    $edit_index = array_search('Edit', $labels);
+    $delete_index = array_search('Delete', $labels);
+
+    // Check that "Edit" comes before "Delete".
+    $this->assertIsInt($edit_index, '"Edit" tab found');
+    $this->assertIsInt($delete_index, '"Delete" tab found');
+    $this->assertLessThan($delete_index, $edit_index, '"Edit" tab appears before "Delete" tab');
+  }
+
 }
