@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\taxonomy\Functional\Views;
 
 use Drupal\Tests\field\Traits\EntityReferenceFieldCreationTrait;
@@ -13,7 +15,6 @@ use Drupal\views\Entity\View;
  * Tests the taxonomy index filter handler UI.
  *
  * @group taxonomy
- * @group #slow
  * @see \Drupal\taxonomy\Plugin\views\field\TaxonomyIndexTid
  */
 class TaxonomyIndexTidUiTest extends UITestBase {
@@ -37,9 +38,7 @@ class TaxonomyIndexTidUiTest extends UITestBase {
   protected $defaultTheme = 'stark';
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = [
     'node',
@@ -92,6 +91,18 @@ class TaxonomyIndexTidUiTest extends UITestBase {
     }
     ViewTestData::createTestViews(static::class, ['taxonomy_test_views']);
 
+    // Extra taxonomy and terms.
+    Vocabulary::create([
+      'vid' => 'other_tags',
+      'name' => 'Other tags',
+    ])->save();
+
+    $this->terms[3][0] = $term = Term::create([
+      'vid' => 'tags',
+      'name' => "Term 3.0",
+    ]);
+    $term->save();
+
     Vocabulary::create([
       'vid' => 'empty_vocabulary',
       'name' => 'Empty Vocabulary',
@@ -101,7 +112,7 @@ class TaxonomyIndexTidUiTest extends UITestBase {
   /**
    * Tests the filter UI.
    */
-  public function testFilterUI() {
+  public function testFilterUI(): void {
     $this->drupalGet('admin/structure/views/nojs/handler/test_filter_taxonomy_index_tid/default/filter/tid');
 
     $result = $this->assertSession()->selectExists('edit-options-value')->findAll('css', 'option');
@@ -148,12 +159,12 @@ class TaxonomyIndexTidUiTest extends UITestBase {
   /**
    * Tests exposed taxonomy filters.
    */
-  public function testExposedFilter() {
+  public function testExposedFilter(): void {
     $node_type = $this->drupalCreateContentType(['type' => 'page']);
 
     // Create the tag field itself.
     $field_name = 'taxonomy_tags';
-    $this->createEntityReferenceField('node', $node_type->id(), $field_name, NULL, 'taxonomy_term');
+    $this->createEntityReferenceField('node', $node_type->id(), $field_name, '', 'taxonomy_term');
 
     // Create 4 nodes: 1 without a term, 2 with the same term, and 1 with a
     // different term.
@@ -279,11 +290,11 @@ class TaxonomyIndexTidUiTest extends UITestBase {
   /**
    * Tests exposed grouped taxonomy filters.
    */
-  public function testExposedGroupedFilter() {
+  public function testExposedGroupedFilter(): void {
     // Create a content type with a taxonomy field.
     $this->drupalCreateContentType(['type' => 'article']);
     $field_name = 'field_views_testing_tags';
-    $this->createEntityReferenceField('node', 'article', $field_name, NULL, 'taxonomy_term');
+    $this->createEntityReferenceField('node', 'article', $field_name, '', 'taxonomy_term');
 
     $nodes = [];
     for ($i = 0; $i < 3; $i++) {
@@ -323,7 +334,7 @@ class TaxonomyIndexTidUiTest extends UITestBase {
   /**
    * Tests that an exposed taxonomy filter doesn't show unpublished terms.
    */
-  public function testExposedUnpublishedFilterOptions() {
+  public function testExposedUnpublishedFilterOptions(): void {
     $this->terms[1][0]->setUnpublished()->save();
     // Expose the filter.
     $this->drupalGet('admin/structure/views/nojs/handler/test_filter_taxonomy_index_tid/default/filter/tid');
@@ -362,15 +373,19 @@ class TaxonomyIndexTidUiTest extends UITestBase {
   /**
    * Tests using the TaxonomyIndexTid in a filter group.
    */
-  public function testFilterGrouping() {
+  public function testFilterGrouping(): void {
     $node_type = $this->drupalCreateContentType(['type' => 'page']);
 
     // Create the tag field itself.
     $field_name = 'taxonomy_tags';
-    $this->createEntityReferenceField('node', $node_type->id(), $field_name, NULL, 'taxonomy_term');
+    $this->createEntityReferenceField('node', $node_type->id(), $field_name, '', 'taxonomy_term');
 
-    // Create 4 nodes: 1 node without any tagging, 2 nodes tagged with 1 term,
-    // and 1 node with 2 tagged terms.
+    // Create the other tag field itself.
+    $field_name2 = 'taxonomy_other_tags';
+    $this->createEntityReferenceField('node', $node_type->id(), $field_name2, '', 'taxonomy_term');
+
+    // Create 5 nodes: 1 node without any tagging, 2 nodes tagged with 1 term,
+    // 1 node with 2 tagged terms and 1 with other tags term.
     $node_no_term = $this->drupalCreateNode();
     $node_with_term_1_0 = $this->drupalCreateNode([
       $field_name => [['target_id' => $this->terms[1][0]->id()]],
@@ -385,6 +400,10 @@ class TaxonomyIndexTidUiTest extends UITestBase {
       $field_name => [['target_id' => $this->terms[2][0]->id()]],
     ]);
 
+    $node_with_term_3_0 = $this->drupalCreateNode([
+      $field_name2 => [['target_id' => $this->terms[3][0]->id()]],
+    ]);
+
     // Create two groups. The first group contains the published filter and set
     // up the second group as an 'OR' group. The first subgroup of the second
     // filter group will vary as follows:
@@ -490,6 +509,45 @@ class TaxonomyIndexTidUiTest extends UITestBase {
     $this->assertSession()->pageTextContainsOnce($node_with_terms_1_0_and_1_1->label());
     $this->assertSession()->pageTextContainsOnce($node_with_term_2_0->label());
     $this->assertSession()->pageTextNotContains($node_no_term->label());
+
+    // Different fields/taxonomies filters/values.
+    // Case 5: OR
+    // - filter "tid" with terms from tags as "is one of"
+    // - filter "taxonomy_other_tags_target_id" with term from other tags
+    // as "is one of".
+    $view = View::load('test_filter_taxonomy_index_tid');
+    $display = &$view->getDisplay('default');
+    $display['display_options']['filters']['tid']['value'][0] = $this->terms[1][0]->id();
+    $display['display_options']['filters']['tid']['value'][1] = $this->terms[1][1]->id();
+    $display['display_options']['filters']['tid']['operator'] = 'or';
+    $display['display_options']['filters']['tid']['group'] = 2;
+    $display['display_options']['filters']['taxonomy_other_tags_target_id'] = $display['display_options']['filters']['tid'];
+    $display['display_options']['filters']['taxonomy_other_tags_target_id']['id'] = 'taxonomy_other_tags_target_id';
+    $display['display_options']['filters']['taxonomy_other_tags_target_id']['value'][0] = $this->terms[3][0]->id();
+    $display['display_options']['filters']['taxonomy_other_tags_target_id']['operator'] = 'or';
+    $display['display_options']['filters']['taxonomy_other_tags_target_id']['group'] = 2;
+    $display['display_options']['filters']['taxonomy_other_tags_target_id']['table'] = 'node__taxonomy_other_tags';
+    $display['display_options']['filters']['taxonomy_other_tags_target_id']['field'] = 'taxonomy_other_tags_target_id';
+    unset($display['display_options']['filters']['tid_2']);
+    $display['display_options']['filter_groups'] = [
+      'operator' => 'AND',
+      'groups' => [
+        1 => 'AND',
+        2 => 'OR',
+      ],
+    ];
+    $view->save();
+
+    $this->drupalGet('test-filter-taxonomy-index-tid');
+    // We expect no nodes tagged with term 1.0 or 1.1. The node tagged with
+    // term 3.0 and the untagged node will be shown.
+    $this->assertSession()->pageTextContainsOnce($node_with_term_1_0->label());
+    // The view does not have DISTINCT query enabled, the node tagged with
+    // both 1.0 and 1.1 will appear twice.
+    $this->assertSession()->pageTextMatchesCount(2, "/{$node_with_terms_1_0_and_1_1->label()}/");
+    $this->assertSession()->pageTextContainsOnce($node_with_term_3_0->label());
+    $this->assertSession()->pageTextNotContains($node_with_term_2_0->label());
+    $this->assertSession()->pageTextNotContains($node_no_term->label());
   }
 
 }
