@@ -24,9 +24,8 @@ class RemoveRoleUser extends ChangeUserRoleBase {
     if ($account !== FALSE && $account->hasRole($rid)) {
       // For efficiency manually save the original account before applying
       // any changes.
-      $account->original = clone $account;
-      $account->removeRole($rid);
-      $account->save();
+      $account->setOriginal(clone $account);
+      $account->removeRole($rid)->save();
     }
   }
 
