@@ -18,22 +18,20 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
 /**
  * Base class for any views plugin types.
  *
- * Via the @Plugin definition the plugin may specify a theme function or
+ * Via the plugin definition the plugin may specify a theme function or
  * template to be used for the plugin. It also can auto-register the theme
  * implementation for that file or function.
- * - theme: the theme implementation to use in the plugin. This may be the name
- *   of the function (without theme_ prefix) or the template file (without
- *   template engine extension).
- *   If a template file should be used, the file has to be placed in the
- *   module's templates folder.
- *   Example: theme = "mymodule_row" of module "mymodule" will implement
- *   mymodule-row.html.twig in the [..]/modules/mymodule/templates folder.
+ * - theme: the theme implementation to use in the plugin. This must be the
+ *   name of the template file (without template engine extension). The file
+ *   has to be placed in the module's templates folder.
+ *   Example: theme = "my_module_row" of module "my_module" will implement
+ *   my_module-row.html.twig in the [..]/modules/my_module/templates folder.
  * - register_theme: (optional) When set to TRUE (default) the theme is
  *   registered automatically. When set to FALSE the plugin reuses an existing
  *   theme implementation, defined by another module or views plugin.
- * - theme_file: (optional) the location of an include file that may hold the
- *   theme or preprocess function. The location has to be relative to module's
- *   root directory.
+ * - theme_file: (optional) the location of an include file that holds any
+ *   preprocess functions. The location has to be relative to the module's root
+ *   directory.
  * - module: machine name of the module. It must be present for any plugin that
  *   wants to register a theme.
  *
@@ -81,14 +79,14 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
    *
    * For display plugins this is empty.
    *
-   * @todo find a better description
-   *
    * @var \Drupal\views\Plugin\views\display\DisplayPluginBase
+   *
+   * @todo find a better description
    */
   public $displayHandler;
 
   /**
-   * Plugins's definition.
+   * Plugins' definition.
    *
    * @var array
    */
@@ -108,13 +106,18 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
    */
   protected $renderer;
 
+  /**
+   * The handler position.
+   */
+  public int $position;
+
   /**
    * Constructs a PluginBase object.
    *
    * @param array $configuration
    *   A configuration array containing information about the plugin instance.
    * @param string $plugin_id
-   *   The plugin_id for the plugin instance.
+   *   The plugin ID for the plugin instance.
    * @param mixed $plugin_definition
    *   The plugin implementation definition.
    */
@@ -134,8 +137,9 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
   /**
    * {@inheritdoc}
    */
-  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
+  public function init(ViewExecutable $view, DisplayPluginBase $display, ?array &$options = NULL) {
     $this->view = $view;
+    $this->options = $this->options ?? [];
     $this->setOptionDefaults($this->options, $this->defineOptions());
     $this->displayHandler = $display;
 
@@ -145,12 +149,12 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
   /**
    * Information about options for all kinds of purposes will be held here.
    * @code
-   * 'option_name' => array(
+   * 'option_name' => [
    *  - 'default' => default value,
    *  - 'contains' => (optional) array of items this contains, with its own
    *      defaults, etc. If contains is set, the default will be ignored and
-   *      assumed to be array().
-   *  ),
+   *      assumed to be [].
+   *  ],
    * @endcode
    *
    * @return array
@@ -265,9 +269,9 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
    */
   public function buildOptionsForm(&$form, FormStateInterface $form_state) {
     // Some form elements belong in a fieldset for presentation, but can't
-    // be moved into one because of the $form_state->getValues() hierarchy. Those
-    // elements can add a #fieldset => 'fieldset_name' property, and they'll
-    // be moved to their fieldset during pre_render.
+    // be moved into one because of the $form_state->getValues() hierarchy.
+    // Those elements can add a #fieldset => 'fieldset_name' property, and
+    // they'll be moved to their fieldset during pre_render.
     $form['#pre_render'][] = [static::class, 'preRenderAddFieldsetMarkup'];
   }
 
@@ -340,15 +344,17 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
   }
 
   /**
-   * Replaces Views' tokens in a given string. The resulting string will be
-   * sanitized with Xss::filterAdmin.
+   * Replaces Views' tokens in a given string.
    *
-   * @param $text
+   * The resulting string will be sanitized with Xss::filterAdmin.
+   *
+   * @param string $text
    *   Unsanitized string with possible tokens.
-   * @param $tokens
+   * @param array $tokens
    *   Array of token => replacement_value items.
    *
    * @return string
+   *   The sanitized string with tokens replaced.
    */
   protected function viewsTokenReplace($text, $tokens) {
     if (!strlen($text)) {
@@ -363,8 +369,8 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
     foreach ($tokens as $token => $replacement) {
       // Twig wants a token replacement array stripped of curly-brackets.
       // Some Views tokens come with curly-braces, others do not.
-      // @todo: https://www.drupal.org/node/2544392
-      if (strpos($token, '{{') !== FALSE) {
+      // @todo https://www.drupal.org/node/2544392
+      if (str_contains($token, '{{')) {
         // Twig wants a token replacement array stripped of curly-brackets.
         $token = trim(str_replace(['{{', '}}'], '', $token));
       }
@@ -372,7 +378,7 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
       // Check for arrays in Twig tokens. Internally these are passed as
       // dot-delimited strings, but need to be turned into associative arrays
       // for parsing.
-      if (strpos($token, '.') === FALSE) {
+      if (!str_contains($token, '.')) {
         // We need to validate tokens are valid Twig variables. Twig uses the
         // same variable naming rules as PHP.
         // @see http://php.net/manual/language.variables.basics.php
@@ -413,10 +419,10 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
       ];
 
       // Currently you cannot attach assets to tokens with
-      // Renderer::renderPlain(). This may be unnecessarily limiting. Consider
-      // using Renderer::executeInRenderContext() instead.
-      // @todo: https://www.drupal.org/node/2566621
-      return (string) $this->getRenderer()->renderPlain($build);
+      // Renderer::renderInIsolation(). This may be unnecessarily limiting.
+      // Consider using Renderer::executeInRenderContext() instead.
+      // @todo https://www.drupal.org/node/2566621
+      return (string) $this->getRenderer()->renderInIsolation($build);
     }
     else {
       return Xss::filterAdmin($text);
@@ -555,7 +561,7 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
    *   Only configurable languages and languages that are in $current_values are
    *   included in the list.
    */
-  protected function listLanguages($flags = LanguageInterface::STATE_ALL, array $current_values = NULL) {
+  protected function listLanguages($flags = LanguageInterface::STATE_ALL, ?array $current_values = NULL) {
     $manager = \Drupal::languageManager();
     $languages = $manager->getLanguages($flags);
     $list = [];
@@ -576,6 +582,7 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
       // translate it again.
       // @see Drupal\Core\Language::filterLanguages().
       if (!$name instanceof TranslatableMarkup) {
+        // phpcs:ignore Drupal.Semantics.FunctionT.NotLiteralString
         $name = $this->t($name);
       }
       $list[PluginBase::VIEWS_QUERY_LANGUAGE_SITE_DEFAULT] = $name;
@@ -653,6 +660,7 @@ abstract class PluginBase extends ComponentPluginBase implements ContainerFactor
    * Returns the render API renderer.
    *
    * @return \Drupal\Core\Render\RendererInterface
+   *   The renderer service.
    */
   protected function getRenderer() {
     if (!isset($this->renderer)) {
