@@ -2,11 +2,14 @@
 
 namespace Drupal\views\Plugin\views\argument;
 
+use Drupal\views\Attribute\ViewsArgument;
+
 /**
  * Argument handler for a full date (CCYYMMDD)
- *
- * @ViewsArgument("date_fulldate")
  */
+#[ViewsArgument(
+  id: 'date_fulldate',
+)]
 class FullDate extends Date {
 
   /**
