@@ -232,8 +232,8 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
         $this->limit_values = TRUE;
       }
 
-      // Otherwise, we only limit values if the user hasn't selected "all", 0, or
-      // the value matching field cardinality.
+      // Otherwise, we only limit values if the user hasn't selected "all", 0,
+      // or the value matching field cardinality.
       if ((($this->options['delta_limit'] > 0) && ($this->options['delta_limit'] != $cardinality)) || intval($this->options['delta_offset'])) {
         $this->limit_values = TRUE;
       }
@@ -254,7 +254,7 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
    * By default, all needed data is taken from entities loaded by the query
    * plugin. Columns are added only if they are used in groupings.
    */
-  public function query($use_groupby = FALSE) {
+  public function query($use_group_by = FALSE) {
     $fields = $this->additional_fields;
     // No need to add the entity type.
     $entity_type_key = array_search('entity_type', $fields);
@@ -262,7 +262,7 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
       unset($fields[$entity_type_key]);
     }
 
-    if ($use_groupby) {
+    if ($use_group_by) {
       // Add the fields that we're actually grouping on.
       $options = [];
       if ($this->options['group_column'] != 'entity_id') {
@@ -270,7 +270,8 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
       }
       $options += is_array($this->options['group_columns']) ? $this->options['group_columns'] : [];
 
-      // Go through the list and determine the actual column name from field api.
+      // Go through the list and determine the actual column name from field
+      // api.
       $fields = [];
       $table_mapping = $this->getTableMapping();
       $field_definition = $this->getFieldStorageDefinition();
@@ -283,7 +284,7 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
     }
 
     // Add additional fields (and the table join itself) if needed.
-    if ($this->add_field_table($use_groupby)) {
+    if ($this->add_field_table($use_group_by)) {
       $this->ensureMyTable();
       $this->addAdditionalFields($fields);
     }
@@ -295,9 +296,9 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
   /**
    * Determine if the field table should be added to the query.
    */
-  public function add_field_table($use_groupby) {
+  public function add_field_table($use_group_by) {
     // Grouping is enabled.
-    if ($use_groupby) {
+    if ($use_group_by) {
       return TRUE;
     }
     // This a multiple value field, but "group multiple values" is not checked.
@@ -357,7 +358,8 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
    *   The field storage definition used by this handler.
    *
    * @throws \Exception
-   *   If no field storage definition was found for the given entity type and field name.
+   *   If no field storage definition was found for the given entity type and
+   *   field name.
    */
   protected function getFieldStorageDefinition() {
     $entity_type_id = $this->definition['entity_type'];
@@ -679,7 +681,7 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
   }
 
   /**
-   * Extend the groupby form with group columns.
+   * Extend the group by form with group columns.
    */
   public function buildGroupByForm(&$form, FormStateInterface $form_state) {
     parent::buildGroupByForm($form, $form_state);
@@ -714,6 +716,9 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
     ];
   }
 
+  /**
+   * {@inheritdoc}
+   */
   public function submitGroupByForm(&$form, FormStateInterface $form_state) {
     parent::submitGroupByForm($form, $form_state);
     $item = &$form_state->get('handler')->options;
@@ -749,6 +754,7 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
       }
       return $this->renderer->render($build);
     }
+    return NULL;
   }
 
   /**
@@ -966,10 +972,16 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
     return $processed_entity;
   }
 
+  /**
+   * {@inheritdoc}
+   */
   public function render_item($count, $item) {
     return $this->renderer->render($item['rendered']);
   }
 
+  /**
+   * {@inheritdoc}
+   */
   protected function documentSelfTokens(&$tokens) {
     $field = $this->getFieldDefinition();
     foreach ($field->getColumns() as $id => $column) {
@@ -977,6 +989,9 @@ class EntityField extends FieldPluginBase implements CacheableDependencyInterfac
     }
   }
 
+  /**
+   * {@inheritdoc}
+   */
   protected function addSelfTokens(&$tokens, $item) {
     $field = $this->getFieldDefinition();
     foreach ($field->getColumns() as $id => $column) {
