@@ -4,15 +4,15 @@ namespace Drupal\views\Plugin\views\field;
 
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\StringTranslation\ByteSizeMarkup;
+use Drupal\views\Attribute\ViewsField;
 use Drupal\views\ResultRow;
 
 /**
  * Render a numeric value as a size.
  *
  * @ingroup views_field_handlers
- *
- * @ViewsField("file_size")
  */
+#[ViewsField("file_size")]
 class FileSize extends FieldPluginBase {
 
   /**
