@@ -21,8 +21,8 @@ use Drupal\views\ViewExecutable;
  * Plugins that handle views filtering.
  *
  * Filter handler plugins extend
- * \Drupal\views\Plugin\views\filter\FilterPluginBase. They must be annotated
- * with \Drupal\views\Annotation\ViewsFilter annotation, and they must be in
+ * \Drupal\views\Plugin\views\filter\FilterPluginBase. They must be attributed
+ * with \Drupal\views\Attribute\ViewsFilter attribute, and they must be in
  * namespace directory Plugin\views\filter.
  *
  * The following items can go into a hook_views_data() implementation in a
@@ -68,6 +68,8 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    *
    * Contains the actual value of the field,either configured in the views ui
    * or entered in the exposed filters.
+   *
+   * @var mixed
    */
   public $value = NULL;
 
@@ -80,25 +82,33 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
 
   /**
    * Contains the information of the selected item in a grouped filter.
+   *
+   * @var array
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName, Drupal.Commenting.VariableComment.Missing
   public $group_info = NULL;
 
   /**
-   * @var bool
    * Disable the possibility to force a single value.
+   *
+   * @var bool
    */
   protected $alwaysMultiple = FALSE;
 
   /**
-   * @var bool
    * Disable the possibility to use operators.
+   *
+   * @var bool
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName, Drupal.Commenting.VariableComment.Missing
   public $no_operator = FALSE;
 
   /**
-   * @var bool
    * Disable the possibility to allow an exposed input to be optional.
+   *
+   * @var bool
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName, Drupal.Commenting.VariableComment.Missing
   public $always_required = FALSE;
 
   /**
@@ -116,7 +126,7 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * This likely has to be overridden by filters which are more complex
    * than simple operator/value.
    */
-  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
+  public function init(ViewExecutable $view, DisplayPluginBase $display, ?array &$options = NULL) {
     parent::init($view, $display, $options);
 
     $this->operator = $this->options['operator'];
@@ -141,6 +151,9 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
     }
   }
 
+  /**
+   * {@inheritdoc}
+   */
   protected function defineOptions() {
     $options = parent::defineOptions();
 
@@ -232,6 +245,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * If overridden, it is best to call through to the parent,
    * or to at least make sure all of the functions in this form
    * are called.
+   *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   public function buildOptionsForm(&$form, FormStateInterface $form_state) {
     parent::buildOptionsForm($form, $form_state);
@@ -273,6 +292,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
 
   /**
    * Simple validate handler.
+   *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   public function validateOptionsForm(&$form, FormStateInterface $form_state) {
     $this->operatorValidate($form, $form_state);
@@ -287,6 +312,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
 
   /**
    * Simple submit handler.
+   *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   public function submitOptionsForm(&$form, FormStateInterface $form_state) {
     // Do not store these values.
@@ -320,6 +351,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * This may be overridden by child classes, and it must
    * define $form['operator'];
    *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
+   *
    * @see buildOptionsForm()
    */
   protected function operatorForm(&$form, FormStateInterface $form_state) {
@@ -345,6 +382,11 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
 
   /**
    * Validate the operator form.
+   *
+   * @param array $form
+   *   Associative array containing the structure of the form.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   protected function operatorValidate($form, FormStateInterface $form_state) {}
 
@@ -352,11 +394,22 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * Perform any necessary changes to the form values prior to storage.
    *
    * There is no need for this function to actually store the data.
+   *
+   * @param array $form
+   *   Associative array containing the structure of the form.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   public function operatorSubmit($form, FormStateInterface $form_state) {}
 
   /**
    * Shortcut to display the value form.
+   *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   protected function showValueForm(&$form, FormStateInterface $form_state) {
     $this->valueForm($form, $form_state);
@@ -372,6 +425,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * This should be overridden by all child classes and it must
    * define $form['value']
    *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
+   *
    * @see buildOptionsForm()
    */
   protected function valueForm(&$form, FormStateInterface $form_state) {
@@ -380,6 +439,11 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
 
   /**
    * Validate the options form.
+   *
+   * @param array $form
+   *   Associative array containing the structure of the form.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   protected function valueValidate($form, FormStateInterface $form_state) {}
 
@@ -387,11 +451,22 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * Perform any necessary changes to the form values prior to storage.
    *
    * There is no need for this function to actually store the data.
+   *
+   * @param array $form
+   *   Associative array containing the structure of the form.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   protected function valueSubmit($form, FormStateInterface $form_state) {}
 
   /**
    * Shortcut to display the exposed options form.
+   *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   public function showBuildGroupForm(&$form, FormStateInterface $form_state) {
     if (empty($this->options['is_grouped'])) {
@@ -415,6 +490,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
 
   /**
    * Shortcut to display the build_group/hide button.
+   *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   protected function showBuildGroupButton(&$form, FormStateInterface $form_state) {
 
@@ -492,6 +573,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
 
   /**
    * Shortcut to display the expose/hide button.
+   *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   public function showExposeButton(&$form, FormStateInterface $form_state) {
     $form['expose_button'] = [
@@ -542,6 +629,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
   /**
    * Options form subform for exposed filter options.
    *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
+   *
    * @see buildOptionsForm()
    */
   public function buildExposeForm(&$form, FormStateInterface $form_state) {
@@ -695,6 +788,9 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * Validate the options form.
    */
   public function validateExposeForm($form, FormStateInterface $form_state) {
+    $remember_role_keys = ['options', 'expose', 'remember_roles'];
+    $roles = $form_state->getValue($remember_role_keys);
+    $form_state->setValue($remember_role_keys, array_filter($roles));
     $identifier = $form_state->getValue(['options', 'expose', 'identifier']);
     $this->validateIdentifier($identifier, $form_state, $form['expose']['identifier']);
 
@@ -715,8 +811,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    *   A group entry as defined by buildGroupForm().
    *
    * @return bool
+   *   TRUE if the grouped filter entry has a valid value, FALSE otherwise.
    */
   protected function hasValidGroupedValue(array $group) {
+    if (!method_exists($this, 'operators')) {
+      throw new \LogicException(get_class($this) . '::operators() not implemented');
+    }
     $operators = $this->operators();
     if ($operators[$group['operator']]['values'] == 0) {
       // Some filters, such as "is empty," do not require a value to be
@@ -753,6 +853,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
         if (empty($group['remove'])) {
           $has_valid_value = $this->hasValidGroupedValue($group);
           if ($has_valid_value && $group['title'] == '') {
+            if (!method_exists($this, 'operators')) {
+              throw new \LogicException(get_class($this) . '::operators() not implemented');
+            }
+            if (!$this instanceof FilterOperatorsInterface) {
+              @trigger_error('Implementing operators() in class ' . get_class($this) . ' without it implementing \Drupal\views\Plugin\views\filter\FilterOperatorsInterface is deprecated in drupal:10.3.0 and will throw a LogicException in drupal:12.0.0. See https://www.drupal.org/node/3412013', E_USER_DEPRECATED);
+            }
             $operators = $this->operators();
             if ($operators[$group['operator']]['values'] == 0) {
               $form_state->setError($form['group_info']['group_items'][$id]['title'], $this->t('A label is required for the specified operator.'));
@@ -783,8 +889,9 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    *   (optional) The form element to set any errors on.
    *
    * @return string
+   *   The error message if validation fails, or NULL if validation passes.
    */
-  protected function validateIdentifier($identifier, FormStateInterface $form_state = NULL, &$form_group = []) {
+  protected function validateIdentifier($identifier, ?FormStateInterface $form_state = NULL, &$form_group = []) {
     $error = '';
     if (empty($identifier)) {
       $error = $this->t('The identifier is required if the filter is exposed.');
@@ -926,6 +1033,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * Render our chunk of the exposed filter form when selecting.
    *
    * You can override this if it doesn't do what you expect.
+   *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   public function buildExposedForm(&$form, FormStateInterface $form_state) {
     if (empty($this->options['exposed'])) {
@@ -1022,6 +1135,12 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * Build the form to let users create the group of exposed filters.
    *
    * This form is displayed when users click on button 'Build group'.
+   *
+   * @param array $form
+   *   An alterable, associative array containing the structure of the form,
+   *   passed by reference.
+   * @param \Drupal\Core\Form\FormStateInterface $form_state
+   *   The current state of the form.
    */
   protected function buildExposedFiltersGroupForm(&$form, FormStateInterface $form_state) {
     if (empty($this->options['exposed']) || empty($this->options['is_grouped'])) {
@@ -1029,10 +1148,10 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
     }
     $form['#theme'] = 'views_ui_build_group_filter_form';
 
-    // #flatten will move everything from $form['group_info'][$key] to $form[$key]
-    // prior to rendering. That's why the preRender for it needs to run first,
-    // so that when the next preRender (the one for fieldsets) runs, it gets
-    // the flattened data.
+    // #flatten will move everything from $form['group_info'][$key] to
+    // $form[$key] prior to rendering. That's why the preRender for it needs to
+    // run first, so that when the next preRender (the one for fieldsets) runs,
+    // it gets the flattened data.
     array_unshift($form['#pre_render'], [static::class, 'preRenderFlattenData']);
     $form['group_info']['#flatten'] = TRUE;
 
@@ -1107,9 +1226,11 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
         continue;
       }
       // Each rows contains three widgets:
-      // a) The title, where users define how they identify a pair of operator | value
-      // b) The operator
-      // c) The value (or values) to use in the filter with the selected operator
+      // - The title, where users define how they identify a pair of
+      //   operator | value.
+      // - The operator.
+      // - The value (or values) to use in the filter with the selected
+      //   operator.
 
       // In each row, we have to display the operator form and the value from
       // $row acts as a fake form to render each widget in a row.
@@ -1285,7 +1406,8 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
       $form['#size'] = NULL;
     }
 
-    // Cleanup in case the translated element's (radios or checkboxes) display value contains html.
+    // Cleanup in case the translated element's (radios or checkboxes) display
+    // value contains html.
     if ($form['#type'] == 'select') {
       $this->prepareFilterSelectOptions($form['#options']);
     }
@@ -1395,7 +1517,8 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
         $this->options['expose']['operator_id'] = $operator_id;
         $this->options['expose']['use_operator'] = TRUE;
 
-        // Value can be optional, For example for 'empty' and 'not empty' filters.
+        // Value can be optional, For example for 'empty' and 'not empty'
+        // filters.
         if (isset($selected_group_options['value']) && $selected_group_options['value'] !== '') {
           $input[$this->options['group_info']['identifier']] = $selected_group_options['value'];
         }
@@ -1534,6 +1657,9 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
     return TRUE;
   }
 
+  /**
+   * {@inheritdoc}
+   */
   public function storeExposedInput($input, $status) {
     if (empty($this->options['exposed']) || empty($this->options['expose']['identifier'])) {
       return TRUE;
@@ -1555,7 +1681,7 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
     // know where to look for session stored values.
     $display_id = ($this->view->display_handler->isDefaulted('filters')) ? 'default' : $this->view->current_display;
 
-    // shortcut test.
+    // Shortcut test.
     $operator = !empty($this->options['expose']['use_operator']) && !empty($this->options['expose']['operator_id']);
 
     // False means that we got a setting that means to recurse ourselves,
@@ -1612,6 +1738,7 @@ abstract class FilterPluginBase extends HandlerBase implements CacheableDependen
    * if OR grouping is in use.
    *
    * @return bool
+   *   TRUE if the filter can be used in OR groups, FALSE otherwise.
    */
   public function canGroup() {
     return TRUE;
