@@ -5,11 +5,14 @@ namespace Drupal\views\Plugin\views\query;
 use Drupal\Component\Utility\NestedArray;
 use Drupal\Core\Cache\Cache;
 use Drupal\Core\Database\Database;
+use Drupal\Core\Database\Statement\FetchAs;
 use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Messenger\MessengerInterface;
+use Drupal\Core\StringTranslation\TranslatableMarkup;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
 use Drupal\Core\Database\DatabaseExceptionWrapper;
+use Drupal\views\Attribute\ViewsQuery;
 use Drupal\views\Plugin\views\join\JoinPluginBase;
 use Drupal\views\Plugin\views\HandlerBase;
 use Drupal\views\ResultRow;
@@ -21,22 +24,25 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  * Views query plugin for an SQL query.
  *
  * @ingroup views_query_plugins
- *
- * @ViewsQuery(
- *   id = "views_query",
- *   title = @Translation("SQL Query"),
- *   help = @Translation("Query will be generated and run using the Drupal database API.")
- * )
  */
+#[ViewsQuery(
+  id: 'views_query',
+  title: new TranslatableMarkup('SQL Query'),
+  help: new TranslatableMarkup('Query will be generated and run using the Drupal database API.')
+)]
 class Sql extends QueryPluginBase {
 
   /**
    * A list of tables in the order they should be added, keyed by alias.
+   *
+   * @var array
    */
   protected $tableQueue = [];
 
   /**
    * Holds an array of tables and counts added so that we can create aliases.
+   *
+   * @var array
    */
   public $tables = [];
 
@@ -45,6 +51,8 @@ class Sql extends QueryPluginBase {
    *
    * These are aliases of the primary table that represent different ways to
    * join the same table in.
+   *
+   * @var array
    */
   public $relationships = [];
 
@@ -53,6 +61,8 @@ class Sql extends QueryPluginBase {
    *
    * Each section is in itself an array of pieces and a flag as to whether or
    * not it should be AND or OR.
+   *
+   * @var array
    */
 
   public $where = [];
@@ -61,22 +71,30 @@ class Sql extends QueryPluginBase {
    *
    * Each section is in itself an array of pieces and a flag as to whether or
    * not it should be AND or OR.
+   *
+   * @var array
    */
   public $having = [];
 
   /**
    * A simple array of order by clauses.
+   *
+   * @var array
    */
   public $orderby = [];
 
   /**
    * A simple array of group by clauses.
+   *
+   * @var array
    */
   public $groupby = [];
 
 
   /**
    * An array of fields.
+   *
+   * @var array
    */
   public $fields = [];
 
@@ -94,16 +112,22 @@ class Sql extends QueryPluginBase {
 
   /**
    * Should this query be optimized for counts, for example no sorts.
+   *
+   * @var bool|null
    */
   protected $getCountOptimized = NULL;
 
   /**
    * An array mapping table aliases and field names to field aliases.
+   *
+   * @var array
    */
   protected $fieldAliases = [];
 
   /**
    * Query tags which will be passed over to the dbtng query object.
+   *
+   * @var array
    */
   public $tags = [];
 
@@ -138,6 +162,7 @@ class Sql extends QueryPluginBase {
   /**
    * The count field definition.
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName, Drupal.Commenting.VariableComment.Missing
   public array $count_field;
 
   /**
@@ -146,7 +171,7 @@ class Sql extends QueryPluginBase {
    * @param array $configuration
    *   A configuration array containing information about the plugin instance.
    * @param string $plugin_id
-   *   The plugin_id for the plugin instance.
+   *   The plugin ID for the plugin instance.
    * @param mixed $plugin_definition
    *   The plugin implementation definition.
    * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
@@ -184,7 +209,7 @@ class Sql extends QueryPluginBase {
   /**
    * {@inheritdoc}
    */
-  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
+  public function init(ViewExecutable $view, DisplayPluginBase $display, ?array &$options = NULL) {
     parent::init($view, $display, $options);
 
     $base_table = $this->view->storage->get('base_table');
@@ -196,7 +221,7 @@ class Sql extends QueryPluginBase {
       'base' => $base_table,
     ];
 
-    // init the table queue with our primary table.
+    // Initialize the table queue with our primary table.
     $this->tableQueue[$base_table] = [
       'alias' => $base_table,
       'table' => $base_table,
@@ -204,7 +229,7 @@ class Sql extends QueryPluginBase {
       'join' => NULL,
     ];
 
-    // init the tables with our primary table
+    // Init the tables with our primary table
     $this->tables[$base_table][$base_table] = [
       'count' => 1,
       'alias' => $base_table,
@@ -266,6 +291,9 @@ class Sql extends QueryPluginBase {
     ];
   }
 
+  /**
+   * {@inheritdoc}
+   */
   protected function defineOptions() {
     $options = parent::defineOptions();
     $options['disable_sql_rewrite'] = [
@@ -352,22 +380,22 @@ class Sql extends QueryPluginBase {
    * relationship.
    *
    * An example of a relationship would be a node reference table.
-   * If you have a node reference named 'book_parent' which links to a
-   * parent node, you could set up a relationship 'node_book_parent'
+   * If you have a node reference named 'content_parent' which links to a
+   * parent node, you could set up a relationship 'node_content_parent'
    * to 'node'. Then, anything that links to 'node' can link to
-   * 'node_book_parent' instead, thus allowing all properties of
+   * 'node_content_parent' instead, thus allowing all properties of
    * both nodes to be available in the query.
    *
-   * @param $alias
+   * @param string $alias
    *   What this relationship will be called, and is also the alias
    *   for the table.
    * @param \Drupal\views\Plugin\views\join\JoinPluginBase $join
    *   A Join object (or derived object) to join the alias in.
-   * @param $base
+   * @param string $base
    *   The name of the 'base' table this relationship represents; this
    *   tells the join search which path to attempt to use when finding
    *   the path to this relationship.
-   * @param $link_point
+   * @param string|null $link_point
    *   If this relationship links to something other than the primary
    *   table, specify that table here. For example, a 'track' node
    *   might have a relationship to an 'album' node, which might
@@ -424,10 +452,10 @@ class Sql extends QueryPluginBase {
    * table is valid and exists; if you do not wish for this testing to
    * occur, use $query->queueTable() instead.
    *
-   * @param $table
+   * @param string $table
    *   The name of the table to add. It needs to exist in the global table
    *   array.
-   * @param $relationship
+   * @param string|null $relationship
    *   An alias of a table; if this is set, the path back to this table will
    *   be tested prior to adding the table, making sure that all intermediary
    *   tables exist and are properly aliased. If set to NULL the path to
@@ -438,7 +466,7 @@ class Sql extends QueryPluginBase {
    *   a different method; this is most likely to be used when tracing
    *   a hierarchy path. (node->parent->parent2->parent3). This parameter
    *   will specify how this table joins if it is not the default.
-   * @param $alias
+   * @param string|null $alias
    *   A specific alias to use, rather than the default alias.
    *
    * @return string
@@ -447,7 +475,7 @@ class Sql extends QueryPluginBase {
    *   adding parts to the query. Or FALSE if the table was not able to be
    *   added.
    */
-  public function addTable($table, $relationship = NULL, JoinPluginBase $join = NULL, $alias = NULL) {
+  public function addTable($table, $relationship = NULL, ?JoinPluginBase $join = NULL, $alias = NULL) {
     if (!$this->ensurePath($table, $relationship, $join)) {
       return FALSE;
     }
@@ -466,10 +494,10 @@ class Sql extends QueryPluginBase {
    * ensureTable() should be used instead of this one, unless you are
    * absolutely sure this is what you want.
    *
-   * @param $table
+   * @param string $table
    *   The name of the table to add. It needs to exist in the global table
    *   array.
-   * @param $relationship
+   * @param string|null $relationship
    *   The primary table alias this table is related to. If not set, the
    *   primary table will be used.
    * @param \Drupal\views\Plugin\views\join\JoinPluginBase $join
@@ -477,7 +505,7 @@ class Sql extends QueryPluginBase {
    *   a different method; this is most likely to be used when tracing
    *   a hierarchy path. (node->parent->parent2->parent3). This parameter
    *   will specify how this table joins if it is not the default.
-   * @param $alias
+   * @param string|null $alias
    *   A specific alias to use, rather than the default alias.
    *
    * @return string
@@ -486,7 +514,7 @@ class Sql extends QueryPluginBase {
    *   adding parts to the query. Or FALSE if the table was not able to be
    *   added.
    */
-  public function queueTable($table, $relationship = NULL, JoinPluginBase $join = NULL, $alias = NULL) {
+  public function queueTable($table, $relationship = NULL, ?JoinPluginBase $join = NULL, $alias = NULL) {
     // If the alias is set, make sure it doesn't already exist.
     if (isset($this->tableQueue[$alias])) {
       return $alias;
@@ -509,8 +537,8 @@ class Sql extends QueryPluginBase {
       }
     }
 
-    // Check this again to make sure we don't blow up existing aliases for already
-    // adjusted joins.
+    // Check this again to make sure we don't blow up existing aliases for
+    // already adjusted joins.
     if (isset($this->tableQueue[$alias])) {
       return $alias;
     }
@@ -549,13 +577,16 @@ class Sql extends QueryPluginBase {
     return $alias;
   }
 
+  /**
+   * Marks a relationship based table as included.
+   */
   protected function markTable($table, $relationship, $alias) {
     // Mark that this table has been added.
     if (empty($this->tables[$relationship][$table])) {
       if (!isset($alias)) {
         $alias = '';
         if ($relationship != $this->view->storage->get('base_table')) {
-          // double underscore will help prevent accidental name
+          // Double underscore will help prevent accidental name
           // space collisions.
           $alias = $relationship . '__';
         }
@@ -580,9 +611,9 @@ class Sql extends QueryPluginBase {
    * the table queue. It will ensure a path leads back to the relationship
    * table.
    *
-   * @param $table
+   * @param string $table
    *   The un-aliased name of the table to ensure.
-   * @param $relationship
+   * @param string|null $relationship
    *   The relationship to ensure the table links to. Each relationship will
    *   get a unique instance of the table being added. If not specified,
    *   will be the primary table.
@@ -593,16 +624,16 @@ class Sql extends QueryPluginBase {
    *   The alias used to refer to this specific table, or NULL if the table
    *   cannot be ensured.
    */
-  public function ensureTable($table, $relationship = NULL, JoinPluginBase $join = NULL) {
-    // ensure a relationship
+  public function ensureTable($table, $relationship = NULL, ?JoinPluginBase $join = NULL) {
+    // Ensure a relationship
     if (empty($relationship)) {
       $relationship = $this->view->storage->get('base_table');
     }
 
     // If the relationship is the primary table, this actually be a relationship
-    // link back from an alias. We store all aliases along with the primary table
-    // to detect this state, because eventually it'll hit a table we already
-    // have and that's when we want to stop.
+    // link back from an alias. We store all aliases along with the primary
+    // table to detect this state, because eventually it'll hit a table we
+    // already have and that's when we want to stop.
     if ($relationship == $this->view->storage->get('base_table') && !empty($this->tables[$relationship][$table])) {
       return $this->tables[$relationship][$table]['alias'];
     }
@@ -644,14 +675,14 @@ class Sql extends QueryPluginBase {
       // example, a view that filters on 3 taxonomy terms using AND
       // needs to join taxonomy_term_data 3 times with the same join.
 
-      // scan through the table queue to see if a matching join and
+      // Scan through the table queue to see if a matching join and
       // relationship exists.  If so, use it instead of this join.
 
-      // TODO: Scanning through $this->tableQueue results in an
-      // O(N^2) algorithm, and this code runs every time the view is
-      // instantiated (Views 2 does not currently cache queries).
-      // There are a couple possible "improvements" but we should do
-      // some performance testing before picking one.
+      // @todo Scanning through $this->tableQueue results in an
+      //   O(N^2) algorithm, and this code runs every time the view is
+      //   instantiated (Views 2 does not currently cache queries).
+      //   There are a couple possible "improvements" but we should do
+      //   some performance testing before picking one.
       foreach ($this->tableQueue as $queued_table) {
         // In PHP 4 and 5, the == operation returns TRUE for two objects
         // if they are instances of the same class and have the same
@@ -750,7 +781,8 @@ class Sql extends QueryPluginBase {
         $this->ensureTable($join->leftTable, $relationship);
       }
 
-      // First, if this is our link point/anchor table, just use the relationship
+      // First, if this is our link point/anchor table, just use the
+      // relationship
       if ($join->leftTable == $this->relationships[$relationship]['table']) {
         $join->leftTable = $relationship;
       }
@@ -771,9 +803,9 @@ class Sql extends QueryPluginBase {
   /**
    * Retrieve join data from the larger join data cache.
    *
-   * @param $table
+   * @param string $table
    *   The table to get the join information for.
-   * @param $base_table
+   * @param string $base_table
    *   The path we're following to get this join.
    *
    * @return \Drupal\views\Plugin\views\join\JoinPluginBase
@@ -814,17 +846,17 @@ class Sql extends QueryPluginBase {
    * This will automatically call ensureTable to make sure the required table
    * exists, *unless* $table is unset.
    *
-   * @param $table
+   * @param string $table
    *   The table this field is attached to. If NULL, it is assumed this will
    *   be a formula; otherwise, ensureTable is used to make sure the
    *   table exists.
-   * @param $field
+   * @param string $field
    *   The name of the field to add. This may be a real field or a formula.
-   * @param $alias
+   * @param string $alias
    *   The alias to create. If not specified, the alias will be $table_$field
    *   unless $table is NULL. When adding formulae, it is recommended that an
    *   alias be used.
-   * @param $params
+   * @param array $params
    *   An array of parameters additional to the field that will control items
    *   such as aggregation functions and DISTINCT. Some values that are
    *   recognized:
@@ -833,7 +865,8 @@ class Sql extends QueryPluginBase {
    *     aggregated in a GROUP BY.
    *
    * @return string
-   *   The name that this field can be referred to as. Usually this is the alias.
+   *   The name that this field can be referred to as. Usually this is the
+   *   alias.
    */
   public function addField($table, $field, $alias = '', $params = []) {
     // We check for this specifically because it gets a special alias.
@@ -850,7 +883,7 @@ class Sql extends QueryPluginBase {
     }
 
     // Make sure an alias is assigned
-    $alias = $alias ? $alias : $field;
+    $alias = $alias ?: $field;
 
     // PostgreSQL truncates aliases to 63 characters:
     // https://www.drupal.org/node/571548.
@@ -866,9 +899,9 @@ class Sql extends QueryPluginBase {
       'alias' => $alias,
     ] + $params;
 
-    // Test to see if the field is actually the same or not. Due to
-    // differing parameters changing the aggregation function, we need
-    // to do some automatic alias collision detection:
+    // Test to see if the field is actually the same or not. Due to different
+    // parameters changing the aggregation function, we need to do some
+    // automatic alias collision detection:
     $base = $alias;
     $counter = 0;
     while (!empty($this->fields[$alias]) && $this->fields[$alias] != $field_info) {
@@ -912,17 +945,17 @@ class Sql extends QueryPluginBase {
    * );
    * @endcode
    *
-   * @param $group
+   * @param string $group
    *   The WHERE group to add these to; groups are used to create AND/OR
    *   sections. Groups cannot be nested. Use 0 as the default group.
    *   If the group does not yet exist it will be created as an AND group.
-   * @param $field
+   * @param string $field
    *   The name of the field to check.
-   * @param $value
-   *   The value to test the field against. In most cases, this is a scalar. For more
-   *   complex options, it is an array. The meaning of each element in the array is
-   *   dependent on the $operator.
-   * @param $operator
+   * @param string|array|null $value
+   *   The value to test the field against. In most cases, this is a scalar. For
+   *   more complex options, it is an array. The meaning of each element in the
+   *   array is dependent on the $operator.
+   * @param string|null $operator
    *   The comparison operator, such as =, <, or >=. It also accepts more
    *   complex options such as IN, LIKE, LIKE BINARY, or BETWEEN. Defaults to =.
    *   If $field is a string you have to use 'formula' here.
@@ -956,17 +989,17 @@ class Sql extends QueryPluginBase {
    * (TABLE.FIELD) and that the table already exists in the query.
    * Internally the dbtng method "where" is used.
    *
-   * @param $group
+   * @param string $group
    *   The WHERE group to add these to; groups are used to create AND/OR
    *   sections. Groups cannot be nested. Use 0 as the default group.
    *   If the group does not yet exist it will be created as an AND group.
-   * @param $snippet
+   * @param string $snippet
    *   The snippet to check. This can be either a column or
-   *   a complex expression like "UPPER(table.field) = 'value'"
-   * @param $args
+   *   a complex expression like "UPPER(table.field) = 'value'".
+   * @param array $args
    *   An associative array of arguments.
    *
-   * @see QueryConditionInterface::where()
+   * @see ConditionInterface::where()
    */
   public function addWhereExpression($group, $snippet, $args = []) {
     // Ensure all variants of 0 are actually 0. Thus '', 0 and NULL are all
@@ -991,20 +1024,20 @@ class Sql extends QueryPluginBase {
    * Add a complex HAVING clause to the query.
    *
    * The caller is responsible for ensuring that all fields are fully qualified
-   * (TABLE.FIELD) and that the table and an appropriate GROUP BY already exist in the query.
-   * Internally the dbtng method "having" is used.
+   * (TABLE.FIELD) and that the table and an appropriate GROUP BY already exist
+   * in the query. Internally the dbtng method "having" is used.
    *
-   * @param $group
+   * @param string $group
    *   The HAVING group to add these to; groups are used to create AND/OR
    *   sections. Groups cannot be nested. Use 0 as the default group.
    *   If the group does not yet exist it will be created as an AND group.
-   * @param $snippet
+   * @param string $snippet
    *   The snippet to check. This can be either a column or
-   *   a complex expression like "COUNT(table.field) > 3"
-   * @param $args
+   *   a complex expression like "COUNT(table.field) > 3".
+   * @param array $args
    *   An associative array of arguments.
    *
-   * @see QueryConditionInterface::having()
+   * @see SelectInterface::having()
    */
   public function addHavingExpression($group, $snippet, $args = []) {
     // Ensure all variants of 0 are actually 0. Thus '', 0 and NULL are all
@@ -1029,25 +1062,25 @@ class Sql extends QueryPluginBase {
   /**
    * Add an ORDER BY clause to the query.
    *
-   * @param $table
+   * @param string $table
    *   The table this field is part of. If a formula, enter NULL.
    *   If you want to orderby random use "rand" as table and nothing else.
-   * @param $field
+   * @param string|null $field
    *   The field or formula to sort on. If already a field, enter NULL
    *   and put in the alias.
-   * @param $order
+   * @param string $order
    *   Either ASC or DESC.
-   * @param $alias
+   * @param string $alias
    *   The alias to add the field as. In SQL, all fields in the order by
    *   must also be in the SELECT portion. If an $alias isn't specified
    *   one will be generated for from the $field; however, if the
    *   $field is a formula, this alias will likely fail.
-   * @param $params
+   * @param array $params
    *   Any params that should be passed through to the addField.
    */
   public function addOrderBy($table, $field = NULL, $order = 'ASC', $alias = '', $params = []) {
     // Only ensure the table if it's not the special random key.
-    // @todo: Maybe it would make sense to just add an addOrderByRand or something similar.
+    // @todo Maybe it would make sense to just add an addOrderByRand or something similar.
     if ($table && $table != 'rand') {
       $this->ensureTable($table);
     }
@@ -1126,8 +1159,8 @@ class Sql extends QueryPluginBase {
    * There is other code in filters which makes sure that the group IDs are
    * higher than zero.
    *
-   * @param $where
-   *   'where' or 'having'.
+   * @param string $where
+   *   The type of clause, either 'where' or 'having'.
    */
   protected function buildCondition($where = 'where') {
     $has_condition = FALSE;
@@ -1295,7 +1328,7 @@ class Sql extends QueryPluginBase {
   /**
    * Generates a query and count query from all of the information supplied.
    *
-   * @param $get_count
+   * @param bool $get_count
    *   Provide a countQuery if this is true, otherwise provide a normal query.
    */
   public function query($get_count = FALSE) {
@@ -1306,10 +1339,9 @@ class Sql extends QueryPluginBase {
       $distinct = TRUE;
     }
 
-    /**
-     * An optimized count query includes just the base field instead of all the fields.
-     * Determine of this query qualifies by checking for a groupby or distinct.
-     */
+    // An optimized count query includes just the base field instead of all the
+    // fields. Determine of this query qualifies by checking for a groupby or
+    // distinct.
     if ($get_count && !$this->groupby) {
       foreach ($this->fields as $field) {
         if (!empty($field['distinct']) || !empty($field['function'])) {
@@ -1400,7 +1432,7 @@ class Sql extends QueryPluginBase {
     }
 
     if (!$this->getCountOptimized) {
-      // we only add the orderby if we're not counting.
+      // We only add the orderby if we're not counting.
       if ($this->orderby) {
         foreach ($this->orderby as $order) {
           if ($order['field'] == 'rand_') {
@@ -1532,14 +1564,15 @@ class Sql extends QueryPluginBase {
         $view->pager->preExecute($query);
 
         if (!empty($this->limit) || !empty($this->offset)) {
-          // We can't have an offset without a limit, so provide a very large limit instead.
+          // We can't have an offset without a limit, so provide a very large
+          // limit instead.
           $limit = intval(!empty($this->limit) ? $this->limit : 999999);
           $offset = intval(!empty($this->offset) ? $this->offset : 0);
           $query->range($offset, $limit);
         }
 
         $result = $query->execute();
-        $result->setFetchMode(\PDO::FETCH_CLASS, 'Drupal\views\ResultRow');
+        $result->setFetchMode(FetchAs::ClassObject, 'Drupal\views\ResultRow');
 
         // Setup the result row objects.
         $view->result = iterator_to_array($result);
@@ -1718,6 +1751,7 @@ class Sql extends QueryPluginBase {
    * Gets all the involved entities of the view.
    *
    * @return \Drupal\Core\Entity\EntityInterface[]
+   *   The involved entities.
    */
   protected function getAllEntities() {
     $entities = [];
@@ -1733,13 +1767,19 @@ class Sql extends QueryPluginBase {
     return $entities;
   }
 
+  /**
+   * {@inheritdoc}
+   */
   public function addSignature(ViewExecutable $view) {
     $view->query->addField(NULL, "'" . $view->storage->id() . ':' . $view->current_display . "'", 'view_name');
   }
 
+  /**
+   * {@inheritdoc}
+   */
   public function getAggregationInfo() {
-    // @todo -- need a way to get database specific and customized aggregation
-    // functions into here.
+    // @todo Need a way to get database specific and customized aggregation
+    //   functions into here.
     return [
       'group' => [
         'title' => $this->t('Group results together'),
@@ -1818,10 +1858,16 @@ class Sql extends QueryPluginBase {
     ];
   }
 
+  /**
+   * Builds a simple SQL expression.
+   */
   public function aggregationMethodSimple($group_type, $field) {
     return strtoupper($group_type) . '(' . $field . ')';
   }
 
+  /**
+   * Builds a SQL expression using DISTINCT.
+   */
   public function aggregationMethodDistinct($group_type, $field) {
     $group_type = str_replace('_distinct', '', $group_type);
     return strtoupper($group_type) . '(DISTINCT ' . $field . ')';
