@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\views\Kernel\Handler;
 
 use Drupal\Tests\views\Kernel\ViewsKernelTestBase;
@@ -46,7 +48,10 @@ class FilterCombineTest extends ViewsKernelTestBase {
     $this->installEntitySchema('entity_test');
   }
 
-  public function testFilterCombineContains() {
+  /**
+   * Tests the Combine field filter with the 'contains' operator.
+   */
+  public function testFilterCombineContains(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -101,7 +106,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests the Combine field filter with the 'regular_expression' operator.
    */
-  public function testFilterCombineRegEx() {
+  public function testFilterCombineRegEx(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -160,7 +165,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests the Combine field filter with the 'word' operator.
    */
-  public function testFilterCombineWord() {
+  public function testFilterCombineWord(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -211,7 +216,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests the Combine field filter with the 'allwords' operator.
    */
-  public function testFilterCombineAllWords() {
+  public function testFilterCombineAllWords(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -263,7 +268,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
    * and fields set in the combine filter are removed from the display
    * but not from the combined filter settings.
    */
-  public function testFilterCombineContainsFieldsOverwritten() {
+  public function testFilterCombineContainsFieldsOverwritten(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -307,7 +312,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests that the "combine" filter is only valid on displays that use fields.
    */
-  public function testNonFieldsRow() {
+  public function testNonFieldsRow(): void {
     $view = Views::getView('entity_test_fields');
     $view->setDisplay();
 
@@ -347,7 +352,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
    *
    * @covers ::opEqual
    */
-  public function testFilterCombineEqual() {
+  public function testFilterCombineEqual(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -447,7 +452,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests the Combine field filter using the 'starts' operator.
    */
-  public function testFilterCombineStarts() {
+  public function testFilterCombineStarts(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -493,7 +498,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests the Combine field filter using the 'not_starts' operator.
    */
-  public function testFilterCombineNotStarts() {
+  public function testFilterCombineNotStarts(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -543,7 +548,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests the Combine field filter using the 'ends' operator.
    */
-  public function testFilterCombineEnds() {
+  public function testFilterCombineEnds(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -589,7 +594,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests the Combine field filter using the 'not_ends' operator.
    */
-  public function testFilterCombineNotEnds() {
+  public function testFilterCombineNotEnds(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -639,7 +644,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests the Combine field filter using the 'not' operator.
    */
-  public function testFilterCombineNot() {
+  public function testFilterCombineNot(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -689,7 +694,7 @@ class FilterCombineTest extends ViewsKernelTestBase {
   /**
    * Tests the combine filter when no realName is used.
    */
-  public function testFilterCombineNoRealName() {
+  public function testFilterCombineNoRealName(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
