@@ -1,7 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\views\Kernel\Handler;
 
+use Drupal\Core\Database\Database;
 use Drupal\Tests\views\Kernel\ViewsKernelTestBase;
 use Drupal\views\Views;
 
@@ -13,6 +16,9 @@ use Drupal\views\Views;
  */
 class FilterStringTest extends ViewsKernelTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
   protected static $modules = ['system'];
 
   /**
@@ -31,6 +37,9 @@ class FilterStringTest extends ViewsKernelTestBase {
     'views_test_data_name' => 'name',
   ];
 
+  /**
+   * Defines Views data for the custom entity.
+   */
   public function viewsData() {
     $data = parent::viewsData();
     $data['views_test_data']['name']['filter']['allow empty'] = TRUE;
@@ -73,6 +82,7 @@ class FilterStringTest extends ViewsKernelTestBase {
    * Build and return a Page view of the views_test_data table.
    *
    * @return \Drupal\views\ViewExecutable
+   *   The page view object.
    */
   protected function getBasicPageView() {
     $view = Views::getView('test_view');
@@ -85,7 +95,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     return $view;
   }
 
-  public function testFilterStringEqual() {
+  /**
+   * Tests the string filter with the 'equal' operator.
+   */
+  public function testFilterStringEqual(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -108,9 +121,51 @@ class FilterStringTest extends ViewsKernelTestBase {
       ],
     ];
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
+    $view->destroy();
+
+    // Get the original dataset
+    $data_set = $this->dataSet();
+    // Adds a new data point in the views_test_data table.
+    $query = Database::getConnection()->insert('views_test_data')
+      ->fields(array_keys($data_set[0]));
+    $query->values([
+      'name' => 'Ringo%',
+      'age' => 31,
+      'job' => 'Drummer',
+      'created' => gmmktime(6, 30, 10, 1, 1, 2000),
+      'status' => 1,
+      'description' => NULL,
+    ]);
+    $query->execute();
+
+    $view = Views::getView('test_view');
+    $view->setDisplay();
+
+    // Change the filtering
+    $view->displayHandlers->get('default')->overrideOption('filters', [
+      'name' => [
+        'id' => 'name',
+        'table' => 'views_test_data',
+        'field' => 'name',
+        'relationship' => 'none',
+        'operator' => '=',
+        'value' => 'Ringo%',
+      ],
+    ]);
+
+    $this->executeView($view);
+    $resultset = [
+      [
+        'name' => 'Ringo%',
+      ],
+    ];
+    $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedEqual() {
+  /**
+   * Returns a set of grouped exposed filters.
+   */
+  public function testFilterStringGroupedExposedEqual(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -131,7 +186,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringNotEqual() {
+  /**
+   * Tests the string filter with the 'not equal' operator.
+   */
+  public function testFilterStringNotEqual(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -165,7 +223,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedNotEqual() {
+  /**
+   * Tests grouped, exposed filtering with not equal operator.
+   */
+  public function testFilterStringGroupedExposedNotEqual(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -196,7 +257,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringContains() {
+  /**
+   * Tests the string filter with the 'contains' operator.
+   */
+  public function testFilterStringContains(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -221,7 +285,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedContains() {
+  /**
+   * Tests grouped, exposed filtering with contains operator.
+   */
+  public function testFilterStringGroupedExposedContains(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -242,7 +309,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringWord() {
+  /**
+   * Tests filtering by a word in the "description" field.
+   */
+  public function testFilterStringWord(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -330,7 +400,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset);
   }
 
-  public function testFilterStringGroupedExposedWord() {
+  /**
+   * Tests grouped and exposed filters with word-based filtering.
+   */
+  public function testFilterStringGroupedExposedWord(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -371,7 +444,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringStarts() {
+  /**
+   * Tests filtering by string using the "starts with" operator.
+   */
+  public function testFilterStringStarts(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -396,7 +472,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedStarts() {
+  /**
+   * Tests grouped and exposed filters with the "starts with" operator.
+   */
+  public function testFilterStringGroupedExposedStarts(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -419,7 +498,7 @@ class FilterStringTest extends ViewsKernelTestBase {
   /**
    * Tests the string filter with negated 'regular_expression' operator.
    */
-  public function testFilterStringGroupedNotRegularExpression() {
+  public function testFilterStringGroupedNotRegularExpression(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -449,7 +528,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringNotStarts() {
+  /**
+   * Tests filtering by string using the "does not start with" operator.
+   */
+  public function testFilterStringNotStarts(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -481,7 +563,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedNotStarts() {
+  /**
+   * Tests grouped and exposed filters with the "does not start with" operator.
+   */
+  public function testFilterStringGroupedExposedNotStarts(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -508,7 +593,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringEnds() {
+  /**
+   * Tests filtering by string using the "ends with" operator.
+   */
+  public function testFilterStringEnds(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -536,7 +624,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedEnds() {
+  /**
+   * Tests grouped and exposed filters with the "ends with" operator.
+   */
+  public function testFilterStringGroupedExposedEnds(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -559,7 +650,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringNotEnds() {
+  /**
+   * Tests filtering by string using the "does not end with" operator.
+   */
+  public function testFilterStringNotEnds(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -588,7 +682,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedNotEnds() {
+  /**
+   * Tests grouped and exposed filters with the "does not end with" operator.
+   */
+  public function testFilterStringGroupedExposedNotEnds(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -612,7 +709,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringNot() {
+  /**
+   * Tests filtering by string using the "does not contain" operator.
+   */
+  public function testFilterStringNot(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -641,7 +741,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedNot() {
+  /**
+   * Tests grouped and exposed filters with the "does not contain" operator.
+   */
+  public function testFilterStringGroupedExposedNot(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -666,7 +769,10 @@ class FilterStringTest extends ViewsKernelTestBase {
 
   }
 
-  public function testFilterStringShorter() {
+  /**
+   * Tests filtering by string using the "shorter than" operator.
+   */
+  public function testFilterStringShorter(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -694,7 +800,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedShorter() {
+  /**
+   * Tests grouped and exposed filters with the "shorter than" operator.
+   */
+  public function testFilterStringGroupedExposedShorter(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -716,7 +825,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringLonger() {
+  /**
+   * Tests filtering by string using the "longer than" operator.
+   */
+  public function testFilterStringLonger(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -741,7 +853,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedLonger() {
+  /**
+   * Tests grouped and exposed filters with the "longer than" operator.
+   */
+  public function testFilterStringGroupedExposedLonger(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -760,7 +875,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringEmpty() {
+  /**
+   * Tests filtering by string using the "empty" operator.
+   */
+  public function testFilterStringEmpty(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -784,7 +902,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  public function testFilterStringGroupedExposedEmpty() {
+  /**
+   * Tests grouped and exposed filters with the "empty" operator.
+   */
+  public function testFilterStringGroupedExposedEmpty(): void {
     $filters = $this->getGroupedExposedFilters();
     $view = $this->getBasicPageView();
 
@@ -806,7 +927,7 @@ class FilterStringTest extends ViewsKernelTestBase {
   /**
    * Tests the string filter handler with the negated 'regular_expression' operator.
    */
-  public function testFilterStringNotRegularExpression() {
+  public function testFilterStringNotRegularExpression(): void {
     $view = Views::getView('test_view');
     $view->setDisplay();
 
@@ -846,7 +967,10 @@ class FilterStringTest extends ViewsKernelTestBase {
     $this->assertIdenticalResultset($view, $resultset, $this->columnMap);
   }
 
-  protected function getGroupedExposedFilters() {
+  /**
+   * Returns a set of grouped exposed filters.
+   */
+  protected function getGroupedExposedFilters(): array {
     $filters = [
       'name' => [
         'id' => 'name',
