@@ -116,6 +116,7 @@ class ViewsDataTest extends UnitTestCase {
    * Returns the views data definition with the provider key.
    *
    * @return array
+   *   The views data definition.
    *
    * @see static::viewsData()
    */
@@ -142,7 +143,7 @@ class ViewsDataTest extends UnitTestCase {
   /**
    * Tests the fetchBaseTables() method.
    */
-  public function testFetchBaseTables() {
+  public function testFetchBaseTables(): void {
     $this->setupMockedModuleHandler();
     $data = $this->viewsData->getAll();
 
@@ -180,7 +181,7 @@ class ViewsDataTest extends UnitTestCase {
   /**
    * Tests fetching all the views data without a static cache.
    */
-  public function testGetOnFirstCall() {
+  public function testGetOnFirstCall(): void {
     // Ensure that the hooks are just invoked once.
     $this->setupMockedModuleHandler();
 
@@ -201,7 +202,7 @@ class ViewsDataTest extends UnitTestCase {
   /**
    * Tests the cache of the full and single table data.
    */
-  public function testFullAndTableGetCache() {
+  public function testFullAndTableGetCache(): void {
     $expected_views_data = $this->viewsDataWithProvider();
     $table_name = 'views_test_data';
     $table_name_2 = 'views_test_data_2';
@@ -220,23 +221,33 @@ class ViewsDataTest extends UnitTestCase {
 
     // The cache should only be called once (before the clear() call) as get
     // will get all table data in the first get().
-    $this->cacheBackend->expects($this->exactly(4))
+    $gets = [
+      'views_data:en',
+      "views_data:$random_table_name:en",
+      'views_data:en',
+      "views_data:$random_table_name:en",
+    ];
+    $this->cacheBackend->expects($this->exactly(count($gets)))
       ->method('get')
-      ->withConsecutive(
-        ['views_data:en'],
-        ["views_data:$random_table_name:en"],
-        ['views_data:en'],
-        ["views_data:$random_table_name:en"],
-      )
+      ->with($this->callback(function (string $key) use (&$gets): bool {
+        return $key === array_shift($gets);
+      }))
       ->willReturn(FALSE);
-    $this->cacheBackend->expects($this->exactly(4))
+
+    $sets = [
+      'views_data:en', $expected_views_data,
+      "views_data:$random_table_name:en", [],
+      'views_data:en', $expected_views_data,
+      "views_data:$random_table_name:en", [],
+    ];
+    $this->cacheBackend->expects($this->exactly(count($sets) / 2))
       ->method('set')
-      ->withConsecutive(
-        ['views_data:en', $expected_views_data],
-        ["views_data:$random_table_name:en", []],
-        ['views_data:en', $expected_views_data],
-        ["views_data:$random_table_name:en", []],
-      );
+      ->with($this->callback(function (string $key) use (&$sets): bool {
+        return $key === array_shift($sets);
+      }), $this->callback(function (array $data) use (&$sets): bool {
+        return $data === array_shift($sets);
+      }));
+
     $this->cacheTagsInvalidator->expects($this->once())
       ->method('invalidateTags')
       ->with(['views_data']);
@@ -267,7 +278,7 @@ class ViewsDataTest extends UnitTestCase {
   /**
    * Tests the caching of the full views data.
    */
-  public function testFullGetCache() {
+  public function testFullGetCache(): void {
     $expected_views_data = $this->viewsDataWithProvider();
 
     // Views data should be invoked once.
@@ -292,7 +303,7 @@ class ViewsDataTest extends UnitTestCase {
   /**
    * Tests the caching of the views data for a specific table.
    */
-  public function testSingleTableGetCache() {
+  public function testSingleTableGetCache(): void {
     $table_name = 'views_test_data';
     $expected_views_data = $this->viewsDataWithProvider();
 
@@ -303,12 +314,12 @@ class ViewsDataTest extends UnitTestCase {
       ->method('alter')
       ->with('views_data', $this->viewsDataWithProvider());
 
-    $this->cacheBackend->expects($this->exactly(2))
+    $gets = ["views_data:$table_name:en", 'views_data:en'];
+    $this->cacheBackend->expects($this->exactly(count($gets)))
       ->method('get')
-      ->withConsecutive(
-        ["views_data:$table_name:en"],
-        ['views_data:en'],
-      )
+      ->with($this->callback(function (string $key) use (&$gets): bool {
+        return $key === array_shift($gets);
+      }))
       ->willReturn(FALSE);
 
     $views_data = $this->viewsData->get($table_name);
@@ -327,7 +338,7 @@ class ViewsDataTest extends UnitTestCase {
   /**
    * Tests building the views data with a non existing table.
    */
-  public function testNonExistingTableGetCache() {
+  public function testNonExistingTableGetCache(): void {
     $random_table_name = $this->randomMachineName();
 
     // Views data should be invoked once.
@@ -337,12 +348,12 @@ class ViewsDataTest extends UnitTestCase {
       ->method('alter')
       ->with('views_data', $this->viewsDataWithProvider());
 
-    $this->cacheBackend->expects($this->exactly(2))
+    $gets = ["views_data:$random_table_name:en", 'views_data:en'];
+    $this->cacheBackend->expects($this->exactly(count($gets)))
       ->method('get')
-      ->withConsecutive(
-        ["views_data:$random_table_name:en"],
-        ['views_data:en'],
-      )
+      ->with($this->callback(function (string $key) use (&$gets): bool {
+        return $key === array_shift($gets);
+      }))
       ->willReturn(FALSE);
 
     // All views data should be requested on the first try.
@@ -357,23 +368,29 @@ class ViewsDataTest extends UnitTestCase {
   /**
    * Tests the cache backend behavior with requesting the same table multiple.
    */
-  public function testCacheCallsWithSameTableMultipleTimes() {
+  public function testCacheCallsWithSameTableMultipleTimes(): void {
     $expected_views_data = $this->viewsDataWithProvider();
 
     $this->setupMockedModuleHandler();
 
-    $this->cacheBackend->expects($this->exactly(2))
+    $gets = ['views_data:views_test_data:en', 'views_data:en'];
+    $this->cacheBackend->expects($this->exactly(count($gets)))
       ->method('get')
-      ->withConsecutive(
-        ['views_data:views_test_data:en'],
-        ['views_data:en'],
-      );
-    $this->cacheBackend->expects($this->exactly(2))
+      ->with($this->callback(function (string $key) use (&$gets): bool {
+        return $key === array_shift($gets);
+      }));
+
+    $sets = [
+      'views_data:en', $expected_views_data,
+      'views_data:views_test_data:en', $expected_views_data['views_test_data'],
+    ];
+    $this->cacheBackend->expects($this->exactly(count($sets) / 2))
       ->method('set')
-      ->withConsecutive(
-        ['views_data:en', $expected_views_data],
-        ['views_data:views_test_data:en', $expected_views_data['views_test_data']],
-      );
+      ->with($this->callback(function (string $key) use (&$sets): bool {
+        return $key === array_shift($sets);
+      }), $this->callback(function (array $data) use (&$sets): bool {
+        return $data === array_shift($sets);
+      }));
 
     // Request the same table 5 times. The caches are empty at this point, so
     // what will happen is that it will first check for a cache entry for the
@@ -394,7 +411,7 @@ class ViewsDataTest extends UnitTestCase {
    *   - all tables
    *   - views_test_data
    */
-  public function testCacheCallsWithSameTableMultipleTimesAndWarmCache() {
+  public function testCacheCallsWithSameTableMultipleTimesAndWarmCache(): void {
     $expected_views_data = $this->viewsDataWithProvider();
     $this->moduleHandler->expects($this->never())
       ->method('invokeAllWith');
@@ -424,18 +441,18 @@ class ViewsDataTest extends UnitTestCase {
    * Not warm cache:
    *   - views_test_data_2
    */
-  public function testCacheCallsWithWarmCacheAndDifferentTable() {
+  public function testCacheCallsWithWarmCacheAndDifferentTable(): void {
     $expected_views_data = $this->viewsDataWithProvider();
     $this->moduleHandler->expects($this->never())
       ->method('invokeAllWith');
 
     // Setup a warm cache backend for a single table.
-    $this->cacheBackend->expects($this->exactly(2))
+    $gets = ['views_data:views_test_data_2:en', 'views_data:en'];
+    $this->cacheBackend->expects($this->exactly(count($gets)))
       ->method('get')
-      ->withConsecutive(
-        ['views_data:views_test_data_2:en'],
-        ['views_data:en'],
-      )
+      ->with($this->callback(function (string $key) use (&$gets): bool {
+        return $key === array_shift($gets);
+      }))
       ->willReturnOnConsecutiveCalls(
         FALSE,
         (object) ['data' => $expected_views_data],
@@ -462,19 +479,19 @@ class ViewsDataTest extends UnitTestCase {
    * Not warm cache:
    *   - $non_existing_table
    */
-  public function testCacheCallsWithWarmCacheAndInvalidTable() {
+  public function testCacheCallsWithWarmCacheAndInvalidTable(): void {
     $expected_views_data = $this->viewsDataWithProvider();
     $non_existing_table = $this->randomMachineName();
     $this->moduleHandler->expects($this->never())
       ->method('invokeAllWith');
 
     // Setup a warm cache backend for a single table.
-    $this->cacheBackend->expects($this->exactly(2))
+    $gets = ["views_data:$non_existing_table:en", 'views_data:en'];
+    $this->cacheBackend->expects($this->exactly(count($gets)))
       ->method('get')
-      ->withConsecutive(
-        ["views_data:$non_existing_table:en"],
-        ['views_data:en'],
-      )
+      ->with($this->callback(function (string $key) use (&$gets): bool {
+        return $key === array_shift($gets);
+      }))
       ->willReturnOnConsecutiveCalls(
         FALSE,
         (object) ['data' => $expected_views_data],
@@ -502,7 +519,7 @@ class ViewsDataTest extends UnitTestCase {
    *   - views_test_data
    *   - $non_existing_table
    */
-  public function testCacheCallsWithWarmCacheForInvalidTable() {
+  public function testCacheCallsWithWarmCacheForInvalidTable(): void {
     $non_existing_table = $this->randomMachineName();
     $this->moduleHandler->expects($this->never())
       ->method('invokeAllWith');
@@ -529,7 +546,7 @@ class ViewsDataTest extends UnitTestCase {
   /**
    * Tests the cache calls for all views data without a warm cache.
    */
-  public function testCacheCallsWithoutWarmCacheAndGetAllTables() {
+  public function testCacheCallsWithoutWarmCacheAndGetAllTables(): void {
     $expected_views_data = $this->viewsDataWithProvider();
     $this->setupMockedModuleHandler();
 
@@ -555,7 +572,7 @@ class ViewsDataTest extends UnitTestCase {
    * Warm cache:
    *   - all tables
    */
-  public function testCacheCallsWithWarmCacheAndGetAllTables() {
+  public function testCacheCallsWithWarmCacheAndGetAllTables(): void {
     $expected_views_data = $this->viewsDataWithProvider();
     $this->moduleHandler->expects($this->never())
       ->method('invokeAllWith');
@@ -581,30 +598,35 @@ class ViewsDataTest extends UnitTestCase {
    *
    * @covers ::get
    */
-  public function testCacheCallsWithoutWarmCacheAndGetMultipleTables() {
+  public function testCacheCallsWithoutWarmCacheAndGetMultipleTables(): void {
     $expected_views_data = $this->viewsDataWithProvider();
     $table_name = 'views_test_data';
     $table_name_2 = 'views_test_data_2';
 
     // Setup a warm cache backend for all table data, but not single tables.
-    $this->cacheBackend->expects($this->exactly(3))
+    $gets = ["views_data:$table_name:en", 'views_data:en', "views_data:$table_name_2:en"];
+    $this->cacheBackend->expects($this->exactly(count($gets)))
       ->method('get')
-      ->withConsecutive(
-        ["views_data:$table_name:en"],
-        ['views_data:en'],
-        ["views_data:$table_name_2:en"],
-      )
+      ->with($this->callback(function (string $key) use (&$gets): bool {
+        return $key === array_shift($gets);
+      }))
       ->willReturnOnConsecutiveCalls(
         FALSE,
         (object) ['data' => $expected_views_data],
         FALSE,
       );
-    $this->cacheBackend->expects($this->exactly(2))
+
+    $sets = [
+      "views_data:$table_name:en", $expected_views_data[$table_name],
+      "views_data:$table_name_2:en", $expected_views_data[$table_name_2],
+    ];
+    $this->cacheBackend->expects($this->exactly(count($sets) / 2))
       ->method('set')
-      ->withConsecutive(
-        ["views_data:$table_name:en", $expected_views_data[$table_name]],
-        ["views_data:$table_name_2:en", $expected_views_data[$table_name_2]],
-      );
+      ->with($this->callback(function (string $key) use (&$sets): bool {
+        return $key === array_shift($sets);
+      }), $this->callback(function (array $data) use (&$sets): bool {
+        return $data === array_shift($sets);
+      }));
 
     $this->assertSame($expected_views_data[$table_name], $this->viewsData->get($table_name));
     $this->assertSame($expected_views_data[$table_name_2], $this->viewsData->get($table_name_2));
@@ -620,14 +642,17 @@ class ViewsDataTest extends UnitTestCase {
    * @covers ::get
    * @dataProvider providerTestGetEmptyKey
    */
-  public function testGetEmptyKey($key) {
+  public function testGetEmptyKey($key): void {
     $this->expectException(\InvalidArgumentException::class);
     $this->expectExceptionMessage('A valid cache entry key is required. Use getAll() to get all table data.');
 
     $this->viewsData->get($key);
   }
 
-  public function providerTestGetEmptyKey() {
+  /**
+   * Provides data to testGetEmptyKey().
+   */
+  public static function providerTestGetEmptyKey() {
     return [
       [NULL],
       [''],
