@@ -347,8 +347,13 @@
     // Perhaps we should precache the text div, too.
     this.$selected_div
       .find('.views-selected-options')
-      .html(this.checkedItems.join(', '))
-      .trigger('dialogContentResize');
+      .html(this.checkedItems.join(', '));
+
+    this.$selected_div
+      ?.get(0)
+      ?.dispatchEvent(
+        new CustomEvent('dialogContentResize', { bubbles: true }),
+      );
   };
 
   /**
@@ -587,7 +592,9 @@
         });
 
         // Adapt dialog to content size.
-        $(event.target).trigger('dialogContentResize');
+        event.target?.dispatchEvent(
+          new CustomEvent('dialogContentResize', { bubbles: true }),
+        );
       },
     },
   );
@@ -1242,7 +1249,6 @@
         context,
       ).forEach((dropdown) => {
         // Closures! :(
-        const $context = $(context);
         const submit = context.querySelector('[id^=edit-submit]');
         const oldValue = submit ? submit.value : '';
 
@@ -1266,8 +1272,10 @@
             } else {
               submit.value = Drupal.t('Apply (this display)');
             }
-            const $dialog = $context.closest('.ui-dialog-content');
-            $dialog.trigger('dialogButtonsChange');
+            if (context !== document) {
+              const dialog = context.closest('.ui-dialog-content');
+              dialog?.dispatchEvent(new CustomEvent('dialogButtonsChange'));
+            }
           })
           .trigger('change');
       });
@@ -1325,8 +1333,7 @@
     attach(context) {
       // Only act on the rearrange filter form.
       if (
-        typeof Drupal.tableDrag === 'undefined' ||
-        typeof Drupal.tableDrag['views-rearrange-filters'] === 'undefined'
+        typeof Drupal?.tableDrag?.['views-rearrange-filters'] === 'undefined'
       ) {
         return;
       }
