@@ -5,8 +5,10 @@ namespace Drupal\views_ui;
 use Drupal\Component\Utility\Html;
 use Drupal\Component\Utility\Timer;
 use Drupal\Component\Utility\Xss;
+use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Link;
+use Drupal\Core\StringTranslation\StringTranslationTrait;
 use Drupal\Core\TempStore\Lock;
 use Drupal\views\Controller\ViewAjaxController;
 use Drupal\views\Views;
@@ -27,6 +29,8 @@ use Symfony\Component\HttpFoundation\Request;
 #[\AllowDynamicProperties]
 class ViewUI implements ViewEntityInterface {
 
+  use StringTranslationTrait;
+
   /**
    * Indicates if a view is currently being edited.
    *
@@ -39,6 +43,7 @@ class ViewUI implements ViewEntityInterface {
    *
    * @var array
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName, Drupal.Commenting.VariableComment.Missing
   public $changed_display;
 
   /**
@@ -46,6 +51,7 @@ class ViewUI implements ViewEntityInterface {
    *
    * @var float
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName, Drupal.Commenting.VariableComment.Missing
   public $render_time;
 
   /**
@@ -70,6 +76,7 @@ class ViewUI implements ViewEntityInterface {
    *
    * @var array
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName, Drupal.Commenting.VariableComment.Missing
   public $temporary_options;
 
   /**
@@ -84,10 +91,9 @@ class ViewUI implements ViewEntityInterface {
    *
    * @var bool
    */
+  // phpcs:ignore Drupal.NamingConventions.ValidVariableName.LowerCamelName, Drupal.Commenting.VariableComment.Missing
   public $live_preview;
 
-  public $renderPreview = FALSE;
-
   /**
    * The View storage object.
    *
@@ -225,15 +231,16 @@ class ViewUI implements ViewEntityInterface {
 
     [$was_defaulted, $is_defaulted, $revert] = $this->getOverrideValues($form, $form_state);
 
-    // Based on the user's choice in the display dropdown, determine which display
-    // these changes apply to.
+    // Based on the user's choice in the display dropdown, determine which
+    // display these changes apply to.
     $display_id = $form_state->get('display_id');
     if ($revert) {
       // If it's revert just change the override and return.
       $display = &$this->getExecutable()->displayHandlers->get($display_id);
       $display->optionsOverride($form, $form_state);
 
-      // Don't execute the normal submit handling but still store the changed view into cache.
+      // Don't execute the normal submit handling but still store the changed
+      // view into cache.
       $this->cacheSet();
       return;
     }
@@ -282,8 +289,8 @@ class ViewUI implements ViewEntityInterface {
    * This will also provide a hidden op operator because the forms plugin
    * doesn't seem to properly provide which button was clicked.
    *
-   * TODO: Is the hidden op operator still here somewhere, or is that part of the
-   * docblock outdated?
+   * @todo Is the hidden op operator still here somewhere, or is that part of
+   *   the docblock outdated?
    */
   public function getStandardButtons(&$form, FormStateInterface $form_state, $form_id, $name = NULL) {
     $form['actions'] = [
@@ -291,11 +298,11 @@ class ViewUI implements ViewEntityInterface {
     ];
 
     if (empty($name)) {
-      $name = t('Apply');
+      $name = $this->t('Apply');
       if (!empty($this->stack) && count($this->stack) > 1) {
-        $name = t('Apply and continue');
+        $name = $this->t('Apply and continue');
       }
-      $names = [t('Apply'), t('Apply and continue')];
+      $names = [$this->t('Apply'), $this->t('Apply and continue')];
     }
 
     // Forms that are purely informational set an ok_button flag, so we know not
@@ -334,14 +341,15 @@ class ViewUI implements ViewEntityInterface {
     $cancel_submit = function_exists($form_id . '_cancel') ? $form_id . '_cancel' : [$this, 'standardCancel'];
     $form['actions']['cancel'] = [
       '#type' => 'submit',
-      '#value' => !$form_state->get('ok_button') ? t('Cancel') : t('Ok'),
+      '#value' => !$form_state->get('ok_button') ? $this->t('Cancel') : $this->t('Ok'),
       '#submit' => [$cancel_submit],
       '#validate' => [],
       '#limit_validation_errors' => [],
     ];
 
     // Compatibility, to be removed later: // TODO: When is "later"?
-    // We used to set these items on the form, but now we want them on the $form_state:
+    // We used to set these items on the form, but now we want them on the
+    // $form_state:
     if (isset($form['#title'])) {
       $form_state->set('title', $form['#title']);
     }
@@ -358,8 +366,9 @@ class ViewUI implements ViewEntityInterface {
   public function getOverrideValues($form, FormStateInterface $form_state) {
     // Make sure the dropdown exists in the first place.
     if ($form_state->hasValue(['override', 'dropdown'])) {
-      // #default_value is used to determine whether it was the default value or not.
-      // So the available options are: $display, 'default' and 'default_revert', not 'defaults'.
+      // #default_value is used to determine whether it was the default value or
+      // not. So the available options are: $display, 'default' and
+      // 'default_revert', not 'defaults'.
       $was_defaulted = ($form['override']['dropdown']['#default_value'] === 'defaults');
       $dropdown = $form_state->getValue(['override', 'dropdown']);
       $is_defaulted = ($dropdown === 'default');
@@ -398,8 +407,8 @@ class ViewUI implements ViewEntityInterface {
 
     $stack = [implode('-', array_filter([$key, $this->id(), $display_id, $type, $id])), $key, $display_id, $type, $id];
     // If we're being asked to add this form to the bottom of the stack, no
-    // special logic is required. Our work is equally easy if we were asked to add
-    // to the top of the stack, but there's nothing in it yet.
+    // special logic is required. Our work is equally easy if we were asked to
+    // add to the top of the stack, but there's nothing in it yet.
     if (!$top || empty($this->stack)) {
       $this->stack[] = $stack;
     }
@@ -458,7 +467,8 @@ class ViewUI implements ViewEntityInterface {
     }
 
     if (!$form_state->isValueEmpty('name') && is_array($form_state->getValue('name'))) {
-      // Loop through each of the items that were checked and add them to the view.
+      // Loop through each of the items that were checked and add them to the
+      // view.
       foreach (array_keys(array_filter($form_state->getValue('name'))) as $field) {
         [$table, $field] = explode('.', $field, 2);
 
@@ -467,9 +477,10 @@ class ViewUI implements ViewEntityInterface {
         }
         $id = $this->getExecutable()->addHandler($display_id, $type, $table, $field);
 
-        // check to see if we have group by settings
+        // Check to see if we have group by settings
         $key = $type;
-        // Footer,header and empty text have a different internal handler type(area).
+        // Footer,header and empty text have a different internal handler
+        // type(area).
         if (isset($types[$type]['type'])) {
           $key = $types[$type]['type'];
         }
@@ -482,7 +493,8 @@ class ViewUI implements ViewEntityInterface {
           $this->addFormToStack('handler-group', $display_id, $type, $id);
         }
 
-        // check to see if this type has settings, if so add the settings form first
+        // Check to see if this type has settings, if so add the settings form
+        // first
         if ($handler && $handler->hasExtraOptions()) {
           $this->addFormToStack('handler-extra', $display_id, $type, $id);
         }
@@ -523,7 +535,8 @@ class ViewUI implements ViewEntityInterface {
   }
 
   public function renderPreview($display_id, $args = []) {
-    // Save the current path so it can be restored before returning from this function.
+    // Save the current path so it can be restored before returning from this
+    // function.
     $request_stack = \Drupal::requestStack();
     $current_request = $request_stack->getCurrentRequest();
     $executable = $this->getExecutable();
@@ -564,7 +577,7 @@ class ViewUI implements ViewEntityInterface {
 
       if (!$executable->setDisplay($display_id)) {
         return [
-          '#markup' => t('Invalid display id @display', ['@display' => $display_id]),
+          '#markup' => $this->t('Invalid display id @display', ['@display' => $display_id]),
         ];
       }
 
@@ -592,12 +605,14 @@ class ViewUI implements ViewEntityInterface {
       foreach ($args as $key => $arg) {
         $request->attributes->set('arg_' . $key, $arg);
       }
+      $request->setSession($request_stack->getSession());
       $request_stack->push($request);
 
       // Suppress contextual links of entities within the result set during a
       // Preview.
-      // @todo We'll want to add contextual links specific to editing the View, so
-      //   the suppression may need to be moved deeper into the Preview pipeline.
+      // @todo We'll want to add contextual links specific to editing the View,
+      //   so the suppression may need to be moved deeper into the Preview
+      //   pipeline.
       views_ui_contextual_links_suppress_push();
 
       $show_additional_queries = $config->get('ui.show.additional_queries');
@@ -662,14 +677,14 @@ class ViewUI implements ViewEntityInterface {
             if (!empty($this->additionalQueries)) {
               $queries[] = [
                 '#prefix' => '<strong>',
-                '#markup' => t('These queries were run during view rendering:'),
+                '#markup' => $this->t('These queries were run during view rendering:'),
                 '#suffix' => '</strong>',
               ];
               foreach ($this->additionalQueries as $query) {
                 $query_string = strtr($query['query'], $query['args']);
                 $queries[] = [
                   '#prefix' => "\n",
-                  '#markup' => t('[@time ms] @query', ['@time' => round($query['time'] * 100000, 1) / 100000.0, '@query' => $query_string]),
+                  '#markup' => $this->t('[@time ms] @query', ['@time' => round($query['time'] * 100000, 1) / 100000.0, '@query' => $query_string]),
                 ];
               }
 
@@ -711,13 +726,13 @@ class ViewUI implements ViewEntityInterface {
               $path = Link::fromTextAndUrl($path->toString(), $path)->toString();
             }
             else {
-              $path = t('This display has no path.');
+              $path = $this->t('This display has no path.');
             }
             $rows['query'][] = [
               [
                 'data' => [
                   '#prefix' => '<strong>',
-                  '#markup' => t('Path'),
+                  '#markup' => $this->t('Path'),
                   '#suffix' => '</strong>',
                 ],
               ],
@@ -736,7 +751,7 @@ class ViewUI implements ViewEntityInterface {
                   '#template' => "<strong>{% trans 'Query build time' %}</strong>",
                 ],
               ],
-              t('@time ms', ['@time' => intval($executable->build_time * 100000) / 100]),
+              $this->t('@time ms', ['@time' => intval($executable->build_time * 100000) / 100]),
             ];
 
             $rows['statistics'][] = [
@@ -746,7 +761,7 @@ class ViewUI implements ViewEntityInterface {
                   '#template' => "<strong>{% trans 'Query execute time' %}</strong>",
                 ],
               ],
-              t('@time ms', ['@time' => intval($executable->execute_time * 100000) / 100]),
+              $this->t('@time ms', ['@time' => intval($executable->execute_time * 100000) / 100]),
             ];
 
             $rows['statistics'][] = [
@@ -756,7 +771,7 @@ class ViewUI implements ViewEntityInterface {
                   '#template' => "<strong>{% trans 'View render time' %}</strong>",
                 ],
               ],
-              t('@time ms', ['@time' => intval($this->render_time * 100) / 100]),
+              $this->t('@time ms', ['@time' => intval($this->render_time * 100) / 100]),
             ];
           }
           \Drupal::moduleHandler()->alter('views_preview_info', $rows, $executable);
@@ -769,13 +784,13 @@ class ViewUI implements ViewEntityInterface {
               [
                 'data' => [
                   '#prefix' => '<strong>',
-                  '#markup' => t('Query'),
+                  '#markup' => $this->t('Query'),
                   '#suffix' => '</strong>',
                 ],
               ],
               [
                 'data' => [
-                  '#markup' => t('No query was run'),
+                  '#markup' => $this->t('No query was run'),
                 ],
               ],
             ];
@@ -785,13 +800,13 @@ class ViewUI implements ViewEntityInterface {
               [
                 'data' => [
                   '#prefix' => '<strong>',
-                  '#markup' => t('Query'),
+                  '#markup' => $this->t('Query'),
                   '#suffix' => '</strong>',
                 ],
               ],
               [
                 'data' => [
-                  '#markup' => t('No query was run'),
+                  '#markup' => $this->t('No query was run'),
                 ],
               ],
             ];
@@ -805,7 +820,7 @@ class ViewUI implements ViewEntityInterface {
           \Drupal::messenger()->addError($error);
         }
       }
-      $preview = ['#markup' => t('Unable to preview due to validation errors.')];
+      $preview = ['#markup' => $this->t('Unable to preview due to validation errors.')];
     }
 
     // Assemble the preview, the query info, and the query statistics in the
@@ -871,7 +886,7 @@ class ViewUI implements ViewEntityInterface {
    */
   public function cacheSet() {
     if ($this->isLocked()) {
-      \Drupal::messenger()->addError(t('Changes cannot be made to a locked view.'));
+      \Drupal::messenger()->addError($this->t('Changes cannot be made to a locked view.'));
       return;
     }
 
@@ -977,7 +992,7 @@ class ViewUI implements ViewEntityInterface {
   /**
    * {@inheritdoc}
    */
-  public static function loadMultiple(array $ids = NULL) {
+  public static function loadMultiple(?array $ids = NULL) {
     return View::loadMultiple($ids);
   }
 
@@ -1047,7 +1062,7 @@ class ViewUI implements ViewEntityInterface {
   /**
    * {@inheritdoc}
    */
-  public function access($operation = 'view', AccountInterface $account = NULL, $return_as_object = FALSE) {
+  public function access($operation = 'view', ?AccountInterface $account = NULL, $return_as_object = FALSE) {
     return $this->storage->access($operation, $account, $return_as_object);
   }
 
@@ -1376,4 +1391,19 @@ class ViewUI implements ViewEntityInterface {
     return $this;
   }
 
+  /**
+   * {@inheritdoc}
+   */
+  public function getOriginal(): ?static {
+    return $this->storage->getOriginal();
+  }
+
+  /**
+   * {@inheritdoc}
+   */
+  public function setOriginal(?EntityInterface $original): static {
+    $this->storage->setOriginal($original);
+    return $this;
+  }
+
 }
