@@ -17,7 +17,7 @@ class RearrangeFilterTest extends UnitTestCase {
   /**
    * Tests static methods.
    */
-  public function testStaticMethods() {
+  public function testStaticMethods(): void {
     // Test the RearrangeFilter::arrayKeyPlus method.
     $original = [0 => 'one', 1 => 'two', 2 => 'three'];
     $expected = [1 => 'one', 2 => 'two', 3 => 'three'];
