@@ -1,4 +1,4 @@
-const fs = require('fs');
+const fs = require('node:fs');
 const log = require('./log');
 const compile = require('./compile');
 
@@ -14,7 +14,7 @@ module.exports = (filePath) => {
         return;
       }
       if (code !== data.toString()) {
-        log(`'${filePath}' is not updated.`);
+        log(`'${filePath}' does not match its CSS file. Recompile the CSS with: yarn run build:css`);
         process.exitCode = 1;
       }
     });
