@@ -79,6 +79,15 @@ const assetsFolder = `${coreFolder}/assets/vendor`;
       library: 'internal.backbone',
       files: ['backbone.js', 'backbone-min.js', 'backbone-min.js.map'],
     },
+    {
+      pack: 'htmx.org',
+      folder: 'htmx',
+      library: 'htmx',
+      files: [
+        { from: 'dist/htmx.min.js', to: 'htmx.min.js' },
+        { from: 'dist/htmx.js', to: 'htmx.js' },
+      ],
+    },
     {
       pack: 'jquery',
       files: [
