@@ -14,9 +14,7 @@ use PHPUnit\Framework\AssertionFailedError;
 class BrowserWithJavascriptTest extends WebDriverTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['test_page_test'];
 
@@ -25,7 +23,7 @@ class BrowserWithJavascriptTest extends WebDriverTestBase {
    */
   protected $defaultTheme = 'stark';
 
-  public function testJavascript() {
+  public function testJavascript(): void {
     $this->drupalGet('<front>');
     $session = $this->getSession();
 
@@ -48,7 +46,7 @@ JS;
     $this->assertFalse($this->isTestUsingGuzzleClient());
   }
 
-  public function testAssertJsCondition() {
+  public function testAssertJsCondition(): void {
     $this->drupalGet('<front>');
     $session = $this->getSession();
 
@@ -74,7 +72,7 @@ JS;
   /**
    * Tests creating screenshots.
    */
-  public function testCreateScreenshot() {
+  public function testCreateScreenshot(): void {
     $this->drupalGet('<front>');
     $this->createScreenshot('public://screenshot.jpg');
     $this->assertFileExists('public://screenshot.jpg');
@@ -86,7 +84,7 @@ JS;
    * @see \Drupal\Tests\WebAssert::assertNoEscaped()
    * @see \Drupal\Tests\WebAssert::assertEscaped()
    */
-  public function testEscapingAssertions() {
+  public function testEscapingAssertions(): void {
     $assert = $this->assertSession();
 
     $this->drupalGet('test-escaped-characters');
@@ -141,8 +139,8 @@ JS;
     $session->visit($url);
 
     // There are 2 alerts to accept before we can get the content of the page.
-    $session->getDriver()->getWebdriverSession()->accept_alert();
-    $session->getDriver()->getWebdriverSession()->accept_alert();
+    $session->getDriver()->getWebdriverSession()->alert()->accept();
+    $session->getDriver()->getWebdriverSession()->alert()->accept();
 
     $out = $session->getPage()->getContent();
 
