@@ -12,6 +12,9 @@ namespace Drupal\FunctionalJavascriptTests;
  */
 class JavascriptDeprecationTest extends WebDriverTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
   protected static $modules = ['js_deprecation_test'];
 
   /**
@@ -22,7 +25,7 @@ class JavascriptDeprecationTest extends WebDriverTestBase {
   /**
    * Tests Javascript deprecation notices.
    */
-  public function testJavascriptDeprecation() {
+  public function testJavascriptDeprecation(): void {
     $this->expectDeprecation('Javascript Deprecation: This function is deprecated for testing purposes.');
     $this->expectDeprecation('Javascript Deprecation: This property is deprecated for testing purposes.');
     $this->drupalGet('js_deprecation_test');
