@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace Drupal\FunctionalJavascriptTests\Tests;
 
+use Behat\Mink\Driver\Selenium2Driver;
 use Drupal\entity_test\Entity\EntityTest;
 use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
 use Drupal\Tests\file\Functional\FileFieldCreationTrait;
@@ -46,8 +47,10 @@ class DrupalSelenium2DriverTest extends WebDriverTestBase {
   /**
    * Tests uploading remote files.
    */
-  public function testGetRemoteFilePath() {
+  public function testGetRemoteFilePath(): void {
     $web_driver = $this->getSession()->getDriver();
+    $this->assertInstanceOf(Selenium2Driver::class, $web_driver);
+
     $file_system = \Drupal::service('file_system');
     $entity = EntityTest::create();
     $entity->save();
