@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\FunctionalTests\Core\Container;
 
 use Drupal\Tests\BrowserTestBase;
@@ -31,7 +33,7 @@ class ServiceDeprecationTest extends BrowserTestBase {
   /**
    * @covers ::get
    */
-  public function testGetDeprecated() {
+  public function testGetDeprecated(): void {
     $this->expectDeprecation('The "deprecation_test.service" service is deprecated in drupal:9.0.0 and is removed from drupal:20.0.0. This is a test.');
     $this->expectDeprecation('The "deprecation_test.alias" alias is deprecated in drupal:9.0.0 and is removed from drupal:20.0.0. This is a test.');
     // @phpstan-ignore-next-line
