@@ -1,18 +1,23 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\FunctionalTests\Core\Test;
 
 use Drupal\Core\Url;
 use Drupal\Tests\BrowserTestBase;
 
 /**
- * Tests Drupal's integration with Symfony PHPUnit Bridge.
+ * Tests Drupal's extension to manage code deprecation.
  *
  * @group Test
  * @group legacy
  */
 class PhpUnitBridgeTest extends BrowserTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
   protected static $modules = ['deprecation_test'];
 
   /**
@@ -21,16 +26,18 @@ class PhpUnitBridgeTest extends BrowserTestBase {
   protected $defaultTheme = 'stark';
 
   /**
-   * @expectedDeprecation This is the deprecation message for deprecation_test_function().
+   * Tests deprecation message from deprecation_test_function().
    */
-  public function testSilencedError() {
+  public function testSilencedError(): void {
+    $this->expectDeprecation('This is the deprecation message for deprecation_test_function().');
     $this->assertEquals('known_return_value', deprecation_test_function());
   }
 
   /**
-   * @expectedDeprecation This is the deprecation message for deprecation_test_function().
+   * Tests deprecation message from deprecated route.
    */
-  public function testErrorOnSiteUnderTest() {
+  public function testErrorOnSiteUnderTest(): void {
+    $this->expectDeprecation('This is the deprecation message for deprecation_test_function().');
     $this->drupalGet(Url::fromRoute('deprecation_test.route'));
   }
 
