@@ -1,9 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Config;
 
 use Drupal\entity_test\Entity\EntityTest;
 use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;
+use Drupal\user\Entity\Role;
 
 /**
  * Tests for configuration dependencies.
@@ -15,7 +18,7 @@ use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;
 class ConfigDependencyTest extends EntityKernelTestBase {
 
   /**
-   * Modules to enable.
+   * Modules to install.
    *
    * The entity_test module is enabled to provide content entity types.
    *
@@ -26,7 +29,7 @@ class ConfigDependencyTest extends EntityKernelTestBase {
   /**
    * Tests that calculating dependencies for system module.
    */
-  public function testNonEntity() {
+  public function testNonEntity(): void {
     $this->installConfig(['system']);
     $config_manager = \Drupal::service('config.manager');
     $dependents = $config_manager->findConfigEntityDependencies('module', ['system']);
@@ -40,7 +43,7 @@ class ConfigDependencyTest extends EntityKernelTestBase {
   /**
    * Tests creating dependencies on configuration entities.
    */
-  public function testDependencyManagement() {
+  public function testDependencyManagement(): void {
     /** @var \Drupal\Core\Config\ConfigManagerInterface $config_manager */
     $config_manager = \Drupal::service('config.manager');
     $storage = $this->container->get('entity_type.manager')->getStorage('config_test');
@@ -188,7 +191,7 @@ class ConfigDependencyTest extends EntityKernelTestBase {
   /**
    * Tests ConfigManager::uninstall() and config entity dependency management.
    */
-  public function testConfigEntityUninstall() {
+  public function testConfigEntityUninstall(): void {
     /** @var \Drupal\Core\Config\ConfigManagerInterface $config_manager */
     $config_manager = \Drupal::service('config.manager');
     /** @var \Drupal\Core\Config\Entity\ConfigEntityStorage $storage */
@@ -227,7 +230,7 @@ class ConfigDependencyTest extends EntityKernelTestBase {
   /**
    * Data provider for self::testConfigEntityUninstallComplex().
    */
-  public function providerConfigEntityUninstallComplex() {
+  public static function providerConfigEntityUninstallComplex() {
     // Ensure that alphabetical order has no influence on dependency fixing and
     // removal.
     return [
@@ -248,7 +251,7 @@ class ConfigDependencyTest extends EntityKernelTestBase {
    *
    * @dataProvider providerConfigEntityUninstallComplex
    */
-  public function testConfigEntityUninstallComplex(array $entity_id_suffixes) {
+  public function testConfigEntityUninstallComplex(array $entity_id_suffixes): void {
     /** @var \Drupal\Core\Config\ConfigManagerInterface $config_manager */
     $config_manager = \Drupal::service('config.manager');
     /** @var \Drupal\Core\Config\Entity\ConfigEntityStorage $storage */
@@ -373,7 +376,7 @@ class ConfigDependencyTest extends EntityKernelTestBase {
    * @covers ::uninstall
    * @covers ::getConfigEntitiesToChangeOnDependencyRemoval
    */
-  public function testConfigEntityUninstallThirdParty() {
+  public function testConfigEntityUninstallThirdParty(): void {
     /** @var \Drupal\Core\Config\ConfigManagerInterface $config_manager */
     $config_manager = \Drupal::service('config.manager');
     /** @var \Drupal\Core\Config\Entity\ConfigEntityStorage $storage */
@@ -488,7 +491,7 @@ class ConfigDependencyTest extends EntityKernelTestBase {
   /**
    * Tests deleting a configuration entity and dependency management.
    */
-  public function testConfigEntityDelete() {
+  public function testConfigEntityDelete(): void {
     /** @var \Drupal\Core\Config\ConfigManagerInterface $config_manager */
     $config_manager = \Drupal::service('config.manager');
     /** @var \Drupal\Core\Config\Entity\ConfigEntityStorage $storage */
@@ -595,7 +598,7 @@ class ConfigDependencyTest extends EntityKernelTestBase {
    *
    * @see \Drupal\Core\Config\ConfigManager::getConfigEntitiesToChangeOnDependencyRemoval()
    */
-  public function testContentEntityDelete() {
+  public function testContentEntityDelete(): void {
     $this->installEntitySchema('entity_test');
     /** @var \Drupal\Core\Config\ConfigManagerInterface $config_manager */
     $config_manager = \Drupal::service('config.manager');
@@ -638,6 +641,57 @@ class ConfigDependencyTest extends EntityKernelTestBase {
     $this->assertEmpty($config_entities['unchanged'], 'No dependencies of the content entity will be unchanged.');
   }
 
+  /**
+   * Tests that config dependency ordering.
+   */
+  public function testDependencyOrder(): void {
+    $storage = $this->container->get('entity_type.manager')->getStorage('config_test');
+    // Test dependencies between modules.
+    $entity1 = $storage->create(['id' => 'entity1']);
+    $entity1->save();
+    // Create additional entities to test dependencies on config entities.
+    $entity2 = $storage->create(['id' => 'entity2', 'dependencies' => ['enforced' => ['config' => [$entity1->getConfigDependencyName()]]]]);
+    $entity2->save();
+    $entity3 = $storage->create(['id' => 'entity3', 'dependencies' => ['enforced' => ['config' => [$entity1->getConfigDependencyName()]]]]);
+    $entity3->save();
+    // Include a role entity to test ordering when dependencies have multiple
+    // entity types.
+    $role = Role::create([
+      'id' => 'test_role',
+      'label' => 'Test role',
+      // This adds an implicit dependency on $entity 2, and hence also $entity1,
+      // to the role.
+      'permissions' => ["permission with {$entity2->getConfigDependencyName()} dependency"],
+    ]);
+    $role->save();
+    $entity4 = $storage->create([
+      'id' => 'entity4',
+      'dependencies' => [
+        'enforced' => [
+          'config' => [
+            // Add dependencies to $entity3 and the role so that the $entity4
+            // should be last to be processed when handling dependency removal.
+            // The role should be processed after $entity1 and $entity2, but
+            // before $entity4.
+            $entity3->getConfigDependencyName(),
+            $role->getConfigDependencyName(),
+          ],
+        ],
+      ],
+    ]);
+    $entity4->save();
+
+    // Create scenario where entity1 is deleted, but all the config_test
+    // entities depending on entity1 are fixed instead of being deleted. This
+    // means that entity2 is not deleted, so the role should not lose the
+    // permission depending on entity2.
+    \Drupal::state()->set('config_test.fix_dependencies', ['config_test.dynamic.entity1']);
+    $entity1->delete();
+    $role = Role::load('test_role');
+    $this->assertNotNull($role);
+    $this->assertTrue($role->hasPermission("permission with {$entity2->getConfigDependencyName()} dependency"));
+  }
+
   /**
    * Gets a list of identifiers from an array of configuration entities.
    *
@@ -647,7 +701,7 @@ class ConfigDependencyTest extends EntityKernelTestBase {
    * @return array
    *   An array with values of entity_type_id:ID
    */
-  protected function getDependentIds(array $dependents) {
+  protected function getDependentIds(array $dependents): array {
     $dependent_ids = [];
     foreach ($dependents as $dependent) {
       $dependent_ids[] = $dependent->getEntityTypeId() . ':' . $dependent->id();
