@@ -1,9 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Config;
 
 use Drupal\Component\Utility\Html;
-use Drupal\Component\Render\FormattableMarkup;
+use Drupal\Core\Config\ConfigCollectionEvents;
 use Drupal\Core\Config\ConfigEvents;
 use Drupal\Core\Config\ConfigImporter;
 use Drupal\Core\Config\ConfigImporterException;
@@ -22,9 +24,7 @@ class ConfigImporterTest extends KernelTestBase {
   const FAIL_MESSAGE = 'There were errors validating the config synchronization.';
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['config_test', 'system', 'config_import_test', 'config_events_test'];
 
@@ -46,7 +46,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests omission of module APIs for bare configuration operations.
    */
-  public function testNoImport() {
+  public function testNoImport(): void {
     $dynamic_name = 'config_test.dynamic.dotted.default';
 
     // Verify the default configuration values exist.
@@ -60,7 +60,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests that trying to import from empty sync configuration directory fails.
    */
-  public function testEmptyImportFails() {
+  public function testEmptyImportFails(): void {
     $this->expectException(ConfigImporterException::class);
     $this->container->get('config.storage.sync')->deleteAll();
     $this->configImporter()->import();
@@ -69,7 +69,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests verification of site UUID before importing configuration.
    */
-  public function testSiteUuidValidate() {
+  public function testSiteUuidValidate(): void {
     $sync = \Drupal::service('config.storage.sync');
     // Create updated configuration object.
     $config_data = $this->config('system.site')->get();
@@ -99,7 +99,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests deletion of configuration during import.
    */
-  public function testDeleted() {
+  public function testDeleted(): void {
     $dynamic_name = 'config_test.dynamic.dotted.default';
     $storage = $this->container->get('config.storage');
     $sync = $this->container->get('config.storage.sync');
@@ -137,7 +137,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests creation of configuration during import.
    */
-  public function testNew() {
+  public function testNew(): void {
     $dynamic_name = 'config_test.dynamic.new';
     $storage = $this->container->get('config.storage');
     $sync = $this->container->get('config.storage.sync');
@@ -192,7 +192,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests that secondary writes are overwritten.
    */
-  public function testSecondaryWritePrimaryFirst() {
+  public function testSecondaryWritePrimaryFirst(): void {
     $name_primary = 'config_test.dynamic.primary';
     $name_secondary = 'config_test.dynamic.secondary';
     $sync = $this->container->get('config.storage.sync');
@@ -233,13 +233,13 @@ class ConfigImporterTest extends KernelTestBase {
 
     $logs = $config_importer->getErrors();
     $this->assertCount(1, $logs);
-    $this->assertEquals(new FormattableMarkup('Deleted and replaced configuration entity "@name"', ['@name' => $name_secondary]), $logs[0]);
+    $this->assertEquals('Deleted and replaced configuration entity "' . $name_secondary . '"', $logs[0]);
   }
 
   /**
    * Tests that secondary writes are overwritten.
    */
-  public function testSecondaryWriteSecondaryFirst() {
+  public function testSecondaryWriteSecondaryFirst(): void {
     $name_primary = 'config_test.dynamic.primary';
     $name_secondary = 'config_test.dynamic.secondary';
     $sync = $this->container->get('config.storage.sync');
@@ -286,7 +286,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests that secondary updates for deleted files work as expected.
    */
-  public function testSecondaryUpdateDeletedParentFirst() {
+  public function testSecondaryUpdateDeletedParentFirst(): void {
     $name_dependency = 'config_test.dynamic.dependency';
     $name_dependent = 'config_test.dynamic.dependent';
     $name_other = 'config_test.dynamic.other';
@@ -363,7 +363,7 @@ class ConfigImporterTest extends KernelTestBase {
 
     $logs = $config_importer->getErrors();
     $this->assertCount(1, $logs);
-    $this->assertEquals(new FormattableMarkup('Update target "@name" is missing.', ['@name' => $name_dependent]), $logs[0]);
+    $this->assertEquals('Update target "' . $name_dependent . '" is missing.', $logs[0]);
   }
 
   /**
@@ -373,7 +373,7 @@ class ConfigImporterTest extends KernelTestBase {
    * configuration tree imports. Therefore, any configuration updates that cause
    * secondary deletes should be reflected already in the staged configuration.
    */
-  public function testSecondaryUpdateDeletedChildFirst() {
+  public function testSecondaryUpdateDeletedChildFirst(): void {
     $name_dependency = 'config_test.dynamic.dependency';
     $name_dependent = 'config_test.dynamic.dependent';
     $storage = $this->container->get('config.storage');
@@ -409,8 +409,9 @@ class ConfigImporterTest extends KernelTestBase {
 
     $entity_storage = \Drupal::entityTypeManager()->getStorage('config_test');
     // Both entities are deleted. ConfigTest::postSave() causes updates of the
-    // dependency entity to delete the dependent entity. Since the dependency depends on
-    // the dependent, removing the dependent causes the dependency to be removed.
+    // dependency entity to delete the dependent entity. Since the dependency
+    // depends on the dependent, removing the dependent causes the dependency to
+    // be removed.
     $this->assertNull($entity_storage->load('dependency'));
     $this->assertNull($entity_storage->load('dependent'));
     $logs = $config_importer->getErrors();
@@ -420,7 +421,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests that secondary deletes for deleted files work as expected.
    */
-  public function testSecondaryDeletedChildSecond() {
+  public function testSecondaryDeletedChildSecond(): void {
     $name_dependency = 'config_test.dynamic.dependency';
     $name_dependent = 'config_test.dynamic.dependent';
     $storage = $this->container->get('config.storage');
@@ -432,7 +433,8 @@ class ConfigImporterTest extends KernelTestBase {
       'label' => 'Dependency',
       'weight' => 0,
       'uuid' => $uuid->generate(),
-      // Add a dependency on dependent, to make sure this delete is synced first.
+      // Add a dependency on dependent, to make sure this delete is synced
+      // first.
       'dependencies' => [
         'config' => [$name_dependent],
       ],
@@ -463,7 +465,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests updating of configuration during import.
    */
-  public function testUpdated() {
+  public function testUpdated(): void {
     $name = 'config_test.system';
     $dynamic_name = 'config_test.dynamic.dotted.default';
     $storage = $this->container->get('config.storage');
@@ -521,10 +523,10 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests the isInstallable method()
    */
-  public function testIsInstallable() {
-    $config_name = 'config_test.dynamic.isinstallable';
+  public function testIsInstallable(): void {
+    $config_name = 'config_test.dynamic.is_installable';
     $this->assertFalse($this->container->get('config.storage')->exists($config_name));
-    \Drupal::state()->set('config_test.isinstallable', TRUE);
+    \Drupal::state()->set('config_test.is_installable', TRUE);
     $this->installConfig(['config_test']);
     $this->assertTrue($this->container->get('config.storage')->exists($config_name));
   }
@@ -535,7 +537,7 @@ class ConfigImporterTest extends KernelTestBase {
    * @see \Drupal\Core\EventSubscriber\ConfigImportSubscriber
    * @see \Drupal\Core\Config\ConfigImporter::createExtensionChangelist()
    */
-  public function testUnmetDependency() {
+  public function testUnmetDependency(): void {
     $storage = $this->container->get('config.storage');
     $sync = $this->container->get('config.storage.sync');
 
@@ -564,7 +566,7 @@ class ConfigImporterTest extends KernelTestBase {
     $extensions['module']['unknown_module'] = 0;
     $extensions['theme']['unknown_theme'] = 0;
     // Add a module and a theme that depend on uninstalled extensions.
-    $extensions['module']['book'] = 0;
+    $extensions['module']['new_dependency_test'] = 0;
     $extensions['theme']['test_subtheme'] = 0;
 
     $sync->write('core.extension', $extensions);
@@ -577,7 +579,7 @@ class ConfigImporterTest extends KernelTestBase {
       $expected = [
         static::FAIL_MESSAGE,
         'Unable to install the <em class="placeholder">unknown_module</em> module since it does not exist.',
-        'Unable to install the <em class="placeholder">Book</em> module since it requires the <em class="placeholder">Node, Text, Field, Filter, User</em> modules.',
+        'Unable to install the <em class="placeholder">New Dependency test</em> module since it requires the <em class="placeholder">New Dependency test with service</em> module.',
         'Unable to install the <em class="placeholder">unknown_theme</em> theme since it does not exist.',
         'Unable to install the <em class="placeholder">Theme test subtheme</em> theme since it requires the <em class="placeholder">Theme test base theme</em> theme.',
         'Configuration <em class="placeholder">config_test.dynamic.dotted.config</em> depends on the <em class="placeholder">unknown</em> configuration that will not exist after import.',
@@ -590,7 +592,7 @@ class ConfigImporterTest extends KernelTestBase {
       $error_log = $config_importer->getErrors();
       $expected = [
         'Unable to install the <em class="placeholder">unknown_module</em> module since it does not exist.',
-        'Unable to install the <em class="placeholder">Book</em> module since it requires the <em class="placeholder">Node, Text, Field, Filter, User</em> modules.',
+        'Unable to install the <em class="placeholder">New Dependency test</em> module since it requires the <em class="placeholder">New Dependency test with service</em> module.',
         'Unable to install the <em class="placeholder">unknown_theme</em> theme since it does not exist.',
         'Configuration <em class="placeholder">config_test.dynamic.dotted.config</em> depends on the <em class="placeholder">unknown</em> configuration that will not exist after import.',
         'Configuration <em class="placeholder">config_test.dynamic.dotted.existing</em> depends on the <em class="placeholder">config_test.dynamic.dotted.deleted</em> configuration that will not exist after import.',
@@ -620,7 +622,7 @@ class ConfigImporterTest extends KernelTestBase {
       $expected = [
         static::FAIL_MESSAGE,
         'Unable to install the <em class="placeholder">unknown_module</em> module since it does not exist.',
-        'Unable to install the <em class="placeholder">Book</em> module since it requires the <em class="placeholder">Node, Text, Field, Filter, User</em> modules.',
+        'Unable to install the <em class="placeholder">New Dependency test</em> module since it requires the <em class="placeholder">New Dependency test with service</em> module.',
         'Unable to install the <em class="placeholder">unknown_theme</em> theme since it does not exist.',
         'Unable to install the <em class="placeholder">Theme test subtheme</em> theme since it requires the <em class="placeholder">Theme test base theme</em> theme.',
         'Configuration <em class="placeholder">config_test.dynamic.dotted.config</em> depends on configuration (<em class="placeholder">unknown, unknown2</em>) that will not exist after import.',
@@ -647,7 +649,7 @@ class ConfigImporterTest extends KernelTestBase {
    *
    * @see \Drupal\Core\EventSubscriber\ConfigImportSubscriber
    */
-  public function testMissingCoreExtension() {
+  public function testMissingCoreExtension(): void {
     $sync = $this->container->get('config.storage.sync');
     $sync->delete('core.extension');
     $config_importer = $this->configImporter();
@@ -668,7 +670,7 @@ class ConfigImporterTest extends KernelTestBase {
    *
    * @see \Drupal\Core\EventSubscriber\ConfigImportSubscriber
    */
-  public function testRequiredModuleValidation() {
+  public function testRequiredModuleValidation(): void {
     $sync = $this->container->get('config.storage.sync');
 
     $extensions = $sync->read('core.extension');
@@ -692,28 +694,28 @@ class ConfigImporterTest extends KernelTestBase {
    *
    * @see \Drupal\Core\EventSubscriber\ConfigImportSubscriber
    */
-  public function testInstallBaseAndSubThemes() {
+  public function testInstallBaseAndSubThemes(): void {
     $sync = $this->container->get('config.storage.sync');
     $extensions = $sync->read('core.extension');
-    $extensions['theme']['test_basetheme'] = 0;
+    $extensions['theme']['test_base_theme'] = 0;
     $extensions['theme']['test_subtheme'] = 0;
     $extensions['theme']['test_subsubtheme'] = 0;
     $sync->write('core.extension', $extensions);
     $config_importer = $this->configImporter();
     $config_importer->import();
-    $this->assertTrue($this->container->get('theme_handler')->themeExists('test_basetheme'));
+    $this->assertTrue($this->container->get('theme_handler')->themeExists('test_base_theme'));
     $this->assertTrue($this->container->get('theme_handler')->themeExists('test_subsubtheme'));
     $this->assertTrue($this->container->get('theme_handler')->themeExists('test_subtheme'));
 
     // Test uninstalling them.
     $extensions = $sync->read('core.extension');
-    unset($extensions['theme']['test_basetheme']);
+    unset($extensions['theme']['test_base_theme']);
     unset($extensions['theme']['test_subsubtheme']);
     unset($extensions['theme']['test_subtheme']);
     $sync->write('core.extension', $extensions);
     $config_importer = $this->configImporter();
     $config_importer->import();
-    $this->assertFalse($this->container->get('theme_handler')->themeExists('test_basetheme'));
+    $this->assertFalse($this->container->get('theme_handler')->themeExists('test_base_theme'));
     $this->assertFalse($this->container->get('theme_handler')->themeExists('test_subsubtheme'));
     $this->assertFalse($this->container->get('theme_handler')->themeExists('test_subtheme'));
   }
@@ -723,7 +725,7 @@ class ConfigImporterTest extends KernelTestBase {
    *
    * @see \Drupal\Core\EventSubscriber\ConfigImportSubscriber
    */
-  public function testInstallProfile() {
+  public function testInstallProfile(): void {
     $sync = $this->container->get('config.storage.sync');
 
     $extensions = $sync->read('core.extension');
@@ -750,7 +752,11 @@ class ConfigImporterTest extends KernelTestBase {
    *
    * @see \Drupal\Core\EventSubscriber\ConfigImportSubscriber
    */
-  public function testInstallProfileMisMatch() {
+  public function testInstallProfileMisMatch(): void {
+    // Install profiles can not be changed. They can only be uninstalled. We
+    // need to set an install profile prior to testing because KernelTestBase
+    // tests do not use one.
+    $this->setInstallProfile('minimal');
     $sync = $this->container->get('config.storage.sync');
 
     $extensions = $sync->read('core.extension');
@@ -764,21 +770,17 @@ class ConfigImporterTest extends KernelTestBase {
       $this->fail('ConfigImporterException not thrown; an invalid import was not stopped due to missing dependencies.');
     }
     catch (ConfigImporterException $e) {
-      $expected = static::FAIL_MESSAGE . PHP_EOL . 'Cannot change the install profile from <em class="placeholder"></em> to <em class="placeholder">this_will_not_work</em> once Drupal is installed.';
+      $expected = static::FAIL_MESSAGE . PHP_EOL . 'Cannot change the install profile from <em class="placeholder">minimal</em> to <em class="placeholder">this_will_not_work</em> once Drupal is installed.';
       $this->assertEquals($expected, $e->getMessage(), 'There were errors validating the config synchronization.');
       $error_log = $config_importer->getErrors();
-      // Install profiles can not be changed. Note that KernelTestBase currently
-      // does not use an install profile. This situation should be impossible
-      // to get in but site's can removed the install profile setting from
-      // settings.php so the test is valid.
-      $this->assertEquals(['Cannot change the install profile from  to this_will_not_work once Drupal is installed.'], $error_log);
+      $this->assertEquals(['Cannot change the install profile from minimal to this_will_not_work once Drupal is installed.'], $error_log);
     }
   }
 
   /**
    * Tests the isSyncing flags.
    */
-  public function testIsSyncingInHooks() {
+  public function testIsSyncingInHooks(): void {
     $dynamic_name = 'config_test.dynamic.dotted.default';
     $storage = $this->container->get('config.storage');
 
@@ -828,12 +830,56 @@ class ConfigImporterTest extends KernelTestBase {
     $this->assertTrue($state['entity_state::predelete'], 'ConfigEntity::isSyncing() returns TRUE');
     $this->assertTrue($state['global_state::delete'], '\Drupal::isConfigSyncing() returns TRUE');
     $this->assertTrue($state['entity_state::delete'], 'ConfigEntity::isSyncing() returns TRUE');
+
+    // Test that isSyncing is TRUE in hook_module_preinstall() when installing
+    // module via config import.
+    $extensions = $sync->read('core.extension');
+    // First, install system_test so that its hook_module_preinstall() will run
+    // when module_test is installed.
+    $this->container->get('module_installer')->install(['system_test']);
+    // Add module_test and system_test to the enabled modules to be imported,
+    // so that module_test gets installed on import and system_test does not get
+    // uninstalled.
+    $extensions['module']['module_test'] = 0;
+    $extensions['module']['system_test'] = 0;
+    $extensions['module'] = module_config_sort($extensions['module']);
+    $sync->write('core.extension', $extensions);
+    $this->configImporter()->import();
+
+    // Syncing values stored in state by hook_module_preinstall should be TRUE
+    // when module is installed via config import.
+    $this->assertTrue(\Drupal::state()->get('system_test_preinstall_module_config_installer_syncing'), '\Drupal::isConfigSyncing() in system_test_module_preinstall() returns TRUE');
+    $this->assertTrue(\Drupal::state()->get('system_test_preinstall_module_syncing_param'), 'system_test_module_preinstall() $is_syncing value is TRUE');
+
+    // Syncing value stored in state by uninstall hooks should be FALSE
+    // when uninstalling outside of config import.
+    $this->container->get('module_installer')->uninstall(['module_test']);
+    $this->assertFalse(\Drupal::state()->get('system_test_preuninstall_module_config_installer_syncing'), '\Drupal::isConfigSyncing() in system_test_module_preuninstall() returns FALSE');
+    $this->assertFalse(\Drupal::state()->get('system_test_preuninstall_module_syncing_param'), 'system_test_module_preuninstall() $is_syncing value is FALSE');
+    $this->assertFalse(\Drupal::state()->get('system_test_modules_uninstalled_config_installer_syncing'), '\Drupal::isConfigSyncing() in system_test_modules_uninstalled returns FALSE');
+    $this->assertFalse(\Drupal::state()->get('system_test_modules_uninstalled_syncing_param'), 'system_test_modules_uninstalled $is_syncing value is FALSE');
+
+    // Syncing value stored in state by hook_module_preinstall should be FALSE
+    // when installing outside of config import.
+    $this->container->get('module_installer')->install(['module_test']);
+    $this->assertFalse(\Drupal::state()->get('system_test_preinstall_module_config_installer_syncing'), '\Drupal::isConfigSyncing() in system_test_module_preinstall() returns TRUE');
+    $this->assertFalse(\Drupal::state()->get('system_test_preinstall_module_syncing_param'), 'system_test_module_preinstall() $is_syncing value is TRUE');
+
+    // Uninstall module_test via config import. Syncing value stored in state
+    // by uninstall hooks should be TRUE.
+    unset($extensions['module']['module_test']);
+    $sync->write('core.extension', $extensions);
+    $this->configImporter()->import();
+    $this->assertTrue(\Drupal::state()->get('system_test_preuninstall_module_config_installer_syncing'), '\Drupal::isConfigSyncing() in system_test_module_preuninstall() returns TRUE');
+    $this->assertTrue(\Drupal::state()->get('system_test_preuninstall_module_syncing_param'), 'system_test_module_preuninstall() $is_syncing value is TRUE');
+    $this->assertTrue(\Drupal::state()->get('system_test_modules_uninstalled_config_installer_syncing'), '\Drupal::isConfigSyncing() in system_test_modules_uninstalled returns TRUE');
+    $this->assertTrue(\Drupal::state()->get('system_test_modules_uninstalled_syncing_param'), 'system_test_modules_uninstalled $is_syncing value is TRUE');
   }
 
   /**
    * Tests that the isConfigSyncing flag is cleanup after an invalid step.
    */
-  public function testInvalidStep() {
+  public function testInvalidStep(): void {
     $this->assertFalse(\Drupal::isConfigSyncing(), 'Before an import \Drupal::isConfigSyncing() returns FALSE');
     $context = [];
     $config_importer = $this->configImporter();
@@ -841,7 +887,7 @@ class ConfigImporterTest extends KernelTestBase {
       $config_importer->doSyncStep('a_non_existent_step', $context);
       $this->fail('Expected \InvalidArgumentException thrown');
     }
-    catch (\InvalidArgumentException $e) {
+    catch (\InvalidArgumentException) {
       // Expected exception; just continue testing.
     }
     $this->assertFalse(\Drupal::isConfigSyncing(), 'After an invalid step \Drupal::isConfigSyncing() returns FALSE');
@@ -850,7 +896,7 @@ class ConfigImporterTest extends KernelTestBase {
   /**
    * Tests that the isConfigSyncing flag is set correctly during a custom step.
    */
-  public function testCustomStep() {
+  public function testCustomStep(): void {
     $this->assertFalse(\Drupal::isConfigSyncing(), 'Before an import \Drupal::isConfigSyncing() returns FALSE');
     $context = [];
     $this->configImporter()->doSyncStep(self::customStep(...), $context);
@@ -864,7 +910,7 @@ class ConfigImporterTest extends KernelTestBase {
   public function testUninstallThemeIncrementsCount(): void {
     $theme_installer = $this->container->get('theme_installer');
     // Install our theme.
-    $theme = 'test_basetheme';
+    $theme = 'test_base_theme';
     $theme_installer->install([$theme]);
 
     $this->assertTrue($this->container->get('theme_handler')->themeExists($theme));
@@ -879,8 +925,8 @@ class ConfigImporterTest extends KernelTestBase {
 
     $cronName = 'system.cron';
     $cron = $sync->read($cronName);
-    $this->assertEquals(1, $cron['logging']);
-    $cron['logging'] = 0;
+    $this->assertTrue($cron['logging']);
+    $cron['logging'] = FALSE;
     $sync->write($cronName, $cron);
 
     // Uninstall the theme in sync.
@@ -930,6 +976,79 @@ class ConfigImporterTest extends KernelTestBase {
     $this->assertSame(['key' => 'bar'], $event['original_config_data']);
   }
 
+  /**
+   * Tests events and collections during a config import.
+   */
+  public function testEventsAndCollectionsImport(): void {
+    $collections = [
+      'another_collection',
+      'collection.test1',
+      'collection.test2',
+    ];
+    // Set the event listener to return three possible collections.
+    // @see \Drupal\config_collection_install_test\EventSubscriber
+    \Drupal::state()->set('config_collection_install_test.collection_names', $collections);
+    $this->enableModules(['config_collection_install_test']);
+    $this->installConfig(['config_collection_install_test']);
+
+    // Export the configuration and uninstall the module to test installing it
+    // via configuration import.
+    $this->copyConfig($this->container->get('config.storage'), $this->container->get('config.storage.sync'));
+    $this->container->get('module_installer')->uninstall(['config_collection_install_test']);
+    $this->assertEmpty($this->container->get('config.storage')->getAllCollectionNames());
+
+    \Drupal::state()->set('config_events_test.all_events', []);
+    $this->configImporter()->import();
+    $this->assertSame($collections, $this->container->get('config.storage')->getAllCollectionNames());
+
+    $all_events = \Drupal::state()->get('config_events_test.all_events');
+    $this->assertArrayHasKey('core.extension', $all_events[ConfigEvents::SAVE]);
+    // Ensure that config in collections does not have the regular configuration
+    // event triggered.
+    $this->assertArrayNotHasKey('config_collection_install_test.test', $all_events[ConfigEvents::SAVE]);
+    $this->assertCount(3, $all_events[ConfigCollectionEvents::SAVE_IN_COLLECTION]['config_collection_install_test.test']);
+    $event_collections = [];
+    foreach ($all_events[ConfigCollectionEvents::SAVE_IN_COLLECTION]['config_collection_install_test.test'] as $event) {
+      $event_collections[] = $event['current_config_data']['collection'];
+    }
+    $this->assertSame($collections, $event_collections);
+  }
+
+  /**
+   * Tests the target storage caching during configuration import.
+   */
+  public function testStorageComparerTargetStorage(): void {
+    $this->installConfig(['config_events_test']);
+    $this->copyConfig($this->container->get('config.storage'), $this->container->get('config.storage.sync'));
+    $this->assertTrue($this->container->get('module_installer')->uninstall(['config_test']));
+    \Drupal::state()->set('config_events_test.all_events', []);
+    \Drupal::state()->set('config_test_install.foo_value', 'transient');
+
+    // Prime the active config cache. If the ConfigImporter and StorageComparer
+    // do not manage the target storage correctly this cache can pollute the
+    // data.
+    \Drupal::configFactory()->get('config_test.system');
+
+    // Import the configuration. This results in a save event with the value
+    // changing from foo to bar.
+    $this->configImporter()->import();
+    $all_events = \Drupal::state()->get('config_events_test.all_events');
+
+    // Test that the values change as expected during the configuration import.
+    $this->assertCount(3, $all_events[ConfigEvents::SAVE]['config_test.system']);
+    // First, the values are set by the module installer using the configuration
+    // import's source storage.
+    $this->assertSame([], $all_events[ConfigEvents::SAVE]['config_test.system'][0]['original_config_data']);
+    $this->assertSame('bar', $all_events[ConfigEvents::SAVE]['config_test.system'][0]['current_config_data']['foo']);
+    // Next, the config_test_install() function changes the value.
+    $this->assertSame('bar', $all_events[ConfigEvents::SAVE]['config_test.system'][1]['original_config_data']['foo']);
+    $this->assertSame('transient', $all_events[ConfigEvents::SAVE]['config_test.system'][1]['current_config_data']['foo']);
+    // Last, the config importer processes all the configuration in the source
+    // storage and ensures the values are as expected.
+    $this->assertSame('transient', $all_events[ConfigEvents::SAVE]['config_test.system'][2]['original_config_data']['foo']);
+    $this->assertSame('bar', $all_events[ConfigEvents::SAVE]['config_test.system'][2]['current_config_data']['foo']);
+  }
+
   /**
    * Helper method to test custom config installer steps.
    *
@@ -938,7 +1057,7 @@ class ConfigImporterTest extends KernelTestBase {
    * @param \Drupal\Core\Config\ConfigImporter $importer
    *   The config importer.
    */
-  public static function customStep(array &$context, ConfigImporter $importer) {
+  public static function customStep(array &$context, ConfigImporter $importer): void {
     $context['is_syncing'] = \Drupal::isConfigSyncing();
   }
 
