@@ -5,8 +5,11 @@ declare(strict_types=1);
 namespace Drupal\KernelTests\Core\Database;
 
 use Drupal\Core\Database\RowCountException;
+use Drupal\Core\Database\Statement\FetchAs;
 use Drupal\Core\Database\StatementInterface;
+use Drupal\Core\Database\StatementPrefetchIterator;
 use Drupal\Tests\system\Functional\Database\FakeRecord;
+use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 
 /**
  * Tests the Database system's various fetch capabilities.
@@ -33,12 +36,34 @@ class FetchTest extends DatabaseTestBase {
     $this->assertCount(1, $records, 'There is only one record.');
   }
 
+  /**
+   * Confirms that we can fetch a single column value.
+   */
+  public function testQueryFetchColumn(): void {
+    $statement = $this->connection
+      ->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25]);
+    $statement->setFetchMode(FetchAs::Column, 0);
+    $this->assertSame('John', $statement->fetch());
+  }
+
+  /**
+   * Confirms that an out of range index throws an error.
+   */
+  public function testQueryFetchColumnOutOfRange(): void {
+    $this->expectException(\ValueError::class);
+    $this->expectExceptionMessage('Invalid column index');
+    $statement = $this->connection
+      ->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25]);
+    $statement->setFetchMode(FetchAs::Column, 200);
+    $statement->fetch();
+  }
+
   /**
    * Confirms that we can fetch a record to an object explicitly.
    */
   public function testQueryFetchObject(): void {
     $records = [];
-    $result = $this->connection->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25], ['fetch' => \PDO::FETCH_OBJ]);
+    $result = $this->connection->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25], ['fetch' => FetchAs::Object]);
     foreach ($result as $record) {
       $records[] = $record;
       $this->assertIsObject($record);
@@ -53,7 +78,7 @@ class FetchTest extends DatabaseTestBase {
    */
   public function testQueryFetchArray(): void {
     $records = [];
-    $result = $this->connection->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25], ['fetch' => \PDO::FETCH_ASSOC]);
+    $result = $this->connection->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25], ['fetch' => FetchAs::Associative]);
     foreach ($result as $record) {
       $records[] = $record;
       $this->assertIsArray($record);
@@ -122,7 +147,7 @@ class FetchTest extends DatabaseTestBase {
    */
   public function testQueryFetchNum(): void {
     $records = [];
-    $result = $this->connection->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25], ['fetch' => \PDO::FETCH_NUM]);
+    $result = $this->connection->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25], ['fetch' => FetchAs::List]);
     foreach ($result as $record) {
       $records[] = $record;
       $this->assertIsArray($record);
@@ -140,7 +165,7 @@ class FetchTest extends DatabaseTestBase {
     $query = $this->connection->select('test');
     $query->addField('test', 'name');
     $query->orderBy('name');
-    $query_result = $query->execute()->fetchAll(\PDO::FETCH_COLUMN);
+    $query_result = $query->execute()->fetchAll(FetchAs::Column);
 
     $expected_result = ['George', 'John', 'Paul', 'Ringo'];
     $this->assertEquals($expected_result, $query_result, 'Returned the correct result.');
@@ -161,6 +186,62 @@ class FetchTest extends DatabaseTestBase {
     }
   }
 
+  /**
+   * Tests ::fetchCol() for edge values returned.
+   */
+  public function testQueryFetchColEdgeCases(): void {
+    $this->connection->insert('test_null')
+      ->fields([
+        'name' => 'Foo',
+        'age' => 0,
+      ])
+      ->execute();
+
+    $this->connection->insert('test_null')
+      ->fields([
+        'name' => 'Bar',
+        'age' => NULL,
+      ])
+      ->execute();
+
+    $this->connection->insert('test_null')
+      ->fields([
+        'name' => 'Qux',
+        'age' => (int) FALSE,
+      ])
+      ->execute();
+
+    $statement = $this->connection->select('test_null')
+      ->fields('test_null', ['age'])
+      ->orderBy('id')
+      ->execute();
+
+    $this->assertSame(['0', NULL, '0'], $statement->fetchCol());
+
+    // Additional fetch returns FALSE since the result set is finished.
+    $this->assertFalse($statement->fetchField());
+  }
+
+  /**
+   * Confirms that an out of range index in fetchCol() throws an error.
+   */
+  public function testQueryFetchColIndexOutOfRange(): void {
+    $this->expectException(\ValueError::class);
+    $this->expectExceptionMessage('Invalid column index');
+    $this->connection
+      ->query('SELECT [name] FROM {test} WHERE [age] > :age', [':age' => 25])
+      ->fetchCol(200);
+  }
+
+  /**
+   * Confirms empty result set prevails on out of range index in fetchCol().
+   */
+  public function testQueryFetchColIndexOutOfRangeOnEmptyResultSet(): void {
+    $this->assertSame([], $this->connection
+      ->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 255])
+      ->fetchCol(200));
+  }
+
   /**
    * Tests ::fetchAllAssoc().
    */
@@ -181,11 +262,11 @@ class FetchTest extends DatabaseTestBase {
     ];
 
     $statement = $this->connection->query('SELECT * FROM {test} WHERE [age] > :age', [':age' => 26]);
-    $result = $statement->fetchAllAssoc('job', \PDO::FETCH_ASSOC);
+    $result = $statement->fetchAllAssoc('job', FetchAs::Associative);
     $this->assertSame($expected_result, $result);
 
     $statement = $this->connection->query('SELECT * FROM {test} WHERE [age] > :age', [':age' => 26]);
-    $result = $statement->fetchAllAssoc('job', \PDO::FETCH_OBJ);
+    $result = $statement->fetchAllAssoc('job', FetchAs::Object);
     $this->assertEquals((object) $expected_result['Singer'], $result['Singer']);
     $this->assertEquals((object) $expected_result['Drummer'], $result['Drummer']);
   }
@@ -230,6 +311,69 @@ class FetchTest extends DatabaseTestBase {
     $this->assertSame($expectedResults, $actualResults);
   }
 
+  /**
+   * Tests ::fetchField() for edge values returned.
+   */
+  public function testQueryFetchFieldEdgeCases(): void {
+    $this->connection->insert('test_null')
+      ->fields([
+        'name' => 'Foo',
+        'age' => 0,
+      ])
+      ->execute();
+
+    $this->connection->insert('test_null')
+      ->fields([
+        'name' => 'Bar',
+        'age' => NULL,
+      ])
+      ->execute();
+
+    $this->connection->insert('test_null')
+      ->fields([
+        'name' => 'Qux',
+        'age' => (int) FALSE,
+      ])
+      ->execute();
+
+    $statement = $this->connection->select('test_null')
+      ->fields('test_null', ['age'])
+      ->orderBy('id')
+      ->execute();
+
+    // First fetch returns '0' since an existing value is always a string.
+    $this->assertSame('0', $statement->fetchField());
+
+    // Second fetch returns NULL since NULL was inserted.
+    $this->assertNull($statement->fetchField());
+
+    // Third fetch returns '0' since a FALSE bool cast to int was inserted.
+    $this->assertSame('0', $statement->fetchField());
+
+    // Fourth fetch returns FALSE since no row was available.
+    $this->assertFalse($statement->fetchField());
+  }
+
+  /**
+   * Confirms that an out of range index in fetchField() throws an error.
+   */
+  public function testQueryFetchFieldIndexOutOfRange(): void {
+    $this->expectException(\ValueError::class);
+    $this->expectExceptionMessage('Invalid column index');
+    $this->connection
+      ->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25])
+      ->fetchField(200);
+  }
+
+  /**
+   * Confirms empty result set prevails on out of range index in fetchField().
+   */
+  public function testQueryFetchFieldIndexOutOfRangeOnEmptyResultSet(): void {
+    $this->assertFalse($this->connection
+      ->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 255])
+      ->fetchField(200));
+  }
+
   /**
    * Tests that rowCount() throws exception on SELECT query.
    */
@@ -245,4 +389,18 @@ class FetchTest extends DatabaseTestBase {
     $this->assertTrue($exception, 'Exception was thrown');
   }
 
+  /**
+   * Confirms deprecation of StatementPrefetchIterator::fetchColumn().
+   */
+  #[IgnoreDeprecations]
+  public function testLegacyFetchColumn(): void {
+    $statement = $this->connection->query('SELECT [name] FROM {test} WHERE [age] = :age', [':age' => 25]);
+    if (!$statement instanceof StatementPrefetchIterator) {
+      $this->markTestSkipped('This test is for StatementPrefetchIterator statements only.');
+    }
+
+    $this->expectDeprecation('Drupal\Core\Database\StatementPrefetchIterator::fetchColumn() is deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Use ::fetchField() instead. See https://www.drupal.org/node/3490312');
+    $statement->fetchColumn();
+  }
+
 }
