@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Entity;
 
 use Drupal\Core\TypedData\DataDefinition;
@@ -19,6 +21,9 @@ class BundleConstraintValidatorTest extends KernelTestBase {
    */
   protected $typedData;
 
+  /**
+   * {@inheritdoc}
+   */
   protected static $modules = ['node', 'field', 'text', 'user'];
 
   /**
@@ -33,7 +38,7 @@ class BundleConstraintValidatorTest extends KernelTestBase {
   /**
    * Tests bundle constraint validation.
    */
-  public function testValidation() {
+  public function testValidation(): void {
     // Test with multiple values.
     $this->assertValidation(['foo', 'bar']);
     // Test with a single string value as well.
