@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Entity;
 
 use Drupal\Core\Entity\ContentEntityInterface;
@@ -21,6 +23,7 @@ use Drupal\Core\TypedData\TypedDataInterface;
 use Drupal\entity_test\Entity\EntityTest;
 use Drupal\entity_test\Entity\EntityTestComputedField;
 use Drupal\entity_test\Entity\EntityTestRev;
+use Drupal\entity_test\EntityTestHelper;
 use Drupal\node\Entity\Node;
 use Drupal\node\Entity\NodeType;
 
@@ -32,9 +35,7 @@ use Drupal\node\Entity\NodeType;
 class EntityFieldTest extends EntityKernelTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['filter', 'text', 'node', 'user', 'field_test'];
 
@@ -59,7 +60,7 @@ class EntityFieldTest extends EntityKernelTestBase {
   protected function setUp(): void {
     parent::setUp();
 
-    foreach (entity_test_entity_types() as $entity_type_id) {
+    foreach (EntityTestHelper::getEntityTypes() as $entity_type_id) {
       // The entity_test schema is installed by the parent.
       if ($entity_type_id != 'entity_test') {
         $this->installEntitySchema($entity_type_id);
@@ -78,8 +79,9 @@ class EntityFieldTest extends EntityKernelTestBase {
    * Creates a test entity.
    *
    * @return \Drupal\Core\Entity\EntityInterface
+   *   The created entity.
    */
-  protected function createTestEntity($entity_type) {
+  protected function createTestEntity($entity_type): EntityInterface {
     $this->entityName = $this->randomMachineName();
     $this->entityUser = $this->createUser();
     $this->entityFieldText = $this->randomMachineName();
@@ -101,7 +103,7 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Test setting field values on revisionable entities.
    */
-  public function testFieldEntityRevisionWrite() {
+  public function testFieldEntityRevisionWrite(): void {
     /** @var \Drupal\Core\Entity\RevisionableStorageInterface $storage */
     $storage = \Drupal::entityTypeManager()->getStorage('entity_test_rev');
 
@@ -129,14 +131,34 @@ class EntityFieldTest extends EntityKernelTestBase {
     // The updated field value should have correctly saved as 'foo'.
     $forward_revision = $storage->loadRevision($forward_revision_id);
     $this->assertEquals('foo', $forward_revision->field_test_text->value);
+
+    // Create another entity.
+    $entity = EntityTestRev::create();
+    $entity->field_test_text->value = 'foo';
+    $entity->save();
+
+    // Create a new non-default revision and set the field value to 'bar'.
+    $entity->setNewRevision(TRUE);
+    $entity->isDefaultRevision(FALSE);
+    $entity->field_test_text->value = 'bar';
+    $entity->save();
+
+    // Now save the pending revision as the default one, without creating a new
+    // revision.
+    $entity->isDefaultRevision(TRUE);
+    $entity->save();
+
+    // The updated field value should have correctly saved as 'bar'.
+    $default_revision = $storage->loadUnchanged($entity->id());
+    $this->assertEquals('bar', $default_revision->field_test_text->value);
   }
 
   /**
    * Tests reading and writing properties and field items.
    */
-  public function testReadWrite() {
+  public function testReadWrite(): void {
     // All entity variations have to have the same results.
-    foreach (entity_test_entity_types() as $entity_type) {
+    foreach (EntityTestHelper::getEntityTypes() as $entity_type) {
       $this->doTestReadWrite($entity_type);
     }
   }
@@ -147,7 +169,7 @@ class EntityFieldTest extends EntityKernelTestBase {
    * @param string $entity_type
    *   The entity type to run the tests with.
    */
-  protected function doTestReadWrite($entity_type) {
+  protected function doTestReadWrite($entity_type): void {
     $entity = $this->createTestEntity($entity_type);
 
     $langcode = 'en';
@@ -249,8 +271,8 @@ class EntityFieldTest extends EntityKernelTestBase {
     $this->assertFalse(isset($entity->name[0]->value), "$entity_type: Name is not set.");
     $this->assertFalse(isset($entity->name->value), "$entity_type: Name is not set.");
 
-    // Test emptying a field by assigning an empty value. NULL and array()
-    // behave the same.
+    // Test emptying a field by assigning an empty value, NULL and an empty
+    // array behave the same.
     foreach ([NULL, [], 'unset'] as $empty) {
       // Make sure a value is present
       $entity->name->value = 'a value';
@@ -400,9 +422,9 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Tries to save and load an entity again.
    */
-  public function testSave() {
+  public function testSave(): void {
     // All entity variations have to have the same results.
-    foreach (entity_test_entity_types() as $entity_type) {
+    foreach (EntityTestHelper::getEntityTypes() as $entity_type) {
       $this->doTestSave($entity_type);
     }
   }
@@ -413,7 +435,7 @@ class EntityFieldTest extends EntityKernelTestBase {
    * @param string $entity_type
    *   The entity type to run the tests with.
    */
-  protected function doTestSave($entity_type) {
+  protected function doTestSave($entity_type): void {
     $langcode_key = $this->entityTypeManager->getDefinition($entity_type)->getKey('langcode');
     $entity = $this->createTestEntity($entity_type);
     $entity->save();
@@ -437,9 +459,9 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Tests introspection and getting metadata upfront.
    */
-  public function testIntrospection() {
+  public function testIntrospection(): void {
     // All entity variations have to have the same results.
-    foreach (entity_test_entity_types() as $entity_type) {
+    foreach (EntityTestHelper::getEntityTypes() as $entity_type) {
       $this->doTestIntrospection($entity_type);
     }
   }
@@ -450,7 +472,7 @@ class EntityFieldTest extends EntityKernelTestBase {
    * @param string $entity_type
    *   The entity type to run the tests with.
    */
-  protected function doTestIntrospection($entity_type) {
+  protected function doTestIntrospection($entity_type): void {
     // Test getting metadata upfront. The entity types used for this test have
     // a default bundle that is the same as the entity type.
     $definitions = \Drupal::service('entity_field.manager')->getFieldDefinitions($entity_type, $entity_type);
@@ -488,7 +510,7 @@ class EntityFieldTest extends EntityKernelTestBase {
     $this->assertEquals('string', $name_definition->getPropertyDefinition('value')->getDataType());
 
     // Test introspecting an entity object.
-    // @todo: Add bundles and test bundles as well.
+    // @todo Add bundles and test bundles as well.
     $entity = $this->container->get('entity_type.manager')
       ->getStorage($entity_type)
       ->create();
@@ -501,9 +523,9 @@ class EntityFieldTest extends EntityKernelTestBase {
     $name_properties = $entity->name->getFieldDefinition()->getPropertyDefinitions();
     $this->assertEquals('string', $name_properties['value']->getDataType(), $entity_type . ': String value property of the name found.');
 
-    $userref_properties = $entity->user_id->getFieldDefinition()->getPropertyDefinitions();
-    $this->assertEquals('integer', $userref_properties['target_id']->getDataType(), $entity_type . ': Entity id property of the user found.');
-    $this->assertEquals('entity_reference', $userref_properties['entity']->getDataType(), $entity_type . ': Entity reference property of the user found.');
+    $user_ref_properties = $entity->user_id->getFieldDefinition()->getPropertyDefinitions();
+    $this->assertEquals('integer', $user_ref_properties['target_id']->getDataType(), $entity_type . ': Entity id property of the user found.');
+    $this->assertEquals('entity_reference', $user_ref_properties['entity']->getDataType(), $entity_type . ': Entity reference property of the user found.');
 
     $textfield_properties = $entity->field_test_text->getFieldDefinition()->getFieldStorageDefinition()->getPropertyDefinitions();
     $this->assertEquals('string', $textfield_properties['value']->getDataType(), $entity_type . ': String value property of the test-text field found.');
@@ -541,9 +563,9 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Tests iterating over properties.
    */
-  public function testIterator() {
+  public function testIterator(): void {
     // All entity variations have to have the same results.
-    foreach (entity_test_entity_types() as $entity_type) {
+    foreach (EntityTestHelper::getEntityTypes() as $entity_type) {
       $this->doTestIterator($entity_type);
     }
   }
@@ -554,7 +576,7 @@ class EntityFieldTest extends EntityKernelTestBase {
    * @param string $entity_type
    *   The entity type to run the tests with.
    */
-  protected function doTestIterator($entity_type) {
+  protected function doTestIterator($entity_type): void {
     $entity = $this->createTestEntity($entity_type);
 
     foreach ($entity as $name => $field) {
@@ -580,9 +602,9 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Tests working with the entity based upon the TypedData API.
    */
-  public function testDataStructureInterfaces() {
+  public function testDataStructureInterfaces(): void {
     // All entity variations have to have the same results.
-    foreach (entity_test_entity_types() as $entity_type) {
+    foreach (EntityTestHelper::getEntityTypes() as $entity_type) {
       $this->doTestDataStructureInterfaces($entity_type);
     }
   }
@@ -593,7 +615,7 @@ class EntityFieldTest extends EntityKernelTestBase {
    * @param string $entity_type
    *   The entity type to run the tests with.
    */
-  protected function doTestDataStructureInterfaces($entity_type) {
+  protected function doTestDataStructureInterfaces($entity_type): void {
     $entity = $this->createTestEntity($entity_type);
 
     // Test using the whole tree of typed data by navigating through the tree of
@@ -602,8 +624,8 @@ class EntityFieldTest extends EntityKernelTestBase {
     $strings = [];
     $this->getContainedStrings($entity->getTypedData(), 0, $strings);
 
-    // @todo: Once the user entity has defined properties this should contain
-    // the user name and other user entity strings as well.
+    // @todo Once the user entity has defined properties this should contain
+    //   the user name and other user entity strings as well.
     $target_strings = [
       $entity->uuid->value,
       'en',
@@ -628,7 +650,7 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Gets all contained strings recursively.
    */
-  public function getContainedStrings(TypedDataInterface $wrapper, $depth, array &$strings) {
+  public function getContainedStrings(TypedDataInterface $wrapper, $depth, array &$strings): void {
 
     if ($wrapper instanceof StringInterface) {
       $strings[] = $wrapper->getValue();
@@ -652,13 +674,13 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Makes sure data types are correctly derived for all entity types.
    */
-  public function testDataTypes() {
+  public function testDataTypes(): void {
     $types = \Drupal::typedDataManager()->getDefinitions();
-    foreach (entity_test_entity_types() as $entity_type) {
+    foreach (EntityTestHelper::getEntityTypes() as $entity_type) {
       $this->assertNotEmpty($types['entity:' . $entity_type]['class'], 'Entity data type registered.');
     }
     // Check bundle types are provided as well.
-    entity_test_create_bundle('bundle');
+    EntityTestHelper::createBundle('bundle');
     $types = \Drupal::typedDataManager()->getDefinitions();
     $this->assertNotEmpty($types['entity:entity_test:bundle']['class'], 'Entity bundle data type registered.');
   }
@@ -668,7 +690,7 @@ class EntityFieldTest extends EntityKernelTestBase {
    *
    * @see entity_test_entity_base_field_info_alter()
    */
-  public function testBaseFieldNonExistingBaseField() {
+  public function testBaseFieldNonExistingBaseField(): void {
     $this->entityTypeManager->getStorage('node_type')->create([
       'type' => 'page',
       'name' => 'page',
@@ -690,10 +712,10 @@ class EntityFieldTest extends EntityKernelTestBase {
    *
    * @see entity_test_entity_base_field_info_alter()
    */
-  public function testFieldOverrideBundleField() {
+  public function testFieldOverrideBundleField(): void {
     // First make sure the bundle field override in code, which is provided by
     // the test entity works.
-    entity_test_create_bundle('some_test_bundle', 'Some test bundle', 'entity_test_field_override');
+    EntityTestHelper::createBundle('some_test_bundle', 'Some test bundle', 'entity_test_field_override');
     $field_definitions = \Drupal::service('entity_field.manager')->getFieldDefinitions('entity_test_field_override', 'entity_test_field_override');
     $this->assertEquals('The default description.', $field_definitions['name']->getDescription());
     $this->assertNull($field_definitions['name']->getTargetBundle());
@@ -718,7 +740,7 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Tests validation constraints provided by the Entity API.
    */
-  public function testEntityConstraintValidation() {
+  public function testEntityConstraintValidation(): void {
     $entity = $this->createTestEntity('entity_test');
     $entity->save();
     // Create a reference field item and let it reference the entity.
@@ -753,7 +775,7 @@ class EntityFieldTest extends EntityKernelTestBase {
       ->setLabel('Test entity')
       ->setSetting('target_type', 'node')
       ->setSetting('handler_settings', ['target_bundles' => ['article' => 'article']]);
-    $reference_field = \Drupal::TypedDataManager()->create($definition);
+    $reference_field = \Drupal::typedDataManager()->create($definition);
     $reference_field->appendItem(['entity' => $node]);
     $violations = $reference_field->validate();
     $this->assertEquals(1, $violations->count());
@@ -772,9 +794,9 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Tests getting processed property values via a computed property.
    */
-  public function testComputedProperties() {
+  public function testComputedProperties(): void {
     // All entity variations have to have the same results.
-    foreach (entity_test_entity_types() as $entity_type) {
+    foreach (EntityTestHelper::getEntityTypes() as $entity_type) {
       $this->doTestComputedProperties($entity_type);
     }
   }
@@ -782,7 +804,7 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Tests all the interaction points of a computed field.
    */
-  public function testComputedFields() {
+  public function testComputedFields(): void {
     $this->installEntitySchema('entity_test_computed_field');
 
     \Drupal::state()->set('entity_test_computed_field_item_list_value', ['foo computed']);
@@ -884,7 +906,7 @@ class EntityFieldTest extends EntityKernelTestBase {
 
     // Test \Drupal\Core\TypedData\ComputedItemListTrait::getIterator().
     $entity = EntityTestComputedField::create([]);
-    foreach ($entity->computed_string_field as $delta => $item) {
+    foreach ($entity->computed_string_field as $item) {
       $this->assertSame('foo computed', $item->value);
     }
 
@@ -914,7 +936,7 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Tests an entity reference computed field.
    */
-  public function testEntityReferenceComputedField() {
+  public function testEntityReferenceComputedField(): void {
     $this->installEntitySchema('entity_test_computed_field');
 
     // Create 2 entities to be referenced.
@@ -943,7 +965,7 @@ class EntityFieldTest extends EntityKernelTestBase {
    * @param string $entity_type
    *   The entity type to run the tests with.
    */
-  protected function doTestComputedProperties($entity_type) {
+  protected function doTestComputedProperties($entity_type): void {
     $entity = $this->createTestEntity($entity_type);
     $entity->field_test_text->value = "The <strong>text</strong> text to filter.";
     $entity->field_test_text->format = filter_default_format();
@@ -962,7 +984,7 @@ class EntityFieldTest extends EntityKernelTestBase {
   /**
    * Tests explicit entity ID assignment.
    */
-  public function testEntityIdAssignment() {
+  public function testEntityIdAssignment(): void {
     $entity_type = 'entity_test';
     /** @var \Drupal\Core\Entity\ContentEntityStorageInterface $storage */
     $storage = $this->container->get('entity_type.manager')->getStorage($entity_type);
