@@ -1,12 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Routing;
 
 use ColinODell\PsrTestLogger\TestLogger;
+use Drupal\Component\Datetime\TimeInterface;
 use Drupal\Core\Cache\MemoryBackend;
 use Drupal\Core\Database\Database;
-use Drupal\Core\DependencyInjection\ContainerBuilder;
 use Drupal\Core\KeyValueStore\KeyValueMemoryFactory;
+use Drupal\Core\Lock\NullLockBackend;
 use Drupal\Core\Path\CurrentPathStack;
 use Drupal\Core\Routing\MatcherDumper;
 use Drupal\Core\Routing\RouteProvider;
@@ -32,7 +35,7 @@ class RouteProviderTest extends KernelTestBase {
   use PathAliasTestTrait;
 
   /**
-   * Modules to enable.
+   * {@inheritdoc}
    */
   protected static $modules = [
     'url_alter_test',
@@ -96,9 +99,10 @@ class RouteProviderTest extends KernelTestBase {
   protected function setUp(): void {
     parent::setUp();
     $this->fixtures = new RoutingFixtures();
-    $this->state = new State(new KeyValueMemoryFactory());
+    $time = \Drupal::service(TimeInterface::class);
+    $this->state = new State(new KeyValueMemoryFactory(), new MemoryBackend($time), new NullLockBackend());
     $this->currentPath = new CurrentPathStack(new RequestStack());
-    $this->cache = new MemoryBackend();
+    $this->cache = new MemoryBackend($time);
     $this->pathProcessor = \Drupal::service('path_processor_manager');
     $this->cacheTagsInvalidator = \Drupal::service('cache_tags.invalidator');
     $this->installEntitySchema('path_alias');
@@ -106,19 +110,6 @@ class RouteProviderTest extends KernelTestBase {
     $this->logger = new TestLogger();
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function register(ContainerBuilder $container) {
-    parent::register($container);
-
-    // Read the incoming path alias for these tests.
-    if ($container->hasDefinition('path_alias.path_processor')) {
-      $definition = $container->getDefinition('path_alias.path_processor');
-      $definition->addTag('path_processor_inbound');
-    }
-  }
-
   /**
    * {@inheritdoc}
    */
@@ -131,7 +122,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Confirms that the correct candidate outlines are generated.
    */
-  public function testCandidateOutlines() {
+  public function testCandidateOutlines(): void {
 
     $connection = Database::getConnection();
     $provider = new TestRouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
@@ -155,7 +146,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Don't fail when given an empty path.
    */
-  public function testEmptyPathCandidatesOutlines() {
+  public function testEmptyPathCandidatesOutlines(): void {
     $provider = new TestRouteProvider(Database::getConnection(), $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
     $candidates = $provider->getCandidateOutlines([]);
     $this->assertCount(0, $candidates, 'Empty parts should return no candidates.');
@@ -164,7 +155,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Confirms that we can find routes with the exact incoming path.
    */
-  public function testExactPathMatch() {
+  public function testExactPathMatch(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -188,7 +179,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Confirms that we can find routes whose pattern would match the request.
    */
-  public function testOutlinePathMatch() {
+  public function testOutlinePathMatch(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -217,7 +208,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Data provider for testMixedCasePaths()
    */
-  public function providerMixedCaseRoutePaths() {
+  public static function providerMixedCaseRoutePaths() {
     // cSpell:disable
     return [
       ['/path/one', 'route_a'],
@@ -241,7 +232,7 @@ class RouteProviderTest extends KernelTestBase {
    *
    * @dataProvider providerMixedCaseRoutePaths
    */
-  public function testMixedCasePaths($path, $expected_route_name, $method = 'GET') {
+  public function testMixedCasePaths($path, $expected_route_name, $method = 'GET'): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -267,7 +258,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Data provider for testMixedCasePaths()
    */
-  public function providerDuplicateRoutePaths() {
+  public static function providerDuplicateRoutePaths() {
     // When matching routes with the same fit the route with the lowest-sorting
     // name should end up first in the resulting route collection.
     return [
@@ -285,7 +276,7 @@ class RouteProviderTest extends KernelTestBase {
    *
    * @dataProvider providerDuplicateRoutePaths
    */
-  public function testDuplicateRoutePaths($path, $number, $expected_route_name = NULL) {
+  public function testDuplicateRoutePaths($path, $number, $expected_route_name = NULL): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -307,7 +298,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Confirms RouteProvider::getAllRoutes() extracts information correctly from the database.
    */
-  public function testGetAllRoutes() {
+  public function testGetAllRoutes(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -333,7 +324,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Confirms that a trailing slash on the request does not result in a 404.
    */
-  public function testOutlinePathMatchTrailingSlash() {
+  public function testOutlinePathMatchTrailingSlash(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -362,7 +353,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Confirms that we can find routes whose pattern would match the request.
    */
-  public function testOutlinePathMatchDefaults() {
+  public function testOutlinePathMatchDefaults(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -392,7 +383,7 @@ class RouteProviderTest extends KernelTestBase {
       $this->assertCount(1, $routes, 'The correct number of routes was found.');
       $this->assertNotNull($routes->get('foo'), 'The first matching route was found.');
     }
-    catch (ResourceNotFoundException $e) {
+    catch (ResourceNotFoundException) {
       $this->fail('No matching route found with default argument value.');
     }
   }
@@ -400,7 +391,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Confirms that we can find routes whose pattern would match the request.
    */
-  public function testOutlinePathMatchDefaultsCollision() {
+  public function testOutlinePathMatchDefaultsCollision(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -431,7 +422,7 @@ class RouteProviderTest extends KernelTestBase {
       $this->assertCount(1, $routes, 'The correct number of routes was found.');
       $this->assertNotNull($routes->get('foo'), 'The first matching route was found.');
     }
-    catch (ResourceNotFoundException $e) {
+    catch (ResourceNotFoundException) {
       $this->fail('No matching route found with default argument value.');
     }
   }
@@ -439,7 +430,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Confirms that we can find routes whose pattern would match the request.
    */
-  public function testOutlinePathMatchDefaultsCollision2() {
+  public function testOutlinePathMatchDefaultsCollision2(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -470,7 +461,7 @@ class RouteProviderTest extends KernelTestBase {
       $this->assertNotNull($routes->get('foo'), 'The second matching route was found.');
       $this->assertNull($routes->get('eep'), 'Non-matching route was not found.');
     }
-    catch (ResourceNotFoundException $e) {
+    catch (ResourceNotFoundException) {
       $this->fail('No matching route found with default argument value.');
     }
   }
@@ -478,7 +469,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Confirms that we can find multiple routes that match the request equally.
    */
-  public function testOutlinePathMatchDefaultsCollision3() {
+  public function testOutlinePathMatchDefaultsCollision3(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -509,7 +500,7 @@ class RouteProviderTest extends KernelTestBase {
       $this->assertNotNull($routes->get('foo2'), 'The second matching route was found.');
       $this->assertNull($routes->get('eep'), 'Non-matching route was not found.');
     }
-    catch (ResourceNotFoundException $e) {
+    catch (ResourceNotFoundException) {
       $this->fail('No matching route found with default argument value.');
     }
   }
@@ -517,7 +508,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Tests a route with a 0 as value.
    */
-  public function testOutlinePathMatchZero() {
+  public function testOutlinePathMatchZero(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -544,15 +535,15 @@ class RouteProviderTest extends KernelTestBase {
 
       $this->assertCount(1, $routes, 'The correct number of routes was found.');
     }
-    catch (ResourceNotFoundException $e) {
-      $this->fail('No matchout route found with 0 as argument value');
+    catch (ResourceNotFoundException) {
+      $this->fail('No matching route found with 0 as argument value');
     }
   }
 
   /**
    * Confirms that an exception is thrown when no matching path is found.
    */
-  public function testOutlinePathNoMatch() {
+  public function testOutlinePathNoMatch(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -576,7 +567,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Tests that route caching works.
    */
-  public function testRouteCaching() {
+  public function testRouteCaching(): void {
     $connection = Database::getConnection();
     $language_manager = \Drupal::languageManager();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes', $language_manager);
@@ -593,7 +584,7 @@ class RouteProviderTest extends KernelTestBase {
     $request = Request::create($path, 'GET');
     $provider->getRouteCollectionForRequest($request);
 
-    $cache = $this->cache->get('route:[language]=en:/path/add/one:');
+    $cache = $this->cache->get('route:[language]=en:[query_parameters]=:/path/add/one');
     $this->assertEquals('/path/add/one', $cache->data['path']);
     $this->assertEquals([], $cache->data['query']);
     $this->assertCount(3, $cache->data['routes']);
@@ -603,17 +594,33 @@ class RouteProviderTest extends KernelTestBase {
     $request = Request::create($path, 'GET');
     $provider->getRouteCollectionForRequest($request);
 
-    $cache = $this->cache->get('route:[language]=en:/path/add/one:foo=bar');
+    $cache = $this->cache->get('route:[language]=en:[query_parameters]=foo=bar,2fb8f40115dd1e695cbe23d4f97ce5b1fb697eee:/path/add/one');
     $this->assertEquals('/path/add/one', $cache->data['path']);
     $this->assertEquals(['foo' => 'bar'], $cache->data['query']);
     $this->assertCount(3, $cache->data['routes']);
 
+    // A path with multivalued query parameters.
+    $path = '/path/add/one?foo=bar&foo2[]=bar2&foo2[]=bar3';
+    $request = Request::create($path, 'GET');
+    $provider->getRouteCollectionForRequest($request);
+
+    $cache = $this->cache->get('route:[language]=en:[query_parameters]=foo=bar&foo2%5B0%5D=bar2&foo2%5B1%5D=bar3,2d3a0851c4970a16be1c851a0e9946e6d10a3fe2:/path/add/one');
+    $this->assertEquals('/path/add/one', $cache->data['path']);
+    $this->assertEquals(
+      [
+        'foo' => 'bar',
+        'foo2' => ['bar2', 'bar3'],
+      ],
+      $cache->data['query']
+    );
+    $this->assertCount(3, $cache->data['routes']);
+
     // A path with placeholders.
     $path = '/path/1/one';
     $request = Request::create($path, 'GET');
     $provider->getRouteCollectionForRequest($request);
 
-    $cache = $this->cache->get('route:[language]=en:/path/1/one:');
+    $cache = $this->cache->get('route:[language]=en:[query_parameters]=:/path/1/one');
     $this->assertEquals('/path/1/one', $cache->data['path']);
     $this->assertEquals([], $cache->data['query']);
     $this->assertCount(2, $cache->data['routes']);
@@ -628,7 +635,7 @@ class RouteProviderTest extends KernelTestBase {
     $request = Request::create($path, 'GET');
     $provider->getRouteCollectionForRequest($request);
 
-    $cache = $this->cache->get('route:[language]=en:/path/add-one:');
+    $cache = $this->cache->get('route:[language]=en:[query_parameters]=:/path/add-one');
     $this->assertEquals('/path/add/one', $cache->data['path']);
     $this->assertEquals([], $cache->data['query']);
     $this->assertCount(3, $cache->data['routes']);
@@ -643,7 +650,7 @@ class RouteProviderTest extends KernelTestBase {
     $request = Request::create($path, 'GET');
     $provider->getRouteCollectionForRequest($request);
 
-    $cache = $this->cache->get('route:[language]=gsw-berne:/path/add-one:');
+    $cache = $this->cache->get('route:[language]=gsw-berne:[query_parameters]=:/path/add-one');
     $this->assertEquals('/path/add/one', $cache->data['path']);
     $this->assertEquals([], $cache->data['query']);
     $this->assertCount(3, $cache->data['routes']);
@@ -652,7 +659,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Tests RouteProvider::getRouteByName() & RouteProvider::getRoutesByNames().
    */
-  public function testRouteByName() {
+  public function testRouteByName(): void {
     $connection = Database::getConnection();
     $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -673,7 +680,7 @@ class RouteProviderTest extends KernelTestBase {
     try {
       $provider->getRouteByName('invalid_name');
     }
-    catch (RouteNotFoundException $e) {
+    catch (RouteNotFoundException) {
       $exception_thrown = TRUE;
     }
     $this->assertTrue($exception_thrown, 'Random route was not found.');
@@ -687,7 +694,7 @@ class RouteProviderTest extends KernelTestBase {
   /**
    * Ensures that the routing system is capable of extreme long patterns.
    */
-  public function testGetRoutesByPatternWithLongPatterns() {
+  public function testGetRoutesByPatternWithLongPatterns(): void {
     $connection = Database::getConnection();
     $provider = new TestRouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
 
@@ -742,10 +749,41 @@ class RouteProviderTest extends KernelTestBase {
     $this->assertCount(7, $candidates);
   }
 
+  /**
+   * @covers \Drupal\Core\Routing\RouteProvider::getRouteAliases
+   */
+  public function testRouteAliases(): void {
+    $connection = Database::getConnection();
+    $provider = new RouteProvider($connection, $this->state, $this->currentPath, $this->cache, $this->pathProcessor, $this->cacheTagsInvalidator, 'test_routes');
+
+    $this->fixtures->createTables($connection);
+
+    $dumper = new MatcherDumper($connection, $this->state, $this->logger, 'test_routes');
+    $dumper->addRoutes($this->fixtures->aliasedRouteCollection());
+    $dumper->dump();
+
+    $aliases = $provider->getRouteAliases('route_a');
+    $this->assertCount(2, $aliases);
+    $this->assertEquals('route_a', $aliases['route_b']->getId());
+    $this->assertEquals('route_a', $aliases['route_c']->getId());
+    $this->assertTrue($aliases['route_c']->isDeprecated());
+
+    $deprecation = $aliases['route_c']->getDeprecation('route_c');
+    $this->assertEquals('drupal/core', $deprecation['package']);
+    $this->assertEquals('11.2.0', $deprecation['version']);
+    $this->assertEquals('route_c is deprecated!', $deprecation['message']);
+  }
+
 }
 
+/**
+ * Stub class for testing RouteProvider.
+ */
 class TestRouteProvider extends RouteProvider {
 
+  /**
+   * {@inheritdoc}
+   */
   public function getCandidateOutlines(array $parts) {
     return parent::getCandidateOutlines($parts);
   }
