@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Test;
 
 use Drupal\KernelTests\KernelTestBase;
@@ -13,15 +15,24 @@ use Drupal\deprecation_test\Deprecation\FixtureDeprecatedClass;
  */
 class PhpUnitBridgeTest extends KernelTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
   protected static $modules = ['deprecation_test'];
 
-  public function testDeprecatedClass() {
+  /**
+   * Tests class deprecation.
+   */
+  public function testDeprecatedClass(): void {
     $this->expectDeprecation('Drupal\deprecation_test\Deprecation\FixtureDeprecatedClass is deprecated.');
     $deprecated = new FixtureDeprecatedClass();
     $this->assertEquals('test', $deprecated->testFunction());
   }
 
-  public function testDeprecatedFunction() {
+  /**
+   * Tests function deprecation.
+   */
+  public function testDeprecatedFunction(): void {
     $this->expectDeprecation('This is the deprecation message for deprecation_test_function().');
     $this->assertEquals('known_return_value', \deprecation_test_function());
   }
