@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Theme;
 
 use Drupal\Core\Extension\ModuleExtensionList;
@@ -18,18 +20,21 @@ use Symfony\Component\HttpKernel\Exception\HttpExceptionInterface;
 class RegistryTest extends KernelTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['theme_test', 'system'];
 
+  /**
+   * The profile to use for this test.
+   *
+   * @var string
+   */
   protected $profile = 'testing';
 
   /**
    * Tests the behavior of the theme registry class.
    */
-  public function testRaceCondition() {
+  public function testRaceCondition(): void {
     // The theme registry is not marked as persistable in case we don't have a
     // proper request.
     \Drupal::request()->setMethod('GET');
@@ -67,57 +72,53 @@ class RegistryTest extends KernelTestBase {
   /**
    * Tests the theme registry with multiple subthemes.
    */
-  public function testMultipleSubThemes() {
+  public function testMultipleSubThemes(): void {
     $theme_handler = \Drupal::service('theme_handler');
-    \Drupal::service('theme_installer')->install(['test_basetheme', 'test_subtheme', 'test_subsubtheme']);
+    \Drupal::service('theme_installer')->install(['test_base_theme', 'test_subtheme', 'test_subsubtheme']);
 
     $module_list = $this->container->get('extension.list.module');
     assert($module_list instanceof ModuleExtensionList);
 
-    $registry_subsub_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $module_list, 'test_subsubtheme');
+    $registry_subsub_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $module_list, \Drupal::service('kernel'), 'test_subsubtheme');
     $registry_subsub_theme->setThemeManager(\Drupal::theme());
-    $registry_sub_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $module_list, 'test_subtheme');
+    $registry_sub_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $module_list, \Drupal::service('kernel'), 'test_subtheme',);
     $registry_sub_theme->setThemeManager(\Drupal::theme());
-    $registry_base_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $module_list, 'test_basetheme');
+    $registry_base_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $module_list, \Drupal::service('kernel'), 'test_base_theme');
     $registry_base_theme->setThemeManager(\Drupal::theme());
 
     $preprocess_functions = $registry_subsub_theme->get()['theme_test_template_test']['preprocess functions'];
     $this->assertSame([
-      'template_preprocess',
-      'test_basetheme_preprocess_theme_test_template_test',
+      'test_base_theme_preprocess_theme_test_template_test',
       'test_subtheme_preprocess_theme_test_template_test',
       'test_subsubtheme_preprocess_theme_test_template_test',
     ], $preprocess_functions);
 
     $preprocess_functions = $registry_sub_theme->get()['theme_test_template_test']['preprocess functions'];
     $this->assertSame([
-      'template_preprocess',
-      'test_basetheme_preprocess_theme_test_template_test',
+      'test_base_theme_preprocess_theme_test_template_test',
       'test_subtheme_preprocess_theme_test_template_test',
     ], $preprocess_functions);
 
     $preprocess_functions = $registry_base_theme->get()['theme_test_template_test']['preprocess functions'];
     $this->assertSame([
-      'template_preprocess',
-      'test_basetheme_preprocess_theme_test_template_test',
+      'test_base_theme_preprocess_theme_test_template_test',
     ], $preprocess_functions);
   }
 
   /**
    * Tests the theme registry with suggestions.
    */
-  public function testSuggestionPreprocessFunctions() {
+  public function testSuggestionPreprocessFunctions(): void {
     $theme_handler = \Drupal::service('theme_handler');
     \Drupal::service('theme_installer')->install(['test_theme']);
 
     $extension_list = $this->container->get('extension.list.module');
     assert($extension_list instanceof ModuleExtensionList);
-    $registry_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $extension_list, 'test_theme');
+    $registry_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $extension_list, \Drupal::service('kernel'), 'test_theme');
     $registry_theme->setThemeManager(\Drupal::theme());
 
     $suggestions = ['__kitten', '__flamingo'];
     $expected_preprocess_functions = [
-      'template_preprocess',
       'theme_test_preprocess_theme_test_preprocess_suggestions',
     ];
     $suggestion = '';
@@ -130,7 +131,6 @@ class RegistryTest extends KernelTestBase {
     } while ($suggestion = array_shift($suggestions));
 
     $expected_preprocess_functions = [
-      'template_preprocess',
       'theme_test_preprocess_theme_test_preprocess_suggestions',
       'test_theme_preprocess_theme_test_preprocess_suggestions',
       'test_theme_preprocess_theme_test_preprocess_suggestions__kitten',
@@ -145,7 +145,7 @@ class RegistryTest extends KernelTestBase {
   /**
    * Tests that the theme registry can be altered by themes.
    */
-  public function testThemeRegistryAlterByTheme() {
+  public function testThemeRegistryAlterByTheme(): void {
 
     /** @var \Drupal\Core\Extension\ThemeHandlerInterface $theme_handler */
     $theme_handler = \Drupal::service('theme_handler');
@@ -154,7 +154,7 @@ class RegistryTest extends KernelTestBase {
 
     $extension_list = $this->container->get('extension.list.module');
     assert($extension_list instanceof ModuleExtensionList);
-    $registry = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $extension_list, 'test_theme');
+    $registry = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $extension_list, \Drupal::service('kernel'), 'test_theme');
     $registry->setThemeManager(\Drupal::theme());
     $this->assertEquals('value', $registry->get()['theme_test_template_test']['variables']['additional']);
   }
@@ -162,7 +162,7 @@ class RegistryTest extends KernelTestBase {
   /**
    * Tests front node theme suggestion generation.
    */
-  public function testThemeSuggestions() {
+  public function testThemeSuggestions(): void {
     // Mock the current page as the front page.
     /** @var \Drupal\Core\Path\PathMatcherInterface $path_matcher */
     $path_matcher = $this->prophesize(PathMatcherInterface::class);
@@ -195,7 +195,7 @@ class RegistryTest extends KernelTestBase {
   /**
    * Tests page theme suggestions for 200 responses.
    */
-  public function test200ThemeSuggestions() {
+  public function test200ThemeSuggestions(): void {
     $path_matcher = $this->prophesize(PathMatcherInterface::class);
     $path_matcher->isFrontPage()->willReturn(FALSE);
     \Drupal::getContainer()->set('path.matcher', $path_matcher->reveal());
@@ -218,7 +218,7 @@ class RegistryTest extends KernelTestBase {
    * @return array
    *   An associative array of 40x theme suggestions.
    */
-  public function provider40xThemeSuggestions() {
+  public static function provider40xThemeSuggestions() {
     return [
       [401, 'page__401'],
       [403, 'page__403'],
@@ -257,52 +257,21 @@ class RegistryTest extends KernelTestBase {
   /**
    * Tests theme-provided templates that are registered by modules.
    */
-  public function testThemeTemplatesRegisteredByModules() {
+  public function testThemeTemplatesRegisteredByModules(): void {
     $theme_handler = \Drupal::service('theme_handler');
     \Drupal::service('theme_installer')->install(['test_theme']);
 
     $extension_list = \Drupal::service('extension.list.module');
     assert($extension_list instanceof ModuleExtensionList);
-    $registry_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $extension_list, 'test_theme');
+    $registry_theme = new Registry($this->root, \Drupal::cache(), \Drupal::lock(), \Drupal::moduleHandler(), $theme_handler, \Drupal::service('theme.initialization'), \Drupal::service('cache.bootstrap'), $extension_list, \Drupal::service('kernel'), 'test_theme');
     $registry_theme->setThemeManager(\Drupal::theme());
 
     $expected = [
-      'template_preprocess',
-      'template_preprocess_container',
       'template_preprocess_theme_test_registered_by_module',
     ];
     $registry = $registry_theme->get();
+    $this->assertEquals('Drupal\Core\Theme\ThemePreprocess:preprocessContainer', $registry['theme_test_registered_by_module']['initial preprocess']);
     $this->assertEquals($expected, array_values($registry['theme_test_registered_by_module']['preprocess functions']));
   }
 
-  /**
-   * Tests deprecated drupal_theme_rebuild() function.
-   *
-   * @see drupal_theme_rebuild()
-   * @group legacy
-   */
-  public function testLegacyThemeRegistryRebuild() {
-    $registry = \Drupal::service('theme.registry');
-    $runtime = $registry->getRuntime();
-    $hooks = $registry->get();
-    $this->expectDeprecation('drupal_theme_rebuild() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. Use theme.registry service reset() method instead. See https://www.drupal.org/node/3348853');
-    drupal_theme_rebuild();
-    $this->assertNotSame($runtime, $registry->getRuntime());
-    $this->assertSame($hooks, $registry->get());
-  }
-
-  /**
-   * Tests deprecated theme_get_registry function.
-   *
-   * @see theme_get_registry()
-   * @group legacy
-   */
-  public function testLegacyThemeGetRegistry() {
-    $registry = \Drupal::service('theme.registry');
-    $this->expectDeprecation('theme_get_registry() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. Use theme.registry service method get() instead. See https://www.drupal.org/node/3348850');
-    $this->assertEquals($registry->get(), theme_get_registry());
-    $this->expectDeprecation('theme_get_registry() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. Use theme.registry service method getRuntime() instead. See https://www.drupal.org/node/3348850');
-    $this->assertEquals($registry->getRuntime(), theme_get_registry(FALSE));
-  }
-
 }
