@@ -1,12 +1,16 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Theme;
 
 use Drupal\Core\DependencyInjection\ContainerBuilder;
 use Drupal\Core\Extension\ExtensionNameLengthException;
+use Drupal\Core\Extension\ExtensionNameReservedException;
 use Drupal\Core\Extension\MissingDependencyException;
 use Drupal\Core\Extension\ModuleUninstallValidatorException;
 use Drupal\Core\Extension\Exception\UnknownExtensionException;
+use Drupal\Core\Extension\ThemeExtensionList;
 use Drupal\KernelTests\KernelTestBase;
 
 /**
@@ -17,16 +21,14 @@ use Drupal\KernelTests\KernelTestBase;
 class ThemeInstallerTest extends KernelTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
   protected static $modules = ['system'];
 
   /**
    * {@inheritdoc}
    */
-  public function register(ContainerBuilder $container) {
+  public function register(ContainerBuilder $container): void {
     parent::register($container);
     // Some test methods involve ModuleHandler operations, which attempt to
     // rebuild and dump routes.
@@ -34,6 +36,9 @@ class ThemeInstallerTest extends KernelTestBase {
       ->register('router.dumper', 'Drupal\Core\Routing\NullMatcherDumper');
   }
 
+  /**
+   * {@inheritdoc}
+   */
   protected function setUp(): void {
     parent::setUp();
     $this->installConfig(['system']);
@@ -42,14 +47,14 @@ class ThemeInstallerTest extends KernelTestBase {
   /**
    * Verifies that no themes are installed by default.
    */
-  public function testEmpty() {
+  public function testEmpty(): void {
     $this->assertEmpty($this->extensionConfig()->get('theme'));
 
     $this->assertEmpty(array_keys($this->themeHandler()->listInfo()));
     $this->assertEmpty(array_keys(\Drupal::service('theme_handler')->listInfo()));
 
     // Rebuilding available themes should always yield results though.
-    $this->assertNotEmpty($this->themeHandler()->rebuildThemeData()['stark'], 'ThemeHandler::rebuildThemeData() yields all available themes.');
+    $this->assertNotEmpty($this->extensionListTheme()->reset()->getList()['stark'], 'ThemeExtensionList::getList() yields all available themes.');
 
     // theme_get_setting() should return global default theme settings.
     $this->assertTrue(theme_get_setting('features.favicon'));
@@ -58,32 +63,32 @@ class ThemeInstallerTest extends KernelTestBase {
   /**
    * Tests installing a theme.
    */
-  public function testInstall() {
-    $name = 'test_basetheme';
+  public function testInstall(): void {
+    $name = 'test_base_theme';
 
     $themes = $this->themeHandler()->listInfo();
     $this->assertFalse(isset($themes[$name]));
 
     $this->themeInstaller()->install([$name]);
 
-    $this->assertIdentical($this->extensionConfig()->get("theme.$name"), 0);
+    $this->assertSame(0, $this->extensionConfig()->get("theme.{$name}"));
 
     $themes = $this->themeHandler()->listInfo();
     $this->assertTrue(isset($themes[$name]));
-    $this->assertEqual($themes[$name]->getName(), $name);
+    $this->assertEquals($name, $themes[$name]->getName());
 
-    // Verify that test_basetheme.settings is active.
+    // Verify that test_base_theme.settings is active.
     $this->assertFalse(theme_get_setting('features.favicon', $name));
-    $this->assertEqual(theme_get_setting('base', $name), 'only');
-    $this->assertEqual(theme_get_setting('override', $name), 'base');
+    $this->assertEquals('only', theme_get_setting('base', $name));
+    $this->assertEquals('base', theme_get_setting('override', $name));
   }
 
   /**
    * Tests installing a sub-theme.
    */
-  public function testInstallSubTheme() {
-    $name = 'test_subtheme';
-    $base_name = 'test_basetheme';
+  public function testInstallSubTheme(): void {
+    $name = 'test_child_theme';
+    $base_name = 'test_parent_theme';
 
     $themes = $this->themeHandler()->listInfo();
     $this->assertEmpty(array_keys($themes));
@@ -94,6 +99,12 @@ class ThemeInstallerTest extends KernelTestBase {
     $this->assertTrue(isset($themes[$name]));
     $this->assertTrue(isset($themes[$base_name]));
 
+    $expectedOrder = [
+      $base_name,
+      $name,
+    ];
+    $this->assertEquals($expectedOrder, array_keys($themes));
+
     $this->themeInstaller()->uninstall([$name]);
 
     $themes = $this->themeHandler()->listInfo();
@@ -104,7 +115,7 @@ class ThemeInstallerTest extends KernelTestBase {
   /**
    * Tests installing a non-existing theme.
    */
-  public function testInstallNonExisting() {
+  public function testInstallNonExisting(): void {
     $name = 'non_existing_theme';
 
     $themes = $this->themeHandler()->listInfo();
@@ -126,7 +137,7 @@ class ThemeInstallerTest extends KernelTestBase {
   /**
    * Tests installing a theme with a too long name.
    */
-  public function testInstallNameTooLong() {
+  public function testInstallNameTooLong(): void {
     $name = 'test_theme_having_veery_long_name_which_is_too_long';
 
     try {
@@ -139,13 +150,31 @@ class ThemeInstallerTest extends KernelTestBase {
     }
   }
 
+  /**
+   * Tests installing a theme with the same name as an enabled module.
+   */
+  public function testInstallThemeSameNameAsModule(): void {
+    $name = 'name_collision_test';
+
+    // Install and uninstall the theme.
+    $this->themeInstaller()->install([$name]);
+    $this->themeInstaller()->uninstall([$name]);
+
+    // Install the module, then the theme.
+    $this->moduleInstaller()->install([$name]);
+    $message = "Theme name {$name} is already in use by an installed module.";
+    $this->expectException(ExtensionNameReservedException::class);
+    $this->expectExceptionMessage($message);
+    $this->themeInstaller()->install([$name]);
+  }
+
   /**
    * Tests installing a theme with unmet module dependencies.
    *
    * @dataProvider providerTestInstallThemeWithUnmetModuleDependencies
    */
-  public function testInstallThemeWithUnmetModuleDependencies($theme_name, $installed_modules, $message) {
-    $this->container->get('module_installer')->install($installed_modules);
+  public function testInstallThemeWithUnmetModuleDependencies($theme_name, $installed_modules, $message): void {
+    $this->moduleInstaller()->install($installed_modules);
     $themes = $this->themeHandler()->listInfo();
     $this->assertEmpty($themes);
     $this->expectException(MissingDependencyException::class);
@@ -153,10 +182,23 @@ class ThemeInstallerTest extends KernelTestBase {
     $this->themeInstaller()->install([$theme_name]);
   }
 
+  /**
+   * Tests trying to install a deprecated theme.
+   *
+   * @covers \Drupal\Core\Extension\ThemeInstaller::install
+   *
+   * @group legacy
+   */
+  public function testInstallDeprecated(): void {
+    $this->expectDeprecation("The theme 'deprecated_theme_test' is deprecated. See https://example.com/deprecated");
+    $this->themeInstaller()->install(['deprecated_theme_test']);
+    $this->assertTrue(\Drupal::service('theme_handler')->themeExists('deprecated_theme_test'));
+  }
+
   /**
    * Data provider for testInstallThemeWithUnmetModuleDependencies().
    */
-  public function providerTestInstallThemeWithUnmetModuleDependencies() {
+  public static function providerTestInstallThemeWithUnmetModuleDependencies() {
     return [
       'theme with uninstalled module dependencies' => [
         'test_theme_depending_on_modules',
@@ -199,25 +241,25 @@ class ThemeInstallerTest extends KernelTestBase {
   /**
    * Tests installing a theme with module dependencies that are met.
    */
-  public function testInstallThemeWithMetModuleDependencies() {
+  public function testInstallThemeWithMetModuleDependencies(): void {
     $name = 'test_theme_depending_on_modules';
     $themes = $this->themeHandler()->listInfo();
     $this->assertArrayNotHasKey($name, $themes);
-    $this->container->get('module_installer')->install(['test_module_required_by_theme', 'test_another_module_required_by_theme']);
+    $this->moduleInstaller()->install(['test_module_required_by_theme', 'test_another_module_required_by_theme']);
     $this->themeInstaller()->install([$name]);
     $themes = $this->themeHandler()->listInfo();
     $this->assertArrayHasKey($name, $themes);
     $this->expectException(ModuleUninstallValidatorException::class);
     $this->expectExceptionMessage('The following reasons prevent the modules from being uninstalled: Required by the theme: Test Theme Depending on Modules');
-    $this->container->get('module_installer')->uninstall(['test_module_required_by_theme']);
+    $this->moduleInstaller()->uninstall(['test_module_required_by_theme']);
   }
 
   /**
    * Tests uninstalling the default theme.
    */
-  public function testUninstallDefault() {
+  public function testUninstallDefault(): void {
     $name = 'stark';
-    $other_name = 'bartik';
+    $other_name = 'olivero';
     $this->themeInstaller()->install([$name, $other_name]);
     $this->config('system.theme')->set('default', $name)->save();
 
@@ -226,7 +268,7 @@ class ThemeInstallerTest extends KernelTestBase {
     $this->assertTrue(isset($themes[$other_name]));
 
     try {
-      $message = 'ThemeInstaller::uninstall() throws InvalidArgumentException upon disabling default theme.';
+      $message = 'ThemeInstaller::uninstall() throws InvalidArgumentException upon uninstalling default theme.';
       $this->themeInstaller()->uninstall([$name]);
       $this->fail($message);
     }
@@ -242,9 +284,9 @@ class ThemeInstallerTest extends KernelTestBase {
   /**
    * Tests uninstalling the admin theme.
    */
-  public function testUninstallAdmin() {
+  public function testUninstallAdmin(): void {
     $name = 'stark';
-    $other_name = 'bartik';
+    $other_name = 'olivero';
     $this->themeInstaller()->install([$name, $other_name]);
     $this->config('system.theme')->set('admin', $name)->save();
 
@@ -269,9 +311,9 @@ class ThemeInstallerTest extends KernelTestBase {
   /**
    * Tests uninstalling a sub-theme.
    */
-  public function testUninstallSubTheme() {
+  public function testUninstallSubTheme(): void {
     $name = 'test_subtheme';
-    $base_name = 'test_basetheme';
+    $base_name = 'test_base_theme';
 
     $this->themeInstaller()->install([$name]);
     $this->themeInstaller()->uninstall([$name]);
@@ -284,8 +326,8 @@ class ThemeInstallerTest extends KernelTestBase {
   /**
    * Tests uninstalling a base theme before its sub-theme.
    */
-  public function testUninstallBaseBeforeSubTheme() {
-    $name = 'test_basetheme';
+  public function testUninstallBaseBeforeSubTheme(): void {
+    $name = 'test_base_theme';
     $sub_name = 'test_subtheme';
 
     $this->themeInstaller()->install([$sub_name]);
@@ -314,30 +356,21 @@ class ThemeInstallerTest extends KernelTestBase {
   /**
    * Tests uninstalling a non-existing theme.
    */
-  public function testUninstallNonExisting() {
+  public function testUninstallNonExisting(): void {
     $name = 'non_existing_theme';
 
     $themes = $this->themeHandler()->listInfo();
     $this->assertEmpty(array_keys($themes));
 
-    try {
-      $message = 'ThemeInstaller::uninstall() throws UnknownExtensionException upon uninstalling a non-existing theme.';
-      $this->themeInstaller()->uninstall([$name]);
-      $this->fail($message);
-    }
-    catch (\Exception $e) {
-      $this->assertInstanceOf(UnknownExtensionException::class, $e);
-    }
-
-    $themes = $this->themeHandler()->listInfo();
-    $this->assertEmpty(array_keys($themes));
+    $this->expectException(UnknownExtensionException::class);
+    $this->themeInstaller()->uninstall([$name]);
   }
 
   /**
    * Tests uninstalling a theme.
    */
-  public function testUninstall() {
-    $name = 'test_basetheme';
+  public function testUninstall(): void {
+    $name = 'test_base_theme';
 
     $this->themeInstaller()->install([$name]);
     $this->assertNotEmpty($this->config("$name.settings")->get());
@@ -352,24 +385,20 @@ class ThemeInstallerTest extends KernelTestBase {
     $this->themeInstaller()->install([$name]);
     $themes = $this->themeHandler()->listInfo();
     $this->assertTrue(isset($themes[$name]));
-    $this->assertEqual($themes[$name]->getName(), $name);
+    $this->assertEquals($name, $themes[$name]->getName());
     $this->assertNotEmpty($this->config("$name.settings")->get());
   }
 
   /**
    * Tests uninstalling a theme that is not installed.
    */
-  public function testUninstallNotInstalled() {
-    $name = 'test_basetheme';
+  public function testUninstallNotInstalled(): void {
+    $name = 'test_base_theme';
 
-    try {
-      $message = 'ThemeInstaller::uninstall() throws UnknownExtensionException upon uninstalling a theme that is not installed.';
-      $this->themeInstaller()->uninstall([$name]);
-      $this->fail($message);
-    }
-    catch (\Exception $e) {
-      $this->assertInstanceOf(UnknownExtensionException::class, $e);
-    }
+    $themes = $this->themeHandler()->listInfo();
+    $this->assertEmpty(array_keys($themes));
+    $this->expectException(UnknownExtensionException::class);
+    $this->themeInstaller()->uninstall([$name]);
   }
 
   /**
@@ -377,8 +406,8 @@ class ThemeInstallerTest extends KernelTestBase {
    *
    * @see module_test_system_info_alter()
    */
-  public function testThemeInfoAlter() {
-    $name = 'seven';
+  public function testThemeInfoAlter(): void {
+    $name = 'stark';
     $this->container->get('state')->set('module_test.hook_system_info_alter', TRUE);
 
     $this->themeInstaller()->install([$name]);
@@ -424,6 +453,7 @@ class ThemeInstallerTest extends KernelTestBase {
    * Returns the theme handler service.
    *
    * @return \Drupal\Core\Extension\ThemeHandlerInterface
+   *   The theme handler service.
    */
   protected function themeHandler() {
     return $this->container->get('theme_handler');
@@ -433,6 +463,7 @@ class ThemeInstallerTest extends KernelTestBase {
    * Returns the theme installer service.
    *
    * @return \Drupal\Core\Extension\ThemeInstallerInterface
+   *   The theme installer service.
    */
   protected function themeInstaller() {
     return $this->container->get('theme_installer');
@@ -442,6 +473,7 @@ class ThemeInstallerTest extends KernelTestBase {
    * Returns the system.theme config object.
    *
    * @return \Drupal\Core\Config\Config
+   *   The system.theme config object.
    */
   protected function extensionConfig() {
     return $this->config('core.extension');
@@ -451,8 +483,9 @@ class ThemeInstallerTest extends KernelTestBase {
    * Returns the ModuleHandler.
    *
    * @return \Drupal\Core\Extension\ModuleHandlerInterface
+   *   The ModuleHandler.
    */
-  protected function moduleHandler() {
+  protected function moduleHandler(): ?object {
     return $this->container->get('module_handler');
   }
 
@@ -460,9 +493,20 @@ class ThemeInstallerTest extends KernelTestBase {
    * Returns the ModuleInstaller.
    *
    * @return \Drupal\Core\Extension\ModuleInstallerInterface
+   *   The ModuleInstaller.
    */
-  protected function moduleInstaller() {
+  protected function moduleInstaller(): ?object {
     return $this->container->get('module_installer');
   }
 
+  /**
+   * Returns the ThemeExtensionList.
+   *
+   * @return \Drupal\Core\Extension\ThemeExtensionList
+   *   The ThemeExtensionList.
+   */
+  protected function extensionListTheme(): ThemeExtensionList {
+    return $this->container->get('extension.list.theme');
+  }
+
 }
