@@ -13,13 +13,6 @@ use PHPUnit\Framework\TestCase;
  */
 class ArgumentsResolverTest extends TestCase {
 
-  /**
-   * {@inheritdoc}
-   */
-  protected function setUp(): void {
-    parent::setUp();
-  }
-
   /**
    * Tests the getArgument() method.
    *
@@ -126,7 +119,8 @@ class ArgumentsResolverTest extends TestCase {
   /**
    * Tests getArgument() with a wildcard parameter with no type hint.
    *
-   * Without the type hint, the wildcard object will not be passed to the callable.
+   * Without the type hint, the wildcard object will not be passed to the
+   * callable.
    */
   public function testGetWildcardArgumentNoTypeHint(): void {
     $a = $this->getMockBuilder('\Drupal\Tests\Component\Utility\Test1Interface')->getMock();
@@ -203,6 +197,9 @@ class TestClass {
 
 }
 
+/**
+ * Provides a class for testing a static method.
+ */
 class TestStaticMethodClass {
 
   public static function access($foo) {
