@@ -19,9 +19,9 @@ class RandomTest extends TestCase {
   /**
    * The first random string passed to the test callback.
    *
-   * @see \Drupal\Tests\Component\Utility\RandomTest::_RandomStringValidate()
-   *
    * @var string
+   *
+   * @see \Drupal\Tests\Component\Utility\RandomTest::_RandomStringValidate()
    */
   protected $firstStringGenerated = '';
 
@@ -30,7 +30,7 @@ class RandomTest extends TestCase {
    *
    * @covers ::string
    */
-  public function testRandomStringUniqueness() {
+  public function testRandomStringUniqueness(): void {
     $strings = [];
     $random = new Random();
     for ($i = 0; $i <= 50; $i++) {
@@ -45,7 +45,7 @@ class RandomTest extends TestCase {
    *
    * @covers ::name
    */
-  public function testRandomNamesUniqueness() {
+  public function testRandomNamesUniqueness(): void {
     $names = [];
     $random = new Random();
     for ($i = 0; $i <= 10; $i++) {
@@ -60,7 +60,7 @@ class RandomTest extends TestCase {
    *
    * @covers ::name
    */
-  public function testRandomNameException() {
+  public function testRandomNameException(): void {
     // There are fewer than 100 possibilities so an exception should occur to
     // prevent infinite loops.
     $random = new Random();
@@ -76,7 +76,7 @@ class RandomTest extends TestCase {
    *
    * @covers ::string
    */
-  public function testRandomStringException() {
+  public function testRandomStringException(): void {
     // There are fewer than 100 possibilities so an exception should occur to
     // prevent infinite loops.
     $random = new Random();
@@ -92,7 +92,7 @@ class RandomTest extends TestCase {
    *
    * @covers ::name
    */
-  public function testRandomNameNonUnique() {
+  public function testRandomNameNonUnique(): void {
     // There are fewer than 100 possibilities if we were forcing uniqueness so
     // exception would occur.
     $random = new Random();
@@ -107,7 +107,7 @@ class RandomTest extends TestCase {
    *
    * @covers ::string
    */
-  public function testRandomStringNonUnique() {
+  public function testRandomStringNonUnique(): void {
     // There are fewer than 100 possibilities if we were forcing uniqueness so
     // exception would occur.
     $random = new Random();
@@ -167,7 +167,7 @@ class RandomTest extends TestCase {
    *
    * @covers ::object
    */
-  public function testRandomObject() {
+  public function testRandomObject(): void {
     // For values of 0 and 1 \Drupal\Component\Utility\Random::object() will
     // have different execution paths.
     $random = new Random();
@@ -182,7 +182,7 @@ class RandomTest extends TestCase {
    *
    * @covers ::string
    */
-  public function testRandomStringValidator() {
+  public function testRandomStringValidator(): void {
     $random = new Random();
     $this->firstStringGenerated = '';
     $str = $random->string(1, TRUE, [$this, '_RandomStringValidate']);
@@ -194,7 +194,7 @@ class RandomTest extends TestCase {
    *
    * @covers ::word
    */
-  public function testRandomWordValidator() {
+  public function testRandomWordValidator(): void {
     $random = new Random();
     $this->assertNotEquals($random->word(20), $random->word(20));
   }
@@ -202,14 +202,14 @@ class RandomTest extends TestCase {
   /**
    * Callback for random string validation.
    *
-   * @see \Drupal\Component\Utility\Random::name()
-   * @see \Drupal\Tests\Component\Utility\RandomTest::testRandomStringValidator()
-   *
    * @param string $string
    *   The random string to validate.
    *
    * @return bool
    *   TRUE if the random string is valid, FALSE if not.
+   *
+   * @see \Drupal\Component\Utility\Random::name()
+   * @see \Drupal\Tests\Component\Utility\RandomTest::testRandomStringValidator()
    */
   public function _RandomStringValidate($string) {
     // Return FALSE for the first generated string and any string that is the
