@@ -18,7 +18,7 @@ class OpenOffCanvasDialogCommandTest extends UnitTestCase {
    *
    * @dataProvider dialogPosition
    */
-  public function testRender($position) {
+  public function testRender($position): void {
     $command = new OpenOffCanvasDialogCommand('Title', '<p>Text!</p>', ['url' => 'example'], NULL, $position);
 
     $expected = [
@@ -34,8 +34,10 @@ class OpenOffCanvasDialogCommandTest extends UnitTestCase {
         'resizable' => 'w',
         'draggable' => FALSE,
         'drupalAutoButtons' => FALSE,
-        'dialogClass' => 'ui-dialog-off-canvas ui-dialog-position-' . $position,
-        'classes' => ['ui-dialog-content' => 'drupal-off-canvas-reset'],
+        'classes' => [
+          'ui-dialog' => 'ui-dialog-off-canvas ui-dialog-position-' . $position,
+          'ui-dialog-content' => 'drupal-off-canvas-reset',
+        ],
         'width' => 300,
         'drupalOffCanvasPosition' => $position,
       ],
@@ -49,6 +51,7 @@ class OpenOffCanvasDialogCommandTest extends UnitTestCase {
    * The data provider for potential dialog positions.
    *
    * @return array
+   *   An array of dialog positions.
    */
   public static function dialogPosition() {
     return [
