@@ -7,13 +7,13 @@ namespace Drupal\Tests\Core\Entity;
 use Drupal\Core\Access\AccessResult;
 use Drupal\Core\Cache\Cache;
 use Drupal\Core\DependencyInjection\ContainerBuilder;
-use Drupal\Core\Entity\EntityBase;
 use Drupal\Core\Entity\EntityStorageInterface;
 use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Entity\EntityTypeRepositoryInterface;
 use Drupal\Core\Language\Language;
 use Drupal\entity_test\Entity\EntityTestMul;
 use Drupal\Tests\UnitTestCase;
+use Prophecy\Argument;
 
 /**
  * @coversDefaultClass \Drupal\Core\Entity\EntityBase
@@ -74,7 +74,7 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * The mocked cache tags invalidator.
    *
-   * @var \Drupal\Core\Cache\CacheTagsInvalidatorInterface|\PHPUnit\Framework\MockObject\MockObject
+   * @var \Drupal\Core\Cache\CacheTagsInvalidatorInterface|\Prophecy\Prophecy\ObjectProphecy
    */
   protected $cacheTagsInvalidator;
 
@@ -102,8 +102,12 @@ class EntityUnitTest extends UnitTestCase {
     $this->entityType->expects($this->any())
       ->method('getListCacheTags')
       ->willReturn([$this->entityTypeId . '_list']);
+    $this->entityType->expects($this->any())
+      ->method('getBundleListCacheTags')
+      ->with($this->entityTypeId)
+      ->willReturn([$this->entityTypeId . '_list:' . $this->entityTypeId]);
 
-    $this->entityTypeManager = $this->getMockForAbstractClass(EntityTypeManagerInterface::class);
+    $this->entityTypeManager = $this->createMock(EntityTypeManagerInterface::class);
     $this->entityTypeManager->expects($this->any())
       ->method('getDefinition')
       ->with($this->entityTypeId)
@@ -117,29 +121,29 @@ class EntityUnitTest extends UnitTestCase {
       ->with('en')
       ->willReturn(new Language(['id' => 'en']));
 
-    $this->cacheTagsInvalidator = $this->createMock('Drupal\Core\Cache\CacheTagsInvalidator');
+    $this->cacheTagsInvalidator = $this->prophesize('Drupal\Core\Cache\CacheTagsInvalidator');
 
     $container = new ContainerBuilder();
     $container->set('entity_type.manager', $this->entityTypeManager);
     $container->set('uuid', $this->uuid);
     $container->set('language_manager', $this->languageManager);
-    $container->set('cache_tags.invalidator', $this->cacheTagsInvalidator);
+    $container->set('cache_tags.invalidator', $this->cacheTagsInvalidator->reveal());
     \Drupal::setContainer($container);
 
-    $this->entity = new EntityBaseTest($this->values, $this->entityTypeId);
+    $this->entity = new StubEntityBase($this->values, $this->entityTypeId);
   }
 
   /**
    * @covers ::id
    */
-  public function testId() {
+  public function testId(): void {
     $this->assertSame($this->values['id'], $this->entity->id());
   }
 
   /**
    * @covers ::uuid
    */
-  public function testUuid() {
+  public function testUuid(): void {
     $this->assertSame($this->values['uuid'], $this->entity->uuid());
   }
 
@@ -147,7 +151,7 @@ class EntityUnitTest extends UnitTestCase {
    * @covers ::isNew
    * @covers ::enforceIsNew
    */
-  public function testIsNew() {
+  public function testIsNew(): void {
     // We provided an ID, so the entity is not new.
     $this->assertFalse($this->entity->isNew());
     // Force it to be new.
@@ -158,21 +162,21 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::getEntityType
    */
-  public function testGetEntityType() {
+  public function testGetEntityType(): void {
     $this->assertSame($this->entityType, $this->entity->getEntityType());
   }
 
   /**
    * @covers ::bundle
    */
-  public function testBundle() {
+  public function testBundle(): void {
     $this->assertSame($this->entityTypeId, $this->entity->bundle());
   }
 
   /**
    * @covers ::label
    */
-  public function testLabel() {
+  public function testLabel(): void {
     $property_label = $this->randomMachineName();
     $this->entityType->expects($this->atLeastOnce())
       ->method('getKey')
@@ -197,7 +201,7 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::access
    */
-  public function testAccess() {
+  public function testAccess(): void {
     $access = $this->createMock('\Drupal\Core\Entity\EntityAccessControlHandlerInterface');
     $operation = $this->randomMachineName();
     $access->expects($this->once())
@@ -218,7 +222,7 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::language
    */
-  public function testLanguage() {
+  public function testLanguage(): void {
     $this->entityType->expects($this->any())
       ->method('getKey')
       ->willReturnMap([
@@ -230,9 +234,9 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * Setup for the tests of the ::load() method.
    */
-  public function setupTestLoad() {
+  public function setupTestLoad(): void {
     // Base our mocked entity on a real entity class so we can test if calling
-    // Entity::load() on the base class will bubble up to an actual entity.
+    // EntityBase::load() on the base class will bubble up to an actual entity.
     $this->entityTypeId = 'entity_test_mul';
     $methods = get_class_methods(EntityTestMul::class);
     unset($methods[array_search('load', $methods)]);
@@ -246,16 +250,18 @@ class EntityUnitTest extends UnitTestCase {
   }
 
   /**
-   * @covers ::load
+   * Tests EntityBase::load().
    *
-   * Tests Entity::load() when called statically on a subclass of Entity.
+   * When called statically on a subclass of Entity.
+   *
+   * @covers ::load
    */
-  public function testLoad() {
+  public function testLoad(): void {
     $this->setupTestLoad();
 
     $class_name = get_class($this->entity);
 
-    $entity_type_repository = $this->getMockForAbstractClass(EntityTypeRepositoryInterface::class);
+    $entity_type_repository = $this->createMock(EntityTypeRepositoryInterface::class);
     $entity_type_repository->expects($this->once())
       ->method('getEntityTypeFromClass')
       ->with($class_name)
@@ -274,22 +280,24 @@ class EntityUnitTest extends UnitTestCase {
 
     \Drupal::getContainer()->set('entity_type.repository', $entity_type_repository);
 
-    // Call Entity::load statically and check that it returns the mock entity.
+    // Call EntityBase::load statically and check that it returns the mock
+    // entity.
     $this->assertSame($this->entity, $class_name::load(1));
   }
 
   /**
-   * @covers ::loadMultiple
+   * Tests EntityBase::loadMultiple().
    *
-   * Tests Entity::loadMultiple() when called statically on a subclass of
-   * Entity.
+   * When called statically on a subclass of Entity.
+   *
+   * @covers ::loadMultiple
    */
-  public function testLoadMultiple() {
+  public function testLoadMultiple(): void {
     $this->setupTestLoad();
 
     $class_name = get_class($this->entity);
 
-    $entity_type_repository = $this->getMockForAbstractClass(EntityTypeRepositoryInterface::class);
+    $entity_type_repository = $this->createMock(EntityTypeRepositoryInterface::class);
     $entity_type_repository->expects($this->once())
       ->method('getEntityTypeFromClass')
       ->with($class_name)
@@ -308,20 +316,20 @@ class EntityUnitTest extends UnitTestCase {
 
     \Drupal::getContainer()->set('entity_type.repository', $entity_type_repository);
 
-    // Call Entity::loadMultiple statically and check that it returns the mock
-    // entity.
+    // Call EntityBase::loadMultiple() statically and check that it returns the
+    // mock entity.
     $this->assertSame([1 => $this->entity], $class_name::loadMultiple([1]));
   }
 
   /**
    * @covers ::create
    */
-  public function testCreate() {
+  public function testCreate(): void {
     $this->setupTestLoad();
 
     $class_name = get_class($this->entity);
 
-    $entity_type_repository = $this->getMockForAbstractClass(EntityTypeRepositoryInterface::class);
+    $entity_type_repository = $this->createMock(EntityTypeRepositoryInterface::class);
     $entity_type_repository->expects($this->once())
       ->method('getEntityTypeFromClass')
       ->with($class_name)
@@ -340,7 +348,7 @@ class EntityUnitTest extends UnitTestCase {
 
     \Drupal::getContainer()->set('entity_type.repository', $entity_type_repository);
 
-    // Call Entity::create() statically and check that it returns the mock
+    // Call EntityBase::create() statically and check that it returns the mock
     // entity.
     $this->assertSame($this->entity, $class_name::create([]));
   }
@@ -348,7 +356,7 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::save
    */
-  public function testSave() {
+  public function testSave(): void {
     $storage = $this->createMock('\Drupal\Core\Entity\EntityStorageInterface');
     $storage->expects($this->once())
       ->method('save')
@@ -365,7 +373,7 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::delete
    */
-  public function testDelete() {
+  public function testDelete(): void {
     $this->entity->id = $this->randomMachineName();
     $storage = $this->createMock('\Drupal\Core\Entity\EntityStorageInterface');
     // Testing the argument of the delete() method consumes too much memory.
@@ -383,14 +391,14 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::getEntityTypeId
    */
-  public function testGetEntityTypeId() {
+  public function testGetEntityTypeId(): void {
     $this->assertSame($this->entityTypeId, $this->entity->getEntityTypeId());
   }
 
   /**
    * @covers ::preSave
    */
-  public function testPreSave() {
+  public function testPreSave(): void {
     // This method is internal, so check for errors on calling it only.
     $storage = $this->createMock('\Drupal\Core\Entity\EntityStorageInterface');
     // Our mocked entity->preSave() returns NULL, so assert that.
@@ -400,57 +408,29 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::postSave
    */
-  public function testPostSave() {
-    $this->cacheTagsInvalidator->expects($this->exactly(2))
-      ->method('invalidateTags')
-      ->withConsecutive([
-        [
-          // List cache tag.
-          $this->entityTypeId . '_list',
-        ],
-      ],
-      [
-        [
-          // List cache tag.
-          $this->entityTypeId . '_list',
-          // Own cache tag.
-          $this->entityTypeId . ':' . $this->values['id'],
-        ],
-      ]);
-
+  public function testPostSave(): void {
     // This method is internal, so check for errors on calling it only.
     $storage = $this->createMock('\Drupal\Core\Entity\EntityStorageInterface');
 
     // A creation should trigger the invalidation of the "list" cache tag.
     $this->entity->postSave($storage, FALSE);
+    $this->cacheTagsInvalidator->invalidateTags([
+      $this->entityTypeId . '_list',
+    ])->shouldHaveBeenCalledOnce();
+
     // An update should trigger the invalidation of both the "list" and the
     // "own" cache tags.
     $this->entity->postSave($storage, TRUE);
+    $this->cacheTagsInvalidator->invalidateTags([
+      $this->entityTypeId . '_list',
+      $this->entityTypeId . ':' . $this->values['id'],
+    ])->shouldHaveBeenCalledOnce();
   }
 
   /**
    * @covers ::postSave
    */
-  public function testPostSaveBundle() {
-    $this->cacheTagsInvalidator->expects($this->exactly(2))
-      ->method('invalidateTags')
-      ->withConsecutive([
-        [
-          // List cache tag.
-          $this->entityTypeId . '_list',
-          $this->entityTypeId . '_list:' . $this->entity->bundle(),
-        ],
-      ],
-      [
-        [
-          // List cache tag.
-          $this->entityTypeId . '_list',
-          $this->entityTypeId . '_list:' . $this->entity->bundle(),
-          // Own cache tag.
-          $this->entityTypeId . ':' . $this->values['id'],
-        ],
-      ]);
-
+  public function testPostSaveBundle(): void {
     $this->entityType->expects($this->atLeastOnce())
       ->method('hasKey')
       ->with('bundle')
@@ -462,15 +442,25 @@ class EntityUnitTest extends UnitTestCase {
     // A creation should trigger the invalidation of the global list cache tag
     // and the one for the bundle.
     $this->entity->postSave($storage, FALSE);
+    $this->cacheTagsInvalidator->invalidateTags([
+      $this->entityTypeId . '_list',
+      $this->entityTypeId . '_list:' . $this->entity->bundle(),
+    ])->shouldHaveBeenCalledOnce();
+
     // An update should trigger the invalidation of the "list", bundle list and
     // the "own" cache tags.
     $this->entity->postSave($storage, TRUE);
+    $this->cacheTagsInvalidator->invalidateTags([
+      $this->entityTypeId . '_list',
+      $this->entityTypeId . '_list:' . $this->entity->bundle(),
+      $this->entityTypeId . ':' . $this->values['id'],
+    ])->shouldHaveBeenCalledOnce();
   }
 
   /**
    * @covers ::preCreate
    */
-  public function testPreCreate() {
+  public function testPreCreate(): void {
     // This method is internal, so check for errors on calling it only.
     $storage = $this->createMock('\Drupal\Core\Entity\EntityStorageInterface');
     $values = [];
@@ -481,7 +471,7 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::postCreate
    */
-  public function testPostCreate() {
+  public function testPostCreate(): void {
     // This method is internal, so check for errors on calling it only.
     $storage = $this->createMock('\Drupal\Core\Entity\EntityStorageInterface');
     // Our mocked entity->postCreate() returns NULL, so assert that.
@@ -491,7 +481,7 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::preDelete
    */
-  public function testPreDelete() {
+  public function testPreDelete(): void {
     // This method is internal, so check for errors on calling it only.
     $storage = $this->createMock('\Drupal\Core\Entity\EntityStorageInterface');
     // Our mocked entity->preDelete() returns NULL, so assert that.
@@ -501,13 +491,7 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::postDelete
    */
-  public function testPostDelete() {
-    $this->cacheTagsInvalidator->expects($this->once())
-      ->method('invalidateTags')
-      ->with([
-        $this->entityTypeId . '_list',
-        $this->entityTypeId . ':' . $this->values['id'],
-      ]);
+  public function testPostDelete(): void {
     $storage = $this->createMock('\Drupal\Core\Entity\EntityStorageInterface');
     $storage->expects($this->once())
       ->method('getEntityType')
@@ -515,24 +499,17 @@ class EntityUnitTest extends UnitTestCase {
 
     $entities = [$this->values['id'] => $this->entity];
     $this->entity->postDelete($storage, $entities);
+
+    $this->cacheTagsInvalidator->invalidateTags([
+      $this->entityTypeId . '_list',
+      $this->entityTypeId . ':' . $this->values['id'],
+    ])->shouldHaveBeenCalledOnce();
   }
 
   /**
    * @covers ::postDelete
    */
-  public function testPostDeleteBundle() {
-    $this->cacheTagsInvalidator->expects($this->once())
-      ->method('invalidateTags')
-      // with() also asserts on the order of array values and array keys that
-      // is something we should avoid here.
-      ->willReturnCallback(function (array $tags) {
-        self::assertEqualsCanonicalizing([
-          $this->entityTypeId . '_list',
-          $this->entityTypeId . ':' . $this->values['id'],
-          $this->entityTypeId . '_list:' . $this->entity->bundle(),
-        ], $tags);
-        return NULL;
-      });
+  public function testPostDeleteBundle(): void {
     $this->entityType->expects($this->atLeastOnce())
       ->method('hasKey')
       ->with('bundle')
@@ -544,12 +521,20 @@ class EntityUnitTest extends UnitTestCase {
 
     $entities = [$this->values['id'] => $this->entity];
     $this->entity->postDelete($storage, $entities);
+
+    // We avoid asserting on the order of array values, just that the values
+    // all exist.
+    $this->cacheTagsInvalidator->invalidateTags(Argument::allOf(
+      Argument::containing($this->entityTypeId . '_list'),
+      Argument::containing($this->entityTypeId . ':' . $this->values['id']),
+      Argument::containing($this->entityTypeId . '_list:' . $this->entity->bundle()),
+    ))->shouldHaveBeenCalledOnce();
   }
 
   /**
    * @covers ::postLoad
    */
-  public function testPostLoad() {
+  public function testPostLoad(): void {
     // This method is internal, so check for errors on calling it only.
     $storage = $this->createMock('\Drupal\Core\Entity\EntityStorageInterface');
     $entities = [$this->entity];
@@ -560,7 +545,7 @@ class EntityUnitTest extends UnitTestCase {
   /**
    * @covers ::referencedEntities
    */
-  public function testReferencedEntities() {
+  public function testReferencedEntities(): void {
     $this->assertSame([], $this->entity->referencedEntities());
   }
 
@@ -569,7 +554,7 @@ class EntityUnitTest extends UnitTestCase {
    * @covers ::getCacheTagsToInvalidate
    * @covers ::addCacheTags
    */
-  public function testCacheTags() {
+  public function testCacheTags(): void {
     // Ensure that both methods return the same by default.
     $this->assertEqualsCanonicalizing([$this->entityTypeId . ':' . 1], $this->entity->getCacheTags());
     $this->assertEqualsCanonicalizing([$this->entityTypeId . ':' . 1], $this->entity->getCacheTagsToInvalidate());
@@ -589,7 +574,7 @@ class EntityUnitTest extends UnitTestCase {
    * @covers ::getCacheContexts
    * @covers ::addCacheContexts
    */
-  public function testCacheContexts() {
+  public function testCacheContexts(): void {
     $cache_contexts_manager = $this->getMockBuilder('Drupal\Core\Cache\Context\CacheContextsManager')
       ->disableOriginalConstructor()
       ->getMock();
@@ -611,7 +596,7 @@ class EntityUnitTest extends UnitTestCase {
    * @covers ::getCacheMaxAge
    * @covers ::mergeCacheMaxAge
    */
-  public function testCacheMaxAge() {
+  public function testCacheMaxAge(): void {
     // Cache max age is permanent by default.
     $this->assertEquals(Cache::PERMANENT, $this->entity->getCacheMaxAge());
 
@@ -623,11 +608,3 @@ class EntityUnitTest extends UnitTestCase {
   }
 
 }
-
-class EntityBaseTest extends EntityBase {
-  public $id;
-  public $langcode;
-  public $uuid;
-  public $label;
-
-}
