@@ -5,7 +5,9 @@ declare(strict_types=1);
 namespace Drupal\Tests\Core\Logger;
 
 use Drupal\Core\Logger\LoggerChannelFactory;
+use Drupal\Core\Session\AccountInterface;
 use Drupal\Tests\UnitTestCase;
+use Symfony\Component\HttpFoundation\RequestStack;
 
 /**
  * @coversDefaultClass \Drupal\Core\Logger\LoggerChannelFactory
@@ -18,9 +20,11 @@ class LoggerChannelFactoryTest extends UnitTestCase {
    *
    * @covers ::get
    */
-  public function testGet() {
-    $factory = new LoggerChannelFactory();
-    $factory->setContainer($this->createMock('Symfony\Component\DependencyInjection\ContainerInterface'));
+  public function testGet(): void {
+    $factory = new LoggerChannelFactory(
+      $this->createMock(RequestStack::class),
+      $this->createMock(AccountInterface::class),
+    );
 
     // Ensure that when called with the same argument, always the same instance
     // will be returned.
@@ -28,3 +32,12 @@ class LoggerChannelFactoryTest extends UnitTestCase {
   }
 
 }
+
+/**
+ * Call to test a logger channel class with no constructor.
+ */
+class LoggerChannelWithoutConstructor extends LoggerChannelFactory {
+
+  public function __construct() {}
+
+}
