@@ -1,15 +1,17 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\Tests\Core\Render\RendererBubblingTest.
- */
+declare(strict_types=1);
 
 namespace Drupal\Tests\Core\Render;
 
+use Drupal\Component\Datetime\Time;
+use Drupal\Component\Datetime\TimeInterface;
+use Drupal\Core\Cache\CacheableMetadata;
 use Drupal\Core\Cache\MemoryBackend;
+use Drupal\Core\Cache\VariationCache;
 use Drupal\Core\KeyValueStore\KeyValueMemoryFactory;
 use Drupal\Core\Security\TrustedCallbackInterface;
+use Drupal\Core\Lock\NullLockBackend;
 use Drupal\Core\State\State;
 use Drupal\Core\Cache\Cache;
 
@@ -33,9 +35,9 @@ class RendererBubblingTest extends RendererTestBase {
   /**
    * Tests bubbling of assets when NOT using #pre_render callbacks.
    */
-  public function testBubblingWithoutPreRender() {
+  public function testBubblingWithoutPreRender(): void {
     $this->setUpRequest();
-    $this->setupMemoryCache();
+    $this->setUpMemoryCache();
 
     $this->cacheContextsManager->expects($this->any())
       ->method('convertTokensToKeys')
@@ -46,7 +48,7 @@ class RendererBubblingTest extends RendererTestBase {
     $element = [
       '#type' => 'container',
       '#cache' => [
-        'keys' => ['simpletest', 'renderer', 'children_attached'],
+        'keys' => ['test', 'renderer', 'children_attached'],
       ],
       '#attached' => ['library' => ['test/parent']],
       '#title' => 'Parent',
@@ -68,7 +70,7 @@ class RendererBubblingTest extends RendererTestBase {
 
     // Load the element from cache and verify the presence of the #attached
     // JavaScript.
-    $element = ['#cache' => ['keys' => ['simpletest', 'renderer', 'children_attached']]];
+    $element = ['#cache' => ['keys' => ['test', 'renderer', 'children_attached']]];
     // Verify that the element was retrieved from the cache.
     $this->assertNotEmpty($this->renderer->renderRoot($element));
     $this->assertEquals($element['#attached']['library'], $expected_libraries, 'The element, child and subchild #attached libraries are included.');
@@ -77,12 +79,12 @@ class RendererBubblingTest extends RendererTestBase {
   /**
    * Tests cache context bubbling with a custom cache bin.
    */
-  public function testContextBubblingCustomCacheBin() {
+  public function testContextBubblingCustomCacheBin(): void {
     $bin = $this->randomMachineName();
 
     $this->setUpRequest();
-    $this->memoryCache = new MemoryBackend();
-    $custom_cache = new MemoryBackend();
+    $this->memoryCache = new VariationCache($this->requestStack, new MemoryBackend(new Time($this->requestStack)), $this->cacheContextsManager);
+    $custom_cache = new VariationCache($this->requestStack, new MemoryBackend(new Time($this->requestStack)), $this->cacheContextsManager);
 
     $this->cacheFactory->expects($this->atLeastOnce())
       ->method('get')
@@ -115,15 +117,14 @@ class RendererBubblingTest extends RendererTestBase {
     ];
     $this->renderer->renderRoot($build);
 
-    $this->assertRenderCacheItem('parent:foo', [
-      '#cache_redirect' => TRUE,
+    $this->assertRenderCacheItem(['parent'], [
+      '#attached' => [],
       '#cache' => [
-        'keys' => ['parent'],
         'contexts' => ['bar', 'foo'],
         'tags' => [],
-        'bin' => $bin,
         'max-age' => 3600,
       ],
+      '#markup' => 'parent',
     ], $bin);
   }
 
@@ -134,22 +135,20 @@ class RendererBubblingTest extends RendererTestBase {
    *
    * @dataProvider providerTestContextBubblingEdgeCases
    */
-  public function testContextBubblingEdgeCases(array $element, array $expected_top_level_contexts, array $expected_cache_items) {
+  public function testContextBubblingEdgeCases(array $element, array $expected_top_level_contexts, $expected_cache_item): void {
     $this->setUpRequest();
-    $this->setupMemoryCache();
+    $this->setUpMemoryCache();
     $this->cacheContextsManager->expects($this->any())
       ->method('convertTokensToKeys')
       ->willReturnArgument(0);
 
     $this->renderer->renderRoot($element);
 
-    $this->assertEquals($expected_top_level_contexts, $element['#cache']['contexts'], 'Expected cache contexts found.');
-    foreach ($expected_cache_items as $cid => $expected_cache_item) {
-      $this->assertRenderCacheItem($cid, $expected_cache_item);
-    }
+    $this->assertEqualsCanonicalizing($expected_top_level_contexts, $element['#cache']['contexts'], 'Expected cache contexts found.');
+    $this->assertRenderCacheItem($element['#cache']['keys'], $expected_cache_item);
   }
 
-  public function providerTestContextBubblingEdgeCases() {
+  public static function providerTestContextBubblingEdgeCases() {
     $data = [];
 
     // Cache contexts of inaccessible children aren't bubbled (because those
@@ -167,39 +166,35 @@ class RendererBubblingTest extends RendererTestBase {
         ],
       ],
     ];
-    $expected_cache_items = [
-      'parent' => [
-        '#attached' => [],
-        '#cache' => [
-          'contexts' => [],
-          'tags' => [],
-          'max-age' => Cache::PERMANENT,
-        ],
-        '#markup' => 'parent',
+    $expected_cache_item = [
+      '#attached' => [],
+      '#cache' => [
+        'contexts' => [],
+        'tags' => [],
+        'max-age' => Cache::PERMANENT,
       ],
+      '#markup' => 'parent',
     ];
-    $data[] = [$test_element, [], $expected_cache_items];
+    $data[] = [$test_element, [], $expected_cache_item];
 
     // Assert cache contexts are sorted when they are used to generate a CID.
     // (Necessary to ensure that different render arrays where the same keys +
     // set of contexts are present point to the same cache item. Regardless of
     // the contexts' order. A sad necessity because PHP doesn't have sets.)
     $test_element = [
-     '#cache' => [
+      '#cache' => [
         'keys' => ['set_test'],
         'contexts' => [],
       ],
     ];
-    $expected_cache_items = [
-      'set_test:bar:baz:foo' => [
-        '#attached' => [],
-        '#cache' => [
-          'contexts' => [],
-          'tags' => [],
-          'max-age' => Cache::PERMANENT,
-        ],
-        '#markup' => '',
+    $expected_cache_item = [
+      '#attached' => [],
+      '#cache' => [
+        'contexts' => [],
+        'tags' => [],
+        'max-age' => Cache::PERMANENT,
       ],
+      '#markup' => '',
     ];
     $context_orders = [
       ['foo', 'bar', 'baz'],
@@ -211,9 +206,8 @@ class RendererBubblingTest extends RendererTestBase {
     ];
     foreach ($context_orders as $context_order) {
       $test_element['#cache']['contexts'] = $context_order;
-      sort($context_order);
-      $expected_cache_items['set_test:bar:baz:foo']['#cache']['contexts'] = $context_order;
-      $data[] = [$test_element, $context_order, $expected_cache_items];
+      $expected_cache_item['#cache']['contexts'] = $context_order;
+      $data[] = [$test_element, $context_order, $expected_cache_item];
     }
 
     // A parent with a certain set of cache contexts is unaffected by a child
@@ -231,18 +225,16 @@ class RendererBubblingTest extends RendererTestBase {
         ],
       ],
     ];
-    $expected_cache_items = [
-      'parent:bar:baz:foo' => [
-        '#attached' => [],
-        '#cache' => [
-          'contexts' => ['bar', 'baz', 'foo'],
-          'tags' => [],
-          'max-age' => 3600,
-        ],
-        '#markup' => 'parent',
+    $expected_cache_item = [
+      '#attached' => [],
+      '#cache' => [
+        'contexts' => ['foo', 'bar', 'baz'],
+        'tags' => [],
+        'max-age' => 3600,
       ],
+      '#markup' => 'parent',
     ];
-    $data[] = [$test_element, ['bar', 'baz', 'foo'], $expected_cache_items];
+    $data[] = [$test_element, ['bar', 'baz', 'foo'], $expected_cache_item];
 
     // A parent with a certain set of cache contexts that is a subset of the
     // cache contexts of a child gets a redirecting cache item for the cache ID
@@ -268,33 +260,21 @@ class RendererBubblingTest extends RendererTestBase {
         '#markup' => '',
       ],
     ];
-    $expected_cache_items = [
-      'parent:foo' => [
-        '#cache_redirect' => TRUE,
-        '#cache' => [
-          // The keys + contexts this redirects to.
-          'keys' => ['parent'],
-          'contexts' => ['bar', 'foo'],
-          'tags' => ['dee', 'fiddle', 'har', 'yar'],
-          'bin' => 'render',
-          'max-age' => Cache::PERMANENT,
-        ],
-      ],
-      'parent:bar:foo' => [
-        '#attached' => [],
-        '#cache' => [
-          'contexts' => ['bar', 'foo'],
-          'tags' => ['dee', 'fiddle', 'har', 'yar'],
-          'max-age' => Cache::PERMANENT,
-        ],
-        '#markup' => 'parent',
+    $expected_cache_item = [
+      '#attached' => [],
+      '#cache' => [
+        'contexts' => ['foo', 'bar'],
+        'tags' => ['yar', 'har', 'fiddle', 'dee'],
+        'max-age' => Cache::PERMANENT,
       ],
+      '#markup' => 'parent',
     ];
-    $data[] = [$test_element, ['bar', 'foo'], $expected_cache_items];
+    $data[] = [$test_element, ['bar', 'foo'], $expected_cache_item];
 
     // Ensure that bubbleable metadata has been collected from children and set
-    // correctly to the main level of the render array. That ensures that correct
-    // bubbleable metadata exists if render array gets rendered multiple times.
+    // correctly to the main level of the render array. That ensures that
+    // correct bubbleable metadata exists if render array gets rendered multiple
+    // times.
     $test_element = [
       '#cache' => [
         'keys' => ['parent'],
@@ -315,30 +295,31 @@ class RendererBubblingTest extends RendererTestBase {
         ],
       ],
     ];
-    $expected_cache_items = [
-      'parent:foo' => [
-        '#attached' => ['library' => ['foo/bar']],
-        '#cache' => [
-          'contexts' => ['foo'],
-          'tags' => ['dee', 'fiddle', 'har', 'yar'],
-          'max-age' => Cache::PERMANENT,
-        ],
-        '#markup' => 'parent',
+    $expected_cache_item = [
+      '#attached' => ['library' => ['foo/bar']],
+      '#cache' => [
+        'contexts' => ['foo'],
+        'tags' => ['yar', 'har', 'fiddle', 'dee'],
+        'max-age' => Cache::PERMANENT,
       ],
+      '#markup' => 'parent',
     ];
-    $data[] = [$test_element, ['foo'], $expected_cache_items];
+    $data[] = [$test_element, ['foo'], $expected_cache_item];
 
     return $data;
   }
 
   /**
    * Tests the self-healing of the redirect with conditional cache contexts.
+   *
+   * @todo Revisit now that we have self-healing tests for VariationCache. This
+   * is essentially a clone of the other bubbling tests now.
    */
-  public function testConditionalCacheContextBubblingSelfHealing() {
+  public function testConditionalCacheContextBubblingSelfHealing(): void {
     $current_user_role = &$this->currentUserRole;
 
     $this->setUpRequest();
-    $this->setupMemoryCache();
+    $this->setUpMemoryCache();
 
     $test_element = [
       '#cache' => [
@@ -362,7 +343,7 @@ class RendererBubblingTest extends RendererTestBase {
             // A lower max-age; the redirecting cache item should be updated.
             'max-age' => 1800,
           ],
-          'grandgrandchild' => [
+          'great grandchild' => [
             '#access_callback' => function () use (&$current_user_role) {
               // Only role C can access this subtree.
               return $current_user_role === 'C';
@@ -383,17 +364,7 @@ class RendererBubblingTest extends RendererTestBase {
     $element = $test_element;
     $current_user_role = 'A';
     $this->renderer->renderRoot($element);
-    $this->assertRenderCacheItem('parent', [
-      '#cache_redirect' => TRUE,
-      '#cache' => [
-        'keys' => ['parent'],
-        'contexts' => ['user.roles'],
-        'tags' => ['a', 'b'],
-        'bin' => 'render',
-        'max-age' => Cache::PERMANENT,
-      ],
-    ]);
-    $this->assertRenderCacheItem('parent:r.A', [
+    $this->assertRenderCacheItem(['parent'], [
       '#attached' => [],
       '#cache' => [
         'contexts' => ['user.roles'],
@@ -408,122 +379,62 @@ class RendererBubblingTest extends RendererTestBase {
     $element = $test_element;
     $current_user_role = 'B';
     $this->renderer->renderRoot($element);
-    $this->assertRenderCacheItem('parent', [
-      '#cache_redirect' => TRUE,
-      '#cache' => [
-        'keys' => ['parent'],
-        'contexts' => ['foo', 'user.roles'],
-        'tags' => ['a', 'b', 'c'],
-        'bin' => 'render',
-        'max-age' => 1800,
-      ],
-    ]);
-    $this->assertRenderCacheItem('parent:foo:r.B', [
+    $this->assertRenderCacheItem(['parent'], [
       '#attached' => [],
       '#cache' => [
-        'contexts' => ['foo', 'user.roles'],
+        'contexts' => ['user.roles', 'foo'],
         'tags' => ['a', 'b', 'c'],
         'max-age' => 1800,
       ],
       '#markup' => 'parent',
     ]);
 
-    // Request 3: role A again, the grandchild is inaccessible again => bubbled
-    // cache contexts: user.roles; but that's a subset of the already-bubbled
-    // cache contexts, so nothing is actually changed in the redirecting cache
-    // item. However, the cache item we were looking for in request 1 is
-    // technically the same one we're looking for now (it's the exact same
-    // request), but with one additional cache context. This is necessary to
-    // avoid "cache ping-pong". (Requests 1 and 3 are identical, but without the
-    // right merging logic to handle request 2, the redirecting cache item would
-    // toggle between only the 'user.roles' cache context and both the 'foo'
-    // and 'user.roles' cache contexts, resulting in a cache miss every time.)
-    $element = $test_element;
+    // Verify that request 1 is still cached and accessible.
     $current_user_role = 'A';
-    $this->renderer->renderRoot($element);
-    $this->assertRenderCacheItem('parent', [
-      '#cache_redirect' => TRUE,
-      '#cache' => [
-        'keys' => ['parent'],
-        'contexts' => ['foo', 'user.roles'],
-        'tags' => ['a', 'b', 'c'],
-        'bin' => 'render',
-        'max-age' => 1800,
-      ],
-    ]);
-    $this->assertRenderCacheItem('parent:foo:r.A', [
+    $this->assertRenderCacheItem(['parent'], [
       '#attached' => [],
       '#cache' => [
-        'contexts' => ['foo', 'user.roles'],
+        'contexts' => ['user.roles'],
         'tags' => ['a', 'b'],
-        // Note that the max-age here is unaffected. When role A, the grandchild
-        // is never rendered, so neither is its max-age of 1800 present here,
-        // despite 1800 being the max-age of the redirecting cache item.
         'max-age' => Cache::PERMANENT,
       ],
       '#markup' => 'parent',
     ]);
 
-    // Request 4: role C, both the grandchild and the grandgrandchild are
+    // Request 3: role C, both the grandchild and the great grandchild are
     // accessible => bubbled cache contexts: foo, bar, user.roles + merged
     // max-age: 300.
     $element = $test_element;
     $current_user_role = 'C';
     $this->renderer->renderRoot($element);
-    $final_parent_cache_item = [
-      '#cache_redirect' => TRUE,
-      '#cache' => [
-        'keys' => ['parent'],
-        'contexts' => ['bar', 'foo', 'user.roles'],
-        'tags' => ['a', 'b', 'c', 'd'],
-        'bin' => 'render',
-        'max-age' => 300,
-      ],
-    ];
-    $this->assertRenderCacheItem('parent', $final_parent_cache_item);
-    $this->assertRenderCacheItem('parent:bar:foo:r.C', [
+    $this->assertRenderCacheItem(['parent'], [
       '#attached' => [],
       '#cache' => [
-        'contexts' => ['bar', 'foo', 'user.roles'],
+        'contexts' => ['user.roles', 'foo', 'bar'],
         'tags' => ['a', 'b', 'c', 'd'],
         'max-age' => 300,
       ],
       '#markup' => 'parent',
     ]);
 
-    // Request 5: role A again, verifying the merging like we did for request 3.
-    $element = $test_element;
+    // Verify that request 2 and 3 are still cached and accessible.
     $current_user_role = 'A';
-    $this->renderer->renderRoot($element);
-    $this->assertRenderCacheItem('parent', $final_parent_cache_item);
-    $this->assertRenderCacheItem('parent:bar:foo:r.A', [
+    $this->assertRenderCacheItem(['parent'], [
       '#attached' => [],
       '#cache' => [
-        'contexts' => ['bar', 'foo', 'user.roles'],
+        'contexts' => ['user.roles'],
         'tags' => ['a', 'b'],
-        // Note that the max-age here is unaffected. When role A, the grandchild
-        // is never rendered, so neither is its max-age of 1800 present here,
-        // nor the grandgrandchild's max-age of 300, despite 300 being the
-        // max-age of the redirecting cache item.
         'max-age' => Cache::PERMANENT,
       ],
       '#markup' => 'parent',
     ]);
 
-    // Request 6: role B again, verifying the merging like we did for request 3.
-    $element = $test_element;
     $current_user_role = 'B';
-    $this->renderer->renderRoot($element);
-    $this->assertRenderCacheItem('parent', $final_parent_cache_item);
-    $this->assertRenderCacheItem('parent:bar:foo:r.B', [
+    $this->assertRenderCacheItem(['parent'], [
       '#attached' => [],
       '#cache' => [
-        'contexts' => ['bar', 'foo', 'user.roles'],
+        'contexts' => ['user.roles', 'foo'],
         'tags' => ['a', 'b', 'c'],
-        // Note that the max-age here is unaffected. When role B, the
-        // grandgrandchild is never rendered, so neither is its max-age of 300
-        // present here, despite 300 being the max-age of the redirecting cache
-        // item.
         'max-age' => 1800,
       ],
       '#markup' => 'parent',
@@ -535,16 +446,14 @@ class RendererBubblingTest extends RendererTestBase {
    *
    * @dataProvider providerTestBubblingWithPrerender
    */
-  public function testBubblingWithPrerender($test_element) {
+  public function testBubblingWithPrerender($test_element): void {
     $this->setUpRequest();
-    $this->setupMemoryCache();
+    $this->setUpMemoryCache();
 
     // Mock the State service.
-    $memory_state = new State(new KeyValueMemoryFactory());
+    $time = $this->prophesize(TimeInterface::class)->reveal();
+    $memory_state = new State(new KeyValueMemoryFactory(), new MemoryBackend($time), new NullLockBackend());
     \Drupal::getContainer()->set('state', $memory_state);
-    $this->controllerResolver->expects($this->any())
-      ->method('getControllerFromDefinition')
-      ->willReturnArgument(0);
 
     // Simulate the theme system/Twig: a recursive call to Renderer::render(),
     // just like the theme system or a Twig template would have done.
@@ -560,13 +469,19 @@ class RendererBubblingTest extends RendererTestBase {
     // - … is not cached DOES get called.
     \Drupal::state()->set('bubbling_nested_pre_render_cached', FALSE);
     \Drupal::state()->set('bubbling_nested_pre_render_uncached', FALSE);
-    $this->memoryCache->set('cached_nested', ['#markup' => 'Cached nested!', '#attached' => [], '#cache' => ['contexts' => [], 'tags' => []]]);
+    $cacheability = new CacheableMetadata();
+    $this->memoryCache->set(
+      ['cached_nested'],
+      ['#markup' => 'Cached nested!', '#attached' => [], '#cache' => ['contexts' => [], 'tags' => []]],
+      $cacheability,
+      $cacheability
+    );
 
     // Simulate the rendering of an entire response (i.e. a root call).
-    $output = $this->renderer->renderRoot($test_element);
+    $output = (string) $this->renderer->renderRoot($test_element);
 
     // First, assert the render array is of the expected form.
-    $this->assertEquals('Cache context!Cache tag!Asset!Placeholder!barquxNested!Cached nested!', trim($output), 'Expected HTML generated.');
+    $this->assertEquals('Cache context!Cache tag!Asset!Placeholder!barstoolNested!Cached nested!', trim($output), 'Expected HTML generated.');
     $this->assertEquals(['child.cache_context'], $test_element['#cache']['contexts'], 'Expected cache contexts found.');
     $this->assertEquals(['child:cache_tag'], $test_element['#cache']['tags'], 'Expected cache tags found.');
     $expected_attached = [
@@ -586,8 +501,9 @@ class RendererBubblingTest extends RendererTestBase {
    * Provides two test elements: one without, and one with the theme system.
    *
    * @return array
+   *   An array of test cases, each containing a render array with different configurations.
    */
-  public function providerTestBubblingWithPrerender() {
+  public static function providerTestBubblingWithPrerender() {
     $data = [];
 
     // Test element without theme.
@@ -615,15 +531,15 @@ class RendererBubblingTest extends RendererTestBase {
   /**
    * Tests that an element's cache keys cannot be changed during its rendering.
    */
-  public function testOverWriteCacheKeys() {
+  public function testOverWriteCacheKeys(): void {
     $this->setUpRequest();
-    $this->setupMemoryCache();
+    $this->setUpMemoryCache();
 
     // Ensure a logic exception
     $data = [
       '#cache' => [
         'keys' => ['llama', 'bar'],
-       ],
+      ],
       '#pre_render' => [__NAMESPACE__ . '\\BubblingTest::bubblingCacheOverwritePrerender'],
     ];
     $this->expectException(\LogicException::class);
@@ -633,11 +549,15 @@ class RendererBubblingTest extends RendererTestBase {
 
 }
 
-
+/**
+ * Test class with implemented trusted callbacks.
+ */
 class BubblingTest implements TrustedCallbackInterface {
 
   /**
-   * #pre_render callback for testBubblingWithPrerender().
+   * Render API callback:Used for testing testBubblingWithPrerender().
+   *
+   * This function is assigned as an #pre_render callback.
    */
   public static function bubblingPreRender($elements) {
     $elements += [
@@ -661,7 +581,7 @@ class BubblingTest implements TrustedCallbackInterface {
       ],
       'child_placeholder' => [
         '#create_placeholder' => TRUE,
-        '#lazy_builder' => [__CLASS__ . '::bubblingPlaceholder', ['bar', 'qux']],
+        '#lazy_builder' => [__CLASS__ . '::bubblingPlaceholder', ['bar', 'stool']],
       ],
       'child_nested_pre_render_uncached' => [
         '#cache' => ['keys' => ['uncached_nested']],
@@ -676,7 +596,9 @@ class BubblingTest implements TrustedCallbackInterface {
   }
 
   /**
-   * #pre_render callback for testBubblingWithPrerender().
+   * Render API callback: Used for testing testBubblingWithPrerender().
+   *
+   * This function is assigned as an #pre_render callback in
    */
   public static function bubblingNestedPreRenderUncached($elements) {
     \Drupal::state()->set('bubbling_nested_pre_render_uncached', TRUE);
@@ -685,7 +607,9 @@ class BubblingTest implements TrustedCallbackInterface {
   }
 
   /**
-   * #pre_render callback for testBubblingWithPrerender().
+   * Render API callback: Used for testing testBubblingWithPrerender().
+   *
+   * This function is assigned as an #pre_render callback in
    */
   public static function bubblingNestedPreRenderCached($elements) {
     \Drupal::state()->set('bubbling_nested_pre_render_cached', TRUE);
@@ -693,7 +617,9 @@ class BubblingTest implements TrustedCallbackInterface {
   }
 
   /**
-   * #lazy_builder callback for testBubblingWithPrerender().
+   * Render API callback: Used for testing testBubblingWithPrerender().
+   *
+   * This function is assigned as an #lazy_builder callback in
    */
   public static function bubblingPlaceholder($foo, $baz) {
     return [
@@ -702,7 +628,9 @@ class BubblingTest implements TrustedCallbackInterface {
   }
 
   /**
-   * #pre_render callback for testOverWriteCacheKeys().
+   * Render API callback: Used for testing testOverWriteCacheKeys().
+   *
+   * This function is assigned as an #pre_render callback in
    */
   public static function bubblingCacheOverwritePrerender($elements) {
     // Overwrite the #cache entry with new data.
