@@ -14,6 +14,8 @@ use Drupal\Core\Security\TrustedCallbackInterface;
 use Drupal\Core\Render\Element;
 use Drupal\Core\Render\Markup;
 use Drupal\Core\Template\Attribute;
+use Drupal\Core\Theme\ThemeManagerInterface;
+use PHPUnit\Framework\MockObject\MockObject;
 
 // cspell:ignore fooalert
 
@@ -23,6 +25,11 @@ use Drupal\Core\Template\Attribute;
  */
 class RendererTest extends RendererTestBase {
 
+  /**
+   * The expected theme variables.
+   *
+   * @var array
+   */
   protected $defaultThemeVars = [
     '#cache' => [
       'contexts' => [
@@ -45,7 +52,7 @@ class RendererTest extends RendererTestBase {
   public function testRenderBasic($build, $expected, ?callable $setup_code = NULL): void {
     if (isset($setup_code)) {
       $setup_code = $setup_code->bindTo($this);
-      $setup_code($this->themeManager);
+      $setup_code($this->themeManager, $this);
     }
 
     if (isset($build['#markup'])) {
@@ -63,8 +70,9 @@ class RendererTest extends RendererTestBase {
    * Provides a list of render arrays to test basic rendering.
    *
    * @return array
+   *   An array of render arrays and their expected output.
    */
-  public static function providerTestRenderBasic() {
+  public static function providerTestRenderBasic(): array {
     $data = [];
 
     // Part 1: the most simplistic render arrays possible, none using #theme.
@@ -267,8 +275,8 @@ class RendererTest extends RendererTestBase {
       '#theme_wrappers' => ['container'],
       '#attributes' => ['class' => ['baz']],
     ];
-    $setup_code_type_link = function ($themeManager) {
-      $themeManager->expects(static::exactly(2))
+    $setup_code_type_link = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->exactly(2))
         ->method('render')
         ->with(static::logicalOr('common_test_foo', 'container'))
         ->willReturnCallback(function ($theme, $vars) {
@@ -294,8 +302,8 @@ class RendererTest extends RendererTestBase {
       '#url' => 'https://www.drupal.org',
       '#title' => 'bar',
     ];
-    $setup_code_type_link = function ($themeManager) {
-      $themeManager->expects(static::exactly(2))
+    $setup_code_type_link = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->exactly(2))
         ->method('render')
         ->with(static::logicalOr('link', 'container'))
         ->willReturnCallback(function ($theme, $vars) {
@@ -333,8 +341,8 @@ class RendererTest extends RendererTestBase {
         'container',
       ],
     ];
-    $setup_code = function ($themeManager) {
-      $themeManager->expects(static::exactly(2))
+    $setup_code = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->exactly(2))
         ->method('render')
         ->with('container')
         ->willReturnCallback(function ($theme, $vars) {
@@ -348,8 +356,8 @@ class RendererTest extends RendererTestBase {
       '#theme_wrappers' => [['container']],
       '#attributes' => ['class' => ['foo']],
     ];
-    $setup_code = function ($themeManager) {
-      $themeManager->expects(static::once())
+    $setup_code = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->once())
         ->method('render')
         ->with(['container'])
         ->willReturnCallback(function ($theme, $vars) {
@@ -365,10 +373,10 @@ class RendererTest extends RendererTestBase {
       '#theme' => ['suggestion_not_implemented'],
       '#markup' => 'foo',
     ];
-    $setup_code = function ($themeManager) {
-      $themeManager->expects(static::once())
+    $setup_code = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->once())
         ->method('render')
-        ->with(['suggestion_not_implemented'], static::anything())
+        ->with(['suggestion_not_implemented'], $testCase->anything())
         ->willReturn(FALSE);
     };
     $data[] = [$build, 'foo', $setup_code];
@@ -380,10 +388,10 @@ class RendererTest extends RendererTestBase {
         '#markup' => 'foo',
       ],
     ];
-    $setup_code = function ($themeManager) {
-      $themeManager->expects(static::once())
+    $setup_code = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->once())
         ->method('render')
-        ->with(['suggestion_not_implemented'], static::anything())
+        ->with(['suggestion_not_implemented'], $testCase->anything())
         ->willReturn(FALSE);
     };
     $data[] = [$build, 'foo', $setup_code];
@@ -394,10 +402,10 @@ class RendererTest extends RendererTestBase {
       '#markup' => 'foo',
     ];
     $theme_function_output = static::randomContextValue();
-    $setup_code = function ($themeManager) use ($theme_function_output) {
-      $themeManager->expects(static::once())
+    $setup_code = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase) use ($theme_function_output): void {
+      $themeManager->expects($testCase->once())
         ->method('render')
-        ->with(['common_test_empty'], static::anything())
+        ->with(['common_test_empty'], $testCase->anything())
         ->willReturn($theme_function_output);
     };
     $data[] = [$build, $theme_function_output, $setup_code];
@@ -421,10 +429,10 @@ class RendererTest extends RendererTestBase {
       '#children' => 'baz',
       'child' => ['#markup' => 'boo'],
     ];
-    $setup_code = function ($themeManager) {
-      $themeManager->expects(static::once())
+    $setup_code = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->once())
         ->method('render')
-        ->with('common_test_foo', static::anything())
+        ->with('common_test_foo', $testCase->anything())
         ->willReturn('foobar');
     };
     $data[] = [$build, 'foobar', $setup_code];
@@ -440,8 +448,8 @@ class RendererTest extends RendererTestBase {
         '#markup' => 'boo',
       ],
     ];
-    $setup_code = function ($themeManager) {
-      $themeManager->expects(static::never())
+    $setup_code = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->never())
         ->method('render');
     };
     $data[] = [$build, 'boo', $setup_code];
@@ -456,8 +464,8 @@ class RendererTest extends RendererTestBase {
         '#markup' => 'boo',
       ],
     ];
-    $setup_code = function ($themeManager) {
-      $themeManager->expects(static::never())
+    $setup_code = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->never())
         ->method('render');
     };
     $data[] = [$build, 'baz', $setup_code];
@@ -475,8 +483,8 @@ class RendererTest extends RendererTestBase {
         '#markup' => 'kitten',
       ],
     ];
-    $setup_code = function ($themeManager) {
-      $themeManager->expects(static::never())
+    $setup_code = function (ThemeManagerInterface&MockObject $themeManager, RendererTestBase $testCase): void {
+      $themeManager->expects($testCase->never())
         ->method('render');
     };
     $data[] = [$build, 'kitten', $setup_code];
@@ -544,6 +552,40 @@ class RendererTest extends RendererTestBase {
     $this->assertLessThan(strpos($output, $first), strpos($output, $second));
   }
 
+  /**
+   * Tests that element defaults are added.
+   *
+   * @covers ::render
+   * @covers ::doRender
+   */
+  public function testElementDefaultsAdded(): void {
+    $build = ['#type' => 'details'];
+    $this->renderer->renderInIsolation($build);
+    $this->assertTrue($build['#defaults_loaded'], "An element with a type had said type's defaults loaded.");
+
+    $build = [
+      '#lazy_builder' => [
+        'Drupal\Tests\Core\Render\TestCallables::lazyBuilder',
+        [FALSE],
+      ],
+      '#create_placeholder' => FALSE,
+    ];
+
+    $this->renderer->renderInIsolation($build);
+    $this->assertArrayNotHasKey('#defaults_loaded', $build, "A lazy builder that did not set a type had no type defaults loaded.");
+
+    $build = [
+      '#lazy_builder' => [
+        'Drupal\Tests\Core\Render\TestCallables::lazyBuilder',
+        [TRUE],
+      ],
+      '#create_placeholder' => FALSE,
+    ];
+
+    $this->renderer->renderInIsolation($build);
+    $this->assertTrue($build['#defaults_loaded'], "A lazy builder that set a type had said type's defaults loaded.");
+  }
+
   /**
    * @covers ::render
    * @covers ::doRender
@@ -666,6 +708,7 @@ class RendererTest extends RendererTestBase {
    * Provides a list of render array iterations.
    *
    * @return array
+   *   An array of render arrays.
    */
   public static function providerRenderTwice() {
     return [
@@ -720,6 +763,7 @@ class RendererTest extends RendererTestBase {
    * Provides a list of both booleans.
    *
    * @return array
+   *   A list of boolean values and AccessResult objects.
    */
   public static function providerAccessValues() {
     return [
@@ -795,6 +839,7 @@ class RendererTest extends RendererTestBase {
    * Provides a list of access conditions and expected cache metadata.
    *
    * @return array
+   *   An array of access conditions and expected cache metadata.
    */
   public static function providerRenderCache() {
     return [
@@ -1083,6 +1128,9 @@ class RendererTest extends RendererTestBase {
 
 }
 
+/**
+ * Test class for mocking the access callback.
+ */
 class TestAccessClass implements TrustedCallbackInterface {
 
   public static function accessTrue() {
@@ -1110,6 +1158,9 @@ class TestAccessClass implements TrustedCallbackInterface {
 
 }
 
+/**
+ * Mock callable for testing the pre_render callback.
+ */
 class TestCallables implements TrustedCallbackInterface {
 
   public function preRenderPrinted($elements) {
@@ -1117,11 +1168,19 @@ class TestCallables implements TrustedCallbackInterface {
     return $elements;
   }
 
+  public static function lazyBuilder(bool $set_type): array {
+    $build['content'] = ['#markup' => 'Content'];
+    if ($set_type) {
+      $build['#type'] = 'details';
+    }
+    return $build;
+  }
+
   /**
    * {@inheritdoc}
    */
   public static function trustedCallbacks() {
-    return ['preRenderPrinted'];
+    return ['preRenderPrinted', 'lazyBuilder'];
   }
 
 }
