@@ -18,7 +18,7 @@ use Drupal\deprecation_test\Deprecation\FixtureDeprecatedClass;
  */
 class PhpUnitBridgeIsolatedTest extends UnitTestCase {
 
-  public function testDeprecatedClass() {
+  public function testDeprecatedClass(): void {
     $this->expectDeprecation('Drupal\deprecation_test\Deprecation\FixtureDeprecatedClass is deprecated.');
     $deprecated = new FixtureDeprecatedClass();
     $this->assertEquals('test', $deprecated->testFunction());
