@@ -120,21 +120,17 @@ class UrlTest extends UnitTestCase {
   public function testUrlFromRequest() {
     $this->router->expects($this->exactly(3))
       ->method('matchRequest')
-      ->withConsecutive(
-        [$this->getRequestConstraint('/node')],
-        [$this->getRequestConstraint('/node/1')],
-        [$this->getRequestConstraint('/node/2/edit')],
-      )
-      ->willReturnOnConsecutiveCalls([
-        RouteObjectInterface::ROUTE_NAME => 'view.frontpage.page_1',
-        '_raw_variables' => new InputBag(),
-      ], [
-        RouteObjectInterface::ROUTE_NAME => 'node_view',
-        '_raw_variables' => new InputBag(['node' => '1']),
-      ], [
-        RouteObjectInterface::ROUTE_NAME => 'node_edit',
-        '_raw_variables' => new InputBag(['node' => '2']),
-      ]);
+      ->willReturnCallback(function (Request $request) {
+        [$route_name, $vars] = match($request->getPathInfo()) {
+          '/node' => ['view.frontpage.page_1', []],
+          '/node/1' => ['node_view', ['node' => '1']],
+          '/node/2/edit' => ['node_edit', ['node' => '2']],
+        };
+        return [
+          RouteObjectInterface::ROUTE_NAME => $route_name,
+          '_raw_variables' => new InputBag($vars),
+        ];
+      });
 
     $urls = [];
     foreach ($this->map as $index => $values) {
@@ -147,27 +143,12 @@ class UrlTest extends UnitTestCase {
     return $urls;
   }
 
-  /**
-   * This constraint checks whether a Request object has the right path.
-   *
-   * @param string $path
-   *   The path.
-   *
-   * @return \PHPUnit\Framework\Constraint\Callback
-   *   The constraint checks whether a Request object has the right path.
-   */
-  protected function getRequestConstraint($path) {
-    return $this->callback(function (Request $request) use ($path) {
-      return $request->getPathInfo() == $path;
-    });
-  }
-
   /**
    * Tests the fromRoute() method with the special <front> path.
    *
    * @covers ::fromRoute
    */
-  public function testFromRouteFront() {
+  public function testFromRouteFront(): void {
     $url = Url::fromRoute('<front>');
     $this->assertSame('<front>', $url->getRouteName());
   }
@@ -178,7 +159,7 @@ class UrlTest extends UnitTestCase {
    * @covers ::fromUserInput
    * @dataProvider providerFromValidInternalUri
    */
-  public function testFromUserInput($path) {
+  public function testFromUserInput($path): void {
     $url = Url::fromUserInput($path);
     $uri = $url->getUri();
 
@@ -210,9 +191,9 @@ class UrlTest extends UnitTestCase {
    * @covers ::fromUserInput
    * @dataProvider providerFromInvalidInternalUri
    */
-  public function testFromInvalidUserInput($path) {
+  public function testFromInvalidUserInput($path): void {
     $this->expectException(\InvalidArgumentException::class);
-    $url = Url::fromUserInput($path);
+    Url::fromUserInput($path);
   }
 
   /**
@@ -220,7 +201,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::fromUri
    */
-  public function testFromRoutedPathWithInvalidRoute() {
+  public function testFromRoutedPathWithInvalidRoute(): void {
     $this->pathValidator->expects($this->once())
       ->method('getUrlIfValidWithoutAccessCheck')
       ->with('invalid-path')
@@ -235,7 +216,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::fromUri
    */
-  public function testFromRoutedPathWithValidRoute() {
+  public function testFromRoutedPathWithValidRoute(): void {
     $url = Url::fromRoute('test_route');
     $this->pathValidator->expects($this->once())
       ->method('getUrlIfValidWithoutAccessCheck')
@@ -250,7 +231,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::createFromRequest
    */
-  public function testCreateFromRequest() {
+  public function testCreateFromRequest(): void {
     $attributes = [
       '_raw_variables' => new InputBag([
         'color' => 'chartreuse',
@@ -274,7 +255,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::createFromRequest
    */
-  public function testUrlFromRequestInvalid() {
+  public function testUrlFromRequestInvalid(): void {
     $request = Request::create('/test-path');
 
     $this->router->expects($this->once())
@@ -293,7 +274,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::isExternal
    */
-  public function testIsExternal($urls) {
+  public function testIsExternal($urls): void {
     foreach ($urls as $url) {
       $this->assertFalse($url->isExternal());
     }
@@ -309,7 +290,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::getUri
    */
-  public function testGetUriForInternalUrl($urls) {
+  public function testGetUriForInternalUrl($urls): void {
     $this->expectException(\UnexpectedValueException::class);
     foreach ($urls as $url) {
       $url->getUri();
@@ -321,7 +302,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::getUri
    */
-  public function testGetUriForExternalUrl() {
+  public function testGetUriForExternalUrl(): void {
     $url = Url::fromUri('http://example.com/test');
     $this->assertEquals('http://example.com/test', $url->getUri());
   }
@@ -332,7 +313,7 @@ class UrlTest extends UnitTestCase {
    * @covers ::getUri
    * @covers ::isExternal
    */
-  public function testGetUriForProtocolRelativeUrl() {
+  public function testGetUriForProtocolRelativeUrl(): void {
     $url = Url::fromUri('//example.com/test');
     $this->assertEquals('//example.com/test', $url->getUri());
     $this->assertTrue($url->isExternal());
@@ -348,7 +329,7 @@ class UrlTest extends UnitTestCase {
    *
    * @depends testUrlFromRequest
    */
-  public function testGetInternalPath($urls) {
+  public function testGetInternalPath($urls): void {
     $map = [];
     $map[] = ['view.frontpage.page_1', [], '/node'];
     $map[] = ['node_view', ['node' => '1'], '/node/1'];
@@ -379,7 +360,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::toString
    */
-  public function testToString($urls) {
+  public function testToString($urls): void {
     foreach ($urls as $index => $url) {
       $path = array_pop($this->map[$index]);
       $this->assertSame($path, $url->toString());
@@ -399,7 +380,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::getRouteName
    */
-  public function testGetRouteName($urls) {
+  public function testGetRouteName($urls): void {
     foreach ($urls as $index => $url) {
       $this->assertSame($this->map[$index][0], $url->getRouteName());
     }
@@ -410,7 +391,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::getRouteName
    */
-  public function testGetRouteNameWithExternalUrl() {
+  public function testGetRouteNameWithExternalUrl(): void {
     $url = Url::fromUri('http://example.com');
     $this->expectException(\UnexpectedValueException::class);
     $url->getRouteName();
@@ -426,7 +407,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::getRouteParameters
    */
-  public function testGetRouteParameters($urls) {
+  public function testGetRouteParameters($urls): void {
     foreach ($urls as $index => $url) {
       $this->assertSame($this->map[$index][1], $url->getRouteParameters());
     }
@@ -437,7 +418,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::getRouteParameters
    */
-  public function testGetRouteParametersWithExternalUrl() {
+  public function testGetRouteParametersWithExternalUrl(): void {
     $url = Url::fromUri('http://example.com');
     $this->expectException(\UnexpectedValueException::class);
     $url->getRouteParameters();
@@ -453,7 +434,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::getOptions
    */
-  public function testGetOptions($urls) {
+  public function testGetOptions($urls): void {
     foreach ($urls as $index => $url) {
       $this->assertSame($this->map[$index][2], $url->getOptions());
     }
@@ -464,7 +445,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::setOptions
    */
-  public function testSetOptions() {
+  public function testSetOptions(): void {
     $url = Url::fromRoute('test_route', []);
     $this->assertEquals([], $url->getOptions());
     $url->setOptions(['foo' => 'bar']);
@@ -478,7 +459,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::mergeOptions
    */
-  public function testMergeOptions() {
+  public function testMergeOptions(): void {
     $url = Url::fromRoute('test_route', [], ['foo' => 'bar', 'bar' => ['key' => 'value']]);
     $url->mergeOptions(['bar' => ['key' => 'value1', 'key2' => 'value2']]);
     $this->assertEquals(['foo' => 'bar', 'bar' => ['key' => 'value1', 'key2' => 'value2']], $url->getOptions());
@@ -494,7 +475,7 @@ class UrlTest extends UnitTestCase {
    * @covers ::accessManager
    * @dataProvider accessProvider
    */
-  public function testAccessRouted($access) {
+  public function testAccessRouted($access): void {
     $account = $this->createMock('Drupal\Core\Session\AccountInterface');
     $url = new TestUrl('entity.node.canonical', ['node' => 3]);
     $url->setAccessManager($this->getMockAccessManager($access, $account));
@@ -506,7 +487,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::access
    */
-  public function testAccessUnrouted() {
+  public function testAccessUnrouted(): void {
     $account = $this->createMock('Drupal\Core\Session\AccountInterface');
     $url = TestUrl::fromUri('base:kittens');
     $access_manager = $this->createMock('Drupal\Core\Access\AccessManagerInterface');
@@ -516,42 +497,10 @@ class UrlTest extends UnitTestCase {
     $this->assertTrue($url->access($account));
   }
 
-  /**
-   * Tests the renderAccess() method.
-   *
-   * @param bool $access
-   *   The access value.
-   *
-   * @covers ::renderAccess
-   * @dataProvider accessProvider
-   * @group legacy
-   */
-  public function testRenderAccess($access) {
-    $element = [
-      '#url' => Url::fromRoute('entity.node.canonical', ['node' => 3]),
-    ];
-    $this->container->set('current_user', $this->createMock('Drupal\Core\Session\AccountInterface'));
-    $this->container->set('access_manager', $this->getMockAccessManager($access));
-    $this->expectDeprecation('Drupal\Core\Url::renderAccess() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3342977');
-    $this->assertEquals($access, TestUrl::renderAccess($element));
-  }
-
-  /**
-   * Tests deprecation of toRenderArray() method.
-   *
-   * @covers ::toRenderArray
-   * @group legacy
-   */
-  public function testToRenderArray() {
-    $this->expectDeprecation('Drupal\Core\Url::toRenderArray() is deprecated in drupal:10.1.0 and is removed from drupal:11.0.0. There is no replacement. See https://www.drupal.org/node/3342977');
-    $url = Url::fromRoute('entity.node.canonical', ['node' => 3]);
-    $this->assertIsArray($url->toRenderArray());
-  }
-
   /**
    * Tests the fromRouteMatch() method.
    */
-  public function testFromRouteMatch() {
+  public function testFromRouteMatch(): void {
     $route = new Route('/test-route/{foo}');
     $route_match = new RouteMatch('test_route', $route, ['foo' => (object) [1]], ['foo' => 1]);
     $url = Url::fromRouteMatch($route_match);
@@ -562,7 +511,7 @@ class UrlTest extends UnitTestCase {
   /**
    * Data provider for testing entity URIs.
    */
-  public function providerTestEntityUris() {
+  public static function providerTestEntityUris() {
     return [
       [
         'entity:test_entity/1',
@@ -625,7 +574,7 @@ class UrlTest extends UnitTestCase {
    *
    * @dataProvider providerTestEntityUris
    */
-  public function testEntityUris($uri, $options, $route_name, $route_parameters, $query, $fragment) {
+  public function testEntityUris($uri, $options, $route_name, $route_parameters, $query, $fragment): void {
     $url = Url::fromUri($uri, $options);
     $this->assertSame($route_name, $url->getRouteName());
     $this->assertEquals($route_parameters, $url->getRouteParameters());
@@ -638,7 +587,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::fromUri
    */
-  public function testInvalidEntityUriParameter() {
+  public function testInvalidEntityUriParameter(): void {
     // Make the mocked URL generator behave like the actual one.
     $this->urlGenerator->expects($this->once())
       ->method('generateFromRoute')
@@ -656,7 +605,7 @@ class UrlTest extends UnitTestCase {
    *
    * @dataProvider providerTestToUriStringForEntity
    */
-  public function testToUriStringForEntity($uri, $options, $uri_string) {
+  public function testToUriStringForEntity($uri, $options, $uri_string): void {
     $url = Url::fromUri($uri, $options);
     $this->assertSame($url->toUriString(), $uri_string);
   }
@@ -664,7 +613,7 @@ class UrlTest extends UnitTestCase {
   /**
    * Data provider for testing string entity URIs.
    */
-  public function providerTestToUriStringForEntity() {
+  public static function providerTestToUriStringForEntity() {
     return [
       ['entity:test_entity/1', [], 'route:entity.test_entity.canonical;test_entity=1'],
       ['entity:test_entity/1', ['fragment' => 'top', 'query' => ['page' => '2']], 'route:entity.test_entity.canonical;test_entity=1?page=2#top'],
@@ -679,7 +628,7 @@ class UrlTest extends UnitTestCase {
    *
    * @dataProvider providerTestToUriStringForInternal
    */
-  public function testToUriStringForInternal($uri, $options, $uri_string) {
+  public function testToUriStringForInternal($uri, $options, $uri_string): void {
     $url = Url::fromRoute('entity.test_entity.canonical', ['test_entity' => '1']);
     $this->pathValidator->expects($this->any())
       ->method('getUrlIfValidWithoutAccessCheck')
@@ -695,7 +644,7 @@ class UrlTest extends UnitTestCase {
   /**
    * Data provider for testing internal URIs.
    */
-  public function providerTestToUriStringForInternal() {
+  public static function providerTestToUriStringForInternal() {
     return [
       // The four permutations of a regular path.
       ['internal:/test-entity/1', [], 'route:entity.test_entity.canonical;test_entity=1'],
@@ -723,7 +672,7 @@ class UrlTest extends UnitTestCase {
    * @covers ::fromUri
    * @dataProvider providerFromValidInternalUri
    */
-  public function testFromValidInternalUri($path) {
+  public function testFromValidInternalUri($path): void {
     $url = Url::fromUri('internal:' . $path);
     $this->assertInstanceOf('Drupal\Core\Url', $url);
   }
@@ -731,7 +680,7 @@ class UrlTest extends UnitTestCase {
   /**
    * Data provider for testFromValidInternalUri().
    */
-  public function providerFromValidInternalUri() {
+  public static function providerFromValidInternalUri() {
     return [
       // Normal paths with a leading slash.
       ['/kittens'],
@@ -763,7 +712,7 @@ class UrlTest extends UnitTestCase {
    * @covers ::fromUri
    * @dataProvider providerFromInvalidInternalUri
    */
-  public function testFromInvalidInternalUri($path) {
+  public function testFromInvalidInternalUri($path): void {
     $this->expectException(\InvalidArgumentException::class);
     Url::fromUri('internal:' . $path);
   }
@@ -771,7 +720,7 @@ class UrlTest extends UnitTestCase {
   /**
    * Data provider for testFromInvalidInternalUri().
    */
-  public function providerFromInvalidInternalUri() {
+  public static function providerFromInvalidInternalUri() {
     return [
       // Normal paths without a leading slash.
       'normal_path0' => ['kittens'],
@@ -798,7 +747,7 @@ class UrlTest extends UnitTestCase {
    *
    * @covers ::fromUri
    */
-  public function testFromUriNumber() {
+  public function testFromUriNumber(): void {
     $url = Url::fromUri('base:2015/10/06');
     $this->assertSame($url->toUriString(), 'base:/2015/10/06');
   }
@@ -810,7 +759,7 @@ class UrlTest extends UnitTestCase {
    *
    * @dataProvider providerTestToUriStringForRoute
    */
-  public function testToUriStringForRoute($uri, $options, $uri_string) {
+  public function testToUriStringForRoute($uri, $options, $uri_string): void {
     $url = Url::fromUri($uri, $options);
     $this->assertSame($url->toUriString(), $uri_string);
   }
@@ -818,7 +767,7 @@ class UrlTest extends UnitTestCase {
   /**
    * Data provider for testing route: URIs.
    */
-  public function providerTestToUriStringForRoute() {
+  public static function providerTestToUriStringForRoute() {
     return [
       ['route:entity.test_entity.canonical;test_entity=1', [], 'route:entity.test_entity.canonical;test_entity=1'],
       ['route:entity.test_entity.canonical;test_entity=1', ['fragment' => 'top', 'query' => ['page' => '2']], 'route:entity.test_entity.canonical;test_entity=1?page=2#top'],
@@ -835,7 +784,7 @@ class UrlTest extends UnitTestCase {
   /**
    * @covers ::fromUri
    */
-  public function testFromRouteUriWithMissingRouteName() {
+  public function testFromRouteUriWithMissingRouteName(): void {
     $this->expectException(\InvalidArgumentException::class);
     $this->expectExceptionMessage("The route URI 'route:' is invalid.");
     Url::fromUri('route:');
@@ -850,6 +799,7 @@ class UrlTest extends UnitTestCase {
    *   The account to test.
    *
    * @return \Drupal\Core\Access\AccessManagerInterface|\PHPUnit\Framework\MockObject\MockObject
+   *   The mocked access manager.
    */
   protected function getMockAccessManager($access, $account = NULL) {
     $access_manager = $this->createMock('Drupal\Core\Access\AccessManagerInterface');
@@ -863,7 +813,7 @@ class UrlTest extends UnitTestCase {
   /**
    * Data provider for the access test methods.
    */
-  public function accessProvider() {
+  public static function accessProvider() {
     return [
       [TRUE],
       [FALSE],
@@ -872,6 +822,9 @@ class UrlTest extends UnitTestCase {
 
 }
 
+/**
+ * URL information holder with overridden access manager for testing.
+ */
 class TestUrl extends Url {
 
   /**
@@ -880,7 +833,7 @@ class TestUrl extends Url {
    * @param \Drupal\Core\Access\AccessManagerInterface $access_manager
    *   The access manager.
    */
-  public function setAccessManager(AccessManagerInterface $access_manager) {
+  public function setAccessManager(AccessManagerInterface $access_manager): void {
     $this->accessManager = $access_manager;
   }
 
