@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests;
 
 use Drupal\TestTools\PhpUnitCompatibility\RunnerVersion;
@@ -13,9 +15,15 @@ class_alias("Drupal\TestTools\PhpUnitCompatibility\PhpUnit" . RunnerVersion::get
 if (FALSE) {
 
   /**
-   * Makes Drupal's test API forward compatible with multiple versions of PHPUnit.
+   * Makes Drupal's test API forward compatible with future PHPUnit releases.
+   *
+   * This stub is present here to allow PHPStan identify the methods present
+   * in the version-bound trait.
    */
   trait PhpUnitCompatibilityTrait {
+
+    use \Drupal\TestTools\PhpUnitCompatibility\PhpUnit10\TestCompatibilityTrait;
+
   }
 
 }
